package actions;

import gui.CpfViewer;
import gui.CpfConfig;
import gui.ParameterTablePanel;
import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.ImageIcon;
import java.awt.event.ActionEvent;
import org.apache.log4j.Logger;

/**
 * Action to close a single file.  If there are unsaved edits, the user is
 * prompted if they really want to close it.
 */
public class CloseAction extends AbstractAction {

    private CpfViewer application;
    private ParameterTablePanel parameterTablePanel = null;
    private static final Logger logger = Logger.getLogger(CloseAction.class);

    /**
     * Defines an action to close the file displayed in the given 
     * ParameterTablePanel.
     * @param v     the CPF Viewer application
     * @param p     the ParameterTablePanel whose file is to be closed
     */
    public CloseAction(CpfViewer v, ParameterTablePanel p) {
        super();
        putValue(NAME, null);
        putValue(SHORT_DESCRIPTION, "Close this file");
        putValue(SMALL_ICON, new ImageIcon(getClass().getResource(
            CpfConfig.CLOSE_ICON)));
        parameterTablePanel = p;
        application = v;
    }

    /**
     * Perform the Close action when the action is invoked.
     * @param e  the invoking event
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        closeFile();
    }

    /**
     * The functionality to close a file and remove its panel from the GUI.
     * Checks if there are unsaved edits before closing.
     */
    public void closeFile() {
        int reallyClose = JOptionPane.YES_OPTION;
        if (parameterTablePanel.parameterToolBar.isModified()) {
            reallyClose = JOptionPane.showConfirmDialog(application,
                application.loadedFileList.getFile(
                    parameterTablePanel.getLoadedFileIndex()).getFileName()
                + " has unsaved modifications.  "
                + "Do you want to close anyway?",
                "Unsaved Modifications",
                JOptionPane.YES_NO_OPTION, JOptionPane.WARNING_MESSAGE);
        }
        if (reallyClose == JOptionPane.NO_OPTION) {
            return;
        }
        logger.debug("Closing " + application.loadedFileList.getFile(
            parameterTablePanel.getLoadedFileIndex()).getFileName());

        application.parameterViewerPanel.removePanel(parameterTablePanel);
        application.loadedFileList.removeFile(parameterTablePanel.
            getLoadedFileIndex());
    }
}
