package actions;

import gui.CpfViewer;
import gui.FileNameDialog;
import library.LoadedFileType;
import library.LoadedFileSchema;
import javax.swing.AbstractAction;
import javax.swing.ImageIcon;
import java.awt.event.ActionEvent;
import java.awt.Point;
import library.CpfStatus;

/**
 * Action to open a file name dialog for various scenarios - EVAL or PROD, CPF
 * or BPF, Import or Baseline.
 */
public class FileNameDialogAction extends AbstractAction {

    private CpfViewer application;
    private String title;
    private String action;
    private LoadedFileType type;
    private LoadedFileSchema schema;
    private CpfStatus status = null;

    /**
     * Constructor specifying the type of files to show in the dialog.
     * @param app       CPF Viewer application
     * @param title     dialog title
     * @param action    action to perform for selected files
     * @param fileType  file type
     * @param fileSchema file schema
     * @param iconName  icon associated with this action
     */
    public FileNameDialogAction(CpfViewer app, String title, String action,
            LoadedFileType fileType, LoadedFileSchema fileSchema,
            String iconName) {
        super();
        // If an icon is specified, use that (assuming the action is attached
        // to a button) otherwise set the name (assuming the action is attached
        // to a menu item).
        if (iconName == null) {
            putValue(NAME, fileType.toString());
        } else {
            putValue(SMALL_ICON,
                new ImageIcon(getClass().getResource(iconName)));
        }
        this.application = app;
        this.title = title;
        this.action = action;
        this.type = fileType;
        this.schema = fileSchema;
    }

    /**
     * Constructor specifying the type of files to show in the dialog.
     * @param app       CPF Viewer application
     * @param title     dialog title
     * @param action    action to perform for selected files
     * @param fileType  file type
     * @param fileSchema file schema
     * @param iconName  icon associated with this action
     * @param status    active/inactive status
     */
    public FileNameDialogAction(CpfViewer app, String title, String action,
            LoadedFileType fileType, LoadedFileSchema fileSchema,
            String iconName, CpfStatus status) {
        this(app, title, action, fileType, fileSchema, iconName);
        this.status = status;

        //Pluralize the schema name title as used for terminate/activate
        if (iconName == null) {
            putValue(NAME, fileType.toString()+"s");
        }
    }
    
    /**
     * Open a new FileNameDialog when the action is invoked.
     * @param e  the invoking event
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        Point loc = application.getLocationOnScreen();
        loc.translate(50, 50);
        FileNameDialog fileNameDialog;

        if (status == null) {
            fileNameDialog = new FileNameDialog(application, title, action,
                    type, schema);
        } else {
            fileNameDialog = new FileNameDialog(application, title, action,
                    type, schema, status, false);
        }
        fileNameDialog.setLocation(loc);
        fileNameDialog.setVisible(true);
    }
}
