package actions;

import gui.CpfViewer;
import gui.CpfConfig;
import gui.ParameterTablePanel;
import javax.swing.AbstractAction;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.ImageIcon;
import java.awt.event.ActionEvent;
import java.awt.Dimension;
import java.io.File;
import org.apache.log4j.Logger;

/**
 * Action to prompt the user for a new name for the given file, and rename it
 */
public class RenameAction extends AbstractAction {

    private CpfViewer application;
    private ParameterTablePanel parameterTablePanel = null;
    private static final Logger logger = Logger.getLogger(RenameAction.class);

    public RenameAction(CpfViewer v, ParameterTablePanel p) {
        super();
        putValue(NAME, null);
        putValue(SHORT_DESCRIPTION, "Rename file without saving");
        putValue(SMALL_ICON, new ImageIcon(getClass().getResource(
            CpfConfig.RENAME_ICON)));
        parameterTablePanel = p;
        application = v;
    }

    /**
     * Perform the Rename action when the action is invoked.  A new file
     * name is prompted for, then the file is renamed.
     * @param e  the invoking event
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        // Get the current file name, separate into path & name parts
        int currentFile = parameterTablePanel.getLoadedFileIndex();

        File file = new File(application.loadedFileList.getFile(currentFile).
            getFileName());
        String currentPath = file.getParent();
        logger.debug("Original path was " + currentPath);
        String baseName = file.getName();

        /* Create an option pane to get the user input */
        JOptionPane pane = new JOptionPane("Please enter new file name",
            JOptionPane.QUESTION_MESSAGE, JOptionPane.OK_CANCEL_OPTION,
            null, null, baseName);
        pane.setWantsInput(true);
        pane.setInitialSelectionValue(baseName);

        /* Create a dialog to hold the pane */
        JDialog dialog = pane.createDialog(application, "Input New Filename");
        Dimension dimension = dialog.getSize();
        dimension.width = 425; // resize it to fit eval BPF filenames
        dialog.setMinimumSize(dimension);
        dialog.show();

        String newBaseName = pane.getInputValue().toString();
        if (JOptionPane.UNINITIALIZED_VALUE.equals(newBaseName)
            || newBaseName.length() == 0) {
            // user must have cancelled
            return;
        }

        // Update the file name portion, keeping original path
        String newFileName = currentPath == null ? newBaseName
            : currentPath + File.separator + newBaseName;

        // Can't rename the file to one already loaded in the GUI
        if (application.loadedFileList.getFile(newFileName) != null) {
            JOptionPane.showMessageDialog(application,
                "Cannot rename file to " + newFileName
                    + ": already open in GUI",
                "Error", JOptionPane.ERROR_MESSAGE);
            return;
        }

        application.loadedFileList.getFile(currentFile).
            updateFileName(newFileName);
        application.parameterViewerPanel.parameterTreePanel.refreshSelected();
        parameterTablePanel.parameterToolBar.setFileNameLabel(newFileName);
    }
}
