package actions;

import gui.CpfViewer;
import gui.CpfConfig;
import gui.ParameterTablePanel;
import gui.ValidateEffectiveDateRange;
import javax.swing.JOptionPane;
import javax.swing.ImageIcon;
import java.awt.event.ActionEvent;
import java.io.File;
import library.LoadedFile;
import org.apache.log4j.Logger;

/**
 * Action allowing save to file system.  If the file didn't previously have
 * a path, the Save As functionality is used to get the location for the file
 * to be written.
 */
public class SaveAction extends SaveAsAction {

    private static final Logger logger = Logger.getLogger(SaveAction.class);

    /**
     * Create action to save a file
     * @param v   the CPF Viewer application
     * @param p   the panel of the file to be saved
     */
    public SaveAction(CpfViewer v, ParameterTablePanel p) {
        super(v, p);
        putValue(SHORT_DESCRIPTION, "Save to file system");
        putValue(SMALL_ICON, new ImageIcon(getClass().getResource(
            CpfConfig.SAVE_ICON)));
    }

    /**
     * Perform the Save action when the action is invoked.
     * @param e  the invoking event
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        saveFile();
    }

    /**
     * The functionality to save a file.  If no path can be determined,
     * the Save As functionality is used so the user can specify a location.
     */
    public void saveFile() {
        int currentFile = parameterTablePanel.getLoadedFileIndex();
        LoadedFile selectedFile 
                = application.loadedFileList.getFile(currentFile);
        
        String fileAndPath = selectedFile.getFileName();
        logger.trace("Saving file " + fileAndPath + " in panel "
            + currentFile);
        File file = new File(fileAndPath);
        // A file name with no path means it was imported, so we need to
        // do a "Save As" to find out  where to put the file
        if (file.getPath().equals(file.getName())) {
            saveFileAs();
        } else {
            if (!ValidateEffectiveDateRange.validate(this.application, 
                    selectedFile)) {
                return;
            }
            if (selectedFile.saveFile()) {
                parameterTablePanel.getUndoableModel().resetModified();
            } else {
                JOptionPane.showMessageDialog(application, "Error saving "
                    + fileAndPath, "Error",
                    JOptionPane.ERROR_MESSAGE);
            }
        }
    }
}
