package actions;

import gov.usgs.ias.gui.common_library.SaveDialog;
import gui.CpfViewer;
import gui.CpfConfig;
import gui.ParameterTablePanel;
import gui.ValidateEffectiveDateRange;
import library.LoadedFile;
import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.ImageIcon;
import java.awt.event.ActionEvent;
import java.io.File;
import java.util.List;
import library.LoadedFileType;
import org.apache.log4j.Logger;

/**
 * Action providing "Save As" functionality - opens a dialog requestiong the
 * new file name
 */
public class SaveAsAction extends AbstractAction {

    protected CpfViewer application;
    protected ParameterTablePanel parameterTablePanel = null;
    private static final Logger logger = Logger.getLogger(SaveAsAction.class);

    /**
     * Create action to save a file with a new name
     * @param v   the CPF Viewer application
     * @param p   the panel of the file to be saved
     */
    public SaveAsAction(CpfViewer v, ParameterTablePanel p) {
        super();
        putValue(NAME, null);
        putValue(SHORT_DESCRIPTION, "Save to file system with new name");
        putValue(SMALL_ICON, new ImageIcon(getClass().getResource(
            CpfConfig.SAVE_AS_ICON)));
        parameterTablePanel = p;
        application = v;
    }

    /**
     * Perform the Save As action when the action is invoked.
     * @param e  the invoking event
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        saveFileAs();
    }

    /**
     * The functionality to save a file with a new file name. Uses a SaveDialog
     * to request a new location/file name.
     */
    public void saveFileAs() {
       // Get the current file name, that is the initial value for the new
       // file name
       int currentFile = parameterTablePanel.getLoadedFileIndex();
       LoadedFile file = application.loadedFileList.getFile(currentFile);
       
       if (!ValidateEffectiveDateRange.validate(this.application, file)) {
           return;
       }

       String fileAndPath = file.getFileName();
       String newFileName = SaveDialog.SaveAs(application, fileAndPath);
        if (newFileName == null) {
            return;
        }
        File newFile = new File(newFileName);
        if (application.loadedFileList.fileIsPresent(newFileName)) {
            JOptionPane.showMessageDialog(application,
                "Cannot save file as " + newFileName
                + " : it is already loaded in the GUI",
                "Error", JOptionPane.ERROR_MESSAGE);
            return;
        }
        int goAhead = JOptionPane.YES_OPTION;
        if (newFile.exists()) {
            goAhead = JOptionPane.showConfirmDialog(application,
                newFile + " already exists - overwrite?",
                "Overwrite File", JOptionPane.YES_NO_OPTION);
        }
        if (goAhead == JOptionPane.YES_OPTION) {
            logger.debug("Saving file " + fileAndPath + "as "
                + newFileName + " in panel " + currentFile);
            file.updateFileName(newFileName);
            if (file.saveFile()) {
                // After saving, reset the filename displayed on the GUI
                parameterTablePanel.parameterToolBar.setFileNameLabel(
                    newFileName);
                parameterTablePanel.getUndoableModel().resetModified();
            } else {
                JOptionPane.showMessageDialog(application, "Error saving "
                    + newFileName, "Error", JOptionPane.ERROR_MESSAGE);
            }
        }
    }
}
