package gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import java.util.Collections;
import java.util.List;

/**
 * Dialog to add or remove a group to the ODL file.
 */
public class AddRemoveGroupDialog extends JDialog implements ActionListener {

    private CpfViewer application;
    private JComboBox<String> groupNameComboBox = null;
    private JTextField groupNameTextField = null;

    /**
     * Constructor to create the dialog.  Add has a text box to enter the
     * new group name; Remove has a dropdown box of existing groups.
     * @param application the overall gui application
     * @param title title for the dialog screen
     */
    public AddRemoveGroupDialog(CpfViewer application, String title) {
        super(application, title + " Group", true);
        setLayout(new BorderLayout());
        setSize(290, 130);
        this.application = application;

        JPanel mainPanel = new JPanel();
        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1;
        gbc.weighty = 1;
        mainPanel.setLayout(gridbag);

        JLabel groupNameLabel = new JLabel("Group Name");
        mainPanel.add(groupNameLabel, gbc);

        if (title.equals("Remove")) {
            List<String> groupNames = application.parameterViewerPanel.
                parameterTreePanel.getGroupNames();
            Collections.sort(groupNames);
            groupNameComboBox = new JComboBox<String>(groupNames.toArray(
                new String[0]));
            mainPanel.add(groupNameComboBox, gbc);
        } else {
            groupNameTextField = new JTextField("", 20);
            Dimension size = groupNameTextField.getPreferredSize();
            groupNameTextField.setMinimumSize(size);
            size.width *= 3;
            groupNameTextField.setMaximumSize(size);
            mainPanel.add(groupNameTextField, gbc);
        }

        JPanel buttonPanel = new JPanel();

        JButton okButton = new JButton("Ok");
        okButton.setMnemonic(KeyEvent.VK_O);
        okButton.setToolTipText(title);
        buttonPanel.add(okButton);
        this.getRootPane().setDefaultButton(okButton);

        JButton closeButton = new JButton("Cancel");
        closeButton.setMnemonic(KeyEvent.VK_C);
        buttonPanel.add(closeButton);

        add(mainPanel, BorderLayout.NORTH);
        add(buttonPanel, BorderLayout.SOUTH);
        
        // add listeners
        okButton.addActionListener(this);
        closeButton.addActionListener(this);

        // Initialize to the 1st group in the box, and select the group
        // highlighted in the tree if possible
        if (groupNameComboBox != null) {
            groupNameComboBox.setSelectedIndex(0);
            String selectedTreeGroup = application.parameterViewerPanel.
                parameterTreePanel.getSelectedGroup();
            if (selectedTreeGroup != null) {
                groupNameComboBox.setSelectedItem(selectedTreeGroup);
            }
        }
    }

    /**
     * Event handler for user action -- OK or Cancel button press
     * @param e event generated by the user
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        if (command.equals("Ok")) {
            if (groupNameTextField != null) { // Add
                String groupName = groupNameTextField.getText().
                    toUpperCase().trim();
                application.parameterViewerPanel.parameterTreePanel.
                    addGroupToFiles(groupName);
            } else { // Remove
                String groupName =
                    (String) groupNameComboBox.getSelectedItem();
                application.parameterViewerPanel.parameterTreePanel.
                    removeGroupFromFiles(groupName);
            }
            setVisible(false);
        } else if (command.equals("Cancel")) {
            setVisible(false);
        }
    }
}
