package gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import java.util.Collections;
import java.util.List;

/**
 * Dialog to add or remove a parameter to an ODL file.
 */
public class AddRemoveParameterDialog
    extends JDialog implements ActionListener {

    private CpfViewer application;
    private JComboBox<String> groupNameComboBox;
    private JComboBox<String> parameterNameComboBox = null;
    private JTextField parameterNameTextField = null;
    private JTextField parameterValueTextField = null;

    /**
     * Constructor to create the dialog.  Add has a dropdown of group names to
     * add the parameter to, and text box to enter the
     * new parameter name; Remove has dropdown boxes of existing groups &
     * parameters.
     * @param application the overall gui application
     * @param title title for the dialog screen
     */
    public AddRemoveParameterDialog(CpfViewer application, String title) {
        super(application, title + " Parameter", true);
        setLayout(new BorderLayout());
        setSize(290, 200);
        this.application = application;

        JPanel mainPanel = new JPanel();
        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1;
        gbc.weighty = 1;
        mainPanel.setLayout(gridbag);

        JLabel groupNameLabel = new JLabel("Group Name");
        mainPanel.add(groupNameLabel, gbc);

        List<String> groupNames = application.parameterViewerPanel.
            parameterTreePanel.getGroupNames();
        Collections.sort(groupNames);
        groupNameComboBox = new JComboBox<String>(groupNames.toArray(
            new String[0]));
        mainPanel.add(groupNameComboBox, gbc);

        if (title.equals("Remove")) {
            JLabel parameterNameLabel = new JLabel("Parameter Name");
            mainPanel.add(parameterNameLabel, gbc);
            parameterNameComboBox = new JComboBox<String>();
            mainPanel.add(parameterNameComboBox, gbc);
        } else {
            JLabel parameterNameLabel = new JLabel("Parameter Name");
            mainPanel.add(parameterNameLabel, gbc);

            parameterNameTextField = new JTextField("", 20);
            Dimension size = parameterNameTextField.getPreferredSize();
            parameterNameTextField.setMinimumSize(size);
            size.width *= 3;
            parameterNameTextField.setMaximumSize(size);
            mainPanel.add(parameterNameTextField, gbc);

            JLabel parameterValueLabel = new JLabel("Parameter Value");
            mainPanel.add(parameterValueLabel, gbc);

            parameterValueTextField = new JTextField("", 20);
            size = parameterValueTextField.getPreferredSize();
            parameterValueTextField.setMinimumSize(size);
            size.width *= 3;
            parameterValueTextField.setMaximumSize(size);
            mainPanel.add(parameterValueTextField, gbc);
        }
        JPanel buttonPanel = new JPanel();

        JButton okButton = new JButton("Ok");
        okButton.setMnemonic(KeyEvent.VK_O);
        okButton.setToolTipText(title);
        buttonPanel.add(okButton);
        getRootPane().setDefaultButton(okButton);

        JButton closeButton = new JButton("Cancel");
        closeButton.setMnemonic(KeyEvent.VK_C);
        buttonPanel.add(closeButton);

        add(mainPanel, BorderLayout.NORTH);
        add(buttonPanel, BorderLayout.SOUTH);
        
        // add listeners
        okButton.addActionListener(this);
        closeButton.addActionListener(this);
        if (title.equals("Remove")) {
            // Reset the parameter name dropdown when a group is selected
            groupNameComboBox.addActionListener(this);        
        }
        // Initialize to the 1st group in the box, then select the group &
        // parameter highlighted in the tree if possible
        if (groupNameComboBox.getItemCount() > 0) {
            groupNameComboBox.setSelectedIndex(0);
            String selectedTreeGroup = application.parameterViewerPanel.
                parameterTreePanel.getSelectedGroup();
            if (selectedTreeGroup != null) {
                groupNameComboBox.setSelectedItem(selectedTreeGroup);
            }
        }
        if (parameterNameComboBox != null) {
            String selectedTreeParameter = application.parameterViewerPanel.
                parameterTreePanel.getSelectedParameter();
            if (selectedTreeParameter != null) {
                parameterNameComboBox.setSelectedItem(selectedTreeParameter);
            }
        }
    }

    /**
     * Event handler for user action -- OK or Cancel button press
     * @param e event generated by the user
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        if (command.equals("Ok")) {
            String groupName = (String) groupNameComboBox.getSelectedItem();
            if (parameterNameTextField != null) { // Add
                String parameterName 
                    = parameterNameTextField.getText().trim();
                String parameterValue 
                    = parameterValueTextField.getText().trim();
                String[] parameterValues = parameterValue.split("\\s*,\\s*");
                application.parameterViewerPanel.parameterTreePanel.
                    addParameterToFiles(groupName, parameterName, 
                    parameterValues);
            } else { // Remove
                String parameterName = (String) parameterNameComboBox.
                    getSelectedItem();
                application.parameterViewerPanel.parameterTreePanel.
                    removeParameterFromFiles(groupName, parameterName);
            }
            setVisible(false);
        } else if (command.equals("Cancel")) {
            setVisible(false);
        } else if (command.equals("comboBoxChanged")) { // New group selected
            // Update the corresponding Parameter combo box with
            // parameters in this group
            String groupName = (String) groupNameComboBox.getSelectedItem();
            parameterNameComboBox.removeAllItems();
            List<String> parameterNames = application.parameterViewerPanel.
                parameterTreePanel.getParameterNames(groupName);
            Collections.sort(parameterNames);
            for (String s : parameterNames) {
                parameterNameComboBox.addItem(s);
            }
        }
    }
}
