package gui;

import java.awt.Dimension;
import javax.swing.BoxLayout;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import java.awt.Color;

/**
 * Implements GUI component to display progress while an
 * operation is proceeding in a background thread.  More than one thread may be
 * running at a time, so the number of busy threads is also tracked.  Use of
 * and updates to the BusyIndicator should only be done on the
 * Event Dispatch Thread.
 */
public class BusyIndicator extends JPanel {

    private JProgressBar progressBar;      // progress bar component
    private static int numThreads = 0;     // keep track of how many threads
                                           // have told me they're busy

    // Constructor for the ProgressIndicator
    //--------------------------------------
    BusyIndicator() {
        setLayout(new BoxLayout(this, BoxLayout.X_AXIS));

        // create the progress bar
        progressBar = new JProgressBar();
        Dimension size = new Dimension(80, 18);
        progressBar.setIndeterminate(true);
        progressBar.setPreferredSize(size);
        progressBar.setMinimumSize(size);
        progressBar.setMaximumSize(size);

        progressBar.setForeground(Color.BLUE);
        progressBar.setVisible(false);
        add(progressBar);

        setPreferredSize(size);
        setMaximumSize(size);
    }

    /**
     * Set the indicator to the busy state
     */
    public void setBusy() {
        numThreads++;
        progressBar.setString("Working");
        progressBar.setStringPainted(true);
        progressBar.setVisible(true);
    }

    /**
     * Set the indicator to the not busy state
     */
    public void clearBusy() {
        // One fewer thread is now busy.  Turn off the progress bar display
        //  when there are no more threads running.
        numThreads--;
        if (numThreads <= 0) {
            progressBar.setVisible(false);
        }
    }

    /**
     * Indicates if the progress indicator is busy (there is at least one thread
     * active)
     * @return boolean indicator if anything is busy
     */
    public boolean isBusy() {
        return (numThreads > 0);
    }
}

