package gui;

/**
 * Stores configuration values for the application and dialog windows.
 * Icon images come from the Java Look & Feel Graphics Repository.
 */
public class CpfConfig {

    /**
     * The default root URL for service resources.  These can be overridden by 
     * properties.
     */
    public final static String IAS_SERVICES_DEFAULT = "http://localhost:8080";
    /**
     * The portion to append to the service URL root for the CPF service's WSDL
     */
    public final static String CPF_SERVICE_WSDL
        = "/dataservices/CpfService?wsdl";
    /**
     * The CPF service's XML namespace
     */
    public final static String CPF_SERVICE_NAMESPACE
        = "uri:CpfQueryService";
    /**
     * The portion to append to the service URL root for the BPF service's WSDL
     */
    public final static String BPF_SERVICE_WSDL
        = "/dataservices/BpfService?wsdl";
    /**
     * The BPF service's XML namespace
     */
    public final static String BPF_SERVICE_NAMESPACE
        = "uri:BpfQueryService";
    /**
     * The portion to append to the service URL root for the CPF REST retrieval
     * service
     */
    public final static String CPF_REST_URL
        = "/dataservices/rest/cpf?operation=getCalParmFile&filename=";
    /**
     * The portion to append to the service URL root for the BPF REST retrieval
     * service
     */
    public final static String BPF_REST_URL 
        = "/dataservices/rest/bpf?operation=getBiasParmFile&filename=";

    /**
     * Image directory path
     */
    public final static String IMAGE_DIR = "/images/";

    /**
     * CPF window Icon
     */
    public final static String CPF_ICON = IMAGE_DIR + "WebComponent16.gif";

    /**
     * Toolbar Open CPF Icon
     */
    public final static String OPEN_ICON = IMAGE_DIR + "Open16.gif";

    /**
     * Toolbar Import from PROD (Baseline) Database Icon
     */
    public final static String IMPORT_BASELINE_DB_ICON = IMAGE_DIR
        + "Import16Dark.gif";
    /**
     * Toolbar Import from EVAL (Test) Database Icon
     */
    public final static String IMPORT_EVAL_DB_ICON = IMAGE_DIR
        + "Import16.gif";

    /**
     * Toolbar Export to PROD (Baseline) Database Icon
     */
    public final static String BASELINE_DB_ICON = IMAGE_DIR
        + "Export16Dark.gif";
    /**
     * Toolbar Export to EVAL (Test) Database Icon
     */
    public final static String EXPORT_TEST_DB_ICON = IMAGE_DIR
        + "Export16.gif";

    /**
     * Toolbar Merge Icon
     */
    public final static String MERGE_ICON = IMAGE_DIR + "Copy16.gif";

    /**
     * Expanded Tree Icon
     */
    public final static String TREE_EXPANDED_ICON = IMAGE_DIR + "treeMinus.gif";
    /**
     * Collapsed Tree Icon
     */
    public final static String TREE_COLLAPSED_ICON = IMAGE_DIR + "treePlus.gif";

    /**
     * Parameter ToolBar Save Icon
     */
    public final static String SAVE_ICON = IMAGE_DIR + "Save16.gif";
    /**
     * Parameter ToolBar Save As Icon
     */
    public final static String SAVE_AS_ICON = IMAGE_DIR + "SaveAs16.gif";
    /**
     * Parameter ToolBar Rename Icon
     */
    public final static String RENAME_ICON = IMAGE_DIR + "New16.gif";

    /**
     * Parameter ToolBar Undo Icon
     */
    public final static String UNDO_ICON = IMAGE_DIR + "Undo16.gif";
    /**
     * Parameter ToolBar Redo Icon
     */
    public final static String REDO_ICON = IMAGE_DIR + "Redo16.gif";
    
    /**
     * Parameter ToolBar Close Icon
     */
    public final static String CLOSE_ICON = IMAGE_DIR + "Close16.gif";
}
