package gui;

import java.awt.event.KeyEvent;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.help.*;
import java.net.URL;
import org.apache.log4j.Logger;

/**
 * Implements the Help Menu Items for the Menu Bar.  Implemented using the
 * JavaHelp (javax.help) package -- see jh.jar.
 */
public class HelpMenu extends JMenu
{
    /**
     * Constructor of the Help Menu
     */
    public HelpMenu()
    {
        // Call the parent constructor, setting the Jmenu Naming and KeyEvent.
        super( "Help" );

        // Find the HelpSet file and create the HelpSet object:
        String guiHelpSetName = "javahelp/CpfGuiHelp.hs";
        ClassLoader loader = HelpMenu.class.getClassLoader();
        HelpSet hs;
        try {
            URL hsURL = HelpSet.findHelpSet(loader, guiHelpSetName);
            hs = new HelpSet(null, hsURL);
        } catch (Exception ee) {
            Logger.getLogger(HelpMenu.class).warn( "HelpSet " + guiHelpSetName +
                    " not found: " + ee.getMessage());
            return;
        }
        // Create a HelpBroker object
        HelpBroker hb = hs.createHelpBroker();

        // Set the menu's keyboard shortcut
        setMnemonic( KeyEvent.VK_H );

        // Create the help menu item
        JMenuItem  helpMenuItem = new JMenuItem("Help Contents", KeyEvent.VK_C);
        // Assign the javax.help Context Sensitive Help action listener to
        // this menu item
        helpMenuItem.addActionListener(new CSH.DisplayHelpFromSource(hb));
        helpMenuItem.setToolTipText("Open on-line help");
        add( helpMenuItem );
    }
}
