package gui;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JPasswordField;

/**
 * A dialog to get database login username and password.  Sets a system
 * property with these values after they are entered by the user.
 */
public class LoginDialog extends JDialog implements ActionListener {

    private String propertyName;   // name of the system property to set
    private JTextField userName;   // user name entered by the user
    private JTextField password;   // password entered by the user
    private boolean cancelled;     // indicates the user cancelled the operation

    /**
     * Constructor for the dialog
     * @param application    application context
     * @param schemaName     name of the schema we're logging in to
     * @param propertyToSet  name of the property to store the username/password
     *                       into
     */
    public LoginDialog(CpfViewer application, String schemaName,
        String propertyToSet) {
        super(application, "Login", true); // this is a modal dialog
        setLayout(new BorderLayout());
        String dialogTitle = "Log Into " + schemaName + " Schema";
        setTitle(dialogTitle);
        propertyName = propertyToSet;
        cancelled = true;

        JPanel mainPanel = new JPanel();
        mainPanel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1;
        gbc.weighty = 1;
        mainPanel.setLayout(gridbag);

        // Set the user and password field labels according to the
        // schema being logged into
        String userLabelString;
        String pwdLabelString;
        if (schemaName.startsWith("PROD"))
        {
            userLabelString = "User Name for IAS_DB_L8_OLITIRS";
            pwdLabelString  = "Password for IAS_DB_L8_OLITIRS";

        }
        else if (schemaName.startsWith("EVAL"))
        {
            userLabelString = "User Name for IAS_DB_L8_OLITIRS_EVAL";
            pwdLabelString  = "Password for IAS_DB_L8_OLITIRS_EVAL";
        }
        else
        {
            userLabelString = "User Name";
            pwdLabelString  = "Password";
        }
        JLabel userNameLabel = new JLabel(userLabelString);
        mainPanel.add(userNameLabel, gbc);
        userName = new JTextField(12);
        mainPanel.add(userName, gbc);

        JLabel passwordLabel = new JLabel(pwdLabelString);
        mainPanel.add(passwordLabel, gbc);
        password = new JPasswordField(12);
        mainPanel.add(password, gbc);

        JPanel buttonPanel = new JPanel();

        JButton okButton = new JButton("Ok");
        okButton.setMnemonic(KeyEvent.VK_O);
        buttonPanel.add(okButton);

        JButton cancelButton = new JButton("Cancel");
        cancelButton.setMnemonic(KeyEvent.VK_C);
        buttonPanel.add(cancelButton);

        add(mainPanel, BorderLayout.NORTH);
        add(buttonPanel, BorderLayout.SOUTH);

        pack();
        setSize(300, 150);
        
        // add listeners
        okButton.addActionListener(this);
        cancelButton.addActionListener(this);
       
    }

    /**
     * Find out if the user cancelled entry of login information
     * @return   true if the user cancelled input; false otherwise
     */
    public boolean isCancelled() {
        return cancelled;
    }

    // ActionListener interface method
    /**
     * Event handler for button clicks
     * @param e   the user event (button selection)
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        if (command.equals("Ok")) {
            if (propertyName != null) {
                System.setProperty(propertyName,
                    userName.getText().trim() + "/"
                    + password.getText().trim());
            }
            cancelled = false;
            setVisible(false);
        } else if (command.equals("Cancel")) {
            cancelled = true;
            setVisible(false);
        }
    }
}
