package gui;

import workers.CpfLoadThread;
import java.io.File;
import org.apache.log4j.Logger;
import javax.swing.JFileChooser;

/**
 * Dialog to open a file from the file system.
 */
public class OpenDialog 
{
    static private File savedDirectory = null;  // persist the user's selection

    // no-op constructor
    private OpenDialog() {
    }

    /**
     * Allow the user to select a file to open
     * @param application   application context for the dialog
     */
    static public void open(final CpfViewer application) {
        // create a swing file chooser to allow the user to select the file(s)
        // to load, default to user's current working directory
        JFileChooser fc = new JFileChooser(System.getProperty("user.dir"));
        CpfFilter defaultFileFilter = new CpfFilter();
        
        fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
        fc.setMultiSelectionEnabled(true);
        fc.setDialogTitle("Open File");

        // Add selectable file filters for BPFs and CPFs
        fc.addChoosableFileFilter(defaultFileFilter);
        fc.addChoosableFileFilter(new BpfOliFilter());
        fc.addChoosableFileFilter(new BpfTirsFilter());

        // Set the CPF filter as the default
        fc.setFileFilter(defaultFileFilter);

        // if there is a previously saved directory and that directory
        // exists, start the file chooser there
        if ((savedDirectory != null) && savedDirectory.exists()) {
            fc.setCurrentDirectory(savedDirectory);
        }

        // show the file chooser dialog
        int result = fc.showOpenDialog(application);
        if (result == JFileChooser.APPROVE_OPTION) {
            // save the directory so it can be defaulted next time
            savedDirectory = fc.getCurrentDirectory();

            // Open all selected files
            for (File selectedFile : fc.getSelectedFiles()) {
                String fileName = fc.getName(selectedFile);

                Logger.getLogger(OpenDialog.class).info(
                    "Starting thread to open " + fileName);
                application.statusBar.progress.setBusy();
                CpfLoadThread loadThread = new CpfLoadThread(application,
                    selectedFile);
                loadThread.execute();
            }
        }
    }
}
