package gui;

import library.DiffStatus;

/**
 * Object to store a single displayed value of a parameter, and its
 * difference status.  
 * This is the Object stored in each cell of the parameter table.  It is used
 * to display both the value in the cell and for color highlighting of the
 * cell in the parameter table panel.
 */
public class ParameterValueStatus {

    private String parameterValue;   // a single value of a parameter in the
                                     // parameter table
    private DiffStatus status;       // status of this item

    ParameterValueStatus(String parameterValue) {
        this.parameterValue = parameterValue;
        this.status = DiffStatus.NONE; // initial default parameter status
    }

    ParameterValueStatus(String parameter, DiffStatus status) {
        this.parameterValue = parameter;
        this.status = status;
    }

    /**
     * Used in displaying this object in the parameter value table
     * @return   string representation of the parameter value
     */
    @Override
    public String toString() {
        return parameterValue;
    }

    /**
     * Get the status of this item
     * @return  difference status
     */
    public DiffStatus getStatus() {
        return status;
    }

    /**
     * Defines how we determine if 2 objects are equal -- having the
     * same value.  We can compare to another ParameterValueStatus or a String.
     * @param obj      the second object to compare to
     * @return         true if the parameterValues are equal; false otherwise
     */
    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        } else if (this.getClass().equals(obj.getClass())) {
            // compare to another ParameterValueStatus
            return (this.toString().equals(
                ((ParameterValueStatus)obj).toString()));
        } else if (obj instanceof String) {
            // compare to a String
            return (this.toString().equals((String)obj));
        } else {
            return super.equals(obj);
        }
    }

    /**
     * Returns the hash code for this object, based on the parameterValue.
     * Required to ensure two equal objects (as defined above) have the same
     * hash code.
     */
    @Override
    public int hashCode() {
        int hash = 7;
        hash = 37 * hash +
            (this.parameterValue != null ? this.parameterValue.hashCode() : 0);
        return hash;
    }
}
