package gui;

import library.InstanceInfo;

import java.awt.Color;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import javax.swing.BorderFactory;
import javax.swing.JTextField;
import javax.swing.JPanel;

/**
 * Status bar and busy indicator which is displayed at the bottom
 * of the GUI window.
 */
public class StatusBar extends JPanel {

    private JTextField status;      // text area for the status bar
    private JTextField instance; 
    private JTextField collection; 
    public BusyIndicator progress;  // busy indicator for loading data

    // constructor for the status bar
    StatusBar() {

        // make sure the background is light gray since some Java
        // implementations get it wrong
        setBackground(Color.LIGHT_GRAY);

        // create an uneditable text field for the status message
        status = new JTextField("");
        status.setBorder(BorderFactory.createEmptyBorder());
        status.setEditable(false);
        status.setFocusable(false);

        instance = new JTextField("Instance: " + InstanceInfo.getInstance());
        instance.setBorder(BorderFactory.createEmptyBorder());
        instance.setEditable(false);
        instance.setFocusable(false);

        collection = new JTextField("Collection: " +
                                String.valueOf(InstanceInfo.getCollection()));
        collection.setBorder(BorderFactory.createEmptyBorder());
        collection.setEditable(false);
        collection.setFocusable(false);

        // create the progress indicator
        progress = new BusyIndicator();

        // use a grid bag layout for the status bar panel
        GridBagLayout gbl = new GridBagLayout();
        setLayout(gbl);
        GridBagConstraints gbc = new GridBagConstraints();

        gbc.weightx = 60.0;
        gbc.weighty = 60.0;
        gbc.fill = GridBagConstraints.BOTH;
        add(instance, gbc);
        gbc.weightx = 20.0;
        gbc.weighty = 20.0;
        add(collection, gbc);
        add(status, gbc);

        gbc.weightx = 0;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        add(progress, gbc);
    }

    /**
     * Update the message displayed in the status bar
     * @param message   the message to display
     */
    public void showStatus(String message) {
        status.setText(message);
        // make sure the beginning of the status message is visible in case
        // the field is too short to display everything
        status.setCaretPosition(0);
    }
}

