package gui;

import library.LoadedFileType;
import library.LoadedFileSchema;
import actions.FileNameDialogAction;
import java.awt.event.ActionEvent;
import java.awt.BorderLayout;
import java.awt.Point;
import javax.swing.AbstractAction;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JToolBar;

/**
 * A panel with a tool bar of buttons of commonly-executed functions.
 */
public class ToolBarPanel extends JPanel {

    private JToolBar toolBar;
    private JButton openButton;
    private JButton importBaselineButton;
    private JButton importEvaluationButton;
    private JButton baselineButton;
    private JButton mergeButton;
    private CpfViewer application;
    private MergeDialog mergeDialog;

    /**
     * Constructor for the toolbar
     * @param v    the application context
     */
    public ToolBarPanel(CpfViewer v) {
        super(new BorderLayout());
        this.application = v;

        // Create the toolbar itself
        toolBar = new JToolBar("Toolbar", JToolBar.HORIZONTAL);
        setLayout(new BorderLayout());
        toolBar.setFloatable(false);

        // Create the various buttons on the toolbar

        // Open
        AbstractAction openAction = new AbstractAction(
            null, new ImageIcon(getClass().getResource(
            CpfConfig.OPEN_ICON))) {
            @Override
            public void actionPerformed(ActionEvent e) {
                OpenDialog.open(application);
            }
        };
        openButton = new JButton(openAction);
        openButton.setToolTipText("Open");
        openButton.setBorderPainted(false);
        toolBar.add(openButton);

        // Import Baseline CPF
        importBaselineButton = new JButton(new FileNameDialogAction(application,
                "Import Baseline CPF", "Import",
                LoadedFileType.CPF, LoadedFileSchema.PROD, 
                CpfConfig.IMPORT_BASELINE_DB_ICON));
        importBaselineButton.setToolTipText("Import Baseline CPF");
        importBaselineButton.setBorderPainted(false);
        toolBar.add(importBaselineButton);

        // Import Eval CPF
        importEvaluationButton = new JButton(new FileNameDialogAction(
            application, "Import Test CPF", "Import",
                LoadedFileType.CPF, LoadedFileSchema.EVAL,
                CpfConfig.IMPORT_EVAL_DB_ICON));
        importEvaluationButton.setToolTipText("Import Test CPF");
        importEvaluationButton.setBorderPainted(false);
        toolBar.add(importEvaluationButton);

        // Baseline CPF
        baselineButton = new JButton(new FileNameDialogAction(application,
                "Select Test CPF to Baseline", "Baseline",
                LoadedFileType.CPF, LoadedFileSchema.EVAL, 
                CpfConfig.BASELINE_DB_ICON));
        baselineButton.setToolTipText("Baseline");
        baselineButton.setBorderPainted(false);
        toolBar.add(baselineButton);

        // Merge Group
       AbstractAction mergeAction = new AbstractAction(null,
            new ImageIcon(getClass().getResource(CpfConfig.MERGE_ICON))) {
            @Override
            public void actionPerformed(ActionEvent e) {
                Point loc = application.getLocationOnScreen();
                loc.translate(50, 50);
                mergeDialog = new MergeDialog(application, "Group");
                mergeDialog.setLocation(loc);
                mergeDialog.setVisible(true);
            }
        };
        mergeButton = new JButton(mergeAction);
        mergeButton.setToolTipText("Merge");
        mergeButton.setBorderPainted(false);
        toolBar.add(mergeButton);

        add(toolBar);      
    }

}
