package gui;

import library.DiffStatus;

/**
 * Stores the name of an item in the Parameter Tree (either group
 * or parameter) and its status.  This is used for color highlighting of the
 * difference status in the parameter tree.
 */
public class TreeNodeStatus {

    private String nodeName;   // the group or parameter name in the
                                // parameter tree view
    private DiffStatus status;  // status of this tree node item

    TreeNodeStatus(String nodeName)
    {
        this.nodeName = nodeName;
        this.status = DiffStatus.NONE; // initial default parameter status
    }

    TreeNodeStatus(String nodeName, DiffStatus status)
    {
        this.nodeName = nodeName;
        this.status = status;
    }

    /**
     * Used in displaying this object in the tree
     * @return  string representation of the node (group or parameter) name
     */
    @Override
    public String toString() {
        return nodeName;
    }

    /**
     * Get the status of this item
     * @return  difference status
     */
    public DiffStatus getStatus() {
        return status;
    }

    /**
     * Initialize the status for this item to no differences.
     */
    public void initStatus(){
        this.status = DiffStatus.NONE;
    }

    /**
     * Add the new status into the current status.
     * The status is updated only if the new status is *worse*
     * than it was before.
     * @param newStatus   the new status to add to the node
     */
    public void addStatus(DiffStatus newStatus) {
       if (this.status.compareTo(newStatus) < 0) {
           this.status = newStatus;
       }
    }
}
