
package gui;

import java.util.List;
import javax.swing.JOptionPane;
import library.LoadedFile;
import library.LoadedFileType;

/**
 * Utility class for verifying the effective date range off a loaded Odl file.
 */
public class ValidateEffectiveDateRange {
    
    /**
     * The effective date range is expected to begin at the start of the first
     * day and end at the end of the last day.  Warn the user if either value
     * is not set as expected.
     * @param file File containing date range to validate
     * @return boolean true if the range is as expected or if the user confirms
     *  unexpected values. 
     */
    public static boolean validate(CpfViewer viewer, LoadedFile file) {

        if (file.getFileType() != LoadedFileType.CPF) {
            return true;
        }
        
        String groupName = System.getProperty(
            "cpf.group.name.file_attributes", "FILE_ATTRIBUTES");
        String parameterBegin = System.getProperty(
            "cpf.parameter.name.file_attributes.begin_date",
            "Effective_Date_Begin");
        String parameterEnd = System.getProperty(
            "cpf.parameter.name.file_attributes.end_date",
            "Effective_Date_End");

        List<String> values = 
            file.getParameterValues(groupName, parameterBegin);
        try {
            String beginDate = values.get(0);
            if (!beginDate.endsWith("00:00:00")) {
                int response = JOptionPane.showConfirmDialog(viewer,
                    "Effective_Date_Begin timestamp does not begin at the "
                    + "start of the selected day. \n\n" + parameterBegin 
                    + " value: " + beginDate + "\n\nIs this correct?",
                    "Warning", JOptionPane.YES_NO_OPTION);
                if (response == JOptionPane.NO_OPTION) {
                    return false;
                }
            }
        } catch (IndexOutOfBoundsException ex) {
            // Catch possible IndexOutOfBoundsException so caller doesn't need
            // to handle it.
            JOptionPane.showMessageDialog(viewer, parameterBegin
                + " is missing", "Error", JOptionPane.ERROR_MESSAGE);
            return false;
        }

        values = file.getParameterValues(groupName, parameterEnd);
        try {
            String endDate = values.get(0);
            if (!endDate.endsWith("23:59:59")) {
                int response = JOptionPane.showConfirmDialog(viewer,
                    "Effective_Date_End timestamp does not end at the end of "
                    + "the selected day.\n\n" + parameterEnd + " value: " 
                    + endDate + "\n\nIs this correct?", "Warning", 
                    JOptionPane.YES_NO_OPTION);
                if (response == JOptionPane.NO_OPTION) {
                    return false;
                }
            }
        } catch (IndexOutOfBoundsException ex) {
            // Catch possible IndexOutOfBoundsException so caller doesn't need
            // to handle it.
            JOptionPane.showMessageDialog(viewer, parameterEnd
                + " is missing", "Error", JOptionPane.ERROR_MESSAGE);
            return false;
        }

        return true;
    }
}
