# Sed script to convert LaTeX to HTML.  This script was set up specially
# for the CPF GUI portion of the IAS User Guide; it is not guaranteed to 
# handle all LaTeX files.
#
# HTML document begin & end tags
1i\
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
1i\
<!-- Generated code.  Do not edit. -->
1i\
<HTML>
$a\
</HTML>
# tex tags to translate
s?\\documentclass\[.*\]{.*}??g
/\\begin{document}/ {
    # add BODY tag
    s?\\begin{document}?<BODY>?g
    # get the hold buffer, containing the title
    g
    # translate the title into a <H1>
    s?\\title*{\(.*\)}?<H1>\1</H1>?g
}
s?\\end{document}?</BODY>?g
# Stuff to ignore
s?\\usepackage{.*}{.*}??
s?\\usepackage{.*}??
s?\\setlength{.*}{.*}??
s?\\chapterstyle{.*}??
s?\\tableofcontents??
s?\\centering??
s?\\endhead??
s?^\%.*??
s?\\ac{\([^}]*\)}?\1?g
s?\\linebreak\[[0-9]\]??g
# character set translations for LaTex special chars
s?\$>\$?\&gt;?g
s?\$<\$?\&lt;?g
s?<\([^>]*\)>?\&lt;\1\&gt;?g
s?\\verb|\([^|]*\)|?<TT>\1</TT>?g
s?\\backslash ?\\?g
s?\\{?{?g
s?\\}?}?g
s?\\%?%?g
s?\\\$?\$?g
s?\\#?#?g
s?\\_?_?g
s?\\~?~?g
s?\\^?\^?g
s?\\&?\&amp;?g
# Use &#47; instead of / for proper HTML encoding
s?\([a-zA-Z]\)\/\([a-zA-Z]\)?\1\&#47;\2?g
# Undo changes to / in URLs from previous command - local and web-based
s?http\(.*\)\&#47;?http\1\/?g
s?http\(.*\)\&#47;?http\1\/?g
s?IAS_\(.*\)\&#47;?IAS_\1\/?g
s?IAS_\(.*\)\&#47;?IAS_\1\/?g
s?IAS_\(.*\)\&#47;?IAS_\1\/?g
s?JBOSS_\(.*\)\&#47;?JBOSS_\1\/?g
s?JBOSS_\(.*\)\&#47;?JBOSS_\1\/?g
# Headings
# put the title into the hold buffer
/\\title/ { h }
s?\\title*{\(.*\)}?<HEAD><TITLE>\1</TITLE></HEAD>?g
s?\\part{?<Hn>?g
s?\\chapter{\([^{]*\)}?<H1>\1</H1>?g
s?\\section{\([^{]*\)}?<H2>\1</H2>?g
s?\\subsection{\([^{]*\)}?<H3>\1</H3>?g
s?\\subsubsection{\([^{]*\)}?<H4>\1</H4>?g
s?\\paragraph{\([^{]*\)}?<H5>\1</H5>?g
s?\\subparagraph{\(.*\)}?<H6>\1</H6>?g
# UL is itemize
s?\\begin{itemize}?<UL>?g
s?\\end{itemize}?</UL>?g
s?\\item ?<LI>?g
# DL is description
s?\\begin{description}?<DL>?g
s?\\end{description}?</DL>?g
s?\\item?<DT>?g
# Tables
s?\\begin{longtable}{.*}?<TABLE BORDER="1" CELLSPACING="0">?g
s?\\begin{tabular}{.*}?<TABLE BORDER="1" CELLSPACING="1">?g
s?\\\\ *\\hline?</TD></TR><TR><TD>?g
s?\\hline?<TR><TD>?g
# Labels and refs
s?\\label{\(.*\)}?<A NAME="\1"/>?g
s?\\hyperref\[\(.*\)\]{\(.*\)}?<A HREF="#\1"/>\2</A>?g
#   replace ampersands surrounded by spaces or at end of line with table data 
#   separators
s?  *&  *?</TD><TD>?g
s?&$?</TD><TD>?g
s?.*\\end{tabular}?</TD></TR></TABLE><BR/>?g
s?.*\\end{longtable}?</TD></TR></TABLE><BR/>?g
# remove ampersands followed by a single space at end of line to join with 
# next line
/& $/{ N; s?& \n?\&?g; }
# reformat latex quotes
s?``?"?g
s?''?"?g
# Figures
s?\\begin{figure}\[.*\]??g
s?\\end{figure}??g
# Images with space surrounding
s?\\includegraphics\[.*\]{\(.*\)}\\caption{\(.*\)}?<IMG alt="\2" src="\1.jpg"><BR/><BR/>?g
s?\\includegraphics\[.*\]{\(.*\)}?<IMG alt="\1" src="\1.jpg"><BR/><BR/>?g
# An in-line image
s?\\includegraphics{\(.*\)}?<IMG alt="\1" src="\1.jpg">?g
# Italics & bold
s?\\textit{\([^}]*\)}?<i>\1</i>?g
s?\\textbf{\([^}]*\)}?<B>\1</B>?g
# Horizontal rule
s?\\hrule?<HR>?g
# Vertical space
s?\\vspace{.*}?<BR/>?
# Included files & graphics
s?\\include{\(.*\)}?<BR/><A HREF="\1.html">\1</A>?g
#   if the latex input has a comment, use that for the link text
s?\\input{\(.*\)} %\(.*\)?<BR/><BR/><A HREF="\1.html">\2</A>?g
s?\\input{\(.*\)}?<BR/><BR/><A HREF="\1.html">\1</A>?g
s?\\url{\(.*\)}?<A HREF="\1">\1</A>?g
# References to other sections of the IAS User Guide
s?subsection\~\\ref{.*}?the IAS User Guide?g
# Predefined formatted text
s?\\begin{verbatim}?<PRE>?g
s?\\end{verbatim}?</PRE>?g
s?\\begin{quote}?<PRE>?g
s?\\end{quote}?</PRE>?g
