package workers;

import gui.CpfViewer;
import library.FileNamingConventions;
import library.LoadedFileType;
import library.Services;

/**
 * Extends the CpfLoadThread, to import from service instead of loading
 * from file system.  Overrides the doInBackground method and uses
 * parent methods otherwise.
 */
public class CpfImportThread extends CpfLoadThread {

    private String newFileName = null; // new name to load the file as

    /**
     * Create a thread to import a file from the service
     * @param application   the CPF Viewer application
     * @param fileName      name of the file to import
     */
    public CpfImportThread(CpfViewer application, String fileName) {
        this.fileNameToLoad = fileName;
        this.newFileName = fileName;
        this.application = application;
    }

    // Constructor for child classes that import a file using a different
    // file name
    CpfImportThread(CpfViewer application, String fileName,
            String newFileName) {
        this.fileNameToLoad = fileName;
        this.newFileName = newFileName;
        this.application = application;
    }

    /**
     * Get the file from the service, parse it, and load it into the GUI.
     * @return                  the name of the file that was imported
     * @throws WorkerException  if an exception occurs retrieving from the
     *                          service, or parsing the file
     */
    @Override
    public String doInBackground() throws WorkerException {
        Services services = new Services();
        LoadedFileType selectedFileType =
                FileNamingConventions.getFileType(fileNameToLoad);
        try {
            services.retrieveFileAndRenameInGui(application, selectedFileType,
                fileNameToLoad, newFileName);
        } catch (Exception ex) {
                // to help tracing the error
                throw new WorkerException("Import thread", ex);
        }

        // Return the name of the file it was loaded as
        return newFileName;
    }
}
