package workers;

/**
 * Class to hold information about the results of processing that happened
 * in a thread.
 */
public class ThreadStatus {

    protected String message;          // informational message to the user
    protected boolean success;         // success of the operation
    protected String fileName;         // name of the file being operated on
    protected boolean affectsModified; // if this operation affects the
                                       // 'modified' indicator in the GUI

    /**
     * Create an object with results of processing
     * @param message            message to the user
     * @param success            success or failure indicator
     * @param fileName           name of the file being processed
     * @param affectsModified    did the processing affect the file's modified
     *                           indicator?
     */
    public ThreadStatus(String message, boolean success, String fileName,
        boolean affectsModified) {
        this.message = message;
        this.success = success;
        this.fileName = fileName;
        this.affectsModified = affectsModified;
    }

    // Basic getters & setters
    public boolean doesAffectModified() {
        return affectsModified;
    }

    public void setAffectsModified(boolean affectsModified) {
        this.affectsModified = affectsModified;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public boolean isSuccess() {
        return success;
    }

    public void setSuccess(boolean success) {
        this.success = success;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }
}
