#!/bin/csh

# Move into the test dir for running the tests
set testdir = `dirname $0`
cd $testdir

# Set up location of the CpfGUI.jar file
setenv IAS_JAVA_LIB ../dist
# Create a link in the local $IAS_JAVA_LIB to the ias.jar file
if (! -e $IAS_JAVA_LIB/ias.jar) then
    ln -s ../../../javalib/ias/dist/ias.jar $IAS_JAVA_LIB/ias.jar
endif

# Test the group merge 
#  Merge in a group that doesn't exist in the original file
set tmpfile = tmp.merge.$$
../cpfmerge.sh -b original.odl -m new.odl -g C > $tmpfile
#  Merge in a group that does exist in the original file (update/add parameters)
../cpfmerge.sh -b $tmpfile -m new.odl -g A > merge.new
diff -q merge.out merge.new
if ($status != 0) then
    echo "Merge failed difference check"
    exit 1
endif
/bin/rm merge.new $tmpfile

# Test the ALL group option and the output file option
../cpfmerge.sh -b all_base.odl -m all_merge.odl -g ALL -o L8CPF19980701_19980815.04
diff -q L8CPF19980701_19980815.04 all_test_baseline.odl
if ($status != 0) then
    echo "Merge failed with ALL option"
    exit 1
endif
/bin/rm L8CPF19980701_19980815.04

# Test the insert CPF script
../cpfinsert.sh -f eval_L8CPF18970701_18970815.01 
if ($status != 0) then
    echo "Insert CPF failed"
    exit 1
endif
./verify_insert_cpf_test.pl eval_L8CPF18970701_18970815.01
if ($status != 0) then
    echo "Insert CPF failed"
    exit 1
endif

# Diff of ODL file against self should match
../cpfdiff.sh new.odl new.odl
if ($status != 0) then
    echo "Diff against self failed"
    exit 1
endif

# Check diff of similar files
../cpfdiff.sh new.odl new_diff.odl
if ($status != 0) then
    echo "Diff of similar files new.odl and new_diff.odl failed"
    exit 1
endif

# Verify cpfdiff.sh skip the FILE_ATTRIBUTES group
../cpfdiff.sh eval_L8CPF18970701_18970815.01 test_exclude_FILE_ATTRIBUTES.odl
if ($status != 0) then
    echo "Diff failed to skip the FILE_ATTRIBUTES group"
    exit 1
endif

# Diff different files should find differences
../cpfdiff.sh new.odl all_merge.odl
if ($status != 1) then
    echo "Diff failed to find differences between new.odl and all_merge.odl"
    exit 1
endif

# Test the UT1 retrieval
#   Occasionaly USNO's algorithm is updated and the entire dataset will be 
#   different.  In that case the expected results need to be regenerated.
../ut1.sh 2009-04-01T00:00:00 2009-06-30T00:00:00 > ut1.new
diff -q ut1.out ut1.new
if ($status != 0) then
    echo "UT1 failed difference check.  ut1.out may need to be updated."
    echo " See http://maia.usno.navy.mil/ser7/archive.notes for a description"
    echo " of algorithm updates."
    exit 1
endif
/bin/rm ut1.new

# delete the log file (see log4j.properties)
/bin/rm -f cpftest.log

exit 0
