#!/usr/bin/perl -w
use strict;

use DBI;
use File::Basename;

if ($#ARGV != 0)
{
    my $exe = basename($0);
    print "Usage: $exe <cpf file>\n";
    exit 1;
}
my $filename = $ARGV[0];

# subroutines 
sub exit_fail($);

# Connect to the DB
my ($user,$pass) = split("/", $ENV{"IAS_DB_L8_OLITIRS_EVAL"});
my $sid = $ENV{"ORACLE_SID"};
my $dbh = DBI->connect("DBI:Oracle:$sid", $user, $pass, 
        {AutoCommit => 0, PrintError => 0, RaiseError => 0});
die "ERROR: could not connect to the database: $DBI::errstr" if (!$dbh);

# Get the cpf_main_id
my ($main_id, $desc);
my $sql = "SELECT cpf_main_id, description FROM cpf_main " . 
    "WHERE file_name = '$filename'";
my $sth = $dbh->prepare($sql);
exit_fail("ERROR: prepare get cpf_main_id") if (!$sth);
if (!$sth->execute()) {
    exit_fail("ERROR: execute get cpf_main_id");
}
if (my @row = $sth->fetchrow_array()) {
    $main_id = $row[0];
    $desc = $row[1];
} else {
    exit_fail("Insert CPF test failed");
}
$sth->finish();

if ($desc ne "Testing ALL")
{
    exit_fail("Description not formatted correctly");
}

# Get the group_main_id list
my @group_ids;
$sql = "SELECT cpf_group_id "
     . "  FROM cpf_main_group "
     . " WHERE cpf_main_id = $main_id";
$sth = $dbh->prepare($sql);
exit_fail("ERROR: prepare get cpf_group_id list") if (!$sth);
if (!$sth->execute()) {
    exit_fail("ERROR: execute get cpf_group_id list");
}
while (my @row = $sth->fetchrow_array()) {
    push(@group_ids, $row[0]);
}
$sth->finish();
my $group_id_str = join(",", @group_ids);

# Cleanup test data
$sql = "DELETE FROM cpf_main_group "
     . " WHERE cpf_group_id IN ($group_id_str) "
     . "   AND cpf_main_id = $main_id";
$dbh->do($sql) or exit_fail("ERROR: cleaning up cpf_main_group");

foreach my $group_id (@group_ids)
{
    $sql = "DELETE FROM cpf_group "
         . " WHERE cpf_group_id = $group_id";
    print "WARN: $group_id used by another CPF. Group was not deleted." 
                unless ($dbh->do($sql));
}

$sql = "DELETE FROM cpf_main "
     . " WHERE cpf_main_id = $main_id";
$dbh->do($sql) or exit_fail("ERROR: cleaning up cpf_main");

$dbh->commit();

exit 0;

sub exit_fail($)
{
    my $msg = shift;
    print "$msg\n";
    $dbh->rollback();
    exit 1;
}
