#!/usr/bin/perl -w
use strict;
use ias_const;
use File::Copy;

# Name:         convert_to_collection1.pl
# Description:  This script converts collection 0 CPFs to collection 1
# Args:         One or more CPF Names to convert.

sub remove_parameters($);
sub _include_line($);

if ( $#ARGV < 0)
{
    print "This script takes one or more CPF names as arguments\n";
    exit FAILURE;
}

my $status;
foreach my $file (@ARGV)
{
    if ($file =~ /(eval_)?L8CPF(\d{8}_\d{8}).(\d\d)/)
    {
        my $eval = "";
        if (defined $1)
        {
            $eval = $1;
        }
        my $new_name = $eval . "LC08CPF_$2_01.$3";
        
        my @args = ("cpfmerge.sh","-g","ALL","-b",$file,"-m","add_these.odl",
                    "-o", $new_name);
        $status = system(@args);
        if ($status != 0)
        {
            print "Call to merge for $file failed\n";
            next;
        }

        if (-f $eval."MERGE_$2")
        {
            # Move previous output to a temp location we can perform a 2nd
            # merge on
            if (move($new_name, $new_name."_tmp") != 1)
            {
                print "Failed to move $file to tmp location\n";
                next;
            }
            @args = ("cpfmerge.sh","-g","ALL","-b",$new_name."_tmp","-m",
                     $eval."MERGE_$2","-o", $new_name);
            $status = system(@args);
            if ($status != 0)
            {
                print "Call to 2nd merge for $file failed\n";
                next;
            }
            # Remove the temp file created
            unlink($new_name."_tmp");
        }
        else
        {
            print "WARN: Date specific merge file not found for $file\n";
        }
        $status = remove_parameters($new_name);
        if ($status != SUCCESS)
        {
            print "Call to remove_parameters for $file failed\n";
            next;
        }

        @args = ("cps_validate.pl", "--nowarnings", "--noformat", "--type",
                 "CPF", $new_name);
        $status = system(@args);
        if ($status != 0)
        {
            print "Call to verify for $file failed\n";
            next;
        }
        print "$new_name created and validated\n";
    }
    else
    {
        print "Skipping $file. It does not appear to be a CPF\n";
    }
}

sub remove_parameters($)
{
    my ($filename) = @_;
    my @old_cont;
    my @new_cont;
    if (open (my $handle, '<', $filename))
    {
        @old_cont = <$handle>;
        close $handle;
    }
    else
    {
        print "Failed to open $filename for reading\n";
        return ERROR;
    }

    @new_cont = grep { _include_line($_); } @old_cont;

    if (open (my $handle, '>', $filename))
    {
        print $handle join('',@new_cont);
        close $handle;
    }
    else
    {
        print "Failed to open $filename for writing\n";
        return ERROR;
    }
    return SUCCESS;
}

sub _include_line($)
{
    my ($line) = @_;

    # Remove cloud cover weights
    if ($line =~ /(ATACCA|Cirrus|See5|ACCA)_Weights/)
    {
        return FALSE;
    }
    if ($line =~ /Number_Of_Classes|CCA_Class_Type|Number_Of_Algorithms|
                  Algorithm_Names|Run_If_Thermal/x)
    {
        return FALSE;
    }
    # TODO Other parameters that need to be removed?

    return TRUE;
}
