#!/bin/sh

# This script uses SQL Loader to insert a RLUT file into the database.
#   It first uses create_rlut_loader to create the Oracle loader file.
#   The data and table are described on the control file. 
#   The table row data are also in the control file, and refer to the
#     sample RLUT files whose contents are loaded into the BLOB columns.

if [ "$2" == "" ]; then
    echo "usage: $0 <rlut_hdf_file> <db_user/password>"
    exit -1
fi

RLUT_FILE="$1"
USERID="$2"

# Since the loader file uses a LOBFILE clause to load the 
# named RLUT file into the BLOB column, the file needs to
# be in the current directory or we need a link to it so
# sqlldr can access it
NAME=`basename $RLUT_FILE .h5`
echo "NAME=$NAME"
LOG=$NAME.load_rlut.log
DATA_FILE_DIR=`dirname $RLUT_FILE`
echo "DATA_FILE_DIR=$DATA_FILE_DIR"
file_linked=0
if [ ! -e $NAME.h5 ]; then
    ln -s $RLUT_FILE .
    file_linked=1
fi

# Create the loader file
create_rlut_loader $NAME.h5 $NAME.ldr
if [ ! $? == 0 ]; then
    echo "Error: create_rlut_loader failed for $NAME.h5"
    exit 1
fi

# use the loader file to load the RLUT file into the DB
$ORACLE_HOME/bin/sqlldr userid=$USERID control=$NAME.ldr \
  log=$NAME.log bad=$NAME.bad 2>&1 > $LOG
if [ ! $? == 0 ]; then
    echo "Load of RLUT data failed"
    echo "  check $LOG, $NAME.log, or $NAME.bad for errors"
    exit 1
fi

/bin/rm -f $NAME.log $NAME.bad
if [ $file_linked == 1 ]; then
    rm $NAME.h5
fi

exit 0
