#!/bin/sh
################################################################################
# Name: create_ldr_test.sh                                                     
#                                                                              
# Function: This script tests the create_rlut_loader program. It will test     
#           good values and bad values and there should be errors thrown in    
#           the first 8 test to ensure that bad values passed are caught.      
#                                                                              
# Returns: Pass if all tests pass Fail if any one test Fails                   
################################################################################
PWD=`pwd`

LOG="$PWD/create_ldr_test.log"

# Unit test directory
UT_DIR="$IAS_UNIT_TEST_DATA_DIR/ias/cps/tools/load_rlut/"

DATE=`date`
echo "Created $DATE" 2>&1 > $LOG

echo "" 2>&1 >> $LOG
echo "--- Creating ldr file ----------------------------------" 2>&1 >> $LOG
echo "" 2>&1 >> $LOG

# Beginning year should not match
TEST[0]="LC08RLUT_19990101_20141231_00_01_test_begin_year"
# Ending day should not match
TEST[1]="LC08RLUT_19990101_20141231_00_01_test_end_day"
# Version should not match
TEST[2]="LC08RLUT_19990101_20141231_00_01_test_version" 
# Data type should not match
TEST[3]="LC08RLUT_20130211_20431231_00_09"
# Normal run with data sets
TEST[4]="LC08RLUT_20130211_20141231_00_07"
# Noraml run with eval data set
TEST[5]="eval_LC08RLUT_20130211_20141231_00_07"
# Testing eval version should not match
TEST[6]="eval_LC08RLUT_19990101_20141231_00_01_test_version"

# Create the symbolic names array to be used
SYM[0]="LC08RLUT_19990101_20141231_00_01"
SYM[1]="LC08RLUT_19990101_20141231_00_01"
SYM[2]="LC08RLUT_19990101_20141231_00_01"
SYM[3]="LC08RLUT_20130211_20431231_00_09"
SYM[4]="LC08RLUT_20130211_20141231_00_07"
SYM[5]="eval_LC08RLUT_20130211_20141231_00_07"
SYM[6]="eval_LC08RLUT_19990101_20141231_00_01"

# Iterate through all 5 tests
for X in {0..6}
do
    echo "Running test on ${UTDIR}${TEST[$X]}.h5" | tee -a $LOG

    # Link the file so there isn't any name conflicts
    ln -sf ${UT_DIR}${TEST[$X]}.h5 ${SYM[$X]}.h5 

    # Run create_rlut_loader
    ../create_rlut_loader ${SYM[$X]}.h5 ${SYM[$X]}.ldr 2>&1 >> $LOG
    if [ "$X" == "4" ] || [ "$X" == "5" ]; then
        diff ${SYM[$X]}.ldr ${UT_DIR}${SYM[$X]}.ldr_eval 2>&1 >> $LOG
        if [ ! $? == 0 ]; then
            echo "create_rlut_loader failed." 2>&1 >> $LOG
            exit 1
        fi
    else 
        if [ -f "${SYM[$X]}.ldr" ]; then
            echo "${SYM[$X]}.ldr should not exist"
            exit 1
        fi   
    fi
    rm -f ${SYM[$X]}.h5 
    echo "" 2>&1 >> $LOG
    echo "" 2>&1 >> $LOG
done

# Check that it is throwing the correct errors
LOG1='filename is LC08RLUT_19980101_20141231_00_01.h5'
LOG2='filename is LC08RLUT_19990101_20141230_00_01.h5'
LOG3='filename is LC08RLUT_19990101_20141231_00_02.h5'
LOG4='Unexpected data type for group /LINEARITY_LOOKUP/Band09/SCA14, dataset DN_LUT'

echo "-----------------GREP SECTION ---------------------------" 2>&1 >> $LOG

# Grep log for errors
for X in "${LOG1}" "${LOG2}" "${LOG3}" "${LOG4}"
do
    grep "${X}" "${LOG}" 2>&1 >> /dev/null
    if [ ! $? == 0 ]; then
        echo "Wrong error was thrown. Exiting Test. $X" 2>&1 >>$LOG
        exit 1
    fi
done

# Temporary files that are going to be deleted
TEMP1="*.ldr"
TEMP2="create_ldr_test.log"

# Remove the temp files.
if [ ! "$1" == "save" ]; then 
    for F in $TEMP1 $TEMP2
    do 
        echo "rm -f ${F}"
        rm -f ${F}
    done
fi

