#! /usr/bin/perl -w

###############################################################################
#
# Name: cps_validate_test.pl
#
# Purpose: To test basic functionality performed by the cps_validate.pl script
#
###############################################################################

use strict;
use Cwd;

my @args;
my $rtn;                                    # system call return value
my $counter = 0;                            # process counter
my $fail = 0;                               # failed test counter
my $masterLogPath;                          # location of master run log
my $dataRoot = $ENV{IAS_UNIT_TEST_DATA_DIR};# get root of data dir
my $binPath = $ENV{IAS_BIN};                # get the executable location
my $cpsPath = $dataRoot . "/ias/cps/validation/";

# reset the data dir for testing
$ENV{IAS_DATA_DIR} = Cwd::getcwd();

$masterLogPath = $dataRoot . "/ias/cps/validation/cps_test_master.log";

open (STDERR, ">cps_test.log");
print "Start CPS Validation tests....\n";

system("date");


print STDERR "Check help function.\n";
@args = ("../cps_validate.pl --help 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "\n$counter ";
$counter++;

print STDERR "Check empty template option and no file name.\n";
@args = ("../cps_validate.pl --t 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check no template or file name, displays help.\n";
@args = ("../cps_validate.pl 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check read from <STDIN> via pipe.\n";
@args = ("cat " . $cpsPath . "LC08CPF_19990701_19990930_01.01 | "
   . "../cps_validate.pl --s LC08CPF_19990701_19990930_01.01 1>&2 "
   . "cps_test.log"); 
system @args;
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check read from <STDIN> via redirection.\n";
@args = ("../cps_validate.pl --s LC08CPF_19990701_19990930_01.01 < " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01   1>&2 cps_test.log"); 
system @args;
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check ability to determine CPF template by file name\n";
@args = ("../cps_validate.pl " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option c\n";
@args = ("../cps_validate.pl --t c " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option cpf\n";
@args = ("../cps_validate.pl --t cpf " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option C\n";
@args = ("../cps_validate.pl --t C " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option CPF\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template invalid type option\n";
@args = ("../cps_validate.pl --t Z " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check ability to determine OLI BPF template by file name.\n";
@args = ("../cps_validate.pl " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check ability to determine TIRS BPF template by file name.\n";
@args = ("../cps_validate.pl " . $cpsPath 
    . "LT8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option ob.\n";
@args = ("../cps_validate.pl --t ob " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option olibpf.\n";
@args = ("../cps_validate.pl --t olibpf " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option OB.\n";
@args = ("../cps_validate.pl --t OB " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option OBPF.\n";
@args = ("../cps_validate.pl --t OBPF " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option tb.\n";
@args = ("../cps_validate.pl --t tb " . $cpsPath 
    . "LT8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option tirsbpf.\n";
@args = ("../cps_validate.pl --t tirsbpf " . $cpsPath 
    . "LT8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option TB.\n";
@args = ("../cps_validate.pl --t TB " . $cpsPath 
    . "LT8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check template type option TBPF.\n";
@args = ("../cps_validate.pl --t TBPF " . $cpsPath 
    . "LT8BPF20140310103310_20140310103345.06 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option, ob instead of c.\n";
@args = ("../cps_validate.pl --t ob " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option, bpf instead of cpf.\n";
@args = ("../cps_validate.pl --t obpf " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option OB instead of C. \n";
@args = ("../cps_validate.pl --t OB " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option BPF instead of CPF. \n";
@args = ("../cps_validate.pl --t OBPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option, c instead of b.\n";
@args = ("../cps_validate.pl --t c " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option, cpf instead of bpf.\n";
@args = ("../cps_validate.pl --t cpf " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option, C instead of B.\n";
@args = ("../cps_validate.pl --t C " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect template type option, CPF instead of BPF.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incremental date problem UT1/UTC Modified Julian Dates.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.incrementDates 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect UT1/UTC Modified Julian Dates.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990702_19990930_01.01.ut1MJD 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check incorrect UT1/UTC Modified Julian Dates "
    . "warnings turned off\n";
@args = ("../cps_validate.pl -nowarnings --t CPF " . $cpsPath 
    . "LC08CPF_19990702_19990930_01.01.ut1MJD 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
} 
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check eval file name.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "eval_LC08CPF_19990701_19990930_01.01 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
} 
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check invalid file name.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.02.badname 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check for duplicate groups.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.dupgroup 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check cpf for duplicate parameter member in group.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.dupparm 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check for missing file end label.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.missend 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check for missing ending group label.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.missgroupend 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check ability to turn off error reporting.\n";
@args = ("../cps_validate.pl -noerrors --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.missgroupend 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check parameter located in incorrect group.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.wronggroup 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check for missing parameter.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.missparam 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check bpf for missing parameter value detector level.\n";
@args = ("../cps_validate.pl --t OBPF " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06.missingval 1>&2 cps_test.log"); 
system @args;
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check group out of place.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.groupoutofplace 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check parameter out of place within correct group.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.paramoutofplace 1>&2 cps_test.log");
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check bpf for invalid template format.\n";
@args = ("../cps_validate.pl --t OBPF " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06.formaterror 1>&2 cps_test.log"); 
system @args;
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check bpf for invalid template format with format errors off.\n";
@args = ("../cps_validate.pl --noformat --t OBPF " . $cpsPath 
    . "LO8BPF20140310103310_20140310103345.06.formaterror 1>&2 cps_test.log"); 
system @args;
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
} 
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check invalid nominal values and missing array values.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.nominalerrs 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check additional array values.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.extravalues 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Check for invalid integers. \n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.badintegers 1>&2 cps_test.log"); 
system @args; 
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
} 
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Test CPF has Detector_Noise_B10_SCA01 parameter on a single "
      .  "line longer than the 2048 character maximum length.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.longline 1>&2 cps_test.log");
system @args;
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
}
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Test CPF has parameter Along_Detector_Offsets_B10_SCA01 "
    . "defined across multiple lines.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.multilineparam 1>&2 cps_test.log");
system @args;
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Test CPF has parameter Along_Detector_Offsets_B10_SCA01 "
    . "alone repeated on multiple lines.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.01.repeatedparam 1>&2 cps_test.log");
system @args;
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
}
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Test CPF having mismatched version in the filename vs the "
           . "attributes.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.02.mismatchver 1>&2 cps_test.log");
system @args;
if (($? >> 8) == 0)
{
    $fail++;
    print STDERR "Validation failed to detect specified errors!\n";
}
elsif (($? >> 8) == 1)
{
    print STDERR "Validation detected errors as designed!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;

print STDERR "Test CPF having different collection number and version.\n";
@args = ("../cps_validate.pl --t CPF " . $cpsPath 
    . "LC08CPF_19990701_19990930_01.02 1>&2 cps_test.log");
system @args;
if (($? >> 8) == 0)
{
    print STDERR "Validation completed successfully!\n";
}
elsif (($? >> 8) == 1)
{
    $fail++;
    print STDERR "Validation completed unsuccessfully!\n";
}
else
{
    $fail++;
    print STDERR "Validation failed!\n";
}
print STDERR "=====================================================\n\n";
print "$counter ";
$counter++;
print "$counter\n";

print STDERR "====== CPS Validation regression tests completed. ======\n";

close STDERR;

# diff the files
$rtn = system("diff cps_test.log $masterLogPath > cps_test.diffs");
if ($rtn == 0)
{
    print "cps_validate_test.pl regression tests completed successfully\n";
    print "\t\t..... $counter tests completed successfully......\n";
    exit 0;
}
else
{
    if ($fail > 0)
    {
        print "\t\t...... $fail of $counter Regression tests failed\n";
        print "CPS validation regression tests failed, "
            . "see diff file cps_test.diffs\n";
        exit 1;
    }
    else
    {
        print "Diffs were reported but no failure counted!\n";
    }
}

system("date");
