%%
%% This is file `unittest.cls', based on `article.cls'.
%% Its purpose is to define a class for test documentation.
%%
% The section below is a template of the various components of a test
% case.  Multiple test cases are generated with multiple \testcase sections.
%
% ---------------- Test case template -----------------------
% \testcase{Title of test case}
%
% \authorrevised{Fname Lname}{Mon day, year of last revision}
%
% \begin{purpose}
% A short presentation of the purpose and objectives of the test.
% \end{purpose}
%
% \begin{prerequisites}
% List any prerequisite steps required.
% \end{prerequisites}
%
% \begin{ccrlist}
% \item[CCR number] CCR title
% ...
% \end{ccrlist}
%
% \begin{inputdata}
% List of input data required for the test.
% \end{inputdata}
%
% \begin{verification}
% Itemized list of criteria for a successful test.
% \item The test machine does not blow up.
% ...
% \end{verification}
%
% \begin{steps}
% List of test case steps with the following format for each step:
% & User actions/inputs & Epected results & & Comments/remarks
%   \tabularnewline\hline
% (The "&" represent the column separators. The information for a
% given cell may be as long as required.)
% \end{steps}
% ---------------- End test case template -----------------------
%
%-------------------- identification --------------------------
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{unittest}[2003/04/29 v0.1]
%-------------------- initial code ----------------------------
\RequirePackage[paperheight=8.5in,paperwidth=11in,textheight=7.0in,
textwidth=9.0in]{geometry}
\RequirePackage{array}
\RequirePackage{wasysym}
\RequirePackage{times}
%-------------------- declaration of options ------------------
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
%-------------------- execution of options --------------------
\ProcessOptions
%-------------------- package loading -------------------------
\LoadClass[12pt]{article}
\RequirePackage{longtable}
%-------------------- main code -------------------------------
\topmargin -0.5in
\oddsidemargin 0in
\textheight 6.3in
\textwidth 9.0in

% Define the \testcase section.
\newcounter{testcase}
\renewcommand{\thetestcase}{Test Case \@arabic\c@testcase:}
\newcommand*{\testcasemark}[1]{}
\newcommand{\ruleunder}[1]{{#1\par\nobreak\vskip 1ex \hrule width \linewidth %
                                                            height 2pt}}
\newcommand{\testcase}{\clearpage
                       \@startsection{testcase}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalfont\Large\bfseries\ruleunder}}%

% Define the \authorrevised command.
\newcommand{\authorrevised}[2]{{\bfseries Author:} #1 %
             \hfill{\bfseries Last Revised:} #2 \rule{2in}{0in}}

% Define the \purpose environment.
\newenvironment{purpose}{\vspace{\baselineskip}\noindent
                         \textbf{Purpose and Objectives:}\begin{quote}}
                        {\end{quote}}

% Define the \prerequisites environment.
\newenvironment{prerequisites}{\vspace{\baselineskip}\noindent
                         \textbf{Prerequisite Steps:}\begin{quote}}
                        {\end{quote}}

% Define the \ccrlist environment.
\newenvironment{ccrlist}{\vspace{\baselineskip}\noindent
                         \textbf{CCRs verified by this test:}
                         \list{}{\labelwidth\z@ \itemindent-\leftmargin
                         \let\makelabel\descriptionlabel}}
                        {\endlist}

% Define the \inputdata environment.
\newenvironment{inputdata}{\vspace{\baselineskip}\noindent
                         \textbf{Input Data Required:}\begin{quote}}
                        {\end{quote}}

% Define the \verification environment.
\newenvironment{verification}{\vspace{\baselineskip}\noindent
                              \textbf{Verification Criteria:} \\[0.1in]
                              This test case will pass if:
                              \begin{itemize}}
                             {\end{itemize}}

% Define the \steps environment.
\newcounter{tabline}
\DeclareRobustCommand\tabitem{\refstepcounter{tabline}\thetabline}
\newenvironment{steps}{\setcounter{tabline}{0}\vspace{\baselineskip}\noindent
                    \begin{longtable}{|>{\tabitem}r|>{\raggedright}p{2.8in}|
                           >{\raggedright}p{2.8in}|c|>{\raggedright}p{1.8in}|}
                    \caption*{\textbf{Test Case \@arabic\c@testcase~Steps}} \\
                    \hline
                    \multicolumn{1}{|c|}{\textbf{Step}} &
                    \multicolumn{1}{c|}{\textbf{User Actions/Inputs}} &
                    \multicolumn{1}{c|}{\textbf{Expected Results}} &
                    \checked &
                    \multicolumn{1}{c|}{\textbf{Comments/Remarks}}
                    \tabularnewline
                    \multicolumn{1}{|c|}{\textbf{Number}} & & & &
                        \tabularnewline\hline
                    \hline \endhead
                    \hline \endfoot}
                  {\end{longtable}}
%%
%% End of file `unittest.cls'.
