%%
%% This is the file `eros.cls', based on `memoir.cls'.
%% Its purpose is to define a tech-writer approved class for documentation.
%%
%-------------------- identification --------------------------
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{eros}[2015/06/30 v0.1]
%-------------------- initial code ----------------------------
%-------------------- declaration of options ------------------
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}
%-------------------- execution of options --------------------
\ProcessOptions
%-------------------- package loading -------------------------
\LoadClass{memoir}

\RequirePackage{alltt}
\RequirePackage{algorithmic}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{array}
\RequirePackage{calc}
\RequirePackage[font={normalsize,it,bf},labelsep=period]{caption}
\RequirePackage{enumitem}
\let\footruleskip\undefined
\RequirePackage{fancyhdr}
\RequirePackage{graphicx}
\RequirePackage{ifthen}
\RequirePackage[letterpaper, portrait, margin=1in]{geometry}
\RequirePackage{lastpage}
\RequirePackage{longtable}
\RequirePackage{multirow}
\RequirePackage[table]{xcolor}
\RequirePackage{mathpazo}
\RequirePackage{mathptmx}
\RequirePackage{memhfixc}
\RequirePackage{multicol}
\RequirePackage[sort,sectionbib]{natbib}
\RequirePackage{paralist}
\RequirePackage{placeins}
\RequirePackage{pgfplots}
\RequirePackage[printonlyused]{acronym}
\RequirePackage{rotating}
\RequirePackage[scaled=0.92]{helvet}
\RequirePackage[T1]{fontenc}
\RequirePackage{textcomp}
\RequirePackage{threeparttable}
\RequirePackage{tikz}
\usetikzlibrary{positioning}
\usetikzlibrary{shapes,arrows}
\RequirePackage{varioref}
\RequirePackage{wasysym}
% Should be loaded after varioref
\RequirePackage[colorlinks=true,linkcolor=blue,urlcolor=blue,plainpages=false,citecolor=blue]{hyperref}

\renewcommand{\familydefault}{\sfdefault}

% Page layout stuff
\setlength\footskip{0.6in}
\hfuzz=2pt % Do not report the set amount of protrusion into the right margin.

% Stuff for tabular content.
%---------------------------
\newcommand{\nl}{\tabularnewline}
\newenvironment{longtable*}{%
  \addtocounter{table}{-1}%
    \longtable
}{%
  \endlongtable
}

% Command for continued from previous page.
\newcommand{\cfpp}[2]{\multicolumn{#1}{#2}{\small\slshape continued from
previous page}}

% Command for continued on next page.
\newcommand{\conp}[2]{\multicolumn{#1}{#2}{\small\slshape continued on next
page}}

% Increase the size of the Appendix Table of Contents entry to match the
% Part level.
\renewleadpage[plain]\appendixpage{Appendices}
\renewcommand\leadpagetoclevel{part}

% Bibliography stuff
\bibliographystyle{mla}
\renewcommand\bibname{References}

% Give up trying to flushbottom pages that are sparse due to new section
% starting on next page.
\raggedbottomsectiontrue

% Stop complaints about "Underfull \vbox" in long verbatims.
\raggedbottom

% Miscellaneous macros
\newcommand{\var}[1]{\textnormal{\slshape #1}}
\newcommand{\ttilde}{\raisebox{-0.7ex}{\textasciitilde}}

% Page formatting, use roman numbers for the beginning sections
\let\cleardoublepage\pagebreak

% Change the format for chapters, both numbered and un-numbered
\chapterstyle{default}
\renewcommand{\chapnamefont}{\normalfont\Large\bfseries}
\renewcommand{\chapnumfont}{\normalfont\Large\bfseries}
\renewcommand{\chaptitlefont}{\normalfont\Large\bfseries}
\renewcommand{\chaptername}{Section}
\renewcommand{\afterchapternum}{\hskip 1.1em}
\renewcommand{\afterchaptertitle}{\par\vskip -0.6\baselineskip%
                                  \rule{\textwidth}{1.5pt}%
                                  \par\vskip \afterchapskip}
\setlength\beforechapskip{-1.333\baselineskip}
\setlength\midchapskip{-2\baselineskip}
\setlength\afterchapskip{-7pt}

% Change the section title format
\setsecheadstyle{\normalfont\large\bfseries}
\setbeforesecskip{2ex plus 1ex minus .2ex}
\setaftersecskip{1ex plus .2ex}
\setbeforesubsecskip{2ex plus 1ex minus .2ex}
\setaftersubsecskip{1ex plus .2ex}

% Dotfill everything in the TOC
\renewcommand\cftdotsep{.5}
\renewcommand{\cftchapterleader}{\cftdotfill{\cftdotsep}}
\renewcommand{\@pnumwidth}{1em}


% TOC spacing between lines
\renewcommand\cftchapterafterpnum{\vskip0pt}
\renewcommand\cftsectionafterpnum{\vskip-5pt}
\renewcommand\cftsubsectionafterpnum{\vskip-5pt}
\renewcommand{\cftbeforechapterskip}{0pt}

% Create the "Table C-3. " in front of list of tables
\newlength\tablelen
\settowidth\tablelen{Table}
\addtolength\cfttablenumwidth{\tablelen}
\renewcommand\cfttablepresnum{Table\ }
\renewcommand\cfttableaftersnum{.}

% Create the "Figure C-3. " in front of list of figures
\newlength\figurelen
\settowidth\figurelen{Figure}
\addtolength\cftfigurenumwidth{\figurelen}
\renewcommand\cftfigurepresnum{Figure\ }
\renewcommand\cftfigureaftersnum{.}

% Paragraph spacing, remove indents
\setlength{\parskip}{\baselineskip}
\setlength{\parindent}{0pt}

% Make table cell borders thicker
\setlength\arrayrulewidth{1pt}

% Less space between lists
\setlist{nolistsep}

% Longtable spacing
\setlength\tabcolsep{12pt}
\setlength\extrarowheight{3pt}

% pagestyle information
\pagestyle{headings}
\makeoddhead{headings}{}{}{}
\makeevenhead{headings}{}{}{}
\makeoddfoot{headings}{}{- \thepage\ - \\}{\dcn \\ \version}
\makeevenfoot{headings}{}{- \thepage\ - \\}{\dcn \\ \version}
\makeoddhead{myheadings}{}{}{}
\makeevenhead{myheadings}{}{}{}
\makeoddfoot{myheadings}{}{- \thepage\ - \\}{\dcn \\ \version}
\makeevenfoot{myheadings}{}{- \thepage\ - \\}{\dcn \\ \version}

% Include DCN and version on first pape of new sections.
\aliaspagestyle{chapter}{myheadings}
\aliaspagestyle{part}{myheadings}

% My new stuff
% Add headers for the
\fancypagestyle{empty}{
  \fancyhf{}
  \renewcommand{\headrulewidth}{0pt}
  \fancyhead[R]{\textbf{\fontsize{10}{12}\selectfont \dcn \\[-.07in] \version}}
}

% Clean up TOC header to match desired template
\maxtocdepth{subsection}
\maxsecnumdepth{subparagraph}
\renewcommand{\tableofcontents}{
  \chapter{Contents}
  \vspace{12pt}
  \setlength{\parskip}{\baselineskip/3}
  \@starttoc{toc}
  \setlength{\parskip}{\baselineskip}
}

% Clean up LOT to match desired template
\renewcommand{\listoftables}{
  \chapter{List of Tables}
  \setlength{\parskip}{\baselineskip/3}
  \@starttoc{lot}
  \setlength{\parskip}{\baselineskip}
}

% Clean up LOF to match desired template
\renewcommand{\listoffigures}{
  \chapter{List of Figures}
  \setlength{\parskip}{\baselineskip/3}
  \@starttoc{lof}
  \setlength{\parskip}{\baselineskip}
}
\addtolength\cftsectionnumwidth{1 ex}
\addtolength\cftsubsectionnumwidth{1 ex}
\addtolength\cftsubsubsectionnumwidth{1 ex}
\addtolength\cfttablenumwidth{1 ex}
\addtolength\cftfigurenumwidth{1 ex}
\setpnumwidth{2em}
% The following sets up the algorithmic package.  We are using Input: and 
% Output: for our algorithms.  This sets up creation of a list of algorithms 
% for the front matter pages.
\renewcommand{\algorithmicrequire}{\textbf{Input:}}
\renewcommand{\algorithmicensure}{\textbf{Output:}}

\newcommand{\listalgorithmname}{List of Algorithms}
\newlistof{listofalgorithms}{loa}{\listalgorithmname}
\newfloat[chapter]{algorithm}{loa}{Algorithm}
\newfixedcaption{\falgocaption}{algorithm}
\newlistentry{algorithm}{loa}{0}
\def\loamark{\markboth{\MakeUppercase{\listalgorithmname}}{}}
\newcommand\algrule{\hrule height.8pt depth0pt \kern2pt}

% Clean up LOA to match desired template
\renewcommand{\listofalgorithms}{
  \chapter{List of Algorithms}
  \vspace{12pt}
  \setlength{\parskip}{\baselineskip/3}
  \@starttoc{loa}
  \setlength{\parskip}{\baselineskip}
}

% Float stuff
\newsubfloat{figure}

%-------------------- main code -------------------------------
\newcommand{\version}{Undefined}
\newcommand{\softwareversion}{Undefined}
\newcommand{\softwareversiontag}{Undefined}
\newcommand{\dcn}{Undefined}
\newcommand{\olddcn}{Undefined}

\newcommand{\setversion}[1]{\renewcommand{\version}{#1}}
\newcommand{\setsoftwareversion}[1]{\renewcommand{\softwareversion}{#1}}
\newcommand{\setsoftwareversiontag}[1]{\renewcommand{\softwareversiontag}{#1}}
\newcommand{\setdcn}[1]{\renewcommand{\dcn}{#1}}
\newcommand{\setolddcn}[1]{\renewcommand{\olddcn}{#1}}

\newcommand{\settitle}[1]{\title{#1 \\ \hfill\break Release \softwareversion}}

\let\oldmainmatter\mainmatter
\renewcommand{\mainmatter}{
  \oldmainmatter
  \setcounter{chapter}{0}
  \renewcommand{\thepage}{\arabic{page}}
  \makeatletter
  \renewcommand{\thetable}{\thechapter-\@arabic\c@table}
  \renewcommand{\thefigure}{\thechapter-\@arabic\c@figure}
  \renewcommand{\thealgorithm}{\thechapter-\@arabic\c@algorithm}
  \makeatother
}

% Creates a eros title page
\newcommand{\erostitle}{
  \begin{titlingpage}
  \renewcommand*{\thepage}{title-\arabic{page}} % fix for PDF page label warning
  
  \fontsize{12}{14.4}\selectfont
  \noindent Department of the Interior \hfill \\
  U.S. Geological Survey \hfill
  
  \fontsize{18}{21.6}\selectfont
  \vspace{18pt}
  \vspace{18pt}
  \vspace{18pt}
  \vspace{18pt}
  \vspace{18pt}
  \textbf{\thetitle}
  \noindent
  \vfill
  \noindent
  \textbf{\version}
  
  \vspace{18pt}
  \noindent
  \textbf{\thedate}
  
  \vspace{18pt}
  \vspace{18pt}
  \vspace{18pt}
  \vspace{9pt}
  
  \noindent
  \includegraphics[width=2in]{usgs_green}
  \end{titlingpage}
}

% Creates a eros signature page
\newcommand{\erossignature}[2]{
  \thispagestyle{myheadings}
  \addtocounter{page}{1}
  \begin{center}
  \fontsize{16}{19.2}\selectfont \textbf{\thetitle} \\
  \fontsize{12}{14.4}\selectfont
  \vspace{12pt}
  \textbf{\thedate}
  \end{center}
  \vspace{12pt}
  \vspace{12pt}
  \noindent
  Approved By:\\[0.3in]
  \underline{\makebox[3in][c]{}}\\
  #1 \hspace{1.25in} Date\\
  #2 \\
  U.S. Geological Survey
  \vfill
  \begin{center}
  EROS \\ Sioux Falls, South Dakota
  \end{center}
}
