#!/usr/bin/perl
#
# Name:  pl2latex.pl
#
# Purpose:  This script extracts rows from the PARM_LIST table for
#           all relevant IAS schemas and formats the information into
#           a LaTeX longtable.
#
# Usage: pl2latex.pl > parm_list.tex

use strict;
use DBI;
use ias_db;

my %bigHash;

foreach my $ias_db_env ("IAS_DB_L8_OLITIRS")
{
    my $ias_db = $ENV{$ias_db_env};

    my ($user_id, $password) = split('/', $ias_db);

#    print $user_id . " " . $password . "\n";

    my $dbh = ias_db_ConnectToDB($user_id, $password);
    if (!$dbh)
    {
        printf __FILE__ . "," . __LINE__ . "," . $ias_db_error . "\n";
        next;
    }
    my $sql = "select PARM_NAME, OUI_VALUE, PROGRAM_VALUE from PARM_LIST";

    my $sth = $dbh->prepare($sql);
    if(!$sth)
    {
        printf "DB-ERROR:$DBI::errstr\n";
        ias_db_DisconnectFromDB($dbh, IAS_DB_DISCONNECT_COMMIT);
        next;
    }
    if(!$sth->execute())
    {
        printf "DB-ERROR:$DBI::errstr\n";
        ias_db_DisconnectFromDB($dbh, IAS_DB_DISCONNECT_COMMIT);
        next;
    }

    while(my $db_row_ref = $sth->fetchrow_hashref())
    {
        my $parm_name = $db_row_ref->{PARM_NAME};
        my $oui_value = $db_row_ref->{OUI_VALUE};
        my $program_value = $db_row_ref->{PROGRAM_VALUE};

#        printf "($user_id)($parm_name)($oui_value)($program_value)\n";

        $bigHash{$parm_name}{$oui_value} = $program_value;
    }

    ias_db_DisconnectFromDB($dbh, IAS_DB_DISCONNECT_COMMIT);
}

my @tkeys = sort(keys(%bigHash));

# Print the table header/footer information.
# (Note all literal backslashes are escaped.)
printf "%% This file is autogenerated by pl2latex.pl.\n";
printf "\\begin{longtable}{p{1.3in}|p{1.7in}|" .
       ">{\\centering}p{1.7in}}\n";
printf "\\hline\n";
printf "\\textbf{PARM\\_NAME} & \\textbf{UI\\_VALUE} & " .
       "\\textbf{PROGRAM\\_VALUE} \\nl \\hline\n";
printf "\\endfirsthead\n";
printf "\\hline\n";
printf "\\cfpp{3}{l} \\nl \\hline\n";
printf "\\textbf{PARM\\_NAME} & \\textbf{UI\\_VALUE} & " .
       "\\textbf{PROGRAM\\_VALUE} \\nl \\hline\n";
printf "\\endhead\n";
printf "\\hline \\conp{3}{r} \\nl \\hline\n";
printf "\\endfoot\n";
printf "\\multicolumn{3}{c}{} \\nl %% increase offset of caption\n";
printf "\\caption{User-to-Program Parameter Conversions} " .
       "\\label{ta:ui-prog-parms}\n";
printf "\\endlastfoot\n";

foreach my $tkey (@tkeys)
{
    my %sHash = %{$bigHash{$tkey}};

    my @skeys = sort(keys(%sHash));

    my $pstr;
    my $ostr = $tkey;
    $ostr =~ s/_/\\_\\-/g;

    printf "$ostr";

#    # If there's more than one key, append them in an array.
#    my $i = 0;
#    foreach my $skey (@skeys)
#    {
#        $i++;
#
#        if ($i == 1)
#        {
#            if ($skey eq "")
#            {
#                $ostr = " & \{\}";
#            }
#            else
#            {
#                $ostr = " & $skey";
#            }
#            if ($bigHash{$tkey}{$skey} eq "")
#            {
#                $pstr = " & \$\\ast\$";
#            }
#            else
#            {
#                $pstr = " & $bigHash{$tkey}{$skey}";
#            }
#        }
#        else
#        {
#            $ostr .= " \\\\ $skey";
#            if ($bigHash{$tkey}{$skey} eq "")
#            {
#                $pstr .= " \\\\ \$\\ast\$";
#            }
#            else
#            {
#                $pstr .= " \\\\ $bigHash{$tkey}{$skey}";
#            }
#        }
#    }
#    $ostr .= "$pstr \\nl\n";
#
#    $ostr =~ s/_/\\_\\-/g;
#    printf $ostr;

    foreach my $skey (@skeys)
    {
        if($bigHash{$tkey}{$skey} eq "")
        {
            $ostr = " & $skey & * \\nl\n";
        }
        else
        {
            $ostr = " & $skey & $bigHash{$tkey}{$skey} \\nl\n";
        }
        $ostr =~ s/_/\\_\\-/g;
        printf $ostr;
    }
}

# Print table end.
printf "\\hline\n";
printf "\\end{longtable}\n";
