
/* Standard C Includes */
#include <stdlib.h>
#include <string.h>

/* IAS Includes */
#include "ias_gcp.h"
#include "ias_logging.h"

/* Local Includes */
#include "generate_chips.h"

/*****************************************************************************
 NAME: allocate_gcp_memory

 PURPOSE: To allocate memory for GCP records and locations.

 RETURN VALUE: Type = int
    Value    Description
    -------  --------------------------
    SUCCESS  Successful completion
    ERROR    Operation failed

  NOTE: Memory is allocated for and returned in the destination GCPs

*****************************************************************************/
int allocate_gcp_memory
(
    int number_of_elements,               /* I: Number of elements */
    GENERATE_CHIPS_GCPS *destination_gcps /* O: Holds the output GCP records */
)
{
    /* Allocate memory to hold all the source GCP records and locations */
    destination_gcps->gcp_records = calloc(number_of_elements,
       sizeof(IAS_GCP_RECORD));

    if (destination_gcps->gcp_records == NULL)
    {
        IAS_LOG_ERROR("Allocating memory for GCP records");
        return ERROR;
    }

    destination_gcps->gcp_locations = calloc(number_of_elements,
        sizeof(GENERATE_CHIPS_GCP_LOCATION));

    /* Check to see that memory was allocated */
    if (destination_gcps->gcp_locations == NULL)
    {
        IAS_LOG_ERROR("Allocating memory for GCP locations");
        free(destination_gcps->gcp_records);
        destination_gcps->gcp_records = NULL;
        return ERROR;
    }
 
    return SUCCESS;
}

