
/* Standard C Includes */
#include <stdlib.h>
#include <string.h>

/* IAS Includes */
#include "ias_gcp.h"

/* Local Includes */
#include "generate_chips.h"

/*****************************************************************************
 NAME: copy_gcps_to_destination_index

 PURPOSE: To copy GCPs from a source set to the destination set starting at a
          specific location in the destination set.

 RETURN VALUE: None

*****************************************************************************/
void copy_gcps_to_destination_index
(
    GCP_VALID_FLAG_TYPE flag_value,         /* I: What to copy */
    const GENERATE_CHIPS_GCPS *source_gcps, /* I: Holds input GCP records */
    int *start_index,                       /* I/O:
        On input it is the starting index for where to copy the data
        On output it is the index after the last data element copied */
    GENERATE_CHIPS_GCPS *destination_gcps   /* O: The output GCP records */
)
{
    int source_index; /* Loop control */
    int number_of_gcps_to_copy;
    int destination_index;

    /* Local source pointer variables */
    IAS_GCP_RECORD *local_source_gcp_records;
    GENERATE_CHIPS_GCP_LOCATION *local_source_gcp_locations;

    /* Local destination pointer variables */
    IAS_GCP_RECORD *local_destination_gcp_records;
    GENERATE_CHIPS_GCP_LOCATION *local_destination_gcp_locations;

    /* Now assign to local variables */
    destination_index = *start_index;
    number_of_gcps_to_copy = source_gcps->number_of_gcps;
    local_source_gcp_records = source_gcps->gcp_records;
    local_source_gcp_locations = source_gcps->gcp_locations;
    local_destination_gcp_records = destination_gcps->gcp_records;
    local_destination_gcp_locations = destination_gcps->gcp_locations;

    /* Iterate through the source GCPs and copy the flag_value ones to the
       destination */
    for (source_index = 0;
         source_index < number_of_gcps_to_copy;
         source_index++)
    {
        /* Only copy the requested records */
        if (local_source_gcp_locations[source_index].valid_flag == flag_value)
        {
            /* The gcp_records may not be present */
            if (local_source_gcp_records != NULL)
            {
                local_destination_gcp_records[destination_index] =
                    local_source_gcp_records[source_index];
            }

            local_destination_gcp_locations[destination_index] =
                local_source_gcp_locations[source_index];

            destination_index++;
        }
    }

    *start_index = destination_index;
}

