/* Standard C Includes */
#include <sys/stat.h>
#include <errno.h>

/* IAS Includes */
#include "ias_const.h"
#include "ias_logging.h"

/*****************************************************************************
 NAME: initialize_directory

 PURPOSE: To initialize a directory or to ensure that it already exists

 RETURN VALUE: Type = int
    Value      Description
    ---------  --------------------------
    SUCCESS    Successful completion
    ERROR      Operation failed

*****************************************************************************/
int initialize_directory
(
    const char *directory      /* I: Directory to create/check */
)
{
    struct stat directory_stat; /* Holds stat's info for the directory */
    int status;                 /* Status of stat call */

    /* Verify that the output directory exists, if it doesn't then create it */
    status = stat(directory, &directory_stat); 
    if (status == 0)
    {
        if (!S_ISDIR(directory_stat.st_mode))
        {
            /* Does exist but is not a directory */
            IAS_LOG_ERROR("Directory %s already exist and is not a directory", 
                directory);
            return ERROR;
        }
    }    
    else
    {
        if (errno == ENOENT)
        {
            /* Directory does not exist so create it */
            status = mkdir(directory, 0777);
            if (status != SUCCESS)
            {
                IAS_LOG_ERROR("Creating the directory %s", directory);
                return ERROR;
            }
        }
        else  
        {
            /* Error besides does not exist error was thrown */
            IAS_LOG_ERROR("Error %d occurred while running stat for %s", 
                errno, directory);
            return ERROR;
        }    
    }
    
    return SUCCESS;
}
