
/* Standard C Includes */
#include <stdlib.h>
#include <string.h>

/* IAS Includes */
#include "ias_const.h"
#include "ias_types.h"
#include "ias_logging.h"

/* Local Includes */
#include "generate_chips.h"

/*****************************************************************************
 NAME: initialize_gcp_record

 PURPOSE: To initialize a GCP record with default values.

 RETURN VALUE: Type = int
    Value      Description
    ---------  --------------------------
    SUCCESS    Successful completion
    ERROR      Operation failed

 NOTE: This routine should only be called within a (!= GM_GCPLIB) method check

*****************************************************************************/
int initialize_gcp_record
(
    const GENERATE_CHIPS_PARAMETERS *parameters, /* I: The input parameters */
    int point_id,          /* I: The value to use for chip identification */
    IAS_GCP_RECORD *record /* O: The GCP record to initialize */
)
{
    int count; /* The number of characters written to the string */
    
    /* Add starting_id to point_id to create new chip index */
    point_id += parameters->starting_id;

    /* The size of the chip to create */
    record->chip_size_lines = parameters->chip_size_lines;
    record->chip_size_samples = parameters->chip_size_samples;

    /* Specify the chip type */
    count = snprintf(record->chip_type, sizeof(record->chip_type), "CONTROL");

    if (count < 0 || count >= sizeof(record->chip_type))
    {
        IAS_LOG_ERROR("Bounds exceeded or internal snprintf error:"
            " assigning CONTROL: count = %d", count);
        return ERROR;
    }

    /* Number the point_id */
    count = snprintf(record->point_id, sizeof(record->point_id), "%03d%03d%04d",
        parameters->target_wrs_path, parameters->target_wrs_row, point_id);

    if (count < 0 || count >= sizeof(record->point_id))
    {
        IAS_LOG_ERROR("Bounds exceeded or internal snprintf error:"
            " assigning point_id for %d%03d%04d: count = %d",
            parameters->target_wrs_path,
            parameters->target_wrs_row, point_id, count);
        return ERROR;
    }

    /* Specify the chip name */
    count = snprintf(record->chip_name, sizeof(record->chip_name), 
        "%03d%03d%04d_01", parameters->target_wrs_path, 
        parameters->target_wrs_row, point_id);

    if (count < 0 || count >= sizeof(record->chip_name))
    {
        IAS_LOG_ERROR("Bounds exceeded or internal snprintf error:"
            " assigning chip name %03d%03d%04d_01, count = %d", 
            parameters->target_wrs_path, parameters->target_wrs_row, point_id, 
            count);

        return ERROR;
    }

    return SUCCESS;
}

