
/* IAS Includes */
#include "ias_logging.h"

/* Local Includes */
#include "generate_chips.h"

/*****************************************************************************
 NAME: moravec_limit_points

 PURPOSE: Iterate through the points and set all the good points above the
          minimum number to keep to the "good but don't use" value.  Since the
          data is sorted by moravec value, this will remove all the lower
          valued points from the "good" status.  During the region check, some
          of these removed points may be added back in so that a region has
          enough points.

 RETURN VALUE: None

*****************************************************************************/
void moravec_limit_points
(
    const GENERATE_CHIPS_PARAMETERS *parameters, /* I: The input parameters */
    GENERATE_CHIPS_GCPS *gcps                    /* I/O: The picked GCPs */
)
{
    int point_index;      /* Loop control */
    int kept_point_count = 0; /* Counter for points kept */

    /* Process through the picked resolution */
    for (point_index = 0; point_index < gcps->number_of_gcps; point_index++)
    {
        /* Only process the good points */
        if (gcps->gcp_locations[point_index].valid_flag
            == GCP_VALID_FLAG_MORAVEC_GOOD)
        {
            /* Determine if we have found enough points or not */
            if (kept_point_count < parameters->points_before_region_filtering)
            {
                kept_point_count++;
            }
            else
            {
                /* Set to good but don't use */
                gcps->gcp_locations[point_index].valid_flag =
                    GCP_VALID_FLAG_MORAVEC_GOOD_DONT_USE;
            }
        }
    }
}

