#!/bin/csh

# Test that will check to make sure the call to generate_chips
# returns error on both calls below because the images that are
# being used are not coregistered 

set wrs_path = "40"
set wrs_row = "30"
set gcp_lib_file = "GCPLib.coregistered"
set gcp_lib_verify_file = "$gcp_lib_file.verify"
set parameter_file = "generate_chips_coregistered.odl"
set parameter_file2 = "generate_chips_coregistered_quality.odl"
set omf_file = "ICOREG1.omf"
set omf_file2 = "ICOREG2.omf"
set template_file = "templates/$parameter_file.template"
set template_file2 = "templates/$parameter_file2.template"
set omf_template_file = "templates/$omf_file.template"
set omf_template_file2 = "templates/$omf_file2.template"
set log_file = "test.coregistered.log"
set output_directory = "gcp_lib_coregistered"
set dump_directory = "intermediate_data_dumps_coregistered"
set remote_data_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/generate_chips"
set exit_status = "0"

# Remove directories if they exist
if (-e $output_directory) then
    rm -rf $output_directory
endif

if (-e $dump_directory) then
    rm -rf $dump_directory
endif

# Create directories we plan to use
mkdir $output_directory
mkdir $dump_directory

# Set up first parameter file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/BBBBB/$gcp_lib_file/" \
    -e "s/CCCCC/$output_directory/" \
    -e "s/FFFFF/$dump_directory/" \
    $template_file > $parameter_file 

# Set up second parameter file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/BBBBB/$gcp_lib_file/" \
    -e "s/CCCCC/$output_directory/" \
    -e "s/FFFFF/$dump_directory/" \
    $template_file2 > $parameter_file2

# Set up first omf file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/DDDDD/$wrs_path/" \
    -e "s/EEEEE/$wrs_row/" \
    $omf_template_file > $omf_file 

# Set up second omf file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/DDDDD/$wrs_path/" \
    -e "s/EEEEE/$wrs_row/" \
    $omf_template_file2 > $omf_file2

../generate_chips $parameter_file |& tee $log_file

# Make sure exit status was an error
if ($status != 1) then
    set exit_status = "1"
endif

../generate_chips $parameter_file2 |& tee $log_file

# Make sure exit status was an error
if ($status != 1) then
    set exit_status = "1"
endif

# Remove temp files
if ($1 != "save") then
    rm -f $parameter_file $parameter_file2
    rm -rf $output_directory $dump_directory
    rm -f $omf_file $omf_file2
endif

exit $exit_status

