#!/bin/csh -e

# This test will check the evenly space generation method for generate chips

set wrs_path = "40"
set wrs_row = "30"
set gcp_lib_file = "GCPLib.evenly_spaced"
set gcp_lib_verify_file = "$gcp_lib_file.verify"
set gcp_lib_verify_template_file = "templates/$gcp_lib_file.verify.template"
set parameter_file = "generate_chips_evenly_spaced.odl"
set omf_file = "IEVENLY.omf"
set template_file = "templates/$parameter_file.template"
set omf_template_file = "templates/$omf_file.template"
set log_file = "test.evenly.spaced.log"
set output_directory = "gcp_lib_evenly_spaced"
set remote_data_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/generate_chips"
set today = `date +"%m-%d-%Y"`

# Remove the directories if they exist
if (-e $output_directory) then
    rm -rf $output_directory
endif

# Replace placeholder with current date
sed -e "s/DD-DD-DDDD/$today/g" \
    $gcp_lib_verify_template_file > $gcp_lib_verify_file

# Create the directories we plan to use
mkdir $output_directory

# Replace text in the template file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/BBBBB/$gcp_lib_file/" \
    -e "s/CCCCC/$output_directory/" \
    $template_file > $parameter_file

# Replace text in the omf file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/DDDDD/$wrs_path/" \
    -e "s/EEEEE/$wrs_row/" \
    $omf_template_file > $omf_file

# Run generate_chips with odl file
../generate_chips $parameter_file |& tee $log_file

# Use regex to replace current VERSION with VERSION = 1 
sed -i "s/VERSION = [[:digit:]]\+/VERSION = 1/" $output_directory/$gcp_lib_file

# Check that GCPLib file and chip file matches.
diff -q $gcp_lib_verify_file $output_directory/$gcp_lib_file
diff -q $remote_data_dir/evenly_spaced_chip_00047 $output_directory/0400300047_01

# Clean up the directories
if ($1 != "save") then
    rm -f $parameter_file
    rm -rf $output_directory
    rm -f $gcp_lib_verify_file
    rm -f $omf_file
endif

