#!/bin/csh -e

# This test will test the implementation of the parameter
# POINTS_BEFORE_REGION_FILTERING to ensure it behave correctly.
 
set wrs_path = "163"
set wrs_row = "44"
set gcp_lib_file = "GCPLib.region.filtering"
set gcp_lib_verify_file = "$gcp_lib_file.verify"
set gcp_lib_verify_template_file = "templates/$gcp_lib_file.verify.template"
set parameter_file = "generate_chips_region_filtering.odl"
set omf_file = "IREGFILT.omf"
set template_file = "templates/$parameter_file.template"
set omf_template_file = "templates/$omf_file.template"
set log_file = "test.region_filtering.log"
set output_directory = "gcp_lib_region_filtering"
set dump_directory = "intermediate_data_dumps_region_filtering"
set envi_point_filename = "${wrs_path}_${wrs_row}.envi"
set remote_data_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/generate_chips"
set today = `date +"%m-%d-%Y"`

# Remove directories if they exist
if (-e $output_directory) then
    rm -rf $output_directory
endif

if (-e $dump_directory) then
    rm -rf $dump_directory
endif

# Replace placeholder with current date
sed -e "s/DD-DD-DDDD/$today/g" \
    $gcp_lib_verify_template_file > $gcp_lib_verify_file

# Set up directories we plan to use
mkdir $output_directory
mkdir $dump_directory

# Replace text in the template file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/BBBBB/$gcp_lib_file/" \
    -e "s/CCCCC/$output_directory/" \
    -e "s/FFFFF/$dump_directory/" \
    -e "s/GGGGG/$envi_point_filename/" \
    $template_file > $parameter_file

# Replace text in the omf file
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/DDDDD/$wrs_path/" \
    -e "s/EEEEE/$wrs_row/" \
    $omf_template_file > $omf_file

# Run generate chips with odl file
../generate_chips $parameter_file |& tee $log_file

# Use regex to replace current VERSION with VERSION = 1 
sed -i "s/VERSION = [[:digit:]]\+/VERSION = 1/" $output_directory/$gcp_lib_file

# Check that GCPLib and GCP chips match
diff -q $gcp_lib_verify_file $output_directory/$gcp_lib_file 
diff -q $remote_data_dir/region_chip_ver2_0188 $output_directory/1630440188_01

# Clean up the directories
if ($1 != "save") then
    rm -f $parameter_file
    rm -rf $output_directory $dump_directory
    rm -f $gcp_lib_verify_file
    rm -f $omf_file
endif

