#!/bin/csh -e

# Test the MORAVEC generation method of generate_chips

set wrs_path = "23"
set wrs_row = "19"
set gcp_lib_file = "GCPLib.water.mask"
set gcp_lib_verify_file = "$gcp_lib_file.verify"
set gcp_lib_verify_template_file = "templates/$gcp_lib_file.verify.template"
set parameter_file = "generate_chips_water_mask.odl"
set parameter_file2 = "generate_chips_binary_water_mask.odl"
set omf_file = "IWATERMASK.omf"
set template_file1 = "templates/$parameter_file.template"
set template_file2 = "templates/$parameter_file2.template"
set omf_template_file = "templates/$omf_file.template"
set log_file = "test.water_mask.log"
set output_directory = "gcp_lib_water_mask"
set dump_directory = "intermediate_data_dumps_water_mask"
set remote_data_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/generate_chips/water"
set today = `date +"%m-%d-%Y"`

# Run the water mask test twice. Once with the polygon file and once
# with the binary water mask. They should produce the exact same results
foreach template_file ($template_file1 $template_file2)
    # Remove the directories if they exist
    if (-e $output_directory) then
        rm -rf $output_directory
    endif

    if (-e $dump_directory) then
        rm -rf $dump_directory
    endif

    # Replace placeholder with current date
    sed -e "s/DD-DD-DDDD/$today/g" \
        $gcp_lib_verify_template_file > $gcp_lib_verify_file

    # Create the directories we plan to use
    mkdir $output_directory
    mkdir $dump_directory

    # Replace text in the template file
    sed -e "s|AAAAA|$remote_data_dir|" \
        -e "s/BBBBB/$gcp_lib_file/" \
        -e "s/CCCCC/$output_directory/" \
        -e "s/FFFFF/$dump_directory/" \
        $template_file > $parameter_file

    # Replace text in the template file
    sed -e "s|AAAAA|$remote_data_dir|" \
        -e "s/DDDDD/$wrs_path/" \
        -e "s/EEEEE/$wrs_row/" \
        $omf_template_file > $omf_file

    # Run generate_chips
    ../generate_chips $parameter_file |& tee $log_file

    # Use regex to replace current VERSION with VERSION = 1 
    sed -i "s/VERSION = [[:digit:]]\+/VERSION = 1/" $output_directory/$gcp_lib_file
    diff -q $gcp_lib_verify_file $output_directory/$gcp_lib_file

    # Clean up the directories
    if ($1 != "save") then
        rm -f $parameter_file
        rm -rf $output_directory $dump_directory
        rm -f $gcp_lib_verify_file
        rm -f $omf_file
    endif
end
