#!/bin/csh -e

# This test will check that the quality image is absent in the odl file
# and then a zero filled quality image is used in its place.

set wrs_path = "40"
set wrs_row = "30"
set gcp_lib_file = "GCPLib.zero.fill"
set gcp_lib_verify_file = "$gcp_lib_file.verify"
set gcp_lib_verify_template_file = "templates/$gcp_lib_file.verify.template"
set parameter_file = "generate_chips_zero_fill.odl"
set omf_file = "IZEROFILL.omf"
set template_file = "templates/$parameter_file.template"
set omf_template_file = "templates/$omf_file.template"
set log_file = "test.zero_fill.log"
set output_directory = "gcp_lib_zero_fill"
set dump_directory = "intermediate_data_dumps_zero_fill"
set remote_data_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/generate_chips"
set today = `date +"%m-%d-%Y"`

# Remove the directories if they exist so they can be replace with the
# version we plan to use.
if (-e $output_directory) then
    rm -rf $output_directory
endif

if (-e $dump_directory) then
    rm -rf $dump_directory
endif

# Replace placeholder with current date
sed -e "s/DD-DD-DDDD/$today/g" \
    $gcp_lib_verify_template_file > $gcp_lib_verify_file

# Create the directories we plan to use.
mkdir $output_directory
mkdir $dump_directory

# Replace the text in the template files
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/BBBBB/$gcp_lib_file/" \
    -e "s/CCCCC/$output_directory/" \
    -e "s/FFFFF/$dump_directory/" \
    $template_file > $parameter_file

# Replace the text in the omf files
sed -e "s|AAAAA|$remote_data_dir|" \
    -e "s/DDDDD/$wrs_path/" \
    -e "s/EEEEE/$wrs_row/" \
    $omf_template_file > $omf_file

# Run the test
../generate_chips $parameter_file |& tee $log_file

# Use regex to replace current VERSION with VERSION = 1 
sed -i "s/VERSION = [[:digit:]]\+/VERSION = 1/" $output_directory/$gcp_lib_file

# Check to see if file matches verification file.
diff -q $gcp_lib_verify_file $output_directory/$gcp_lib_file

# Clean up directory
if ($1 != "save") then
    rm -f $parameter_file
    rm -rf $output_directory $dump_directory
    rm -f $gcp_lib_verify_file
    rm -f $omf_file
endif

