/******************************************************************************
NAME:           get_targets.h

PURPOSE:
Include file for structure definition and associated function prototypes
for software to bridge target definition parameters.

******************************************************************************/

#ifndef GET_TARGETS_H
#define GET_TARGETS_H

#include <math.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "ias_types.h"
#include "ias_logging.h"
#include "ias_const.h"
#include "ias_satellite_attributes.h"
#include "ias_structures.h"
#include "mtf.h"

/* #define variables */
#define MAX_TARGETS       3 /* Maximum number of targets in one scene */

/* Structures */
typedef struct span
{
    double width;           /* Span width in meters */
    double offset;          /* Span offset from target centerline (meters) */
    double reflectance[IAS_MAX_NBANDS]; /* Span reflectance in each band */
} SPAN;

typedef struct polygon
{
    int number_of_vertices;  /* Number of vertices in polygon */
    IAS_DBL_XY *coordinates; /* Array of vertex coordinates */
} POLYGON;

typedef struct center_line
{
    IAS_DBL_XY start_point;
    IAS_DBL_XY end_point;
} CENTER_LINE;

typedef struct target
{
    int number_of_bands;           /* Number of bands defined in band_list */
    int band_list[IAS_MAX_NBANDS]; /* Bands defined for target */
    char target_name[NAME_STRLEN]; /* Target name */
    int number_of_spans;           /* Number of spans in bridge */
    SPAN *span;                    /* Array of span structures */
    double water[IAS_MAX_NBANDS];  /* Background reflectance in each band */
    double asymmetry[IAS_MAX_NBANDS]; /* Background asymmetry in each band */
    int number_of_polygons;        /* Number of polygons covering target */
    POLYGON *polygon;              /* Array of polygon structures */
    double height;                 /* Target elevation */
    CENTER_LINE center_line;       /* Target centerline coordinates */
} TARGET;

/* Function prototypes */
/* Load the target parameters from the input file */
int get_targets             /* Return the number of targets loaded */
(
    const char *target_file, /* I: Target parameter file name */
    TARGET target[]         /* O: Populated target structure array */
);

#endif /* GET_TARGETS_H */

