/******************************************************************************
NAME:           conversion_utilities 

PURPOSE:
A package of routines that converts between structures and arrays for the
bridge parameters, STF parameters, bridge mask, and STF mask. 

******************************************************************************/

#include "model.h"                 /* Defines model and control structures */


void convert_bridge_to_structure
(
    const double *bridge_array,    /* I: Bridge parameters to convert */
    BRIDGE_PARMS *bridge           /* O: Destination for conversion */
)
{
    int span;                      /* Span index */

    bridge->rad_water = bridge_array[RADWATER];
    bridge->rad_asym = bridge_array[RADASYM];
    bridge->gsd = bridge_array[GSD];
    for (span = 0; span < MAXSPAN; span++)
    {
        bridge->span[span].rad_bridge = bridge_array[RADBRIDGE + 3 * span];
        bridge->span[span].width = bridge_array[WIDTH + 3 * span];
        bridge->span[span].offset = bridge_array[OFFSET + 3 * span];
    }
}

void convert_stf_to_structure
(
    const double *stf_array,       /* I: STF to convert */
    STF_FD_PARMS *stf              /* O: Destination for conversion */
)
{
    stf->g_optics = stf_array[GOPTICS];
    stf->xt_detector =  stf_array[XTDETECTOR];
    stf->at_detector =  stf_array[ATDETECTOR];
    stf->integ =  stf_array[INTEG];
    stf->diffusion = stf_array[DIFFUSION];
    stf->phase = stf_array[PHASE];
}

void convert_bridge_to_array
(
    const BRIDGE_PARMS *bridge,    /* I: Bridge parameters to convert */
    double *bridge_array           /* O: Destination for conversion */
)
{
    int span;                      /* Span index */

    bridge_array[RADWATER] = bridge->rad_water;
    bridge_array[RADASYM] = bridge->rad_asym;
    bridge_array[GSD] = bridge->gsd;
    for (span = 0; span < MAXSPAN; span++)
    {
        bridge_array[RADBRIDGE + 3 * span] = bridge->span[span].rad_bridge;
        bridge_array[WIDTH + 3 * span] = bridge->span[span].width;
        bridge_array[OFFSET + 3 * span] = bridge->span[span].offset;
    }
}

void convert_stf_to_array
(
    const STF_FD_PARMS *stf,       /* I: STF to convert */
    double *stf_array              /* O: Destination for conversion */
)
{
    stf_array[GOPTICS] = stf->g_optics;
    stf_array[XTDETECTOR] = stf->xt_detector;
    stf_array[ATDETECTOR] = stf->at_detector;
    stf_array[INTEG] = stf->integ;
    stf_array[DIFFUSION] = stf->diffusion;
    stf_array[PHASE] = stf->phase;
}

void convert_bridge_mask_to_array
(
    const BRIDGE_PARMS_MASK *bridgemask, /* I: Bridge mask to convert */
    int *bridgemask_array          /* O: Destination for conversion */
)
{
    int span;                      /* Span index */

    bridgemask_array[RADWATER] = bridgemask->rad_water;
    bridgemask_array[RADASYM] = bridgemask->rad_asym;
    bridgemask_array[GSD] = bridgemask->gsd;
    for (span = 0; span < MAXSPAN; span++)
    {
        bridgemask_array[RADBRIDGE + 3 * span] 
            = bridgemask->span[span].rad_bridge;
        bridgemask_array[WIDTH + 3 * span] = bridgemask->span[span].width;
        bridgemask_array[OFFSET + 3 * span] = bridgemask->span[span].offset;
    }
}

void convert_stf_mask_to_array
(
    const STF_FD_PARMS_MASK *stfmask, /* I: STF mask to convert */
    int *stfmask_array             /* O: Destination for conversion */
)
{
    stfmask_array[GOPTICS] = stfmask->g_optics;
    stfmask_array[XTDETECTOR] = stfmask->xt_detector;
    stfmask_array[ATDETECTOR] = stfmask->at_detector;
    stfmask_array[INTEG] = stfmask->integ;
    stfmask_array[DIFFUSION] = stfmask->diffusion;
    stfmask_array[PHASE] = stfmask->phase;
}

