/******************************************************************************
NAME:           trend_fit

PURPOSE:
Genarate output trending for the MTF estimation results and send it to a 
file.  Normally the retrieve_profile.pl utility will be used to gather this 
output from the database records of all MTF runs.  However, the file output
produced by this routine can still be used to manually piece together similar 
results on a per-Work Order basis.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

******************************************************************************/

#include "get_targets.h"           /* Defines target structure */
#include "model.h"                 /* Defines model and control structures */
#include "profile.h"               /* Defines profile structure */

int trend_fit 
(
    FILE *trend_file_pointer,      /* I: Output trend file pointer */
    TARGET target,                 /* I: Current target structure */
    PROFILE profile,               /* I: Current profile structure */
    MTFMODEL model,                /* I: Best-fit model parameters */
    double rms,                    /* I: Best-fit RMS error */
    int *year_doy,                 /* I: Scene year and day of year */
    int *path_row                  /* I: Scene path and row */
)
{
    int span_index;                /* Loop counter */

    /* Write the results for the current band to the text trending file */

    /* Year, DOY, WRS Path, WRS Row, Target Name, Band number, Target
       Orientation, Gaussian Blur Parameter, Detector Dimensions, Integration
       Time, Charge Diffusion, Profile Phase, RMS Fit, GSD, Range, Velocity,
       Water Radiance, Water Asymmetry, Number of Spans */
    if (fprintf(trend_file_pointer, "%04d | %03d | %03d | %03d | %s | %d | "
        "%9.6lf | %7.4lf | %6.3lf | %6.3lf | %6.3lf | %6.3lf | %11.4e | "
        "%6.3lf | %6.3lf | %10.3lf | %8.3lf | %6.1lf | %4.1lf | %d | ",   
        year_doy[0], year_doy[1], path_row[0], path_row[1], target.target_name,
        profile.band_number, profile.angle, model.stf.g_optics, 
        model.stf.at_detector, model.stf.xt_detector, model.stf.integ, 
        model.stf.diffusion, model.stf.phase, rms, model.bridge.gsd, 
        profile.range, profile.velocity, model.bridge.rad_water, 
        model.bridge.rad_asym, target.number_of_spans) < 0)
    {
        IAS_LOG_ERROR("Writing data to trending file");
        return ERROR;
    }

    /* Span information */
    for (span_index = 0; span_index < target.number_of_spans; span_index++)
    {
        /* Span Radiance, Span Width and Span Offset */
        if (span_index < target.number_of_spans - 1)
        {
            if (fprintf(trend_file_pointer, "%6.1lf | %5.2lf | %6.2lf | ", 
                model.bridge.span[span_index].rad_bridge,
                model.bridge.span[span_index].width,
                model.bridge.span[span_index].offset) < 0)
            {
                IAS_LOG_ERROR("Writing data to trending file for span index %d",
                    span_index);
                return ERROR;
            }
        }
        else
        {
            if (fprintf(trend_file_pointer, "%6.1lf | %5.2lf | %6.2lf\n", 
                model.bridge.span[span_index].rad_bridge,
                model.bridge.span[span_index].width,
                model.bridge.span[span_index].offset) < 0)
            {
                IAS_LOG_ERROR("Writing data to trending file for span index %d",
                    span_index);
                return ERROR;
            }
        }
    }

    fflush(trend_file_pointer);

    return SUCCESS;
}
