/******************************************************************************
NAME:           free_polygons

PURPOSE:
Free the polygon structures up to the specified index.  Free all of the
polygons for all but the last target.  Also free the targets structure holding
the polygons.

RETURN VALUE: None

******************************************************************************/
#include <stdlib.h>                /* Free */

#include "mtfextract.h"            /* MTF Extract library */

void free_polygons 
(
    MTF_TARGET *targets,           /* I: Pointer to MTF targets structure */
    int number_targets             /* I: Number of targets to free */
)
{
    int target_index;              /* Current index into targets */
    int polygon_index;             /* Current index into polygons */

    /* There's nothing to free if targets is NULL */
    if (targets == NULL)
    {
        return;
    }
 
    for (target_index = 0; target_index < number_targets; target_index++)
    {
        /* There's nothing to free in this polygon if the polygon is NULL */
        if (targets[target_index].polygons == NULL)
        {
            continue;
        }

        for (polygon_index = 0; polygon_index 
            < targets[target_index].number_polygons; polygon_index++) 
        {
            /* Free all elements of the polygon */
            free(targets[target_index].polygons[polygon_index].utm_x);
            free(targets[target_index].polygons[polygon_index].utm_y);
            free(targets[target_index].polygons[polygon_index].l1g_sample);
            free(targets[target_index].polygons[polygon_index].l1g_line);
            free(targets[target_index].polygons[polygon_index].l1r_sample);
            free(targets[target_index].polygons[polygon_index].l1r_line);
            free(targets[target_index].polygons[polygon_index].sca);
        }

        /* Free the polygons */
        free(targets[target_index].polygons);
    }

    /* Free the MTF targets */
    free(targets);
}
