/******************************************************************************
NAME:           update_omf

PURPOSE:
Update the OMF file with the MTF input directory name.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

******************************************************************************/
#include <string.h>

#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "mtfextract.h"

int update_omf
(
    const char *omf_filename,      /* I: OMF filename */
    char *mtf_input_directory      /* I: MTF-specific input directory */
)
{
    int write_count;

    /* Initialize the OMF table */
    IAS_PARM_DECLARE_TABLE(omf_parms, 1);

    /* Add the MTF input directory parameter */
    IAS_PARM_MTF_INPUT_DIRECTORY(omf_parms, mtf_input_directory,
        sizeof(mtf_input_directory));
    IAS_PARM_SET_COUNT_WRITE(omf_parms, MTF_INPUT_DIRECTORY, 1);

    /* Set the number of parameters to write to the OMF */
    write_count = IAS_PARM_GET_TABLE_SIZE(omf_parms);

    /* Update the OMF file */
    if (ias_parm_update(omf_filename, omf_parms, write_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Updating OMF with MTF input directory");
        return ERROR;
    }

    return SUCCESS;
}
