/*****************************************************************************
NAME:        fit_stf.h

PURPOSE:
Include file for OLI system transfer function (STF) fit routine.
******************************************************************************/
#ifndef FIT_STF_H
#define FIT_STF_H

#include "trendrec.h"     /* defines TRENDREC */

typedef struct stf_fit_parms
{
    double xt_optics;     /* cross-track optics (urad) */
    double at_optics;     /* along-track optics (urad) */
    double xt_detector;   /* cross-track detector (urad) */
    double at_detector;   /* along-track detector (urad) */
    double integration_milliseconds; /* integration time (msec) */
    double diffusion;     /* charge diffusion (urad) */
} STF_FIT_PARMS;

/* Estimate the OLI STF parameters */
int fit_stf                  /* Return SUCCESS or ERROR */
(
    int numrec,              /* I: Number of trending records */
    const TRENDREC *trend,   /* I: Array of trending records */
    int band_number,         /* I: Current band number */
    STF_FIT_PARMS *stf_fit,  /* O: Best fit STF parameters */
    double *xt_best,         /* O: 90% range of XT optics parameter */
    double *at_best          /* O: 90% range of AT optics parameter */
);


#endif /* FIT_STF_H */

