/******************************************************************************
NAME:           mtfperform.h

PURPOSE:
Main include file for software to load and analyze OLI STF parameter sets
computed at multiple target angles to determine the best fit along- and
acorss-track STF parameters. These parameters are then used to calculate
spatial edge response performance parameters.

******************************************************************************/

#ifndef MTFPERFORM_H
#define MTFPERFORM_H

#include "report.h"         /* Defines SPATIAL */
#include "fit_stf.h"        /* Defines STF_FIT_PARMS */

/* Function prototypes */
/* Read the input processing parameters */
int get_perform_parms       /* Return SUCCESS or ERROR */
(
    const char *odlfile,    /* I: Input ODL parameter file */
    char *trend_file,       /* O: File containing trending data */
    char *report_file,      /* O: Output report file name */
    int *numbands,          /* O: Number of bands to process */
    int band_list[],        /* O: List of bands to process */
    int *nsamp,             /* O: Length of PSF (point spread function) / ESF 
                                  (edge spread function) to analyze */
    int *oversamp           /* O: PSF/ESF oversample factor */
);

/* Calculate the PSF, ESF, and spatial performance parameters */
int calc_spatial_perf       /* Return SUCCESS or ERROR */
(
    const char *output_dir, /* Output directory */
    const STF_FIT_PARMS *stf_fit, /* I: Struct of STF fit parameters */
    double gsd,             /* I: Band ground sample distance */
    double range,           /* I: Range to scale STF to ground */
    double gvel,            /* I: Velocity to scale STF to ground */
    int nsamp,              /* I: Length of PSF/ESF to analyze */
    int oversamp,           /* I: PSF/ESF oversample factor */
    double xt_best,         /* I: 90% range of XT optics parameter */
    double at_best,         /* I: 90% range of AT optics parameter */
    SPATIAL *result         /* O: Parameter results structure */
);

/* Write the modeled ESF to a CSV ASCII file */
int write_esf               /* Return SUCCESS or ERROR */
(
    const char *output_dir, /* I: output directory name */
    const char *prefix,     /* I: "XT" or "AT" */
    int band_number,        /* I: Data band number */
    int npts,               /* I: Number of points in ESF */
    const double *esf_buf   /* I: Model ESF data */
);

/* Calculate the edge slope and edge extent parameters */
int calc_spatial_stats      /* Return SUCCESS or ERROR */ 
(
    double gsd,             /* I: Ground sample distance in meters */
    int nsamp,              /* I: Length of ESF sequence */
    int oversamp,           /* I: ESF oversampling factor */
    double *esf_buf,        /* I: ESF data */
    double *edge_slope,     /* O: Edge slope */
    double *edge_extent     /* O: Edge extent */
);

#endif /* MTFPERFORM_H */
