/******************************************************************************
NAME:           report.h

PURPOSE:
Include file for structures and software to generate output spatial
performance report file.

******************************************************************************/

#ifndef REPORT_H
#define REPORT_H

#include "trendrec.h"       /* TRENDREC definition */
#include "fit_stf.h"        /* STF_FIT_PARMS definition */

/* Structures */
typedef struct spatial
{
    int band_number;        /* Band number */
    int numrec;             /* Number of observations used */
    double xt_slope;        /* Cross-track edge slope */
    double xt_extent;       /* Cross-track half edge extent */
    double at_slope;        /* Along-track edge slope */
    double at_extent;       /* Along-track half edge extent */
    double xt_slope_best;   /* Best case cross-track edge slope */
    double xt_extent_best;  /* Best case cross-track half edge extent */
    double at_slope_best;   /* Best case along-track edge slope */
    double at_extent_best;  /* Best case along-track half edge extent */

} SPATIAL;

/* Function prototypes */
/* Create and open the output report file */
int create_spatial_report   /* Return SUCCESS or ERROR */
(
    char *report_file       /* I: Name of report file to create */
);

/* Write fitted STF info to the output report file */
int report_stf              /* Return SUCCESS or ERROR */
(
    int band_number,        /* I: Current band number */
    int numrec,             /* I: Number of records used in fit */
    TRENDREC *trend,        /* I: Array of input trending records */
    STF_FIT_PARMS stf_fit   /* I: Best fit STF parameters */
);

/* Write spatial performance parameters to the output report file */
int report_performance      /* Return SUCCESS or ERROR */
(
    int nband,              /* I: Number of bands analyzed */
    SPATIAL *stats          /* I: Array of results structures */
);

/* Close out the output report file */
int  close_spatial_report();

#endif
