#!/bin/csh

set errcnt = 0
set log = "$PWD/mtfperform_check.log"
set ut_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/mtf/mtfperform"

echo "Performing unit tests" > $log

# Handle 2 "make check"s without a "make clean" in the middle
set cleanup_files = "AT_ESF_Band3.csv AT_ESF_Band5.csv AT_ESF_Band6.csv AT_ESF_Band7.csv AT_ESF_Band8.csv XT_ESF_Band3.csv XT_ESF_Band5.csv XT_ESF_Band6.csv XT_ESF_Band7.csv XT_ESF_Band8.csv"

# Cleanup files from any previous run
foreach f ( $cleanup_files ) 
    if ( -f $f ) then
        rm $f 
    endif
end

# run the unit tests on the mtfperform functions
./mtfperform_unit_tests >>& $log
if ( $status != 0 ) then
    @ errcnt++
    echo mtfperform_unit_tests failed!
else
   foreach f ( *.csv *.txt )
       diff -q $f $ut_dir/output_from_unit_tests/$f
       if ( $status != 0 ) then
           @ errcnt++
           echo $f and $ut_dir/output_from_unit_tests/$f difference failed!
       endif
   end
endif

if ( -e ../mtfperform == 0 ) then
    cd ..
    make mtfperform
    cd tests
endif 

# run the actual mtfperform on sample input 
echo "Running mtfperform" >>& $log

cp $ut_dir/input/mtfestimate_trend.dat .
../mtfperform $ut_dir/input/MTFPERFORM_2.odl >>& $log
if ( $status != 0 ) then
   @ errcnt++
   echo mtfperform failed!
else
   set check_files = "AT_ESF_Band1.csv AT_ESF_Band2.csv AT_ESF_Band3.csv AT_ESF_Band4.csv AT_ESF_Band5.csv AT_ESF_Band6.csv AT_ESF_Band7.csv AT_ESF_Band8.csv XT_ESF_Band1.csv XT_ESF_Band2.csv XT_ESF_Band3.csv XT_ESF_Band4.csv XT_ESF_Band5.csv XT_ESF_Band6.csv XT_ESF_Band7.csv XT_ESF_Band8.csv mtf_performance.rpt"

   foreach f ( $check_files )
       diff -q $f $ut_dir/output_expected/$f
       if ( $status != 0 ) then
           @ errcnt++
           echo $f and $ut_dir/output_expected/$f difference failed!
       endif
   end
endif

if ( $errcnt == 0 ) then
   echo mtfperform tests PASS

   # Cleanup files
   foreach f ( $cleanup_files ) 
       if ( -f $f ) then
           rm $f 
       endif
   end
else
   echo mtfperform FAILED, check $log 
endif


exit($errcnt)
 
