/******************************************************************************
NAME:           trendrec.h

PURPOSE:
Include file for structure definition and associated function prototypes
for MTF trending record manipulation.

******************************************************************************/

#ifndef TRENDREC_H
#define TRENDREC_H

#include "mtf.h"        /* Defines NAME_STRLEN */
#include "model.h"      /* Definition of MAXSPAN */
#include "ias_const.h"  /* IAS constants */

/* #define variables */
#define RECLEN 512      /* Trending record max length */
#define TREND_EOF -3    /* Encountered end of file */

/* Structures */
typedef struct span
{
    double reflect;     /* Span reflectance in this band */
    double width;       /* Span width in meters */
    double offset;      /* Span offset from target centerline (meters) */
} SPAN;

typedef struct trendrec
{
    char work_order_id[IAS_WORKORDER_ID_LENGTH]; /* Work order ID string */
    int year;           /* Scene acquisition year */
    int doy;            /* Scene acquisition day of year */
    int wrs_path;       /* Target WRS path */
    int wrs_row;        /* Target WRS row */
    char target_name[NAME_STRLEN]; /* Target name */
    int band_number;    /* Band number for current record */
    double angle;       /* Target orientation angle (radians) */
    double optics;      /* Gaussian blur parameter (urad) */
    double atdetector;  /* Along-track detector parameter (urad) */
    double xtdetector;  /* Across-track detector parameter (urad) */
    double inttime;     /* Integration time parameter (msec) */
    double diffuse;     /* Charge diffusion parameters (urad) */
    double phase;       /* Target phase (in meters) */
    double rms;         /* RMS fit statistic */
    double gsd;         /* Image GSD (in meters) */
    double range;       /* Target range (in meters) */
    double velocity;    /* Target velocity (in meters/second) */
    double water;       /* Background reflectance in this band */
    double asym;        /* Background asymmetry in this band */
    int nspan;          /* Number of spans in bridge target */
    SPAN span[MAXSPAN]; /* Array of span structures */
} TRENDREC;

/* Function prototypes */

int get_trend_band      /* Return number of trending records */
(
    char *trend_file,   /* I: Trending file name */
    int band_number,    /* I: Band number to retrieve */
    TRENDREC **trend    /* O: Array of trending records */
);

#endif
