#!/bin/csh

set errcnt = 0
set log = "$PWD/mtfprofile_check.log"
set ut_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/mtf/mtfprofile"
set template_file = "$ut_dir/input/I10.omf"
set parameter_file = "I10.omf"
echo "Performing unit tests" > $log

# copy input data to the current directory
cp $ut_dir/input/Tar*.dat .

# copy OMF to the current directory after replacing path
sed -e "s|AAAAAA|$ut_dir|" $template_file > $parameter_file

# run the unit tests on the mtfprofile functions
./mtfprofile_unit_tests >>& $log
if ( $status != 0 ) then
    @ errcnt++
    echo mtfprofile_unit_tests failed!
else
    # check the output files created from unit tests
    echo "Differencing update_omf_test.omf" >>& $log
    diff -q update_omf_test.omf $ut_dir/output_expected/update_omf_test.omf >>& $log
    if ( $status != 0 ) then
        @ errcnt++
        echo update_omf_test.omf failed!
    endif

    echo "Differencing Profile_Tar9900Band99.odl" >>& $log
    diff -q Profile_Tar9900Band99.odl $ut_dir/output_expected/Profile_Tar9900Band99.odl >>& $log
    if ( $status != 0 ) then
        @ errcnt++
        echo Profile_Tar9900Band99.odl failed!
    endif
endif

# run the actual mtfprofile on sample input 
echo "Running mtfprofile" >>& $log

../mtfprofile $ut_dir/input/MTFPROFILE_1.odl >>& $log
if ( $status != 0 ) then
    @ errcnt++
    echo mtfprofile failed!
else
    # now check the mtfprofile output
    pushd $ut_dir/input >>& $log
    foreach f ( Profile_Tar*.odl )
       echo "Differencing $f" >>& $log
       diff -q $f ../output_expected/$f >>& $log
        if ( $status != 0 ) then
            @ errcnt++
            echo $f failed!
        endif
    end
    popd >>& $log
endif
  
if ( $errcnt == 0 ) then
   echo mtfprofile tests PASS
else
   echo mtfprofile FAILED, check $log 
endif

exit($errcnt) 

