/******************************************************************************
NAME:           update_omf

PURPOSE:
Update the OMF file with the MTF Target definition file.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

******************************************************************************/
#include <string.h>
#include <limits.h>

#include "mtfprofile.h"
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"

int update_omf
(
    const char *omf_filename,   /* I: OMF filename */
    char *mtf_target_file       /* I: MTF-specific target definition file */
)
{
    int write_count;
    int status;

    if ((omf_filename == NULL) || (mtf_target_file == NULL))
    {
        IAS_LOG_ERROR("Input OMF and MTF Target filename strings must be set");
        return ERROR;
    }

    /* Initialize the OMF table */
    IAS_PARM_DECLARE_TABLE(omf_parms, 1);

    IAS_PARM_ADD_STRING(omf_parms, MTF_TARGET_DESCRIPTION_FILENAME, "MTF "
                        "target description file", IAS_PARM_REQUIRED, 0, NULL,
                        0, NULL, mtf_target_file, PATH_MAX, 1);

    IAS_PARM_SET_COUNT_WRITE(omf_parms, MTF_TARGET_DESCRIPTION_FILENAME, 1);

    /* Set the number of parameters to write to the OMF */
    write_count = IAS_PARM_GET_TABLE_SIZE(omf_parms);

    /* Update the OMF file */
    status = ias_parm_update(omf_filename, omf_parms, write_count);
    if (status != SUCCESS)
    {
        IAS_LOG_ERROR("Updating OMF with MTF Target Defininition File");
        return ERROR;
    }

    return SUCCESS;
}
