/******************************************************************************
NAME:           process_odl_error

PURPOSE:
Process the error status returned from ias_odl_get_field

RETURN VALUE: None

******************************************************************************/
#include <string.h>                /* strcpy */

#include "ias_logging.h"           /* IAS logging library */
#include "ias_odl.h"               /* IAS ODL library */

void process_odl_error 
(
    int status,                    /* I: Error status from IAS ODL library */
    char *field_name,              /* I: Name of ODL field with the error */
    char *source_file              /* I: ODL-format source file */ 
)
{
    const char *errString;

    if (status == IAS_ODL_NOT_ENOUGH_MEMORY_SUPPLIED)
        errString = "not enough memory available";
    else if (status == IAS_ODL_NOT_FOUND)
        errString = "requested object not found";
    else if (status == IAS_ODL_INVALID_DATA_TYPE)
        errString = "data type mismatch";
    else
        errString = "unknown ODL error encountered";

    IAS_LOG_ERROR("Getting %s parameter from %s, status = %s", field_name,
        source_file, errString);
}

