#ifndef SELECT_CONTROL_GCPS_H
#define SELECT_CONTROL_GCPS_H

/* Standard Library Includes */
#include <limits.h>

/* IAS Library Includes */
#include "ias_gcp.h"

/*****************************************************************************
NAME:           select_control_gcps.h

******************************************************************************/
int fill_in
(
    int num_gcps,             /* I: Number of chips */
    int num_hull_points,      /* I: Number of points in convex hull */
    int max_control,          /* I: Max number of control points */
    double percentage_control,/* I: Percentage of control points */
    int *hull_points,         /* I/O: Array of indexes into hull for gcp_hull */
    IAS_GCP_RECORD *gcp_hull, /* I/O: Chip structure */
    int *num_control_gcps     /* O: Number of points designated as control */
);

void convex_hull_area
(
    const IAS_GCP_RECORD *gcp_hull,/* I: Chip structure */
    const int *hull_points,    /* I: Array of indexes into hull for gcp_hull */
    int num_points,            /* I: Number of points in convex hull */
    double *hull_area          /* O: Area of convex hull */
);   

int convex_hull
( 
    int num_gcps,             /* I: Number of chips */
    int max_control,          /* I: Maximum number of control points. */
    int min_control,          /* I: Minimum number of control points. */
    IAS_GCP_RECORD *gcp_hull, /* I/O: Chip structure */
    int *num_control_gcps,    /* O: Number of points designated as control */
    int *hull_points,         /* O: Array of indexes into hull for gcp_hull */
    double *hull_area         /* O: Area of convex hull */
);

/* Parameters structure used throughout select_control_gcps */
typedef struct select_control_gcps_parameters
{
    char gcplib_filename[PATH_MAX];     /* Input GCPLib */
    int wrs_path;		                /* WRS Path */
    int wrs_row;		                /* WRS Row */
    int max_control; /* Maximum number of control points selected */
    int min_control; /* Minimum number of control points selected */    
    double percentage_control; /* Percetage of control points to select */
    char gcplib_out_filename[PATH_MAX]; /* Ouput GCPLib */
    int generate_hull_file;             /* Ouput hull filename */
} SELECT_CONTROL_GCPS_PARAMETERS;
  
int get_parameters
(
    const char *filename,                       /* I: Parameter Filename */
    SELECT_CONTROL_GCPS_PARAMETERS *parameters  /* O: Parameters struct */
);

#endif
