#!/bin/csh -f

# Setting up the directories
set SUCCESS = 0
set ERROR = 1
set exit_status = $SUCCESS 

# Setting up Tests, OMFs, and DIFF
set TESTS = ("043031" "040030" "040030_all_control" "001011")
set DIFF = ("GCPLib.043031 GCPLib.verify" "GCPLib.040030 GCPLib.verify" \
    "GCPLib.040030 GCPLib.verify" "GCPLib.001011 GCPLib.verify")

# Starting the select_control_gcps testing
echo "Running select_control_gcps tests" 

foreach i (1 2 3 4)

    cd $TESTS[$i]

    # Running select control gcps
    ../../select_control_gcps select.odl 

    # Checking completion status
    if ($status != $SUCCESS) then
        echo "-- Error: select_control_gcps test $TESTS[$i] did not exit cleanly" 
        set exit_status = $ERROR
    else
        echo "-- select_control_gcps test $TESTS[$i] ran successfully." 
    endif

    # Starting the library diff testing
    echo "Checking if the library files match." 

    # Running diff
    diff $DIFF[$i] 

    # Checking completion status
    if ($status != $SUCCESS) then
        echo "-- Error: GCPLib files $DIFF[$i] does not match" 
        set exit_status = $ERROR
    else
        echo "-- Library files $DIFF[$i] matched." 
    endif
    
    # Remove testing files
    if ($1 != 'save') then
        echo "Removing test files " 
        rm -f GCPLib.040030 GCPLib.043031 h040030.hull.dat h001011.hull.dat  \
            GCPLib.001011
        echo "--rm -f GCPLib.040030  h040030.hull.dat GCPLib.043031 "\
            "h001011.hull.dat GCPLib.001011" 
    endif

    cd ..
end


# Setting up the log footer
echo "Testing has completed and exited with status ${exit_status}" 

exit $exit_status
