/*****************************************************************************
NAME:           test_get_parameters.c

PURPOSE: The purpose is to test the functionality of the get_odl_parameters
		 routine. It will test the correct functionality along with the 
		 incorrect functionality of the routine. It is tested again in the
		 main test routine to ensure it behaves properly.


RETURN VALUE:   Type = char
Value             Description
-----             -----------
test passed       Testing Succeeded
test failed       Testing Failed
******************************************************************************
                Landsat Image Assessment System (IAS) Software
                        Property of the U.S. Government
                                NASA/GSFC/EDC
*****************************************************************************/
#include <limits.h>
#include <string.h>

#include "cgreen/cgreen.h"
#include "select_control_gcps.h"
#include "ias_const.h"
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"

char *test_file_one;
char *test_file_two;
char *test_file_three;

/*-----Checking to see if parameters are correct */
Ensure get_parameters_test
(
)
{
    SELECT_CONTROL_GCPS_PARAMETERS parameters; /* Parameters Structure */
    
    /* Read parameter file */ 
    assert_equal(get_parameters(test_file_one, &parameters), SUCCESS);

    /* Checking GCP Lib parameter */
    assert_string_equal(parameters.gcplib_filename, "GCPLib.org");

    /* Checking WRS Path parameter */
    assert_equal(parameters.wrs_path, 24);
   
    /* Checking WRS Row parameter */
    assert_equal(parameters.wrs_row, 38);
   
    /* Checking Max Control parameter */
    assert_equal(parameters.max_control, 300);
   
    /* Checking Min control parameter */
    assert_equal(parameters.min_control, 200);
   
    /* Checking Percentage Control parameter */
    assert_equal(parameters.percentage_control, .6);
    
    /* Checking GCP Lib output filename parameter */
    assert_string_equal(parameters.gcplib_out_filename, "GCPLib.new");

    /* Checking Generate hull file parameter */
    assert_equal(parameters.generate_hull_file, 1);

    /* Disable output messages for errors */ 
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
 
    /* Read parameter file which should return error because the file 
       should not exist */ 
    assert_equal(get_parameters(test_file_two, &parameters), ERROR);

    /* Read parameter file which should return error because the file 
       is missing a required parameter */ 
    assert_equal(get_parameters(test_file_three, &parameters), ERROR);

    /* Disable output messages for errors */ 
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

}

int main 
(
    int argc,
    char **argv
)
{
    TestSuite *suite;
    test_file_one = "./odl/select_control_gcps.odl";
    test_file_two = "does_not_exist.odl";
    test_file_three = "./odl/select_control_gcps_missing_param.odl";

    suite = create_test_suite();
    add_test(suite, get_parameters_test);

    if (argc > 1)
    {
        return run_single_test(suite, argv[1], create_text_reporter());
    }

    return run_test_suite(suite, create_text_reporter());
}
