#!/bin/sh

# This wrapper calls the Sensor Alignment tool, setting up various required
# parameters.  It also enforces use of manually entered usernames and 
# passwords rather than environment variables for login.

command_line_choice="FALSE" # Are we processing the -c (command line) option? 
command_line_on="FALSE" # Is the command line option a "Y" (for yes)?

# Scan the command line options looking for a -c, followed by a "Y", which is
# the instruction to Sensor Alignment to run in command line mode instead of 
# GUI mode.  -c is for "command line mode"; y is for "YES".
for i in $*
do
    # If we just found a -c, we can now check if the next parameter is a "Y"
    if [ $command_line_choice == "TRUE" ]; then
        if [ $i == "Y" ]; then
            command_line_on="TRUE"
        fi
    fi
    if [ $i == "-c" ]; then
        command_line_choice="TRUE"
    else
        # Turn it off again; it's only good for the single selection after -c
        command_line_choice="FALSE"
    fi
done

# If the command line mode isn't being used, unset the PROD database login 
# environment variable to force the user to type their login/password in the 
# GUI
if [ $command_line_on != "TRUE" ]; then 
    unset IAS_DB_L8_OLITIRS
fi

java -Dlog4j.configuration=.sensor_alignment.properties \
-Doracle.net.tns_admin=$TNS_ADMIN \
-Djava.util.logging.config.class=gov.usgs.ias.gui.common_library.RouteToLog4jConfig \
-cp "$HOME:$IAS_JAVA_LIB/SensorAlignment.jar:$IAS_JAVA_LIB/ias.jar:$JAVA_LIB/ojdbc/ojdbc5.jar:/$JAVA_LIB/jboss/log4j.jar" \
sensor_alignment.SensorAlignment $*

