package sensor_alignment;

/**
 * Display the GUI screen that shows the alignment results.  Manage the
 * user selections for saving those results to file and database
 */

import gov.usgs.ias.gui.common_library.SaveDialog;
import javax.swing.JDialog;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.WindowEvent;
import java.awt.BorderLayout;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JOptionPane;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import javax.swing.JLabel;
import java.io.File;
import java.io.IOException;
import java.text.DateFormat;
import java.text.DecimalFormat;

public class SensorAlignmentResultsDialog extends JDialog implements 
    ActionListener
{
    private boolean saveToDatabaseFlag = false; // Initialize flag to no save
    private String defaultReportFileName = "sensor_alignment.rpt"; // This
                         // changes to the previous user choice
    private SensorAlignment application; // This application
    private Results res; // local results ActionPerformed can see

    static final long serialVersionUID = 0; // Get rid of a compiler warning

    /**
     * Build the user interface elements of the initial results display screen
     */
    public SensorAlignmentResultsDialog
    (
        boolean saveToDatabase, // I: Flag for saving data to the database
        Results ResultSet // I: Results to write to report files and the DB
    )
    {
        super();
        JPanel mainPanel; // Main panel for the window
        JPanel buttonPanel; // Panel for the buttons
        JButton saveResultsButton; // Button to save results to file/DB
        JButton closeButton; // Button to close the window
        JLabel dateRangeLabel;
        JLabel dateRangeStartLabel;
        JLabel dateRangeStartTextLabel;
        JLabel dateRangeEndLabel;
        JLabel dateRangeEndTextLabel; 
        JLabel alignmentAnglesLabel; 
        JLabel numScenesLabel;
        JLabel doqWeightLabel; 
        JLabel glsWeightLabel; 
        JLabel numScenesResultLabel;
        JLabel doqWeightResultLabel; 
        JLabel glsWeightResultLabel; // All of the labels in this section 
        JLabel rollLabel;            // are just the subset of the report 
        JLabel pitchLabel;           // file data displayed on the screen 
        JLabel yawLabel; 
        JLabel RMSalignmentAnglesLabel; 
        JLabel alignmentMatrixLabel; 
        JLabel rollResultLabel; 
        JLabel pitchResultLabel; 
        JLabel yawResultLabel; 
        JLabel RMSrollResultLabel; 
        JLabel RMSpitchResultLabel; 
        JLabel RMSyawResultLabel; 
        JLabel alignmentMatrixResult00Label; 
        JLabel alignmentMatrixResult01Label; 
        JLabel alignmentMatrixResult02Label; 
        JLabel alignmentMatrixResult10Label; 
        JLabel alignmentMatrixResult11Label; 
        JLabel alignmentMatrixResult12Label; 
        JLabel alignmentMatrixResult20Label; 
        JLabel alignmentMatrixResult21Label; 
        JLabel alignmentMatrixResult22Label; 
        JLabel dateRangeSpaceLabel; 
        JLabel alignmentAnglesSpaceLabel; 
        JLabel alignmentMatrixSpaceLabel; 

        setLayout(new BorderLayout());
        setSize(800, 350);
        setTitle("Sensor Alignment - Results Dialog");

        // Allow ActionPerformed to see results fields and saveToDatabase flag
        res = ResultSet;
        saveToDatabaseFlag = saveToDatabase;

        mainPanel = new JPanel();
        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints gbc = new GridBagConstraints();
        mainPanel.setLayout(gridbag);

        // Set up labels to take up vertical space
        dateRangeSpaceLabel = new JLabel(" ");
        alignmentAnglesSpaceLabel = new JLabel(" ");
        alignmentMatrixSpaceLabel = new JLabel(" ");

        // Set up date range display, converting Dates to a presentable format
        DateFormat dateFormatter;
        dateRangeLabel = new JLabel("CPF Effective Date Range");
        dateRangeStartLabel = new JLabel("Start:");
        dateRangeEndLabel = new JLabel("End:");
        dateFormatter = DateFormat.getDateInstance(DateFormat.DEFAULT);
        dateRangeStartTextLabel = new JLabel(dateFormatter.format(
            res.effectiveStartDate));  
        dateRangeEndTextLabel = new JLabel(dateFormatter.format(
            res.effectiveEndDate)); 

        gbc.ipadx = 10; // Use this for all components

        gbc.gridx = 0;
        gbc.gridy = 0;
        gbc.gridwidth = 1;
        gbc.anchor = GridBagConstraints.LINE_START;
        mainPanel.add(dateRangeSpaceLabel, gbc);
        gbc.gridx = 0;
        gbc.gridy = 1;
        gbc.gridwidth = 2;
        gbc.anchor = GridBagConstraints.EAST;
        gbc.ipady = 10; // Use this for all headings 
        mainPanel.add(dateRangeLabel, gbc);
        gbc.ipady = 0; // Turn off the heading horizonal pad 
        gbc.gridx = 0;
        gbc.gridy = 2;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(dateRangeStartLabel, gbc);
        gbc.gridx = 1;
        gbc.gridy = 2;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(dateRangeStartTextLabel, gbc);
        gbc.gridx = 0;
        gbc.gridy = 3;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(dateRangeEndLabel, gbc);
        gbc.gridx = 1;
        gbc.gridy = 3;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(dateRangeEndTextLabel, gbc);

        // Set up the number of scenes display
        numScenesLabel = new JLabel("Number Scenes Processed:");
        numScenesResultLabel = new JLabel(Integer.toString(
            res.rollPrimes.length));

        gbc.gridx = 2;
        gbc.gridy = 1;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(numScenesLabel, gbc);
        gbc.gridx = 3;
        gbc.gridy = 1;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_START;
        mainPanel.add(numScenesResultLabel, gbc);

        // Set up the control type weight display 
        doqWeightLabel = new JLabel("DOQ Scene Weight:"); 
        glsWeightLabel = new JLabel("GLS Scene Weight:"); 
        doqWeightResultLabel = new JLabel(Integer.toString(res.doqWeight));
        glsWeightResultLabel = new JLabel(Integer.toString(res.glsWeight));

        gbc.gridx = 2;
        gbc.gridy = 2;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(doqWeightLabel, gbc);
        gbc.gridx = 3;
        gbc.gridy = 2;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_START;
        mainPanel.add(doqWeightResultLabel, gbc);
        gbc.gridx = 2;
        gbc.gridy = 3;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(glsWeightLabel, gbc);
        gbc.gridx = 3;
        gbc.gridy = 3;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_START;
        mainPanel.add(glsWeightResultLabel, gbc);

        // Set up a decimal format for the alignment angle screen entries
        DecimalFormat alignmentAngleFmt = new DecimalFormat("########0.000");

        // Set up the alignment angles display
        alignmentAnglesLabel = new JLabel("Estimated Alignment Angles");
        rollLabel = new JLabel("Roll:");
        pitchLabel = new JLabel("Pitch:");
        yawLabel = new JLabel("Yaw:");
        rollResultLabel = new JLabel(alignmentAngleFmt.format(
            res.rollAlignmentEstimate));
        pitchResultLabel = new JLabel(alignmentAngleFmt.format(
            res.pitchAlignmentEstimate));
        yawResultLabel = new JLabel(alignmentAngleFmt.format(
            res.yawAlignmentEstimate));

        gbc.gridx = 0;
        gbc.gridy = 4;
        gbc.gridwidth = 1; 
        mainPanel.add(alignmentAnglesSpaceLabel, gbc);
        gbc.gridx = 0;
        gbc.gridy = 5;
        gbc.gridwidth = 2; 
        gbc.anchor = GridBagConstraints.EAST;
        gbc.ipady = 10; // Use this for all headings 
        mainPanel.add(alignmentAnglesLabel, gbc);
        gbc.ipady = 0; // Turn off the heading horizonal pad 
        gbc.gridx = 0;
        gbc.gridy = 6;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(rollLabel, gbc);
        gbc.gridx = 1;
        gbc.gridy = 6;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(rollResultLabel, gbc);
        gbc.gridx = 0;
        gbc.gridy = 7;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(pitchLabel, gbc);
        gbc.gridx = 1;
        gbc.gridy = 7;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(pitchResultLabel, gbc);
        gbc.gridx = 0;
        gbc.gridy = 8;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.LINE_END;
        mainPanel.add(yawLabel, gbc);
        gbc.gridx = 1;
        gbc.gridy = 8;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(yawResultLabel, gbc);

        // Set up the RMS alignment angles display
        RMSalignmentAnglesLabel = new JLabel("RMS Alignment Fit Residuals");
        RMSrollResultLabel = new JLabel(alignmentAngleFmt.format(res.rollRms));
        RMSpitchResultLabel = new JLabel(alignmentAngleFmt.format(
            res.pitchRms));
        RMSyawResultLabel = new JLabel(alignmentAngleFmt.format(res.yawRms));

        gbc.gridx = 1;
        gbc.gridy = 5;
        gbc.gridwidth = 2; 
        gbc.anchor = GridBagConstraints.EAST;
        gbc.ipady = 10; // Use this for all headings 
        mainPanel.add(RMSalignmentAnglesLabel, gbc);
        gbc.ipady = 0; // Turn off the heading horizonal pad 
        gbc.gridx = 2;
        gbc.gridy = 6;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(RMSrollResultLabel, gbc);
        gbc.gridx = 2;
        gbc.gridy = 7;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(RMSpitchResultLabel, gbc);
        gbc.gridx = 2;
        gbc.gridy = 8;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(RMSyawResultLabel, gbc);

        // Set up a decimal format for the alignment matrix screen entries
        DecimalFormat alignmentMatrixFmt = new DecimalFormat("0.000000000");

        // Set up the alignment matrix display
        alignmentMatrixLabel = new JLabel("ACS to OLI Reference Alignment " +
            "Matrix");
        alignmentMatrixResult00Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[0][0]));
        alignmentMatrixResult01Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[0][1]));
        alignmentMatrixResult02Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[0][2]));
        alignmentMatrixResult10Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[1][0]));
        alignmentMatrixResult11Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[1][1]));
        alignmentMatrixResult12Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[1][2]));
        alignmentMatrixResult20Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[2][0]));
        alignmentMatrixResult21Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[2][1]));
        alignmentMatrixResult22Label = new JLabel(alignmentMatrixFmt.format(
            res.alignmentMatrix[2][2]));

        gbc.gridx = 0;
        gbc.gridy = 9;
        gbc.gridwidth = 1; 
        gbc.weightx = 0.5; // This is used for the whole column
        mainPanel.add(alignmentMatrixSpaceLabel, gbc);
        gbc.gridx = 1;
        gbc.gridy = 10;
        gbc.gridwidth = 2; 
        gbc.weightx = 0.5; // This is used for the whole column
        gbc.ipady = 10; // Use this for all headings 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixLabel, gbc);
        gbc.ipady = 0; // Turn off the heading horizonal pad 
        gbc.gridx = 1;
        gbc.gridy = 11;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult00Label, gbc);
        gbc.gridx = 2;
        gbc.gridy = 11;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult01Label, gbc);
        gbc.gridx = 3;
        gbc.gridy = 11;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult02Label, gbc);
        gbc.gridx = 1;
        gbc.gridy = 12;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult10Label, gbc);
        gbc.gridx = 2;
        gbc.gridy = 12;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult11Label, gbc);
        gbc.gridx = 3;
        gbc.gridy = 12;
        gbc.gridwidth = 1; 
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult12Label, gbc);
        gbc.gridx = 1;
        gbc.gridy = 13;
        gbc.gridwidth = 1; 
        gbc.weightx = 0.2; // This is used for the whole column
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult20Label, gbc);
        gbc.gridx = 2;
        gbc.gridy = 13;
        gbc.gridwidth = 1; 
        gbc.weightx = 0.2; // This is used for the whole column
        gbc.anchor = GridBagConstraints.EAST;
        mainPanel.add(alignmentMatrixResult21Label, gbc);
        gbc.gridx = 3;
        gbc.gridy = 13;
        gbc.gridwidth = 1; 
        gbc.weightx = 0.2; // This is used for the whole column
        mainPanel.add(alignmentMatrixResult22Label, gbc);

        // Set up the Save Results and Close buttons
        buttonPanel = new JPanel();
        
        saveResultsButton = new JButton("Save Results");
        saveResultsButton.setMnemonic(KeyEvent.VK_S);
        if (saveToDatabaseFlag)
        {
            saveResultsButton.setToolTipText("Save Alignment Parameters to "
                + "Reports and Database");
        }
        else
        {
            saveResultsButton.setToolTipText("Save Alignment Parameters to "
                + "Reports");
        }
        saveResultsButton.addActionListener(this);
        buttonPanel.add(saveResultsButton);
        
        closeButton = new JButton("Close");
        closeButton.setMnemonic(KeyEvent.VK_C);
        closeButton.setToolTipText("Close Dialog Box");
        closeButton.addActionListener(this);
        buttonPanel.add(closeButton);
        
        add(mainPanel,BorderLayout.NORTH);
        add(buttonPanel,BorderLayout.SOUTH);
    }

    // method to handle the windowClosing event
    //-----------------------------------------
    public void windowClosing(WindowEvent e)  {    }

    // dummy window event handlers for events that do not need handling
    //-----------------------------------------------------------------
    public void windowActivated(WindowEvent e) { }
    public void windowClosed(WindowEvent e) { }
    public void windowDeactivated(WindowEvent e) { }
    public void windowDeiconified(WindowEvent e) { }
    public void windowIconified(WindowEvent e) { }
    public void windowOpened(WindowEvent e) { }
    
    /**
     * Action performed event handler responds to user actions
     */
    public void actionPerformed(ActionEvent e) 
    {
        String command = e.getActionCommand();

        if (command.equals("Close"))
        {
            setVisible(false);
        }
        else if (command.equals("Save Results"))
        {
            // Get the report file name from the user
            String newReportFileName = SaveDialog.SaveAs(application, 
                defaultReportFileName);

            // Use the most recent user choice as the next default
            defaultReportFileName = newReportFileName;

            if (newReportFileName != null)
            {
                // Convert the report file name string to a File
                File reportFile = new File(newReportFileName);

                // Save Results to the report file
                try 
                {
                    res.writeSensorAlignmentReports(reportFile);
                } 
                catch (IOException ex) 
                {
                    JOptionPane.showMessageDialog(application,
                        "Could not save results to the report file: "
                        + ex.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
                }
            }

            if (saveToDatabaseFlag)
            {
                // Save results to the database
                try 
                {
                    res.saveToDatabase();
                } 
                catch (Exception ex) 
                {
                    JOptionPane.showMessageDialog(application,
                        "Could not save results to the database: "
                        + ex.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
                }
            }
        }
    }
}

