#!/bin/csh -f
################################################################################
# Name: distribute_estimated_tirs_ssm_position_file.csh
#
# Description: Calls the dump_estimated_tirs_ssm_position script to dump the
#   entire set of estimated SSM positions to a file. This file is then copied
#   to a location making it available to the Landsat website. This location is
#   supplied as a command line parameter
#
# Usage:
#   distribute_estimated_tirs_ssm_position_file.csh location
################################################################################

set prog = $0
if ( $#argv < 1 ) then
    echo "Usage $prog target_location_to_distribute"
    echo "   target_location is the directory to copy the file to.  If the"
    echo "   file needs to be copied to a different server, provide the target"
    echo "   in host:directory format for scp to use"
    exit 1
endif

# Read in copy location from command line
set copy_location = $1

# Output file from dump script is hardcoded
set dump_file = "l8_tirs_estimated_ssm_position.txt"

# Call dump script. We want the entire set of active estimated SSM positions
$IAS_BIN/dump_estimated_tirs_ssm_positions.pl --output_file=$dump_file --quiet
if ( $status != 0 ) then
    echo "Errors calling the dump script"
    exit 1
endif

# Copy the dump file to the specified location using scp in case the target
# location is on a different server
scp -q $dump_file $copy_location
if ( $status != 0 ) then
    echo "ERROR: Unable to copy output file $dump_file to location " \
        "$copy_location"
    exit 1
endif

# Remove the local dumped file so it doesn't clutter up the disk.  Don't bother
# checking for success since it shouldn't fail and if it does it isn't a big
# concern.
rm -f $dump_file

exit 0
