
class DatabaseObjects():
    """ DatabaseObjects provides a mechanism for defining the names of the
        database objects used.  The reason for encapsulating this information
        in a separate class is to allow the unit tests to redirect the scripts
        to different database objects for testing.
    """
    _db_objects = {"mode_switch_events_table": "TIRS_SSM_MODE_SWITCH_EVENTS",
                   "position_model_table": "TIRS_SSM_POS_MODEL_PARAMS",
                   "position_estimates_table": "TIRS_SSM_POS_ESTIMATES",
                   "switch_event_id_sequence": "DBSEQ_TIRS_SSM_SWITCH_ID_PK",
                   "model_id_sequence": "DBSEQ_TIRS_SSM_POS_MODEL_ID_PK",
                   "tirs_command_table": "TIRS_TELEMETRY_COMMAND",
                   "tirs_circuit_table": "TIRS_TELEMETRY_CIRCUIT"}

    # To support unit tests using different table names, attempt to import
    # a module with modified table names.  If the import fails, it is not
    # running under the unit tests and can be ignored.
    try:
        from database_unit_test_override import unit_test_tables
        _db_objects = unit_test_tables
    except:
        pass

    @staticmethod
    def get_name(key):
        """ Get the name of the requested database object """
        return DatabaseObjects._db_objects[key]

    @staticmethod
    def set_name(key, name):
        """ Set the name of the requested database object """
        DatabaseObjects._db_objects[key] = name
