
import argparse
from ias.misc import satellite_attributes as sat_attr
from ias.db import database as db
from ssm_exceptions import TimestampError
from timestamp import Timestamp


def connect_to_database(use_common=False):
    """ Connect to the database using either the currently configured
        satellite/sensor schema or the common schema.  If not using
        the common schema, the caller is expected to have properly initialized
        the satellite attributes library prior to calling this routine.
    """

    if use_common:
        db_connection = db.DatabaseConnection("COMMON")
    else:
        # Get the satellite attributes
        sa = sat_attr.get_default()

        # Connect to the database sensor schema
        db_connection = db.DatabaseConnection()
        db_connection.set_login_using_satellite_sensor(
            sa.get_satellite_name(), sa.get_satellite_sensor_name())

    db_connection.connect()

    # return the DB connection
    return db_connection


def valid_timestamp(s):
    """ Validate and return timestamp parameters.  If the timestamp
        fails to parse, throw an ArgumentTypeError exception. This is
        used as the argument to type when adding a parameter to
        an argparser. This results is a much "cleaner" failure since
        the argparse will catch this type of Exception.
    """
    try:
        return Timestamp.from_string(s)
    except TimestampError as error:
        raise argparse.ArgumentTypeError(error)


def valid_timestamp_dual_format(s):
    """ Validate and return timestamp parameters.  If the timestamp
        fails to parse, throw an ArgumentTypeError exception. This is
        used as the argument to type when adding a parameter to
        an argparser. This results is a much "cleaner" failure since
        the argparse will catch this type of Exception.
        Will except either a timestamp in the YYYY-DOY-HH:MM:SS[.S] or
        YYYY:DOY:SECONDS
    """
    try:
        return Timestamp.from_string_dual_format(s)
    except TimestampError as error:
        raise argparse.ArgumentTypeError(error)
