#ifndef DATABASE_ROUTINES_H
#define DATABASE_ROUTINES_H

typedef struct telemetry_information
{
    double l0r_time_days_from_j2000;      /* Days counted from J2000 TAI */
    double l0r_time_sec_of_day;           /* Seconds of the day counter with
                                             microsecond resolution */
    int elec_enabled_flags;               /* Flag indicates which set of
                                             electronics are use - side A or
                                             side B */
    int mc_encoder_flags;                 /* Flag indicates whether or not
                                             the SSM encoder is powered and
                                             whether or not it has been
                                             indexed */
    int ssm_mech_mode;                    /* SSM encoder operating mode
                                             (0 or 4) */
    double ssm_encoder_position_sample_2; /* Second of up to 21 encoder
                                             samples in the current ancillary
                                             data record */
    double diff_secs;                     /* Difference of time from
                                             switch event start time
                                             from the record time stamp
                                             from db in J2000 second of day */
} TELEMETRY_INFORMATION;

/* Structure that holds TIRS SSM ESTIMATION information that match the
   input search criteria */
typedef struct ssm_calibration_information
{
    double ssm_epoch_year;
    double ssm_epoch_doy;
    double ssm_epoch_sod;
    double net_ssm_angle;
    int number_of_scas;
    int sca_number;
    int nbr_of_pnts_used;
    double post_fit_alng_trk_rmse;
    double post_fit_acrss_trk_rmse;
    double net_rmse;
    double diff_secs;              /* Difference of time from
                                      switch event start time */
    double encoder_counts;
} SSM_CALIBRATION_INFORMATION;


int connect_to_database(void);
void disconnect_from_database(void);

TELEMETRY_INFORMATION *get_db_telemetry_list
(
    double start_day,         /* I: J2000 Start J2000 day */ 
    double start_sec_of_day,  /* I: J2000 Start Second of day */
    double end_day,           /* I: J2000 End J2000 day */
    double end_sec_of_day,    /* I: J2000 End Second of day */  
    int *number_of_records    /* O: Number of records */  
);

int get_db_ssm_calibration_scenes
(
    double event_start_time[3],  /* I: Event start time in UTC */
    double event_end_time[3],    /* I: Event end time in UTC */
    SSM_CALIBRATION_INFORMATION **records, /* I: Returned records.  Caller is
                                                 needs to free this. */
    int *number_of_records       /* O: Number of records return from db */
);

#endif
