#!/bin/csh -f

# NAME: test_tirs_ssm_fit_model.csh
#
# PURPOSE: Set up the environment to run the tirs ssm fit model algorithm
# and generate the report file. It will be run in a command line mode.
# RETURNS: 0 on SUCCESS
#          1 on ERROR

# Ensure the test environment variable is set
if ( ! $?IAS_UNIT_TEST_DATA_DIR ) then
    echo "IAS_UNIT_TEST_DATA_DIR isn't set"
    exit 1
endif

set application_log = test_fit.log
set diff_log = test_fit_diff.log
set data_dir = $IAS_UNIT_TEST_DATA_DIR/ias/gps/tirs_ssm_model/tirs_fit_ssm_model/tirs_fit_ssm_model

rm -f $application_log
rm -f $diff_log
rm -rf test_fit_output
rm -f tirs_fit_test_data
mkdir test_fit_output

if (-e $data_dir/input) then
    echo "Input directory does not exist"
    exit 1
endif

ln -sf $data_dir/inputs tirs_fit_test_data
if ($status != 0) then
    echo "Failed setting up symbolic link to test data"
    exit 1
endif

set odls = ( \
    TIRS_SSM_MODEL_FIT.odl.Greater_12Day_TC \
    TIRS_SSM_MODEL_FIT.odl.Greater_1Day_N1_N2_TC \
    TIRS_SSM_MODEL_FIT.odl.Greater_1Day_N2_TC \
    TIRS_SSM_MODEL_FIT.odl.Greater_1Day_TC \
    TIRS_SSM_MODEL_FIT.odl.Greater_7Day_N3_TC \
    TIRS_SSM_MODEL_FIT.odl.Greater_7Day_TC \
    TIRS_SSM_MODEL_FIT.odl.Less_12Day_MaxTimes_TC \
    TIRS_SSM_MODEL_FIT.odl.Less_12Day_TC \
    TIRS_SSM_MODEL_FIT.odl.Less_1Day_N1_TC \
    TIRS_SSM_MODEL_FIT.odl.Less_1Day_TC \
    TIRS_SSM_MODEL_FIT.odl.Less_7Day_TC \
    TIRS_SSM_MODEL_FIT.odl.Less_Than_2000_Secs_TC \
    TIRS_SSM_MODEL_FIT.odl.masks \
    TIRS_SSM_MODEL_FIT.odl.nan \
)

set count = 0
echo "Running tests"
foreach file ($odls)
    @ count += 1
    echo "-------------------------------------------" >> $application_log
    echo "Running application with ODL: $file" >> $application_log
    ../tirs_fit_ssm_model test_fit_odls/$file >> $application_log
    set save_status = $status
    # Expect the last one to fail
    if ($count == $#odls) then
        if ($save_status == 0) then
            echo "Expected $file to return an error"
            exit 1
        endif
    else if ($save_status != 0) then
        echo "Failure returned running $file"
        exit 1
    endif
end

if ($count != $#odls) then
    echo "Unexpected number of test files run"
    exit 1
endif

set result_count = 0
echo "Comparing results"
foreach file (test_fit_output/*)
    set target_file = `basename $file`
    echo "Checking $target_file" |& tee -a $diff_log
    # chop the first 4 lines line off the file since they change all the time
    tail -n +5 $file > temp_diff.rpt
    diff -u temp_diff.rpt $data_dir/reports/$target_file |& tee -a $diff_log
    if ($status != 0) then
        echo "Differences in $file, see $diff_log"
        exit 1
    endif
    #tkdiff temp_diff.rpt $data_dir/reports/$target_file
    @ result_count += 1
end

if ($result_count != 13) then
    echo "Unexpected number of results files"
    exit 1
endif

# Clean up since the test passed
rm -f $diff_log
rm -rf test_fit_output
rm -f tirs_fit_test_data
rm -f temp_diff.rpt

exit 0
