#ifndef TIRS_ENCODER_H
#define TIRS_ENCODER_H

#include "ssm_telemetry.h"

#define SSM_OBSERVATION_GAP_WINDOWS  3
#define SSM_OBSERVATION_GAP_PARAMS   (2 * SSM_OBSERVATION_GAP_WINDOWS)
#define SSM_BREAK_POINT_TIMES        4
#define SSM_TABLE_TIMES             14

typedef enum
{
    TELEMETRY_RMSE = 0,
    IMAGE_RMSE = 1,
    COMBINED_RMSE = 2,
    RMSE_COUNT = 3
} RMSE_TYPE;

typedef enum
{
    SSM_FIT_A0     = 0,
    SSM_FIT_A1     = 1,
    SSM_FIT_A2     = 2,
    SSM_FIT_A3     = 3,
    SSM_FIT_TAU1   = 4,
    SSM_FIT_TAU2   = 5,
    SSM_FIT_TAU3   = 6,
    SSM_FIT_SLOPE  = 7,
    SSM_FIT_NPARMS = 8
} SSM_FIT_PARAMETER;


/* Type of solution to perform */
typedef enum
{
    SSM_SOLUTION_START_UP = 0, 
    SSM_SOLUTION_DAY,
    SSM_SOLUTION_WEEK,
    SSM_SOLUTION_TWO_WEEKS,
    SSM_SOLUTION_FULL,
    NUMBER_SSM_SOLUTION_TYPES
} SSM_SOLUTION_PARMS;


int read_parameters
(
    const char *parameter_filename   /* I: Name of the parameter file */
);

int fit_lsq_ias
(
    const ENCODER_RECORD *tirs_data, /* I: TIRS data records */
    int number_tirs_data,          /* I: Number of TIRS encoder values */
    double encoder_value0,         /* I: Initial encoder value */
    double *coeff,      /* O: New model coefficients.  Array sized by NPARMS. */
    int *final_num,     /* O: Number of points in final rmse.  Array sized by
                              RMSE_COUNT. */
    double *final_rms   /* O: Best fit RMS error.  Array sized by RMSE_COUNT */
);

int analyze_time_period
(
    const ENCODER_RECORD *tirs_data,  /* I: TIRS data records */
    int number_tirs_data,             /* I: Number of TIRS encoder values */
    int *number_samples_per_break     /* O: Number of samples in each 
                                            observation window.  Sized of
                                            SSM_OBSERVATION_GAP_WINDOWS */
);

int create_report
(
    const ENCODER_RECORD *tirs_data, /* I: TIRS data records */
    int number_tirs_data,          /* I: Number of TIRS encoder values */
    double encoder_value0,         /* I: Initial encoder value */
    int switch_event_id,           /* I: Switch event ID */
    int model_id,                  /* I: Model ID */
    const double *new_coefficients,/* I: Array of NPARMS new model
                                         coefficients */
    const int *final_num,          /* I: Array of RMSE_COUNT point counts */
    const double *final_rms,       /* I: Array of RMSE_COUNT RMS errors */
    const double *event_start_time,/* I: Event Start time */
    const double *event_end_time   /* I: Event end time */
);

char *get_ssm_encoder_filename(void);
char *get_output_filename(void);
char *get_report_filename(void);
void get_initial_values
(
    double *values /* O: Filled array */
);

void get_break_point_times
(
    double *values /* O: Filled array */
);

void get_coefficient_masks
(
    int *values  /* O: Filled array */
);

double get_convergence_threshold(void);

void get_convergence_threshold_weights
(
    double *values /* O: Filled array */
);

void get_observation_gap_windows
(
    double *values /* O: Filled array */
);

void get_break_times_samples 
(
    int *values   /* O: Filled array */
);

int get_maximum_iterations(void);
double get_encoder_value0(void);
int get_telemetry_start_offset(void);
int get_telemetry_subsample_threshold(void);
int get_telemetry_subsample_step(void);

char *get_cpf_filename(void);
int get_switch_event_id(void);
int get_model_id(void);

void get_event_start_time
(
    double *values  /* O: Filled array */
);

void get_event_end_time
(
    double *values  /* O: Filled array */
);

void get_apriori_weights
(
    double *values  /* O: Filled array */
);

double encoder_model
(
    const double *coeff,    /* I: Array of NPARMS model coefficients */
    double enc0,            /* I: Initial encoder position */
    double secs_diff        /* I: Seconds from start of event */
);

void encoder_model_partial
(
    const double *coeff,    /* I: Array of SSM_FIT_NPARMS model coefficients */
    double secs_diff,       /* I: Seconds from start of event */
    double *partials        /* O: Computed partial with SSM_FIT_NPARMS terms*/
);

double get_cal_outlier_rmse_threshold(void);
double get_telemetry_obs_stdev(void);
double get_image_obs_stdev(void);

#endif
