#ifndef UTILITIES_H
#define UTILITIES_H

#include "ias_cpf.h"
#include "database_routines.h"     /* TELEMETRY_INFORMATION structure */
#include "ssm_telemetry.h"         /* Final telemetry structure */

int convert_utc_to_j2000_seconds
(
    const IAS_MATH_LEAP_SECONDS_DATA *leap_seconds_data, /* Leap second info */
    double utc_time[3],     /* I: Array with the UTC time */
    double *j2000_seconds   /* O: output J2000 seconds */
);

void convert_j2000_seconds_to_days_sod
(
    double seconds,     /* I: J2000 time in seconds */
    double *day,        /* O: J2000 start day */
    double *sod         /* O: J2000 start second of day */
);

double convert_j2000_days_sod_to_seconds
(
    double day_J2000,  /* I: Time days from J2000*/
    double sod         /* I: Time second of day */
);

void get_refined_telemetry_list
(
    TELEMETRY_INFORMATION *telemetry_list, /* I/O: Telemetry list pointer */
    double start_event_time_sec,           /* I: Event start time in sec */
    int *number_of_records                 /* I/O: Number of records */
);

int get_refined_ssm_calibration_scenes
(
    SSM_CALIBRATION_INFORMATION *ssm_calibration_scenes,
                                 /* I/O: SSM calibration scene pointer */
    int *number_of_records_est   /* I/O: Number of records return from db on
                                         input, reduced record count on
                                         return */
);

int get_combined_telemetry_ssm_base_obs
(
    const TELEMETRY_INFORMATION *telemetry_list,
                                  /* I: Telemetry pointer */
    const SSM_CALIBRATION_INFORMATION *ssm_calibration_list,
                                  /* I: SSM calibraton scenes pointer */
    const struct IAS_CPF_EARTH_CONSTANTS *earth_const, /* I: Earth Constant */
    int number_of_records,        /* I:  Telemetry records */
    int number_of_records_est,    /* I:  SSM calibration scene records */
    ENCODER_RECORD *tirs_data     /* O:  Combined telemetry and tirs ssm
                                         base observation pointer */
);

int get_nadir_encoder_position
(
    IAS_CPF *cpf,           /* I: Pointer to an open CPF */
    TELEMETRY_INFORMATION *telemetry_list,  /* I: Telemetry list */  
    int number_of_records,  /* I: Number of records */
    double *new_encoder     /* O: New encoder value */
);

void fix_stuck_ssm_bits
(
    int nadir_encoder,      /* I: Nadir encoder count */
    TELEMETRY_INFORMATION *telemetry_list,  /* I/O: Telemetry list */  
    int number_of_records   /* I: Number of records */
);

void get_encoder_count_tirs_ssm_estimation
(
    SSM_CALIBRATION_INFORMATION *refined_ssm_calibration_scenes,
                            /* I/O: Pointer for ssm calibration information */
    int number_of_records_est, /* I: Number of records */
    int encoder_origin         /* I: nadir encoder position in counts */
);

#endif
