#!/bin/csh -f
################################################################################
#   Name: test3_wo_creation.csh
#
#   Desc: Reads a few scenes from a file and creates work orders with those
#       scenes. Makes sure the work orders have correct information.
#
#   Usage: ./test_wo_creation.csh
################################################################################

################################################################################
# Check work order creation for default procedure id
################################################################################
set woid_out_file = "created_woids.tmp"
set scene_list_file = "test3_input_scenes.txt"
set sql_results_file = "work_order_query_results.tmp"
set log = "test3_wo_creation.log"
set scenes = `cat $scene_list_file`
set num_expected_wos = 3

# Delete old files in case of previous test failure
rm -f $woid_out_file
rm -f $sql_results_file

echo "Starting test number 3" |& tee $log
echo "Creating first set of work orders" |& tee -a $log
../create_gps_work_orders.pl \
    --scene_list_file=$scene_list_file \
    --output_woid_filename=$woid_out_file |& tee -a $log
if ( $status != 0 ) then
    echo "Unable to create work orders" |& tee -a $log
    exit 1
endif
echo "First set of work orders created. Reading information" |& tee -a $log

set woids = `cat $woid_out_file`
foreach woid ( $woids )
    sqlplus $IAS_DB_COM >> $sql_results_file << EONG
        SELECT WORK_ORDER_ID, SCENE_ID, PROCEDURE_ID FROM WORK_ORDERS WHERE WORK_ORDER_ID='$woid';
        UPDATE WORK_ORDERS SET STATE='A'
        WHERE WORK_ORDER_ID='$woid';
EONG

end

echo "Information read. Validating" |& tee -a $log

if ( $#woids != $num_expected_wos ) then
    echo "Wrong number of work orders created" |& tee -a $log
endif

set i = 1
while ( $i <= $num_expected_wos )
    grep $woids[$i] $sql_results_file | grep $scenes[$i] | \
        grep "TIRS SSM Calibration" > & /dev/null
    if ( $status != 0 ) then
        echo "Work order $woid[$i] with scene $scenes[$i] and procedure id" \
            "TIRS SSM Calibration not created" |& tee -a $log
        exit 1
    endif
    @ i++
end

echo "Successful validation for first set of work orders" |& tee -a $log

# Remove work order ids from WORK_ORDERS table
./load_work_orders.pl --remove --wo_file $woid_out_file
rm -f $woid_out_file
rm -f $sql_results_file

################################################################################
# Check work order creation for different procedure id
################################################################################
set num_expected_wos = 3

echo "Creating second set of work orders" |& tee -a $log
../create_gps_work_orders.pl \
    --scene_list_file=$scene_list_file \
    --output_woid_filename=$woid_out_file \
    --procedure_id="TIRS Alignment" |& tee -a $log
if ( $status != 0 ) then
    echo "Unable to create work orders" |& tee -a $log
    exit 1
endif
echo "Second set of work orders created. Reading information" |& tee -a $log

set woids = `cat $woid_out_file`
foreach woid ( $woids )
    sqlplus -s $IAS_DB_COM >> $sql_results_file << EONG
        SELECT WORK_ORDER_ID,SCENE_ID,PROCEDURE_ID FROM WORK_ORDERS WHERE WORK_ORDER_ID='$woid';
        UPDATE WORK_ORDERS SET STATE='A'
        WHERE WORK_ORDER_ID='$woid';
EONG

end

echo "Information read. Validating" |& tee -a $log

if ( $#woids != $num_expected_wos ) then
    echo "Wrong number of work orders created" |& tee -a $log
endif

set i = 1
while ( $i <= $num_expected_wos )
    grep $woids[$i] $sql_results_file | grep $scenes[$i] | \
        grep "TIRS Alignment" > & /dev/null
    if ( $status != 0 ) then
        echo "Work order $woid[$i] with scene $scenes[$i] and procedure id" \
            "TIRS Alignment not created" |& tee -a $log
        exit 1
    endif
    @ i++
end

echo "Successful validation for second set of work orders" |& tee -a $log
echo "Test 3 success: Work orders are properly created" |& tee -a $log

# Remove work order ids from WORK_ORDERS table
./load_work_orders.pl --remove --wo_file $woid_out_file
rm -f $woid_out_file
rm -f $sql_results_file

exit 0
