/*****************************************************************************
NAME:       gxx_ReadDDR

PURPOSE:    Read the DDR structure to an HDF file

RETURN VALUE: 
Type = int
Value       Description
-----       -----------
SUCCESS     Successfully closed image
ERROR       Error; image not closed

NOTES:      This function is a bridge routine from the actual xxx_ReadDDR
        support.  This function only flips SOM corner coorindates
        after they are read.  This allows a consistant user interface,
        yet allows the algorithms using SOM coodinates not to change.

******************************************************************************
        Landsat 7 Image Assessment System (IAS) Software
                Property of the U.S. Government
                                NASA/GSFC/EDC
*****************************************************************************/

#include <stdio.h>
#include "gctp.h"
#include "xxx_DDR.h"
#include "gxx_ddr.h"

xxx_DDRControl_TYPE *gxx_ReadDDR
(
    char *p_PathName     /* I: DDR filename */
)
{
    xxx_DDRControl_TYPE *p_DDRControl = NULL;   /* Pointer to DDR info  */

    int i;      /* Looping variable         */

    double tmp; /* Temporary variable for SOM flipping  */

    
    /*
      Read the DDR from the HDF file
    */
    p_DDRControl = xxx_ReadDDR(p_PathName);
    if (p_DDRControl == NULL)
        return NULL;

    /*
      Flip the corner points for the SOM projection ONLY
    */
    for (i=0; i < p_DDRControl->Count; i++)
    {
        if (p_DDRControl->p_DDR[i].ProjectCode == SOM)
        {
            tmp = -p_DDRControl->p_DDR[i].UpperLeft[1];
            p_DDRControl->p_DDR[i].UpperLeft[1] =
                p_DDRControl->p_DDR[i].UpperLeft[0];
            p_DDRControl->p_DDR[i].UpperLeft[0] = tmp;

            tmp = -p_DDRControl->p_DDR[i].LowerLeft[1];
            p_DDRControl->p_DDR[i].LowerLeft[1] =
                p_DDRControl->p_DDR[i].LowerLeft[0];
            p_DDRControl->p_DDR[i].LowerLeft[0] = tmp;

            tmp = -p_DDRControl->p_DDR[i].UpperRight[1];
            p_DDRControl->p_DDR[i].UpperRight[1] =
                p_DDRControl->p_DDR[i].UpperRight[0];
            p_DDRControl->p_DDR[i].UpperRight[0] = tmp;

            tmp = -p_DDRControl->p_DDR[i].LowerRight[1];
            p_DDRControl->p_DDR[i].LowerRight[1] =
                p_DDRControl->p_DDR[i].LowerRight[0];
            p_DDRControl->p_DDR[i].LowerRight[0] = tmp;
        }
    }

    /*
      Return the DDR information
    */
    return p_DDRControl;
}
