/*****************************************************************************
NAME:       gxx_WriteDDR

PURPOSE:    Write the DDR structure to a file

RETURN VALUE: 
Type = int
Value       Description
-----       -----------
SUCCESS     Successfully closed image
ERROR       Error; image not closed

NOTES:      This function is a bridge routine to the actual xxx_WriteDDR
        support.  This function only flips SOM corner coorindates
        before they are sent to be written.  This allows a consistant
        user interface, yet allows the algorithms using SOM coodinates
                not to change.

******************************************************************************
        Landsat 7 Image Assessment System (IAS) Software
                Property of the U.S. Government
                                NASA/GSFC/EDC
*****************************************************************************/

#include <stdio.h>
#include "gctp.h"
#include "xxx_DDR.h"
#include "gxx_ddr.h"

int gxx_WriteDDR
(
    char *p_PathName,                   /* I: DDR filename */
    xxx_DDRControl_TYPE *p_DDRControl  /* I: DDR control structure */
)
{
    int i;      /* Looping variable         */
    double tmp; /* Temporary variable for SOM flipping  */

    
    /*
      Flip the corner points for the SOM projection ONLY
    */
    for (i=0; i < p_DDRControl->Count; i++)
    {
        if (p_DDRControl->p_DDR[i].ProjectCode == SOM)
        {
            tmp = -p_DDRControl->p_DDR[i].UpperLeft[0];
            p_DDRControl->p_DDR[i].UpperLeft[0] =
                p_DDRControl->p_DDR[i].UpperLeft[1];
            p_DDRControl->p_DDR[i].UpperLeft[1] = tmp;

            tmp = -p_DDRControl->p_DDR[i].LowerLeft[0];
            p_DDRControl->p_DDR[i].LowerLeft[0] =
                p_DDRControl->p_DDR[i].LowerLeft[1];
            p_DDRControl->p_DDR[i].LowerLeft[1] = tmp;

            tmp = -p_DDRControl->p_DDR[i].UpperRight[0];
            p_DDRControl->p_DDR[i].UpperRight[0] =
                p_DDRControl->p_DDR[i].UpperRight[1];
            p_DDRControl->p_DDR[i].UpperRight[1] = tmp;

            tmp = -p_DDRControl->p_DDR[i].LowerRight[0];
            p_DDRControl->p_DDR[i].LowerRight[0] =
                p_DDRControl->p_DDR[i].LowerRight[1];
            p_DDRControl->p_DDR[i].LowerRight[1] = tmp;
        }
    }

    /*
      Write the DDR to an HDF file
    */
    return xxx_WriteDDR(p_PathName, p_DDRControl);
}
