/*****************************************************************************
NAME:       gxx_close_1g_image

PURPOSE:    Close the specified 1G image.

RETURN VALUE: 
Type = int
Value       Description
-----       -----------
SUCCESS     Successfully closed image
ERROR       Error; image not closed

NOTES:      Need to deattach all the data before closing the file

******************************************************************************
        Landsat 7 Image Assessment System (IAS) Software
                Property of the U.S. Government
                                NASA/GSFC/EDC
*****************************************************************************/

#include <stdio.h>
#include "ias_logging.h"
#include "ias_const.h"
#include "gxx_hdf_io.h"

int gxx_close_1g_image
(
    HDFIO *hdfid        /* I: HDF IO structure id    */
)
{
    intn hdf_status;        /* HDF function return status   */
    BandNumber band;    /* band loop counter        */
    BAND_NODE_TYPE *band_node; /* an element of the band linked list */
    BAND_HDR_TYPE *band_hdr;


    band_hdr = xxx_GetBands();

    if (hdfid == NULL)
        return SUCCESS;

    /*
     * Info about the group
     */

    band_node = band_hdr->Head;

    while (band_node != NULL)
    {
        band = band_node->band_id;

        if (hdfid->sds_id[(int)band] != -1)
        {
            /*
             * Done with this SDS
             */
            hdf_status = SDendaccess(hdfid->sds_id[(int)band]);

            if (hdf_status == FAIL)
            {

                free(hdfid);
                hdfid = NULL;
                IAS_LOG_ERROR ("Error releasing SDS %s", 
                      hdfid->sds_name[(int)band]);
                return ERROR;
            }
        }

        band_node = band_node->Next;
    }

    /*
     * Close down
     */
    hdf_status = SDend(hdfid->sd_id);
    if (hdf_status == FAIL)
    {
        free(hdfid);
        hdfid = NULL;
        IAS_LOG_ERROR ("Error ending SDS interface");
        return ERROR;
    }

    Vdetach(hdfid->group_id);
    Vend(hdfid->file_id);

    hdf_status = Hclose(hdfid->file_id);
    if (hdf_status == FAIL)
    {
        free(hdfid);
        hdfid = NULL;
        IAS_LOG_ERROR ("Error closing HDF file, check attachments");
        return ERROR;
    }

    free(hdfid);

    return SUCCESS;
}
