#ifndef _GXX_HDF_IO_H_
#define _GXX_HDF_IO_H_

#include <string.h>
#include "mfhdf.h"
#include "ias_types.h"
#include "xxx_Band.h"

#define IMAGE_CLASS "Image"


typedef struct HDFIO
{
    int32 file_id;              /* HDF file id                  */
    int32 group_id;             /* HDF group id                 */
    int32 sd_id;                /* HDF SDS interface id         */
    int32 sds_id[NBANDS];       /* HDF SDS id per band          */
    char  sds_name[NBANDS][MAX_NC_NAME];/* HDF SDS name per band */
    char  hdf_dir_name[FILENAME_MAX]; /* name of HDF directory file   */
    char  extdir[FILENAME_MAX];   /* external file directory  */
} HDFIO;


/* 1G I/O */
HDFIO *gxx_open_1g_image
(
    const char *image_filename,/* I: Path & name of the 1G image file*/
    IAS_ACCESS_MODE access_mode, /* I: Requested access mode of image*/
    unsigned int *nbands,      /* I/O: Number of bands      */
    BandNumber bandno[NBANDS], /* I/O: enumerated band numbers   */
    IAS_DATA_TYPE dtype[NBANDS],    /* I/O: Data type of each band   */
    int  nl[NBANDS],           /* I/O: Number of lines per band */
    int  ns[NBANDS]            /* I/O: Number of samples per band*/
);

int gxx_close_1g_image
(
    HDFIO *hdfid       /* I: HDF IO structure id    */
);

int gxx_read_1g_image
(
    const HDFIO *hdfid, /* I: HDF IO structure           */
    BandNumber band,    /* I: (enumerated) band number to read */
    int  sl,            /* I: Line to start reading (0-rel)  */
    int  ss,            /* I: Sample to start reading (0-rel)    */
    int  nl,            /* I: Number of lines to read        */
    int  ns,            /* I: Number of samples to read      */
    int  subsamp,       /* I: Subsampling factor         */
    void *data          /* O: Data buffer            */
);


int gxx_write_1g_image
(
    const HDFIO *hdfid, /* I: HDF IO structure           */
    BandNumber band,    /* I: (enumerated) band number to write */
    int  sl,            /* I: Line to start writing (0-rel)  */
    int  ss,            /* I: Sample to start writing (0-rel)    */
    int  nl,            /* I: Number of lines to write       */
    int  ns,            /* I: Number of samples to write     */
    int  subsamp,       /* I: Subsampling factor             */
    void *data          /* O: Data buffer            */
);

int32 gxx_open_1g_band
(
    HDFIO *hdfid,       /* I: HDF info structure for the image   */
    BandNumber bandno   /* I: enumerated band number     */
);

int gxx_create_1g_band
(
    HDFIO *hdfid,       /* I/O: SDS id for the band added to structure */
    BandNumber bandno,  /* I: Enumerated band number */
    IAS_DATA_TYPE dtype,     /* I: Data type of the band  */
    int  nl,            /* I: Number of lines for the band*/
    int  ns             /* I: Number of samples for the band*/
);

void gxx_create_band_name
(
    const char *HDF_name,/* I: HDF name to form band file name from     */
    const char *type,    /* I: SDS or FILE name ("SDS" or "FILE")    */
    BandNumber bandno,   /* I: enumerated band number            */
    char *band_name      /* O: constructed band file name        */
);

#endif
