/*****************************************************************************
NAME:           gxx_splitname

PURPOSE:
Split the specified filename into a directory, a root file name, and an
extension.  The last character of the directory path will be a '/'.

******************************************************************************
                Landsat 7 Image Assessment System (IAS) Software
                        Property of the U.S. Government
                                NASA/GSFC/EDC
*****************************************************************************/
#include <stdio.h>   /* need FILENAME_MAX */
#include <string.h>
#include "gxx_utility.h"


void gxx_splitname
(
    const char *filename,       /* I: Name of file to split              */
    char *directory,            /* O: Directory portion of file name     */
    char *root,                 /* O: Root portion of the file name      */
    char *extension             /* O: Extension portion of the file name */
)
{
    char file_name[FILENAME_MAX], /* Local copy of filename              */
        *ptr,                  /* String pointer                        */
        *ptr2;                 /* String pointer                        */

    
    /* Make a local copy of filename so it is not destroyed
     */
    strcpy(file_name, filename);

    /* Check for a directory path
     */
    ptr  = (char *) strchr (file_name, '/');  /* Find beginning '/' */
    ptr2 = (char *) strrchr(file_name, '/');  /* Find ending '/'    */
    if (ptr != NULL && ptr != ptr2)
    { /* watch out for /filename */
        strcpy (directory, file_name);
        ptr = (char *) strrchr(directory, '/');
        ptr++;
        strcpy (file_name, ptr);
        *ptr = '\0';
    }
    else if (ptr != NULL && ptr == ptr2)
    { /* watch for filedir/filename */
        strcpy (directory, file_name);
        ptr  = (char *) strchr (directory, '/');
        ptr++;
        *ptr = '\0';
        ptr2++;
        strcpy (file_name, ptr2);
    }
    else
        strcpy (directory, "");

    /* Check for a file extension
     */
    ptr = (char *) strrchr(file_name, '.');
    if (ptr != NULL)
    {
        *(ptr++) = '\0';
        strcpy (root, file_name);
        strcpy (extension, ptr);
    }
    else
    {
        strcpy (root, file_name);
        strcpy (extension, "");
    }
}
