/*****************************************************************************
                Landsat 7 Image Assessment System (IAS) Software
                        Property of the U.S. Government
                            NASA / GSFC / Code 510
******************************************************************************

UNIT NAME: xxx_BandGetInfo_tm.c

PURPOSE: This contains TM-specific band functions.  These are used to build
a TM band or band list.
*****************************************************************************/

/* System headers */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* Local headers */

#include "ias_logging.h"

#include <xxx_Band.h>
#include <xxx_Types.h>
#include <tm/xxx_Sensor_tm.h>


/***************************************************************/
/* Given a band list, add band number band_num to the list.    */
/***************************************************************/

void xxx_CreateBandNode_tm 
(
    BAND_HDR_TYPE* band_list, /* I: band list to put the band node in */
    BAND_OPTION_TYPE option,  /* I: standard band list, or customized one */
    int bnum                  /* I: number of the band to add         */
)
{
    int band_number;         /* This is the physical band number.            */
    int band_long_number;    /* This is a long version of the band number.   */
    BandNumber band_id;      /* This is an enumerated type (eg: b1, etc)     */
                             /* that is often used in GPS. Can it be merged? */
    BAND_TYPE band_id_rps;   /* This is an enumerated type (eg: B1, etc)     */
                             /* akin to band_id that is often used in RPS.   */
    char *band_short_name;   /* This is a short version of the band's name.  */
    char *band_name;         /* This is the band's name for display.         */
    char *sds_band_name;     /* This is the SDS band filename section.       */
    char *band_name_ext;     /* This is the band name with a "_".            */
    char *band_name_ext_81;  /* This is the band name with a "_" (and "81"). */
    float band_resolution;   /* This is in meters.                           */
    band_mode_type band_mode; /* This is an enumerated type (THERMAL...)    */
    temp_corr_type temp_corr; /* enumerated type (NO_TEMP_CORRECTION...)    */
    int num_detectors;      /* This is the number of detectors for the band. */
    long int maxImgPixels; /* These are from rxx_Constants.h.  They will be  */
    long int maxCalPixels; /* sent to structures that look like the          */
    char band_id_msg[5];    /* from rxx_BAND_TYPE_MSG,    */
    char IMGnames[5];       /* from RXX_BAND1, etc...     */
    char CALnames[5];       /* from RXX_CAL_BAND1, etc... */
    char SLOvdata[6];       /* from XXX_SLO_BAND1, etc... */
    int joffset;           /* offset - used in IC Trend write                */
    int active;             /* This indicates whether the band is in use.    */
    int status;            


    bnum--;  /* This translates from band number to array index. */

    band_number = band_number_tm[bnum];
    band_long_number = band_long_number_tm[bnum];
    band_id = band_id_tm[bnum];
    band_id_rps = band_id_rps_tm[bnum];
    band_short_name = malloc (strlen (band_short_name_tm[bnum]) + 1);
    strcpy (band_short_name, band_short_name_tm[bnum]);
    band_name = malloc (strlen (band_name_tm[bnum]) + 1);
    strcpy (band_name, band_name_tm[bnum]);
    sds_band_name = malloc (strlen (sds_band_name_tm[bnum]) + 1);
    strcpy (sds_band_name, sds_band_name_tm[bnum]);
    band_name_ext = malloc (strlen (band_name_ext_tm[bnum]) + 1);
    strcpy (band_name_ext, band_name_ext_tm[bnum]);
    band_name_ext_81 = malloc (strlen (band_name_ext_81_tm[bnum]) + 1);
    strcpy (band_name_ext_81, band_name_ext_81_tm[bnum]);
    band_resolution = band_resolution_tm[bnum];
    band_mode = band_mode_tm[bnum];
    temp_corr = temp_corr_tm[bnum];
    num_detectors = num_detectors_tm[bnum];
    maxImgPixels = MaxImgPixels_tm[bnum];
    maxCalPixels = MaxCalPixels_tm[bnum];
    strcpy (band_id_msg, band_id_msg_tm[bnum]);
    strcpy (IMGnames, IMGnames_tm[bnum]);
    strcpy (CALnames, CALnames_tm[bnum]);
    strcpy (SLOvdata, SLOvdata_tm[bnum]);
    joffset = joffset_tm[bnum];
    active = active_tm[bnum];

    status = xxx_BuildBandNode (band_list,
                           option,
                           band_number,
                           band_long_number,
                           band_id,
                           band_id_rps,
                           band_short_name,
                           band_name,
                           sds_band_name,
                           band_name_ext,
                           band_name_ext_81,
                           band_resolution,
                           band_mode,
                           temp_corr,
                           num_detectors,
                           maxImgPixels,
                           maxCalPixels,
                           band_id_msg,
                           IMGnames,
                           CALnames,
                           SLOvdata,
                           joffset,
                           active);
    if (status != SUCCESS)
    {
        IAS_LOG_ERROR ("failed in call to xxx_BuildBandNode");
    }
    if (band_short_name != NULL) free(band_short_name);
    if (band_name != NULL) free (band_name);
    if (sds_band_name != NULL) free (sds_band_name);
    if (band_name_ext != NULL) free (band_name_ext);
    if (band_name_ext_81 != NULL) free (band_name_ext_81);
}


/***************************************************************/
/* Get the "standard" band information, which is a list of     */
/* band nodes in ascending order of band ID.                   */
/***************************************************************/

void xxx_BandGetInfo_tm(void)
{
    BAND_HDR_TYPE *band_hdr;

    band_hdr = xxx_CreateBandHdr (STANDARD);

    xxx_CreateBandNode_tm (band_hdr, STANDARD, 1);
    xxx_CreateBandNode_tm (band_hdr, STANDARD, 2);
    xxx_CreateBandNode_tm (band_hdr, STANDARD, 3);
    xxx_CreateBandNode_tm (band_hdr, STANDARD, 4);
    xxx_CreateBandNode_tm (band_hdr, STANDARD, 5);
    xxx_CreateBandNode_tm (band_hdr, STANDARD, 6);
    xxx_CreateBandNode_tm (band_hdr, STANDARD, 7);

    /* Set the reference band pointer. */

    band_hdr = xxx_GetBands();

    band_hdr->ref_band = xxx_GetBandNode (band_hdr, b5, BAND_ID_TYPE);

}

