/*****************************************************************************
                Landsat 7 Image Assessment System (IAS) Software
                        Property of the U.S. Government
                            NASA / GSFC / Code 510
******************************************************************************

UNIT NAME: xxx_BandGetInfo_xxx.c

PURPOSE: This contains generic band functions.  These are used to build
         a generic band or band list.
*****************************************************************************/

/* System headers */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* Local headers */

#include "ias_logging.h"

#include "xxx_Band.h"
#include "xxx_Types.h"
#include "xxx/xxx_Sensor_xxx.h"


/***************************************************************/
/* Given a band list, add a new band.                          */
/***************************************************************/

void xxx_CreateBandNode_xxx
(
    BAND_HDR_TYPE* band_list, /* I: Band list to put the band node in */
    BAND_OPTION_TYPE option,  /* I: Standard band list, or customized one */
    int bnum                  /* I: Number of the band to add */
)
{
    int band_number;          /* physical band number */
    int band_long_number;     /* long version of the band number */
    BandNumber band_id;       /* enumerated type (eg: b1, etc) that is often
                                 used in GPS */
    BAND_TYPE band_id_rps;    /* enumerated type (eg: B1, etc) */
                              /* akin to band_id that is often used in RPS */
    char *band_short_name;    /* short version of the band's name */
    char *band_name;          /* band's name for display */
    char *sds_band_name;      /* SDS band filename section */
    char *band_name_ext;      /* band name with a "_" */
    char *band_name_ext_81;   /* band name with a "_" (and "81") */
    float band_resolution;    /* in meters */
    band_mode_type band_mode; /* enumerated type (THERMAL...) */
    temp_corr_type temp_corr; /* enumerated type (NO_TEMP_CORRECTION...) */
    int num_detectors;        /* number of detectors for the band */
    long int maxImgPixels;    /* from rxx_Constants.h; will be sent to */
    long int maxCalPixels;    /* structures */
    char band_id_msg[5];      /* from rxx_BAND_TYPE_MSG */
    char IMGnames[5];         /* from RXX_BAND1, etc... */
    char CALnames[5];         /* from RXX_CAL_BAND1, etc... */
    char SLOvdata[6];         /* from XXX_SLO_BAND1, etc... */
    int joffset;              /* offset - used in IC Trend write */
    int active;               /* indicates whether the band is in use */
    int status;            

    band_number = bnum;
    band_long_number = bnum;
    band_id = bnum-1;
    band_id_rps = bnum-1;
    band_short_name = malloc(4);
    snprintf(band_short_name, 4, "B%d", bnum-1);
    band_name = malloc(8);
    snprintf(band_name, 8, "BAND %d", bnum-1);
    sds_band_name = malloc(4);
    snprintf(sds_band_name, 4, "B%02d", bnum-1);
    band_name_ext = malloc(5);
    snprintf(band_name_ext, 5, "_B%02d", bnum-1);
    band_name_ext_81 = malloc(5);
    strcpy(band_name_ext_81, band_name_ext_81);
    band_resolution = 30;
    band_mode = REFLECTIVE;
    temp_corr = TEMP_NO_CORRECTION;
    num_detectors = 1;
    maxImgPixels = 1;
    maxCalPixels = 1;
    strcpy(band_id_msg, "");
    strcpy(IMGnames, "");
    strcpy(CALnames, "");
    strcpy(SLOvdata, "");
    joffset = 0;
    active = TRUE;

    status = xxx_BuildBandNode(band_list, option, band_number, band_long_number,
                          band_id, band_id_rps, band_short_name, band_name,
                          sds_band_name, band_name_ext, band_name_ext_81,
                          band_resolution, band_mode, temp_corr,
                          num_detectors, maxImgPixels, maxCalPixels,
                          band_id_msg, IMGnames, CALnames, SLOvdata, joffset,
                          active);
    if (status != SUCCESS)
    {
        IAS_LOG_ERROR ("failed in call to xxx_BuildBandNode");
    }
    if (band_short_name != NULL) free(band_short_name);
    if (band_name != NULL) free (band_name);
    if (sds_band_name != NULL) free (sds_band_name);
    if (band_name_ext != NULL) free (band_name_ext);
    if (band_name_ext_81 != NULL) free (band_name_ext_81);
}


/***************************************************************/
/* Get the "standard" band information, which is a list of     */
/* band nodes in ascending order of band ID.                   */
/***************************************************************/

void xxx_BandGetInfo_xxx(void)
{
    BAND_HDR_TYPE *band_hdr = NULL;
    int b;

    band_hdr = xxx_CreateBandHdr(STANDARD);

    for (b=1; b<=MAX_BANDS_XXX; b++)
        xxx_CreateBandNode_xxx(band_hdr, STANDARD, b);

    /* Set the reference band pointer. */
    band_hdr = xxx_GetBands();
    band_hdr->ref_band = xxx_GetBandNode(band_hdr, b1, BAND_ID_TYPE);

}
