#ifndef XXX_DDR_H
#define XXX_DDR_H

#include <stdlib.h>
#include "hdfi.h"
#include "hlimits.h"

#define XXX_DDR_EXTENSION       "DDR"   /* DDR  extension where HDF is in HDF
                                           name */

#define XXX_DDR_FIELD_SIZE      500 /* latest strlen on fields was 497 */
#define XXX_DATUM_CODE_SIZE     16
#define XXX_PROJECTION_UNITS_SIZE   12
#define XXX_PROJECTION_COEF_SIZE    15  
#define XXX_POINT_SIZE          2
#define XXX_SOURCE_SIZE         32
#define XXX_INSTRUMENT_SIZE     32
#define XXX_DIRECTION_SIZE      64
#define XXX_CAPTURE_DATE            11
#define XXX_CAPTURE_TIME        8
#define XXX_VALID_FLAGS         8

typedef enum
{
    xxx_Systematic = 1,
    xxx_Precision  = 2,
    xxx_Terrain    = 3
} 
xxx_CorrectionType_TYPE;

/* Valid CaptureDirection field values */
#define XXX_DIRECTION_ASCEND        "ascending"
#define XXX_DIRECTION_DESCEND       "descending"

typedef struct xxx_DDR_TYPE
{
    int8 BandNumber;              /* Band number */
    int16 NumberScansInScene;     /* Number of scans in the scene */
    int8 NumberdetectorsPerScan;  /* Number of detectors per scan */
    int32 NumberLinesInScene;     /* Number of lines in the scene */
    int32 NumberSamplesInScene;   /* Number of samples in the scene */
    int16 DataType;               /* unit8, int16, etc.*/
    float64 MaxPixelValue;        /* Maximum pixel value */
    float64 MinPixelValue;        /* Minimum pixel value */
    float64 MaxRadianceValue;     /* Maximum radiance value */
    float64 MinRadianceValue;     /* Minimum radiance value */
    int32 MasterLine;             /* Line relative to original image */
    int32 MasterSample;           /* Sample relative to original image */
    int16 ProjectCode;            /* GCTP project code */
    int16 ZoneCode;               /* UTM zone */
    char8 DatumCode[XXX_DATUM_CODE_SIZE+1]; /* GCTP datum code */
    int32 SpheroidCode;                     /* Spheroid code, GPS only */
    char8 ProjectionUnits[XXX_PROJECTION_UNITS_SIZE+1]; /* Projection units */
    float64 ProjectionCoef[XXX_PROJECTION_COEF_SIZE];   /* GCTP projection
                                                           parameters */
    float64 UpperLeft[XXX_POINT_SIZE];  /* Upper left Y (lat), x (long) */
    float64 LowerLeft[XXX_POINT_SIZE];  /* Lower left Y (lat), x (long) */
    float64 UpperRight[XXX_POINT_SIZE]; /* Upper right Y (lat), x (long) */
    float64 LowerRight[XXX_POINT_SIZE]; /* Lower right Y (lat), x (long) */
    float64 ProjectionDistY;      /* Projection distance per pixel (y) */
    float64 ProjectionDistX;      /* Projection distance per pixel (x) */
    float64 LineSubsampleInc;     /* Line subsampleing factor */
    float64 SampleSubsampleInc;   /* Sample subsampleing factor */
    char8 SpaceCraftSource[XXX_SOURCE_SIZE+1];     /* Spacecraft source */
    char8 InstrumentSource[XXX_INSTRUMENT_SIZE+1]; /* Instrument source */
    uint8 WRSPath;    /* Staring WRS path for the scene, GPS only */
    float64 WRSRows;  /* Starting fractional row of the WRS scene, GPS only */
    char8 CaptureDirection[XXX_DIRECTION_SIZE+1]; /* Capture direction */
    char8 CaptureDate[XXX_CAPTURE_DATE+1];  /* Capture date */
    char8 CaptureTime[XXX_CAPTURE_TIME+1];  /* Capture time */
    int8 FieldValidityFlags[XXX_VALID_FLAGS];     /* Field validity flags */
    int8 CorrectionType;          /* Indicates image type, systematic,
                                     precision, or terrain, GPS only */
} xxx_DDR_TYPE;

typedef struct xxx_DDRControl_TYPE
{
    int32 Count;          /* Number of rows in DDR format */
    xxx_DDR_TYPE *p_DDR;  /* Format DDR */

    /* vdata information about the file */
    char vdataName[VSNAMELENMAX+1];
    char vdataClass[VSNAMELENMAX+1];
    int32 Interlace;
    int32 vdataSize;
} xxx_DDRControl_TYPE;

typedef struct xxx_DDRInfo_TYPE
{
    char FieldName[24];
    int32 Datatype;
    int32 Order;
} xxx_DDRInfo_TYPE;

#define XXX_FREE_DDR(DDRControl) \
{ \
    if (DDRControl) \
    { \
        free(DDRControl->p_DDR); \
        free(DDRControl); \
    } \
}

xxx_DDRControl_TYPE *xxx_ReadDDR
(
    char *p_PathName     /* I: Pathname to DDR file */
);

int xxx_WriteDDR
(
    char *p_PathName,                  /* I: Pathname to DDR file */
    xxx_DDRControl_TYPE *p_DDRControl /* I: DDR information */
);

#endif
