/*****************************************************************************
                Landsat 7 Image Assessment System (IAS) Software
                        Property of the U.S. Government
                            NASA / GSFC / Code 510
******************************************************************************
UNIT NAME:  xxx_sensor.c
         
PURPOSE:  To handle multi-sensor initialization and data access.
*****************************************************************************/

#include <strings.h>
#include "xxx_Sensor.h"
#include "ias_logging.h"
#include "xxx_DDR.h"

#define MAX_SSS 10  /* max sensor/satellite string length */

static xxx_FuncPtrs xxx;
static H4_IAS_SENSOR_TYPE SensorType = IAS_SENSOR_UNKNOWN;
static IAS_SATELLITE_TYPE SatelliteType = IAS_SAT_UNKNOWN;

static char Sensor_str[MAX_SSS] = "UNK"; /* sensor type string */
static char Satellite_str[MAX_SSS] = "UNK"; /* satellite string ("L5" "L7") */

/* This function just converts the input string to an enumeration value. */
H4_IAS_SENSOR_TYPE xxx_initialize_sensor_type
(
    const char * SensorTypeStr   /* I: sensor type string */
)
{
    /* If TM setup */
    if (strcasecmp(SensorTypeStr,"TM") == 0 ||
        strcasecmp(SensorTypeStr,"L5_TM") == 0 ||
        strcasecmp(SensorTypeStr,"L4_TM") == 0)
    {
        SensorType = IAS_SENSOR_TM;
        strcpy(Sensor_str, "TM");
        if (strcasecmp(SensorTypeStr,"L5_TM") == 0)
        {
            SatelliteType = IAS_SAT_L5;
            strcpy(Satellite_str, "L5");
        }
        else if (strcasecmp(SensorTypeStr,"L4_TM") == 0)
        {
            SatelliteType = IAS_SAT_L4;
            strcpy(Satellite_str, "L4");
        }
    }
    /* If ETM setup */
    else if (strcasecmp(SensorTypeStr,"ETM") == 0 ||
             strcasecmp(SensorTypeStr,"L7_ETM") == 0)
    {
        SensorType = IAS_SENSOR_ETM;
        SatelliteType = IAS_SAT_L7;
        strcpy(Sensor_str, "ETM");
        strcpy(Satellite_str, "L7");
    }
    /* MSS */
    else if (strcasecmp(SensorTypeStr,"MSS") == 0 ||
        strcasecmp(SensorTypeStr,"L1_MSS") == 0 ||
        strcasecmp(SensorTypeStr,"L2_MSS") == 0 ||
        strcasecmp(SensorTypeStr,"L3_MSS") == 0 ||
        strcasecmp(SensorTypeStr,"L4_MSS") == 0 ||
        strcasecmp(SensorTypeStr,"L5_MSS") == 0)
    {
        SensorType = IAS_SENSOR_MSS;
        strcpy(Sensor_str, "MSS");
        if (strcasecmp(SensorTypeStr,"L1_MSS") == 0)
        {
            SatelliteType = IAS_SAT_L1;
            strcpy(Satellite_str, "L1");
        }
        else if (strcasecmp(SensorTypeStr,"L2_MSS") == 0)
        {
            SatelliteType = IAS_SAT_L2;
            strcpy(Satellite_str, "L2");
        }
        else if (strcasecmp(SensorTypeStr,"L3_MSS") == 0)
        {
            SatelliteType = IAS_SAT_L3;
            strcpy(Satellite_str, "L3");
        }
        else if (strcasecmp(SensorTypeStr,"L4_MSS") == 0)
        {
            SatelliteType = IAS_SAT_L4;
            strcpy(Satellite_str, "L4");
        }
        else if (strcasecmp(SensorTypeStr,"L5_MSS") == 0)
        {
            SatelliteType = IAS_SAT_L5;
            strcpy(Satellite_str, "L5");
        }
    }
    else if (strcasecmp(SensorTypeStr,"XXX") == 0)
    {
        SensorType = IAS_SENSOR_GENERIC;
        SatelliteType = IAS_SAT_GENERIC;
        strcpy(Satellite_str, "XXX");
        strcpy(Satellite_str, "Lxx");
    }
    else
    {
    /* Unknown sensor type */
        SensorType = IAS_SENSOR_UNKNOWN;
        SatelliteType = IAS_SAT_UNKNOWN;
        strcpy(Sensor_str, "UNK");
        strcpy(Satellite_str, "UNK");
        IAS_LOG_INFO("Setting sensor to UNKNOWN");
    }

    return SensorType;
}


H4_IAS_SENSOR_TYPE xxx_get_sensor_type(void)
{
    return SensorType;
}


IAS_SATELLITE_TYPE xxx_get_satellite_type(void)
{
    return SatelliteType;
}


/* Returning the current function pointers */
xxx_FuncPtrs *xxx_get_funcs( void )
{
    return ( &xxx );
}



