/*****************************************************************************
                Landsat 7 Image Assessment System (IAS) Software
                        Property of the U.S. Government
                            NASA / GSFC / Code 510
******************************************************************************
UNIT NAME:  xxx_Sensor_funcs.c
         
PURPOSE:  To handle multi-sensor function initialization.
*****************************************************************************/

#include <stdlib.h>
#include <stdio.h>
#include "xxx_Sensor.h"
#include "ias_const.h"
#include "ias_logging.h"

int xxx_initialize_func_ptr(void)
{
    int ret_val = SUCCESS;              /* return value        */
    H4_IAS_SENSOR_TYPE SensorType = xxx_get_sensor_type();
    xxx_FuncPtrs *xxx = xxx_get_funcs();


    switch( SensorType )
    {
        /* Initialize all ETM function pointers here */
        case IAS_SENSOR_ETM:
            xxx->InitBands      = &(xxx_BandGetInfo_etm);
            xxx->CreateBandNode = &(xxx_CreateBandNode_etm);
            break;

        /* Initialize all TM function pointers here */
        case IAS_SENSOR_TM:
            xxx->InitBands      = &(xxx_BandGetInfo_tm);
            xxx->CreateBandNode = &(xxx_CreateBandNode_tm);
            break;

        /* Initialize all MSS function pointers here */
        case IAS_SENSOR_MSS:
            xxx->InitBands      = &(xxx_BandGetInfo_mss);
            xxx->CreateBandNode = &(xxx_CreateBandNode_mss);
            break;

        case IAS_SENSOR_GENERIC:
            xxx->InitBands      = &(xxx_BandGetInfo_xxx);
            xxx->CreateBandNode = &(xxx_CreateBandNode_xxx);
            break;

        /* Something bad happened */
        default:
            IAS_LOG_ERROR("Sensor type %d is not supported. \n", SensorType);
            ret_val = ERROR;
            break;
      
    }
    
    return ret_val;
}

