#!/bin/csh -f
################################################################################
#
# Name: check_converter.csh
#
# Description: Unit test for H5 and H4 converters
#
#
# Note: Opening the H4 files using hdfview will cause the binary file to be
#       changed which will cause this test to fail. This cannot use hdiff
#       since it doesn't seem to set the return status if there is a comparison 
#       failure
################################################################################

set log = "$PWD/convertor.log"
set ut_dir = "$IAS_UNIT_TEST_DATA_DIR/ias/gps/tools/l1g_h4_h5_convertor"

echo "Performing unit tests" > $log

echo "Converting HDF4 to HDF5" >> $log
../convert_l1g_h4_to_h5 $ut_dir/input_l7/systematic_HDF.l1g output_l7.h5 >> $log
if ($status != 0) then
    echo convert_l1g_h4_to_h5 failed!
    exit 1
endif

# Verify the output
h5diff output_l7.h5 $ut_dir/expected_output_l7/output_l7_V2.h5
if ($status != 0) then
    echo h5diff failed!
    exit 1
endif

echo "Converting HDF5 to HDF4" >> $log
../convert_l1g_h5_to_h4 $ut_dir/input_l8/l1t.h5 output_l8.h4 >> $log
if ($status != 0) then
    echo convert_l1g_h5_to_h4 failed!
    exit 1
endif

# Verify the output.  
set exit_status = 0
foreach file (output_l8_B01.h4 output_l8_B02.h4 output_l8_B03.h4 \
              output_l8_B04.h4 output_l8_B05.h4 output_l8_B06.h4 \
              output_l8_B07.h4 output_l8_B08.h4 output_l8_B09.h4 \
              output_l8_B10.h4 output_l8_B11.h4 output_l8_DDR.h4 \
              output_l8.h4)
    diff $file $ut_dir/expected_output_l8/$file
    if ($status != 0) then
        echo diff of $file failed!
        set exit_status = 1
    endif
end

if ($exit_status == 0) then
    echo L1G convertor tests PASS
endif

exit $exit_status

