--------------------------------------------------------
-- Ground Control Points table modifications.
--------------------------------------------------------

  DROP TABLE "DEV_GROUND_CONTROL_POINTS" cascade constraints;

--------------------------------------------------------
-- Image Chips table modifications.
--------------------------------------------------------

  DROP TABLE "DEV_IMAGE_CHIPS" cascade constraints;

--------------------------------------------------------
-- Drop "DEV_IMAGE_CHIPS" Primary Key sequence.
--------------------------------------------------------
  DROP SEQUENCE "DBSEQ_DEV_IMAGE_CHIPS";

--------------------------------------------------------
-- Create new table GCP_DATA_VERSION.
--------------------------------------------------------

  ---DROP TABLE "GCP_DATA_VERSION" cascade constraints;

--------------------------------------------------------
--  DDL for Sequence DBSEQ_DEV_IMAGE_CHIPS
--------------------------------------------------------

   CREATE SEQUENCE  "DBSEQ_DEV_IMAGE_CHIPS"  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 999 CACHE 20 NOORDER  NOCYCLE ;

--------------------------------------------------------
--  DDL for Table DEV_GROUND_CONTROL_POINTS
--------------------------------------------------------
PROMPT
PROMPT Creating DEV_GROUND_CONTROL_POINTS 
PROMPT

  CREATE TABLE "DEV_GROUND_CONTROL_POINTS" 
   (	"GROUND_CONTROL_POINTS_ID"		NUMBER(10,0),
	"ACTIVE"					VARCHAR2(1),
	"DATE_UPDATED"				DATE,
	"ELEVATION"				NUMBER(11,6),
	"LATITUDE"					NUMBER(8,6),
	"LONGITUDE"				NUMBER(9,6),
	"SHAPE"					"SDO_GEOMETRY",
	"SOURCE"					VARCHAR2(10),
	"TYPE"					VARCHAR2(10),
	"UPDATE_REASON"				VARCHAR2(10), 
	"VERSION"					NUMBER(4,0),
	"WRS_PATH"					NUMBER(3,0),
	"WRS_ROW"					NUMBER(3,0)
   ) ;
 
   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."GROUND_CONTROL_POINTS_ID" IS 'Primary Key';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."ACTIVE" IS 'Y/N flag indicating whether the Ground Control Point state is active.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."DATE_UPDATED" IS 'Date that this row was updated in the database.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."ELEVATION" IS 'GCP WGS84 ellipsoid height in meters.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."LATITUDE" IS 'GCP latitude in degrees.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."LONGITUDE" IS 'GCP longitude in degrees.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."SHAPE" IS 'Geometry information for spatial search on this ground control point.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."SOURCE" IS 'Source of GCP, either DOQ or GLS.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."TYPE" IS 'Control/validation point flag, either CONTROL or VALIDATION.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."VERSION" IS 'Current version of the Ground Control Point.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."UPDATE_REASON" IS 'Reason why the GCP was updated.';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."WRS_PATH" IS 'WRS-defined nominal Landsat satellite track (path).';

   COMMENT ON COLUMN "DEV_GROUND_CONTROL_POINTS"."WRS_ROW" IS 'WRS latitudinal center line of a Landsat image. Values:  001-059 = Northern Hemisphere (Descending).  060 = Equator (Descending).  061-119 = Southern Hemisphere (Descending).  120-122 = Southern Polar Zone (Descending).  123-183 = Southern Hemisphere (Ascending).  184 = Equator (Ascending).  185-246 = Northern Hemisphere (Ascending).  247-248 = Northern Polar Zone (Descending).';

   COMMENT ON TABLE "DEV_GROUND_CONTROL_POINTS"  IS 'Ground control points are a precisely known UTM, Polar Stereographic or Geographic coordinate of a point on the earth used to geolocate the image. GCPs are needed to perform precision correction for the L1T products.  They represent a point on the surface of the earth of known location (i.e. fixed within an established co-ordinate system) which is used to geo-reference Image data sources, such as remotely sensed images or scanned maps.';

GRANT SELECT ON "DEV_GROUND_CONTROL_POINTS" TO PUBLIC;

--------------------------------------------------------
--  Constraints for Table DEV_GROUND_CONTROL_POINTS
--------------------------------------------------------

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_CK1" CHECK (TYPE IN ('CONTROL','VALIDATION')) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_CK2" CHECK (SOURCE IN ('DOQ','GLS')) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_CK3" CHECK (VERSION BETWEEN 1 AND 9999) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_CK4" CHECK (WRS_PATH BETWEEN 1 AND 233) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_CK5" CHECK (WRS_ROW BETWEEN 1 AND 248) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_CK6" CHECK (ACTIVE IN ('Y','N')) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK1" CHECK ("GROUND_CONTROL_POINTS_ID" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK2" CHECK ("SOURCE" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK3" CHECK ("LATITUDE" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK4" CHECK ("LONGITUDE" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK5" CHECK ("ELEVATION" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK6" CHECK ("TYPE" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK7" CHECK ("VERSION" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK8" CHECK ("DATE_UPDATED" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK9" CHECK ("WRS_PATH" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK10" CHECK ("WRS_ROW" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_NN_CK11" CHECK ("ACTIVE" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_PK" PRIMARY KEY ("GROUND_CONTROL_POINTS_ID") ENABLE;

  ALTER TABLE "DEV_GROUND_CONTROL_POINTS" ADD CONSTRAINT "GROUND_CONTROL_POINTS_UQ1" UNIQUE ("SOURCE", "LATITUDE", "LONGITUDE", "ELEVATION", "GROUND_CONTROL_POINTS_ID") ENABLE;

--------------------------------------------------------
--  DDL for Table DEV_IMAGE_CHIPS
--------------------------------------------------------
PROMPT
PROMPT Creating DEV_IMAGE_CHIPS
PROMPT

  CREATE TABLE "DEV_IMAGE_CHIPS" 
   (	"IMAGE_CHIPS_ID"			VARCHAR2(13),
	"GROUND_CONTROL_POINTS_ID" 	NUMBER(10,0),
	"VERSION"					NUMBER(4,0),
	"ACTIVE"					VARCHAR2(1),
	"DATE_ACQUIRED"				DATE, 
	"DATE_UPDATED"				DATE,
	"REFERENCE_LINE"			NUMBER(12,6),
	"REFERENCE_SAMPLE"			NUMBER(12,6),
	"PROJECTION"				VARCHAR2(4), 
	"PROJECTION_Y"				NUMBER(15,6),
	"PROJECTION_X"				NUMBER(15,6),
	"ZONE_CODE"				NUMBER(2,0), 
	"PIXEL_SIZE_X"				NUMBER(10,6),
	"PIXEL_SIZE_Y"				NUMBER(10,6),
	"LINES"					NUMBER(10,6),
	"SAMPLES"					NUMBER(10,6),
	"SENSOR"					VARCHAR2(10), 
	"ABS_REL_FLAG"				VARCHAR2(3), 
	"CHIP_DATA"				BLOB,
	"CHIP_DATA_TYPE"			VARCHAR2(5) DEFAULT 'BYTE',
	"SELECT_METHOD"				VARCHAR2(10),
	"MORAVEC_RANK"				NUMBER(4,0),
	"SOURCE_WRS_PATH"			NUMBER(3,0),
	"SOURCE_WRS_ROW"			NUMBER(3,0)
   ) ;
 

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."IMAGE_CHIPS_ID" IS 'Primary Key.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."GROUND_CONTROL_POINTS_ID" IS 'Foreign Key to GROUND_CONTROL_POINTS Parent.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."VERSION" IS 'Current version of the Ground Control Point.';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."ACTIVE" IS 'Y/N flag indicating whether the GCP image chip state is active.';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."REFERENCE_LINE" IS 'GCP location within image chip - line coordinate (fractional pixel).';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."REFERENCE_SAMPLE" IS 'GCP location within image chip - sample coordinate (fractional pixel).';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."PROJECTION" IS 'UTM or PS';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."ZONE_CODE" IS 'UTM zone number (1-60), 0 for PS.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."PROJECTION_Y" IS 'GCP projected Y coordinate in meters.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."PROJECTION_X" IS 'GCP projected X coordinate in meters.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."PIXEL_SIZE_X" IS 'Chip pixel size in meters.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."PIXEL_SIZE_Y" IS 'Chip pixel size in meters.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."LINES" IS 'Number of lines in image chip.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."SAMPLES" IS 'Number of samples in image chip.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."SENSOR" IS 'Sensor (satelite) that served as the source for the image chips.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."DATE_ACQUIRED" IS 'Acquisition date of GCP source.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."DATE_UPDATED" IS 'Date that this row was updated in the database.';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."ABS_REL_FLAG" IS 'Information to be added later.';
 
   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."CHIP_DATA" IS 'Image data.';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."CHIP_DATA_TYPE" IS 'Describes data type of image chip.';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."SOURCE_WRS_PATH" IS 'WRS-defined nominal Landsat satellite track (path).';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."SOURCE_WRS_ROW" IS 'WRS latitudinal center line of a Landsat image. Values:  001-059 = Northern Hemisphere (Descending).  060 = Equator (Descending).  061-119 = Southern Hemisphere (Descending).  120-122 = Southern Polar Zone (Descending).  123-183 = Southern Hemisphere (Ascending).  184 = Equator (Ascending).  185-246 = Northern Hemisphere (Ascending).  247-248 = Northern Polar Zone (Descending).';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."SELECT_METHOD" IS 'SME Provide details.';

   COMMENT ON COLUMN "DEV_IMAGE_CHIPS"."MORAVEC_RANK" IS 'SME Provide details.';

   COMMENT ON TABLE "DEV_IMAGE_CHIPS"  IS 'The GCP image chips are correlated to the product imagery to identify pixel and line locations that correspond to georeferenced image chip positions.  The information provides for the ability to define search criteria and return correlated matches.';

GRANT SELECT ON DEV_IMAGE_CHIPS TO PUBLIC;

--------------------------------------------------------
--  Constraints for Table DEV_IMAGE_CHIPS
--------------------------------------------------------

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK1" CHECK (ZONE_CODE BETWEEN 0 AND 60) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK2" CHECK (PROJECTION IN ('UTM','PS')) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK3" CHECK (CHIP_DATA_TYPE IN ('BYTE','I*2','UI*2','R*4')) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK4" CHECK (VERSION BETWEEN 1 AND 9999) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK5" CHECK (SOURCE_WRS_PATH BETWEEN 1 AND 233) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK6" CHECK (SOURCE_WRS_ROW BETWEEN 1 AND 248) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK7" CHECK (SELECT_METHOD IN ('MORAVEC','GRID','MANUAL','UNKNOWN')) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK8" CHECK (MORAVEC_RANK BETWEEN -1 AND 9999) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_CK9" CHECK (ACTIVE IN ('Y','N')) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK1" CHECK ("IMAGE_CHIPS_ID" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK2" CHECK ("REFERENCE_LINE" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK3" CHECK ("REFERENCE_SAMPLE" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK4" CHECK ("PROJECTION" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK5" CHECK ("ZONE_CODE" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK6" CHECK ("PROJECTION_Y" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK7" CHECK ("PROJECTION_X" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK8" CHECK ("PIXEL_SIZE_X" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK9" CHECK ("PIXEL_SIZE_Y" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK10" CHECK ("LINES" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK11" CHECK ("SAMPLES" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK12" CHECK ("SENSOR" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK13" CHECK ("DATE_ACQUIRED" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK14" CHECK ("ABS_REL_FLAG" IS NOT NULL) ENABLE;
 
  --ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK15" CHECK ("CHIP_DATA" IS NOT NULL) ENABLE;
 
  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK16" CHECK ("CHIP_DATA_TYPE" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK17" CHECK ("VERSION" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK18" CHECK ("DATE_UPDATED" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK19" CHECK ("SOURCE_WRS_PATH" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK20" CHECK ("SOURCE_WRS_ROW" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_NN_CK21" CHECK ("ACTIVE" IS NOT NULL) ENABLE;

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_PK" PRIMARY KEY ("IMAGE_CHIPS_ID") ENABLE;
--------------------------------------------------------
--  INDEX generation.  
--  Note:  DDL statements creating primary keys / unique indexes are
--  commented out intentially (to prevent error conditions) and listed only as reference 
--  points to the indexes that are automatically generated at the time the primary key / 
--  unique constraints are created.
--------------------------------------------------------

--------------------------------------------------------
--  DDL for Index IMAGE_CHIPS_PK
--------------------------------------------------------

  CREATE UNIQUE INDEX "IMAGE_CHIPS_PK" ON "DEV_IMAGE_CHIPS" ("IMAGE_CHIPS_ID");

--------------------------------------------------------
--  DDL for Index IMAGE_CHIPS_NONUQ_IDX1
--------------------------------------------------------

  CREATE INDEX "IMAGE_CHIPS_NONUQ_IDX1" ON "DEV_IMAGE_CHIPS" ("GROUND_CONTROL_POINTS_ID");

--------------------------------------------------------
--  DDL for Index GROUND_CONTROL_POINTS_PK
--------------------------------------------------------

  CREATE UNIQUE INDEX "GROUND_CONTROL_POINTS_PK" ON "DEV_GROUND_CONTROL_POINTS" ("GROUND_CONTROL_POINTS_ID");

--------------------------------------------------------
--  DDL for Index GROUND_CONTROL_POINTS_UQ1
--------------------------------------------------------

--  CREATE UNIQUE INDEX "GROUND_CONTROL_POINTS_UQ1" ON "DEV_GROUND_CONTROL_POINTS" ("SOURCE", "LATITUDE", "LONGITUDE", "ELEVATION", "GCP_ID");

--------------------------------------------------------
--  DDL for Index GROUND_CTRL_POINTS_NONUQ_IDX1
--------------------------------------------------------

  CREATE INDEX "GROUND_CTRL_POINTS_NONUQ_IDX1" ON "DEV_GROUND_CONTROL_POINTS" ("GCP_ID");

--------------------------------------------------------
--  Delete the spatial index before updating the USER_SDO_GEOM_METADATA view.
--------------------------------------------------------
DELETE FROM USER_SDO_GEOM_METADATA WHERE TABLE_NAME = 'DEV_GROUND_CONTROL_POINTS';
COMMIT;

--------------------------------------------------------
--  Update the USER_SDO_GEOM_METADATA view.  This is required before the Spatial Index can
--  be created.
--------------------------------------------------------

INSERT INTO USER_SDO_GEOM_METADATA 
  VALUES (
  'DEV_GROUND_CONTROL_POINTS',
  'shape',
  SDO_DIM_ARRAY(   -- 20X20 grid
    SDO_DIM_ELEMENT('longitude', -180, 180, 1),
    SDO_DIM_ELEMENT('latitude', -90, 90, 1)
     ),
  8307   -- SRID
);

--------------------------------------------------------
--  DDL for Index GCP_SPATIAL_INDEX
--------------------------------------------------------

  CREATE INDEX "GCP_SPATIAL_INDEX" ON "DEV_GROUND_CONTROL_POINTS" ("SHAPE") 
   INDEXTYPE IS "MDSYS"."SPATIAL_INDEX" ;

--------------------------------------------------------
--  Ref Constraints for Table DEV_IMAGE_CHIPS
--------------------------------------------------------

  ALTER TABLE "DEV_IMAGE_CHIPS" ADD CONSTRAINT "IMAGE_CHIPS_GROUND_CONTRO_FK1" FOREIGN KEY ("GROUND_CONTROL_POINTS_ID")
	  REFERENCES "DEV_GROUND_CONTROL_POINTS" ("GROUND_CONTROL_POINTS_ID") ENABLE;


--------------------------------------------------------
--  DDL for Table GCP_DATA_VERSION
--------------------------------------------------------
PROMPT
PROMPT Creating GCP_DATA_VERSION 
PROMPT

 CREATE TABLE "DEV_GCP_DATA_VERSION" 
   (	"VERSION"					NUMBER(2,0),
	"DESCRIPTION"				VARCHAR2(4000),
	"DATE_UPDATED"				DATE
   ) ;

COMMENT ON COLUMN "DEV_GCP_DATA_VERSION"."VERSION" IS 'Stores the overall GCP version number.  Primary Key.';
 
COMMENT ON COLUMN "DEV_GCP_DATA_VERSION"."DESCRIPTION" IS 'Narrative text describing the the version.';
 
COMMENT ON COLUMN "DEV_GCP_DATA_VERSION"."DATE_UPDATED" IS 'Date that this row was updated in the database.';

COMMENT ON TABLE "DEV_GCP_DATA_VERSION" IS 'Stores relevant information pertaining the the overall GCP version.';

GRANT SELECT ON "DEV_GCP_DATA_VERSION" TO PUBLIC;

--------------------------------------------------------
--  Constraints for Table GCP_DATA_VERSION
--------------------------------------------------------

ALTER TABLE "DEV_GCP_DATA_VERSION" ADD CONSTRAINT "GCP_DATA_VERSION_CK1" CHECK (VERSION BETWEEN 1 AND 99) ENABLE;

ALTER TABLE "DEV_GCP_DATA_VERSION" ADD CONSTRAINT "GCP_DATA_VERSION_NN_CK1" CHECK ("VERSION" IS NOT NULL) ENABLE;

ALTER TABLE "DEV_GCP_DATA_VERSION" ADD CONSTRAINT "GCP_DATA_VERSION_NN_CK2" CHECK ("DESCRIPTION" IS NOT NULL) ENABLE;

ALTER TABLE "DEV_GCP_DATA_VERSION" ADD CONSTRAINT "GCP_DATA_VERSION_NN_CK3" CHECK ("DATE_UPDATED" IS NOT NULL) ENABLE;

exit;

--INSERT INTO GCP_DATA_VERSION  VALUES ('2', 'N/A', 
    --TO_DATE('05-01-2014', 'MM-DD-YYYY'));

--BEGIN
--FOR Inum IN 1..20 
---LOOP 
--INSERT INTO DEV_GROUND_CONTROL_POINTS
 --  ("GROUND_CONTROL_POINTS_ID",	"ACTIVE", "DATE_UPDATED", "ELEVATION", 
 --   "LATITUDE", "LONGITUDE", "SHAPE", "SOURCE", "TYPE",	"UPDATE_REASON", 
--	"VERSION", "WRS_PATH", "WRS_ROW") 
 --   VALUES (CONCAT('38037500',Inum), 'Y', SYSDATE, 10000, 11.112333, 12.334566, 
  --  NULL, 'GLS', 'CONTROL', NULL, 1, 40, 39); 
--INSERT INTO DEV_IMAGE_CHIPS ("IMAGE_CHIPS_ID", "GROUND_CONTROL_POINTS_ID", "VERSION",
--	"ACTIVE", "DATE_ACQUIRED", "DATE_UPDATED", "REFERENCE_LINE", "REFERENCE_SAMPLE",
---	"PROJECTION", "PROJECTION_Y", "PROJECTION_X", "ZONE_CODE", "PIXEL_SIZE_X",
--	"PIXEL_SIZE_Y",	"LINES", "SAMPLES", "SENSOR", "ABS_REL_FLAG", "CHIP_DATA",
--	"CHIP_DATA_TYPE", "SELECT_METHOD", "MORAVEC_RANK", "SOURCE_WRS_PATH", 
 --   "SOURCE_WRS_ROW"
  -- ) VALUES (CONCAT(CONCAT('38037500', Inum),'_01'),CONCAT('38037500',Inum), 1,
   --  'Y', SYSDATE, SYSDATE, 128,
--	128, 'UTM', 64, 64, 1, 256, 256, 5, 5, 'OLI', 'ABS', NULL,
--	'BYTE', 'GRID',	1, 40,	39) ;
--END LOOP;
--END;
--/


