
#ifndef BROWSEWOPARMS_H
#define BROWSEWOPARMS_H

/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name:   BrowseWOParms.h
 *
 * PURPOSE:
 * This is the declaration file of the BrowseWOParms class which is used to 
 * view work order information from the work_orders, wo_scripts, and wo_parms
 * tables.
 *
 *****************************************************************************/
 
/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "IASListViewItem.h"
#include "ui_BrowseWOParmsBase.h"

#define ALL_WORK_ORDERS "All Work Orders"
#define ALL_PROCEDURES "All Procedures"
#define ALL_REQUESTERS "All Requesters"
#define MAX_BROWSE_FIELDS 14

class BrowseWOParms : public QWidget, public Ui::BrowseWOParmsBase
{
    Q_OBJECT

    public:

        BrowseWOParms(QWidget* parent = 0,
                      Qt::WindowFlags fl = 0);

    protected slots:

        void popWOScripts(); // Populates work order scripts listview
        void popWOParms();   // Populates the work order parameter listview
        void popWO();             // Populates the work order listview
        void queryWO();           // Queries dbase using filters
        void changeToDateMin();   // Resets the min of the todate filter
        void changeFromDateMax(); // Resets the max of the from date filter
        void setWoFilter();       // Sets up WO ID filter based on date range
        void changedSchema(const QString & val = QString::null);
                                  // Updates the procedure Ids.

    private:

        void setupFilters();      // Sets up the filter lists
        QString convertText(QString fldText, QString fldName);
                                  // Converts table codes to strings 
        void setupListViews();    // Sets up listview columns
        void getInstances();      // Gets all of the instance names
        QString woWhereClause();  // Creates the filter query clause
        void initStructs();       // Initialize column info structures

        int m_numWOFields;        // Number of WO fields in the WO listview
        int m_numWOScriptsFields; // Number of fields in the WO scripts listview
        int m_numWOParmsFields;   // Number of fields in the WO parms listview
        lvFields woFields[MAX_BROWSE_FIELDS];
        lvFields woScriptsFields[MAX_BROWSE_FIELDS];
        lvFields woParmsFields[MAX_BROWSE_FIELDS];
        columnDataTypesList m_woTypesList; // Contains listview column types
        bool getCurrentConfiguration(QString& instance, QString& satellite,
            QString& sensor); // Gets the current instace, satellite, and sensor
};

#endif /* BROWSEWOPARMS_H */

