#ifndef CREATE_NEW_PROCEDURE_H
#define CREATE_NEW_PROCEDURE_H
/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name:   CreateNewProcedure.h
 *
 * PURPOSE:
 * This is the definition of the CreateNewProcedure class which is used to 
 * create new test procedures.
 *
 *****************************************************************************/
 
/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "ui_CreateNewProcedureBase.h"
#include "IASParameterModel.h"

class CreateNewProcedure : public QWidget, public Ui::CreateNewProcedureBase
{
    Q_OBJECT

    public:

        CreateNewProcedure(QWidget* parent = 0,
                           Qt::WindowFlags fl = 0);

    protected slots:

        void commitAndClose();      // commits dbase changes and closes 
        void rollbackAndClose();    // rolls back dbase changes and closes
        void showPopupMenu(const QPoint&);
        void copyFromProcedure();
        void deleteScript();
        bool validateProcedureName();
        void selectScriptToInsert();
        void enteredParmCell(const QModelIndex& pIndex);
        void modifiedParmCell(const QModelIndex& pIndex); 
        void writeNewProceduretoDatabase(); 
        void scriptSelectionChanged();
        void verifyScriptSelectionChanged(const QModelIndex& sIndex);
        void updateParametersWithDefaultValues(const QString& str);
        void descReturnPressed();
        void sensorSelected();

    private slots:

       void moveScriptUp();
       void moveScriptDown();

    private:

        bool m_validNewProcedureName;   // Flag indicates the new procedure 
                                        // name is valid
        QStringList m_changedScripts;   // List of changed strings, the number
                                        // of modified (changed) parameters and
                                        // a list of rows containing changed
                                        // parameters
        QStringList m_changedParameters;// List of changed parameters, script 
                                        // containing the parameter, and their
                                        // values
        QStringList m_globalParameterElements;  // List containing the element
                                        // occurrence of the changed parameter
        QStringList m_globalParameterNames; // List of all modified global
                                            // parameters
        QStringList m_globalParameterValues; // List containing the values for
                                        // the global
        QStringList m_globalParameterRequired; // List containing the values for
                                        // the required field 
        QStringList m_globalParameterAttributes; // List containing the values 
                                        // for the attributes 
        int m_currentScriptsTblRow;
        bool ignore;
        QString m_currentParmVal;       // value of the currently selected cell
                                        // on entry into the parameters table 
                                        // cell.
        int m_NumScripts;               // Contains the number of scripts 
                                        // displayed in the scripts table 
                                                                                
        QStringList m_strRows;          // List of the rows that have been
                                        // modified for the current script
                                        // (strCurrentScript);
        QStringList::Iterator m_Rows_it; // List iterator that is used to step
                                        // through the rows in m_strRows
        QString strCurrentScript;       // Script we are currently working with
        int m_previousScriptsTblRow;    // Last row selected, set when a new 
                                        // row is selected in the tblScripts 
                                        // table, the previous row is set to
                                        // this value
        QString schema;                 // schema we are working with

        // Variables used for accessing the models.
        IASParameterModel* sModel;
        IASParameterModel* pModel;

        bool checkParmMaxMin(int); 
        bool fillCopyDefaultValuesList();
        void fillSatsAndSensorsList();
        bool fillProceduresList();  
        void fillScriptsList();
        bool getCurrRow(int &row);
        bool getNextRow(bool, const QString, int &);
        QStringList getParamElements(QString);
        int  getCurrentNumParmsChanged( QString &);
        int  getParamElementIndex(QString, QString);
        void setParmGlobalValues();
        int  getParmValues(const QString, QStringList &);
        bool getParmValues(QString, int, QStringList &);
        bool getAttribute(QString, QString &);
        QStringList getStoredModifiedRows(QString); 
        int  getStoredNumParmsChanged(QString);
        void insertParmItems();
        void insertParmValueItem();
        void insertParmAttributeItem();
        void insertRow(QString, int);
        void insertReplaceRow(QString, int);
        bool isParamElementPresent(QString, QString);
        bool isRowPresent(QString, int); 
        bool isScriptPresent(QString);
        QStringList::Iterator locateScriptBeginP(QString);
        QStringList::Iterator locateScriptBeginS(QString);
        QStringList::Iterator locateScriptRow(QString, int);
        int locateScriptEnd(QString);
        void replaceRow(QString, int);
        void saveScriptParmValues();
        void setParmValuesTexttoStoredValues(QString);
        void setupParmsTable();
        void setupScriptsTable();
        void delScriptAndUpdateSeqNbrs(const QModelIndex& sIndex); 
        bool validateParm(int row);
        bool verifyParmUpdate();
        bool writeNewProceduretoDefParmsTable();
        bool writeNewProceduretoModulesTable(); 
        bool writeNewProceduretoSubModulesTable();  
};

#endif // CREATE_NEW_PROCEDURE_H

