/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name:   CreateNewScript.h
 *
 * PURPOSE:
 * This is the definition of the CreateNewScript class which is used to 
 * create new test scripts.
 *
 *****************************************************************************/
#ifndef CREATE_NEW_SCRIPT_H
#define CREATE_NEW_SCRIPT_H

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "ui_CreateNewScriptBase.h"
#include "IASParameterModel.h"

class CreateNewScript : public QWidget, public Ui::CreateNewScriptBase
{
    Q_OBJECT

    public:

        CreateNewScript(QWidget* parent = 0,
                        Qt::WindowFlags fl = 0);

    protected slots:

        void commitAndClose();		
        void rollbackAndClose();	
        void DeleteParam();
        void clearList();
        void accept();
        void selectScriptToInsert(const QString&);
        void selectedParameterToInsert(const QString&);
        bool validateScriptName();
        void sensorSelected();

    private:

        void fillAddParamsList();
        int getNextParmOccur(QString, int&, QString&);
        void fillScriptsList();		 
        void fillSatsAndSensorsList();		 
        void setupParmsTable();	
        void insertParmValueItem();
        void writeNewScripttoDatabase();	
        bool writeNewScripttoModulesTable();
        bool writeNewScripttoParametersTable();
        bool verifyDistinctParameters();
        QStringList parameterTypes();

        bool m_validNewScriptName;		
        QString m_schema;  // The schema we are working with.
        QStringList m_options; // The options used in the table's QComboBox.

        IASParameterModel* m_model;
};

#endif // CREATE_NEW_SCRIPT_H

