#ifndef OUI_CREATEWO_H
#define OUI_CREATEWO_H

/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name: CreateWO.h
 *
 * PURPOSE:
 * This is the declaration file of the CreateWO class which is used to
 * Create and modify a work order.
 *
 *****************************************************************************/

#include "ui_CreateWOBase.h"
#include "IASParameterModel.h"

class CreateWO : public QWidget, public Ui::CreateWOBase
{
    Q_OBJECT

    public:

        CreateWO(QWidget* parent = 0,
                 Qt::WindowFlags fl = 0);

        bool initialize();
        void selectDefaultPriority();

    protected slots:

        void populateScriptId(const QString& procId);

    protected:

        QString changeDateFormat(const QString& date);
        void insertWOParms();

        QString cw_l0rDataPath;
        QString cw_l0rDataStatus;
        void showEvent(QShowEvent *event);

        bool allowReset;
        bool allowParmChanges;

    private slots:

        void changedSchema(const QString&);
        void changedInstance(const QString& test);
        void deleteWorkOrder();
        virtual void closeEvent(QCloseEvent* ce);
        virtual void cancelWorkOrder();
        void updateCommonParms();
        void updateScriptParms();
        void updateWorkOrders();
        void getCalParmFile();
        void getL0RDataPath();
        void getWorkOrderPath();

    private:

        void populateDefaults();
        virtual bool populateInitialDb();
        virtual void setTitle();
        virtual void setupButtons();
        void setupSignalsSlots();
        virtual QString getWoId();
        void updatePcdDefEph();
        void updateOutputDbSchema();
        void getProcedureIds();
        virtual QString getScriptSql(const QString& id);
        virtual void populateNewWorkOrder();
        void deleteWOParms();
        virtual QString getWoParmSql();
        void getInstances();
        bool getCurrentConfiguration(QString& instance, QString& satellite,
                                QString& sensor);
        QString m_systemId;
        QString m_oldSatSensor;
        IASParameterModel* m_model;
        bool m_deletedFlag;
        int scriptIDHeaderWidth;
        QString instance_name;
};

#endif /* OUI_CREATEWO_H */

