
#ifndef EVENTS_H
#define EVENTS_H

/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name:   Events.h
 *
 * PURPOSE:
 * This is the declaration file of the Events class which is used to 
 * view messages from IAS processing (events table) and task status.
 *
 *****************************************************************************/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "ui_EventsBase.h"
#include "IASListViewItem.h"

class Events : public QWidget, public Ui::EventsBase
{
    Q_OBJECT

    public:

        Events(QWidget* parent = 0,
               Qt::WindowFlags fl = 0);

    protected slots:

        void updateTaskStatus(); // Get the task IDs and and status of each
        void updateEvents();     // Get events from the events table
        void timerExpired();     // Update events listview
        void resetTimer(int timeInterval); // Reset on time change
        void dispMessage();      // Get the detailed message for an event
        void changedWO();        // Update events and reset taskId filter
        void changedTaskId();    // Update events and reset WO filter
        void issueQuery();       // Update events listview and status 

    private:

        void setupListViews();   // Set up column names and widths
        void setupFilters();     // Initialize filter lists

        int m_numEventsFields;   // Number of fields in the events listview
        int m_lastInterval;      // Last value of the time interval filter
        columnDataTypesList m_colTypesList; // Contains listview column types
        QTimer *queryTimer;      // Timer used for automatic events query
        QLabel *lblTask[10];     // pointers to qlabels for the labels to
                                 // hold task names
        QLabel *lblStatus[10];   // pointer to qlabels for the labels to
                                 // hold the task statuses
        int m_TaskCount;
        QString m_systemId;
};

#endif //EVENTS_H

