
#ifndef MODGLOBALWOPARMS_H
#define MODGLOBALWOPARMS_H

/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name:   ModGlobalWOParms.h
 *
 * PURPOSE: This is the declaration file of the ModGlobalWOParms class which
 *          is used to view work order information from the work_orders,
 *          wo_scripts, and wo_parms tables.
 *
 *****************************************************************************/
 
/* System Includes */

/* Qt Includes */
#include <QtCore>

/* Local Includes */
#include "ui_ModGlobalWOParmsBase.h"
#include "IASParameterModel.h"

class ModGlobalWOParms : public QDialog, public Ui::ModGlobalWOParmsBase
{
    Q_OBJECT

    public:

        ModGlobalWOParms(const QString workOrderId,
                         const QString procedureId,
                         const QString instance,
                         const QString satellite,
                         const QString sensor,
                         QWidget* parent = 0,
                         Qt::WindowFlags fl = 0);

    protected slots:

        void dispParmDesc(const QModelIndex& index);
                                 // displays a description for a parameter
        void updateDBase(const QModelIndex& index);
                                 // updates parm value after change
        void commitAndClose();   // commits dbase changes and closes dialog
        void rollbackAndClose(); // rollback any database changes and close
                                 // the dialog

    private:

        void createParmTable();       // Sets up the common parms table
        QString getParmType(const QString& parmName,
                            const QString& parmOccur);
                                      // Gets parameter type from def_parms
        bool checkMaxMin(int row);    // Checks for parameter value in range
        bool updateTables(int row);   // Updates work order parameter tables 
        void configParmValueItem(IASParameterItem* item,
                                 const QString& parmName,
                                 const QString& value);
                                      // Inserts the proper item to select
                                      // the parameter value

        QString m_CurrentParmVal;     // Contains the current parameter value
        QString m_Instance;  // Instance name used throughout this session
        QString m_Satellite;  // Satellite used throughout this session
        QString m_Sensor;  // Sensorused throughout this session

        IASParameterModel* m_model;
};

#endif /* MODGLOBALWOPARMS_H */

