
#ifndef MODSCRIPTWOPARMS_H
#define MODSCRIPTWOPARMS_H

/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name:   ModScriptWOParms.h
 *
 * PURPOSE:
 * This is the definition of the ModScriptWOParms class which is used to 
 * modify parameter values and script status for scripts in a particular
 * work order.
 *
 *****************************************************************************/

/* System Includes */

/* Qt Includes */
#include <QtCore>

/* Local Includes */
#include "ui_ModScriptWOParmsBase.h"
#include "IASParameterModel.h"

class ModScriptWOParms : public QDialog, public Ui::ModScriptWOParmsBase
{
    Q_OBJECT

    public:

        ModScriptWOParms(const QString workOrderId,
                         const QString procedureId,
                         const QString instance,
                         const QString satellite,
                         const QString sensor,
                         const QString scriptId = "",
                         bool allowParmChanges = true, 
                         bool allowReset = true, 
                         QWidget* parent = 0);

    private slots:

        void popParmTable(int scriptsRow);
                                 // Populates the script parameters table

        void dispParmDesc(const QModelIndex& cIndex,
                          const QModelIndex& pIndex);
                                 // Displays the parameter description
        void updateParms(const QModelIndex& pIndex);
                                 // Checks for script parameter update

        void checkScriptState(const QModelIndex&);
                                 // Checks for update of the scripts state

        void scriptChanged(const QModelIndex& cIndex,
                           const QModelIndex& pIndex);
                                 // Checks and sets values whenever the current
                                 // script is changed.
        void commitAndClose();   // commits dbase changes and closes dialog
        void rollbackAndClose(); // rolls back dbase changes and closes dialog

        void continueWO(); // Sets failed scripts and WO state to pending
        void restartWO();  // Sets all scripts and WO state to pending

    private:

        void setupScriptsTable();  // Sets up the scripts table
        QString getCurrentWOState(QString id);
                                   // Retrieves the current work order state
        void setupParmsTable();    // Sets up the script parameters table
        QString convToState(QString code);
                                   // Converts wo_script state field codes
        QString convToCode(QString state); // Converts wo_scripts state codes
                                           // to state name
        void insertTypeRequired(int sriptsRow); // Inserts from def_parms into
                                                // the script parameters table
        void insertParmValueItem(); // Inserts combobox item or line edit
                                    // for parameter value
        bool updateParmsTable(int row, int scriptsRow);
                                   // Updates wo_parms table
        bool validateParm(int row); // Validates a parameter value

        bool allowedToUpdate(); // Double check before doing any updates.

        bool updateScriptRow(int row,
                             QString state);
                       // Updates a single script row to the specified state
        bool setWoStateToPending(); // Updates the work order state to pending

        int m_LastScriptsRow;    // Contains the last scripts table row accessed
        QString m_CurrentParmVal; // Contains the current parameters value
        QString m_LastScriptState; // Contains the state of the current script
        QString m_LastScriptExitcode; // Contains the exit code of the current
                                      // script
        QString m_Instance;  // Instance name used throughout this session
        QString m_Satellite;  // Satellite used throughout this session
        QString m_Sensor;  // Sensorused throughout this session
        QString m_initialWoState;

        /* Create variables to hold the script and script parameter models. */
        IASParameterModel* scriptDataModel;
        IASParameterModel* parameterDataModel;
        bool resetAllowed;
        bool parmChangesAllowed;
};

#endif /* MODSCRIPTWOPARMS_H */

