
#ifndef MODIFYWOFACTORY_H
#define MODIFYWOFACTORY_H

/****************************************************************************

    Name: ModifyWOFactory.h

    Purpose: To provide a mechanism to only allow one instance of a ModifyWO
             interface per work order.  This implementation does not
             prevent multiple instances of the UI from displaying the ModifyWO
             interface for the same work order.

 ****************************************************************************/

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "ModifyWO.h"

/****************************************************************************
    Name: ModifyWOFactory

    Design: This class is implemented as a singleton so that only one copy of
            it is usable at any time during the execution of the UI.

            This class is also written specifically for the ModifyWO
            interface.

            A QMap is used to track/manage the work order IDs that have a
            ModifyWO instance running.

            A QSignalMapper is used to determine when a ModifyWO instance is
            terminated, so that the work order ID can be removed from the
            QMap.
 ****************************************************************************/
class ModifyWOFactory : public QObject
{
    Q_OBJECT

    public:

        static ModifyWOFactory* instance();
        ModifyWO* newModifyWO(QString &workOrderId);
        bool isManaged(QString &workOrderId);
        void showModifyWindow(QString &workOrderId);

    public slots:
        void remove(const QString &workOrderId);

    private:

        ModifyWOFactory();

        static ModifyWOFactory *myInstance;

        QMap<QString, ModifyWO*> managedModifyWOs;
        QSignalMapper *signalMapper;
};

#endif /* MODIFYWOFACTORY_H */

