
/****************************************************************************

    Name: ModifyWOFactory.cpp

    Purpose: To provide the implementation for the class.

 ****************************************************************************/

/* Qt Includes */
#include <QtCore>
#include <QtGui>
#include <QtSql>

// IAS Qt Includes 
#include <IASQtConst.h>
#include <iasQtWoConst.h>

/* Local Includes */
#include "IASSqlQuery.h"
#include "ModifyWOFactory.h"

/* Initialize the instance variable to NULL */
ModifyWOFactory *ModifyWOFactory::myInstance = NULL;

/* Constructor to create the QSignalMapper object and connect it to the remove
   method.  Also make sure that the managedModifyWOs object is empty. */
ModifyWOFactory::ModifyWOFactory()
{
    signalMapper = new QSignalMapper(this);

    managedModifyWOs.clear();

    connect(signalMapper, SIGNAL(mapped(const QString &)),
            this, SLOT(remove(const QString &)));
}

/* Create and/or return the instance of the factory object. */
ModifyWOFactory* ModifyWOFactory::instance()
{
    /* If we don't have one create one */
    if (myInstance == NULL)
    {
        myInstance = new ModifyWOFactory();
    }

    return myInstance;
}

/* Create and/or return a managed ModifyWO object. */
ModifyWO* ModifyWOFactory::newModifyWO(QString &workOrderId)
{
    IASSqlQuery query;

    /* If we already have one for this work order ID return it or continue and
       create one. */
    if (managedModifyWOs.contains(workOrderId))
    {
        /* Show and raise the interface since the operator must not remember
           or see that one is already available for this work order ID. */
        managedModifyWOs[workOrderId]->showNormal();
        managedModifyWOs[workOrderId]->raise();
        return managedModifyWOs[workOrderId];
    }

    /* Get the current state of the work order. */
    QString sqlStmt  = "SELECT state FROM work_orders"
                       " WHERE work_order_id = '" + workOrderId + "'";

    if(!query.exec(sqlStmt, __FILE__, __LINE__))
    {
        QMessageBox::critical(0, "Error",
                              "Failed to retrieve work order state");
        return NULL;
    }
    query.next();

    /* If the state is not one of the listed ones return NULL to indicate that
       we can't modify this work order. */
    QString state = query.value("STATE").toString();
    if(state != DB_WO_PENDING && state != DB_WO_HALTED &&
       state != DB_WO_RUNNING && state != DB_WO_EVALUATE)
    {
        QMessageBox::warning(0, "Error",
            "Work order state is not valid for modifying the work order.\n"
            "Only work orders in the 'Pending', 'Halted', 'Running', and"
            " 'Evaluate' states can be modified.",
            QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
        return NULL;
    }

    /* We made it here so create a ModifyWO object. */
    ModifyWO *modifyWO = new ModifyWO(workOrderId, 0);

    /* Attempt to initialize the ModifyWO object. */
    if (!modifyWO->initialize())
    {
        /* If it failed to initialize then terminate the interface. */
        modifyWO->close();
        QMessageBox::critical(0, "Error",
                              "Failed to initialize ModifyWO");
        return NULL;
    }

    /* Add the work order ID and ModifyWO object to the managing QMap. */
    managedModifyWOs[workOrderId] = modifyWO;
    /* Connect the destroyed signal to the signal mapper. */
    connect(modifyWO, SIGNAL(destroyed()), signalMapper, SLOT(map()));
    /* Set the mapping value to the work order ID so that we know where the
       signal came from. */
    signalMapper->setMapping(modifyWO, workOrderId);

    /* Finally show and raise the interface before returning the object. */
    modifyWO->showNormal();
    modifyWO->raise();

    return modifyWO;
}

/* Create and/or return a managed ModifyWO object. */
bool ModifyWOFactory::isManaged(QString &workOrderId)
{
    /* Check and see if we are managing the work order. */
    if (managedModifyWOs.contains(workOrderId))
    {
        return true;
    }

    return false;
}

/* Show the window if we are still managing it. */
void ModifyWOFactory::showModifyWindow(QString &workOrderId)
{
    /* Check and see if we are managing the work order. */
    if (managedModifyWOs.contains(workOrderId))
    {
        managedModifyWOs[workOrderId]->showNormal();
        managedModifyWOs[workOrderId]->raise();
    }
}

/* Remove the work order ID from the signal mapper and managing QMap */
void ModifyWOFactory::remove(const QString &workOrderId)
{
    signalMapper->removeMappings(managedModifyWOs[workOrderId]);

    managedModifyWOs.remove(workOrderId);
}

