#!/bin/csh -f
################################################################################
# Name: create_informal_wos.csh
#
# Description:
#   This script runs each processing flow under a scene which requires SSM
#   positions to ensure they evaluate. They just need to reach the evaluate
#   state. No data comparisions required.
################################################################################

set comments = ( \
    "Informal Generate L1R" \
    "Informal L1GT Product" \
    "Informal L1T Product" \
    "Informal Geodetic Accuracy" \
    "Informal Geometric Accuracy" \
    "Informal Band Calibration TIRS" \
    "Informal Band to Band OLI-TIRS" \
    "Informal TIRS Alignment" \
    "Informal L1T with PICS" \
    "Informal Generate Chips" \
    "Informal L1T with Sun Correction" \
    "Informal TIRS SSM Calibration" \
)

set lunar_comments = ( \
    "Informal Lunar Product" \
)

set procedures = ( \
    "Generate L1R" \
    "L1GT Product" \
    "L1T Product" \
    "Geodetic Accuracy" \
    "Geometric Accuracy" \
    "Band Calibration TIRS" \
    "Band to Band OLI-TIRS" \
    "TIRS Alignment" \
    "L1T with PICS" \
    "Generate Chips" \
    "L1T with Sun Correction" \
    "TIRS SSM Calibration" \
)

set lunar_procedures = ( \
    "L1G Lunar Product" \
)

set scene_id = "LC80400332015052LGN00"
set l0r_path_dir = "LC80400332015052LGN00/LC80400332015052LGN00"

set lunar_collection_id = "LO800U0616342013204LGN00"
set lunar_l0r_path_dir = "LO800U0616342013204LGN00/LO800U0616342013204LGN00"

set index = 0
set pwg_status = 0
echo "Inserting Work Orders"

# Place orders using the test scene
while ( $index < ${#comments} )
    @ index++

    set output = `PWG \
        -interactive \
        -procedure_id "$procedures[$index]" \
        -scene_id $scene_id \
        -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dir \
        -comment "$comments[$index]"`
    set save_status = $status

    if ( $save_status ) then
        echo $output
        echo "Error loading dataset $index"
        @ pwg_status++
    endif
end

# Place orders using the lunar collection
set index = 0
while ( $index < ${#lunar_comments} )
    @ index++

    set output = `PWG \
        -interactive \
        -procedure_id "$lunar_procedures[$index]" \
        -scene_id $lunar_collection_id \
        -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$lunar_l0r_path_dir \
        -comment "$lunar_comments[$index]"`
    set save_status = $status

    if ( $save_status ) then
        echo $output
        echo "Error loading dataset $index"
        @ pwg_status++
    endif
end

if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders"
    exit 1
endif

echo "All work orders created successfully"

exit 0
