#!/bin/csh -f
#
# Removes CPF, BPF, and RLUT files from the indicated environment.  Currently,
# developer and the IT environments are supported.

# pick the correct
if ($1 == "dev") then
    set cpf_schema = ""
    set eval_cpf_schema = ""
    set bpf_schema = ""
    set eval_bpf_schema = ""
else if ($1 == "it") then
    set cpf_schema = "CPF."
    set eval_cpf_schema = "CPF_EVAL."
    set bpf_schema = "BPF."
    set eval_bpf_schema = "BPF_EVAL."
else if ($1 == "st") then
    set cpf_schema = "CPF."
    set eval_cpf_schema = "CPF_EVAL."
    set bpf_schema = "BPF."
    set eval_bpf_schema = "BPF_EVAL."
else
    echo "Unsupported environment: $1"
    echo "Usage: remove_cal_files_from_db.csh dev|it|st [cpf|bpf|rlut]"
    exit 1
endif

set remove_cpf = "Y"
set remove_bpf = "Y"
set remove_rlut = "Y"
if ($2 == "cpf") then
    set remove_bpf = "N"
    set remove_rlut = "N"
else if ($2 == "bpf") then
    set remove_cpf = "N"
    set remove_rlut = "N"
else if ($2 == "rlut") then
    set remove_cpf = "N"
    set remove_bpf = "N"
endif

# Delete all the entries from the RLUT_MAIN table
if ($remove_rlut == "Y") then
    echo "Removing RLUT files from RLUT_MAIN"
    sqlplus -s ${IAS_DB_L8_OLITIRS} << ENDRLUT
        set head off;
        DELETE FROM ${cpf_schema}RLUT_MAIN;
        exit;
ENDRLUT
endif

# Delete the CPFs from the following tables:
#   CPF_GROUP, CPF_GROUP_PARAMETER, CPF_MAIN, CPF_MAIN_GROUP, 
#   CPF_PARAMETER, CPF_PARAMETER_VALUES
# Note the CPF_PARAMETER table is left alone since it doesn't contain info 
# specific to any CPF contents, just parameter names.
if ($remove_cpf == "Y") then
    echo "Removing CPF files from CPF_MAIN and the related child tables"
    sqlplus -s ${IAS_DB_L8_OLITIRS} << ENDCPF
        set head off;
        DELETE FROM ${cpf_schema}CPF_PARAMETER_VALUES;
        DELETE FROM ${cpf_schema}CPF_GROUP_PARAMETER;
        DELETE FROM ${cpf_schema}CPF_MAIN_GROUP;
        DELETE FROM ${cpf_schema}CPF_GROUP;
        DELETE FROM ${cpf_schema}CPF_MAIN;
        exit;
ENDCPF

# Delete the CPFs from the following tables for the eval schema:
#   CPF_GROUP, CPF_GROUP_PARAMETER, CPF_MAIN, CPF_MAIN_GROUP, 
#   CPF_PARAMETER, CPF_PARAMETER_VALUES
    echo "Removing CPF files from the EVAL CPF_MAIN and the related child tables"
    sqlplus -s ${IAS_DB_L8_OLITIRS_EVAL} << ENDEVALCPF
        set head off;
        DELETE FROM ${eval_cpf_schema}CPF_PARAMETER_VALUES;
        DELETE FROM ${eval_cpf_schema}CPF_GROUP;
        DELETE FROM ${eval_cpf_schema}CPF_GROUP_PARAMETER;
        DELETE FROM ${eval_cpf_schema}CPF_MAIN_GROUP;
        DELETE FROM ${eval_cpf_schema}CPF_MAIN;
        exit;
ENDEVALCPF
endif

# Delete the BPFs from the following tables:
#   BPF_GROUP, BPF_MAIN, BPF_MAIN_GROUP, BPF_PARAMETER_VALUES_DATA
# Note that BPF_PARAMETER is not deleted since it doesn't contain info for any
# specific BPF file
if ($remove_bpf == "Y") then
    echo "Removing BPF files from BPF_MAIN and the related child tables"
    sqlplus -s ${IAS_DB_L8_OLITIRS} << ENDBPF
        set head off;
        DELETE FROM ${bpf_schema}BPF_PARAMETER_VALUES_DATA;
        DELETE FROM ${bpf_schema}BPF_MAIN_GROUP;
        DELETE FROM ${bpf_schema}BPF_GROUP;
        DELETE FROM ${bpf_schema}BPF_MAIN;
        exit;
ENDBPF

# Delete the BPFs from the following tables:
#   BPF_GROUP, BPF_MAIN, BPF_MAIN_GROUP, BPF_PARAMETER_VALUES_DATA
# Note that BPF_PARAMETER is not deleted since it doesn't contain info for any
# specific BPF file
    echo "Removing BPF files from the EVAL BPF_MAIN and the related child tables"
    sqlplus -s ${IAS_DB_L8_OLITIRS_EVAL} << ENDEVALBPF
        set head off;
        DELETE FROM ${eval_bpf_schema}BPF_PARAMETER_VALUES_DATA;
        DELETE FROM ${eval_bpf_schema}BPF_MAIN_GROUP;
        DELETE FROM ${eval_bpf_schema}BPF_GROUP;
        DELETE FROM ${eval_bpf_schema}BPF_MAIN;
        exit;
ENDEVALBPF
endif

exit 0
