#!/bin/csh -f

#*************************************************************************
# NAME:    clean_up_data.csh
#
# PURPOSE: Database cleanup that was inserted in this test case 001.
#          (RADIOMETRIC_WORK_ORDER_COMMON and HISTOGRAM_STATISTICS_CAL)
#
# USAGE:   clean_up_data.csh
#
# RETURNS: Integer status of 0 if script completes successfully;
#          1 if an error occurs
#*************************************************************************

# Remove any previous instance of the clean_up_data.log file.
rm -f clean_up_data.log

# Initialize the error status to indicate no errors
set errorStatus = 0

echo "Deleting radiometric_work_order_common table data..."
sqlplus -s ${IAS_DB_L8_OLITIRS} >>& clean_up_data.log << END
    set head off;
    DELETE FROM RADIOMETRIC_WORK_ORDER_COMMON where RADIOMETRIC_WO_COMMON_ID = '9999999998';
    DELETE FROM RADIOMETRIC_WORK_ORDER_COMMON where RADIOMETRIC_WO_COMMON_ID = '9999999997';
    exit;
END

# Check for error
if (${status}) then
    echo "ERROR: ${sql}"
    set errorStatus = 1
endif

echo "Deleting histogram_statistics_cal table data..."
sqlplus -s ${IAS_DB_L8_OLITIRS} >>& clean_up_data.log << END
    set head off;
    DELETE FROM HISTOGRAM_STATISTICS_CAL where RADIOMETRIC_WO_COMMON_ID = '9999999998';
    DELETE FROM HISTOGRAM_STATISTICS_CAL where RADIOMETRIC_WO_COMMON_ID = '9999999997';
    exit;
END

# Check for error
if (${status}) then
    echo "ERROR: ${sql}"
    set errorStatus = 1
endif

# If error occurs check the log file
if ( ${errorStatus} ) then
    echo ""
    echo "Errors occurred.  See clean_up_data.log for more information."
    exit 1
endif

# Remove log file
rm -f clean_up_data.log

# Display message for successful deletion
echo "Data deleted successfully."

# Exit
exit 0
