#!/bin/csh -f

# Create work orders for test_case_001

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

set log = tc001.log
set woid_file = tc001_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC001 1 Nominal Earth - w/artifacts" \
    "TC001 2 Nominal Earth - ascending night" \
    "TC001 3 Nominal Earth - descending day" \
    "TC001 4 TIRS Lunar" \
    "TC001 5 OLI only" \
    "TC001 6 TIRS only" \
    "TC001 7 Deep Space" \
    "TC001 8 Blackbody" \
    "TC001 9 Shutter" \
    "TC001 10 Lamp" \
    "TC001 11 Solar" \
    "TC001 12 OLI Lunar" \
    "TC001 13 Mt Everest scene" \
    "TC001 14 Process to radiance" \
    "TC001 15 No characterizations or corrections no DB" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
# Note: The remaining single scene L0Rp use is for special artifact scenes
# and OLI-only scenes where a 3 scene TIRS product isn't necessary.
set l0r_path_dirs = ( \
    single_scene/LC81382062013189LGN00_artifacts/LC81382062013189LGN00 \
    three_tirs_scenes/LC81382062013189LGN00/LC81382062013189LGN00 \
    three_tirs_scenes/LC80330422013173LGN00/LC80330422013173LGN00 \
    lunar/LT800U0450372013204LGN00/LT800U0450372013204LGN00 \
    single_scene/LO80670172013203LGN01/LO80670172013203LGN01 \
    three_tirs_scenes/LT80400312013126LGN01/LT80400312013126LGN01 \
    deep_space/LT800D0132272013205LGN00/LT800D0132272013205LGN00 \
    black_body/LT800B0134152013205LGN00/LT800B0134152013205LGN00 \
    shutter/LO800S0131342013205LGN00/LO800S0131342013205LGN00 \
    lamp/LO800L0725332013153LGN00/LO800L0725332013153LGN00 \
    solar/LO800O1139142013195LGN00/LO800O1139142013195LGN00 \
    lunar/LO800U0450412013204LGN00/LO800U0450412013204LGN00 \
    three_tirs_scenes/LC81400412013123LGN01/LC81400412013123LGN01 \
    three_tirs_scenes/LC80330422013173LGN00/LC80330422013173LGN00 \
    single_scene/LC81382062013189LGN00_artifacts/LC81382062013189LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LC81382062013189LGN00 \
    LC81382062013189LGN00 \
    LC80330422013173LGN00 \
    LT800U0450372013204LGN00 \
    LO80670172013203LGN01 \
    LT80400312013126LGN01 \
    LT800D0132272013205LGN00 \
    LT800B0134152013205LGN00 \
    LO800S0131342013205LGN00 \
    LO800L0725332013153LGN00 \
    LO800O1139142013195LGN00 \
    LO800U0450412013204LGN00 \
    LC81400412013123LGN01 \
    LC80330422013173LGN00 \
    LC81382062013189LGN00 \
    )

# Procedures in proper order
set procedures = ( \
    "Generate L1R-Night" \
    "Generate L1R-Night" \
    "Generate L1R" \
    "Generate L1R-Non Earth" \
    "Generate L1R" \
    "Generate L1R" \
    "Generate L1R-Non Earth" \
    "L1R-Blackbody TIRS" \
    "Generate L1R-Non Earth" \
    "L1R-Lamp OLI" \
    "L1R-Solar OLI" \
    "Generate L1R-Non Earth" \
    "Generate L1R-Reports" \
    "Generate L1R" \
    "Generate L1R-Night" \
    )

# Datasets 1 and 15 need a CPF that has inoperable detectors added
set modified_cpf = "eval_LC08CPF_20130701_20130930_01.02"

# For dataset 4, tirs_lunar, use the following bpf in IT and ST
set bpf_tirs_parm = "LT8BPF20130723022635_20130723045952.01"

# The optional processing datasets need special parameters
set algo = "-parm L8RPS:ALGORITHMS_ELEM"
# Dataset 14: Process to gain parameters
set gain_parms = ( \
    "-parm COMMON:STORE_CHARACTERIZATION_IN_DB=0" \
    "${algo}22=reflectance_conversion_SKIP" )
# Dataset 15: No characterizations and no gain dataset parameters.  This
# uses three mechanisms: 1) SKIP the algorithm; 2) remove the algorithm from
# the list; and 3) override the algorithm with flag
set ncng_parms = ( \
    "${algo}1=inoperable_detector_identification_SKIP" \
    "${algo}2=dropped_frame_characterization_SKIP" \
    "${algo}3=impulse_noise_characterization_SKIP" \
    "${algo}4=saturated_pixel_characterization_SKIP" \
    "${algo}7=tirs_histogram_statistics_characterization_SKIP" \
    "${algo}8=temperature_sensitivity_correction_SKIP" \
    "${algo}15=oli_histogram_statistics_characterization_SKIP" \
    "${algo}16=gain_application" \
    "${algo}19=" \
    "${algo}20=" \
    "${algo}21=" \
    "${algo}22=" \
    "${algo}23=" \
    "-parm L8RPS:APPLY_ABSOLUTE_GAIN=0" \
    "-parm L8RPS:PERFORM_TEMP_SENS=0" \
    )

# Make sure the radiometric_work_order_common entry for any existing records
# are set to 'N' for consistency in the results.  LC80330422013173LGN00 is run
# twice far enough apart that the second one should be consistently set to "N".
# Setting the evaluation flag to N so it doesn't update EVAL
set output = `../tools/set_wo_common_state.csh RPS N N $scene_ids`
if ($status != 0) then
    echo "Error setting the RADIOMETRIC_WORK_ORDER_COMMON VALID flags" \
        |& tee -a $log
    exit 1;
endif

# setting the cpf and additional parameters for above scenes
set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++
    if ( $i == 1 ) then
        set cpf_parameter = "-parm DSW:CAL_PARM_FILENAME=$modified_cpf"
        set bpf_parameter = ""
        set additional_parms = ""
    
    # For earth_nominal to populate the histogram scene summary table
    else if ( $i == 3 ) then
        set cpf_parameter = "" 
        set bpf_parameter = ""
        set additional_parms = "-parm L8RPS:POPULATE_SCENE_SUMMARY_STATS_FLAG=1"
    
    # FIXME - Explicity forcing to use the $bpf_tirs_parm in ST and IT
    # due to conflict in the expected value
    else if ( $i == 4 ) then
        set cpf_parameter = ""
        set bpf_parameter = "-parm DSW:BIAS_PARM_FILENAME_TIRS=$bpf_tirs_parm"
        set additional_parms = ""
    else if ( $i == 14 ) then
        set cpf_parameter = ""
        set bpf_parameter = ""
        set additional_parms = `echo $gain_parms`
    else if ( $i == 15 ) then
        set cpf_parameter = "-parm DSW:CAL_PARM_FILENAME=$modified_cpf"
        set bpf_parameter = ""
        set additional_parms = `echo $ncng_parms`
    else
        set cpf_parameter = ""
        set bpf_parameter = ""
        set additional_parms = ""
    endif

    # For the first scene (Nominal Earth - w/artifacts) we have to use the 
    # L0R from l0r directory for both IT and ST. The l0r provided by the 
    # subsetter is different than the one we are using here (modified) 
    # for the same scene.
    if ( $mode == "IT" || $i == 1 ) then
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] \
            -i -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -comment "$comments[$i]" $cpf_parameter $bpf_parameter \
            $additional_parms`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] \
            -i -comment "$comments[$i]" $cpf_parameter $bpf_parameter \
            $additional_parms`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

# Log the error
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
