#!/bin/csh -f

set test_case = $1

# Ensure there is a database environment variable defined
if ( ! $?IAS_DB_COM ) then
    echo "IAS_DB_COM isn't set"
    exit 1
endif

set userid = `echo $IAS_DB_COM | awk -F'/' '{print $1}'`
set now = `date +"%Y-%m-%d %H:%M:%S"`

# Get the next work order ID
set select = "select wo_seq.nextval from dual;"
set sn = `echo $select | sqlplus $IAS_DB_COM | grep -A 2 NEXTVAL | sed '3,$!'d`
set woid = "I$sn"

# Load the work_orders table substituting the work order ID, date and user
# from the template
sed s%__WOID__%$woid% templates/${test_case}_work_orders.tpl > \
    ${test_case}_work_orders.ldr
sed -i s%__DATE__%"$now"%g ${test_case}_work_orders.ldr
sed -i s%__USER__%$userid% ${test_case}_work_orders.ldr
sed -i s%__L0RDATAPATH__%$IAS_IT_TEST_DATA_DIR% ${test_case}_work_orders.ldr
sqlldr $IAS_DB_COM ${test_case}_work_orders.ldr

# Check for errors 
if ( $status || -e ${test_case}_work_orders.bad ) then
    echo "An error occurred loading database see: ${test_case}_work_orders.bad"
    exit 1
endif

# Load the wo_scripts table substituting the work order ID from the template
sed s%__WOID__%$woid% templates/${test_case}_wo_scripts.tpl > \
    ${test_case}_wo_scripts.ldr
sqlldr $IAS_DB_COM ${test_case}_wo_scripts.ldr

# Check for errors 
if ( $status || -e ${test_case}_wo_scripts.bad ) then
    echo "An error occurred loading database see: ${test_case}_wo_scripts.bad"
    exit 1
endif

# Load the wo_common_parms table substituting the work order ID from the
# template
sed s%__WOID__%$woid% templates/${test_case}_wo_common_parms.tpl > \
    ${test_case}_wo_common_parms.ldr
sqlldr $IAS_DB_COM ${test_case}_wo_common_parms.ldr

# Check for errors 
if ( $status || -e ${test_case}_wo_common_parms.bad ) then
    echo "An error occurred loading database see: \
        ${test_case}_wo_common_parms.bad"
    exit 1
endif

# Load the wo_scripts table substituting the work order ID from the template
sed s%__WOID__%$woid% templates/${test_case}_wo_parms.tpl > \
    ${test_case}_wo_parms.ldr
sed -i s%__L0RDATAPATH__%$IAS_IT_TEST_DATA_DIR% ${test_case}_wo_parms.ldr
sed -i s%__TESTDIRPATH__%$IAS_IT_TEST_DATA_DIR% ${test_case}_wo_parms.ldr
sqlldr $IAS_DB_COM ${test_case}_wo_parms.ldr

# Check for errors 
if ( $status || -e ${test_case}_wo_parms.bad ) then
    echo "An error occurred loading database see: ${test_case}_wo_parms.bad"
    exit 1
endif

# These files can safely be removed now
rm ${test_case}_*.ldr ${test_case}_*.log

# Up to this point the work order won't show up as an active order since the
# scene ID isn't 'Local' ... L0R_DATA_STATUS of 1
set update = "UPDATE work_orders SET L0R_DATA_STATUS=1 WHERE \
    work_order_id='$woid';"
echo $update | sqlplus $IAS_DB_COM

echo
echo "***** Inserted work order: $woid *****"
echo

exit 0
