#!/bin/csh -f

if ( ${#argv} != 3 ) then
    echo "Usage: $0 <file prefix> <input file> <sensor>"
    exit 1
endif

if ( "$3" == "OLITIRS" ) then
    set bands = (01 02 03 04 05 06 07 08 09 10 11)
else if ( "$3" == "TIRS" ) then
    set bands = (10 11)
endif


foreach band ( $bands )
    echo "Extracting band $band"
    set extents = `h5dump -b NATIVE -d /B$band -o ${1}_$band $2 | grep SIMPLE`
    # If there was an error it generally means the band wasn't present, so
    # remove the empty file created and continue to the next band.
    if ( $status != 0 ) then
        rm ${1}_$band
        continue
    endif

    # Get the extents of the image
    set samples = `echo $extents | awk -F',' '{print $3}' | awk '{print $1}'`
    set lines = `echo $extents | awk -F',' '{print $2}' | awk '{print $1}'`

    # Create a header
    set header = ${1}_${band}.hdr
    echo "ENVI" > $header
    echo "description = {" >> $header
    echo "  File Imported into ENVI.}" >> $header
    echo "samples = $samples" >> $header
    echo "lines   = $lines" >> $header
    echo "bands   = 1" >> $header
    echo "header offset = 0" >> $header
    echo "file type = ENVI Standard" >> $header
    echo "data type = 4" >> $header
    echo "interleave = bsq" >> $header
    echo "sensor type = Unknown" >> $header
    echo "byte order = 0" >> $header
    echo "wavelength units = Unknown" >> $header
end
