#!/bin/csh -f

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

set log = wo_inserts.log
set woid_file = tc012_woids.txt
rm -f $log $woid_file

set corrupted_scene_id="LC80400302001213EDC00"
set l0r_dir="$IAS_IT_TEST_DATA_DIR/l0r"
set cpf_dir="$IAS_IT_TEST_DATA_DIR/cpf"
set bpf_dir="$IAS_IT_TEST_DATA_DIR/bpf"
set rlut_dir="$IAS_IT_TEST_DATA_DIR/rlut"

set comments = ( \
    "Test Case 012 Dataset 01 (No-Anomalies)" \
    "Test Case 012 Dataset 02 (Anomalies)" \
    "Test Case 012 Dataset 03 (Anomalies)" \
    "Test Case 012 Dataset 04 (Anomalies)" \
    "Test Case 012 Dataset 05 (Anomalies)" \
    "Test Case 012 Dataset 06 (Anomalies)" \
    "Test Case 012 Dataset 07 (Anomalies)" \
    "Test Case 012 Dataset 08 (Anomalies)" \
    "Test Case 012 Dataset 09 (Anomalies)" \
    "Test Case 012 Dataset 10 (Anomalies)" \
    "Test Case 012 Dataset 11 (Anomalies)" \
    "Test Case 012 Dataset 12 (Anomalies)" \
    "Test Case 012 Dataset 13 (Anomalies)" \
    "Test Case 012 Dataset 14 (Anomalies)" \
    "Test Case 012 Dataset 15 (Quaternions, SIRU)" \
    "Test Case 012 Dataset 16 (Quaternions, SIRU)" \
    "Test Case 012 Dataset 17 (Quaternions, SIRU)" \
    "Test Case 012 Dataset 18 (SIRU)" \
    )

set l0r_path_dirs = ( \
    "$l0r_dir/$corrupted_scene_id/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_02/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_03/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_04/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_05/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_06/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_07/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_08/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_09/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_10/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_11/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_12/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_13/$corrupted_scene_id" \
    "$l0r_dir/$corrupted_scene_id""_anc_corrupt_14/$corrupted_scene_id" \
    "$l0r_dir/LC80410232013117LGN00/LC80410232013117LGN00" \
    "$l0r_dir/LC80780102013120LGN01/LC80780102013120LGN01" \
    "$l0r_dir/LC80820102013116LGN01/LC80820102013116LGN01" \
    "$l0r_dir/LC80650132013141LGN00/LC80650132013141LGN00" \
    )

set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    set scene_id = $corrupted_scene_id
    set cpf_parameter = "-parm DSW:CAL_PARM_FILENAME=$cpf_dir/tc012_L8CPF20130401_20130630.05"
    set rlut_parameter = "-parm DSW:RLUT_FILENAME=$rlut_dir/L8RLUT20130211_20431231v06.h5"
    if ( $i == 15 ) then
        set scene_id = "LC80410232013117LGN00"
        set bpf_oli = "-parm DSW:BIAS_PARM_FILENAME_OLI=$bpf_dir/tc012_LO8BPF20130427181425_20130427183147.01"
        set bpf_tirs = "-parm DSW:BIAS_PARM_FILENAME_TIRS=$bpf_dir/tc012_LT8BPF20130427181032_20130427183239.01"
    else if ( $i == 16 ) then
        set scene_id = "LC80780102013120LGN01"
        set bpf_oli = "-parm DSW:BIAS_PARM_FILENAME_OLI=$bpf_dir/tc012_LO8BPF20130430220730_20130430223537.02"
        set bpf_tirs = "-parm DSW:BIAS_PARM_FILENAME_TIRS=$bpf_dir/tc012_LT8BPF20130430220336_20130430223629.02"
    else if ( $i == 17 ) then
        set scene_id = "LC80820102013116LGN01"
        set bpf_oli = "-parm DSW:BIAS_PARM_FILENAME_OLI=$bpf_dir/tc012_LO8BPF20130426223211_20130426225931.01"
        set bpf_tirs = "-parm DSW:BIAS_PARM_FILENAME_TIRS=$bpf_dir/tc012_LT8BPF20130426222817_20130426230023.01"
    else if ( $i == 18 ) then
        set scene_id = "LC80650132013141LGN00"
        set bpf_oli = "-parm DSW:BIAS_PARM_FILENAME_OLI=$bpf_dir/tc012_LO8BPF20130521204238_20130521211444.01"
        set bpf_tirs = "-parm DSW:BIAS_PARM_FILENAME_TIRS=$bpf_dir/tc012_LT8BPF20130521203844_20130521211536.01"
    else
        # Only the last 4 work orders use custom CPF, BPF and RLUT
        set cpf_parameter = ""
        set bpf_oli = ""
        set bpf_tirs = ""
        set rlut_parameter = ""
    endif
    if ($mode == "IT") then
        set output = `PWG -procedure_id "L1T Product" -scene_id $scene_id \
            -i -l0r_data_path $l0r_path_dirs[$i] $cpf_parameter $bpf_oli \
            $bpf_tirs $rlut_parameter -comment "$comments[$i]"`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "L1T Product" -i \
            -scene_id $scene_id $cpf_parameter $bpf_oli \
            $bpf_tirs $rlut_parameter -comment "$comments[$i]"`
        set saveStatus = $status
    endif
    
    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0

