#!/usr/bin/perl -w
use strict;

###
# verify_gcp_types.pl
#
# Verify gcpcorrelate is using the correct GCPs during each pass.
#
###

# Variables
my $wodir = $ENV{IAS_WO};
my $wo_full_path;
my %control_list;
my %validation_list;
my $error_cnt = 0;
my $control_cnt;
my $validation_cnt;

# Get <work order id> parameter
my $work_order_id = $ARGV[0];
$wo_full_path = "$wodir/$work_order_id";

##### Load GCPLib #############################################################
open(GCP, "< $wo_full_path/gcp_lib/GCPLib")
    or die "Could not open GCPLib\n";

while(<GCP>)
{
    chomp;

    # Skip white space
    if (/^\s*$/) { next; }

    # Skip begin and the GCP count line
    if (/^BEGIN/)
    {
        <GCP>;
        next;
    }

    my @values = split(/\s/, $_);

    # Find out the GCP type and add GCP to appropriate list
    if ($values[13] eq 'CONTROL')
    {
        $control_list{$values[0]} = 1;
    }
    elsif ($values[13] eq 'VALIDATION')
    {
        $validation_list{$values[0]} = 1;
    }
    else
    {
        print "WARN: unknown GCP type: " . $values[13] . "\n";
        next;
    }
}

close(GCP);

##### Verify GCPLib contained both CONTROL and VALIDATION GCPs ################
$control_cnt = scalar keys %control_list;
$validation_cnt = scalar keys %validation_list;

if ($control_cnt == 0)
{
    print "ERROR: Control GCPs missing from GCPLib\n";
    $error_cnt++;
}

if ($validation_cnt == 0)
{
    print "ERROR: Validation GCPs missing from GCPLib\n";
    $error_cnt++;
}

##### Verify the Control GCPs #################################################
print "Checking CONTROL GCP file.\n";

open(M1, "< $wo_full_path/measured.gcp")
    or die "Could not open measured.gcp\n";

while(<M1>)
{
    chomp;

    my @values = split(/,/, $_);
    my $id = $values[0];

    if (not exists $control_list{$id})
    {
        print "ERROR: Invalid Control GCP found in measured.gcp: $id\n";
        $error_cnt++;
    }
}

close(M1);

##### Verify the Validation GCPs ##############################################
print "Checking VALIDATION GCP file.\n";

open(M2, "< $wo_full_path/measured_pass2.gcp")
    or die "Could not open measured_pass2.gcp\n";

while(<M2>)
{
    chomp;

    my @values = split(/,/, $_);
    my $id = $values[0];

    if (not exists $validation_list{$id})
    {
        print "ERROR: Invalid Validation GCP found in measured_pass2.gcp: " 
              . $id . "\n";
        $error_cnt++;
    }
}

close(M2);

# Check for errors
if ($error_cnt == 0)
{
    print "Validating GCPs passed\n";
}
else
{
    print "Validating GCPs failed\n";
}
