#!/bin/csh -f
#***************************************************************************
# NAME:     create_wos.csh
# 
#  PURPOSE:  Creates the work orders for test_case_014 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: SUCCESS / ERROR
# 
#  USAGE:    ./create_wos.csh
# ***************************************************************************

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

# Set up the created files
set log = 'tc014.log'
set wo_id_file = 'tc014_wo_ids.txt'

# Start with new files
rm -f $log $wo_id_file

# Setup the arrays for what to process
# All of the arrays must contain an equal number of items
# Comments array for PWG
set comments = ( \
    'TC014 1 - Geometric supersite' \
    'TC014 2 - Off-Nadir supersite' \
    'TC014 3 - Geometric supersite' \
    'TC014 4 - Geometric supersite' \
    'TC014 5 - Geometric supersite' )

# Scene id array used in PWG
set scene_ids = ( \
    LC80400332013110LGN01 \
    LC80170372013141LGN01 \
    LC80400332013110LGN01 \
    LC80400332013110LGN01 \
    LC80400332013110LGN01 )

# L0R relative path
set l0r_path_dirs = ( \
    LC80400332013110LGN01/LC80400332013110LGN01 \
    LC80170372013141LGN01/LC80170372013141LGN01 \
    LC80400332013110LGN01/LC80400332013110LGN01 \
    LC80400332013110LGN01/LC80400332013110LGN01 \
    LC80400332013110LGN01/LC80400332013110LGN01 )

# Procedure to use
set procedures = ( \
    'Image Registration' \
    'Image Registration' \
    'Image Registration' \
    'Image Registration' \
    'L1GT Product' )

# Reference images
set ref_images = ( \
    "-parm I2ICHAR:L1G_REF_IMAGE=$IAS_IT_TEST_DATA_DIR/test_case_014/LC80400332013110LGN01.h5" \
    "-parm I2ICHAR:L1G_REF_IMAGE=$IAS_IMG/ias018037_UTM_doq.h5" \
    "-parm I2ICHAR:L1G_REF_IMAGE=l1t.h5" \
    "-parm I2ICHAR:L1G_REF_IMAGE=$IAS_IT_TEST_DATA_DIR/test_case_014/LC80400332013110LGN01.h5" \
    "" )

set index = 0
set pwg_status = 0

# Inserting the work orders
# Loop through arrays creating WOs
echo "Inserting Work Orders" |& tee -a $log
while ( $index < ${#comments} )
    @ index++

    # Add parameter override code here if needed
    # May also need a parameter override list above to help with things
    set ref_band_list = ""
    set tiept_type = ""
    set store_db_char = ""
    set search_band_list = ""
    set cpf = ""

    # Set the reference band list to 8 for dataset 1
    if ( $index == 1 ) then
        set ref_band_list = "-parm I2ICHAR:REFERENCE_BAND_LIST=(8)"
    endif
    # Don't store the characterization for dataset 2
    if ( $index == 2 ) then
        set store_db_char = "-parm TDIST:STORE_CHARACTERIZATION_IN_DB=0"
    endif
    # Set the reference band list to 8 for dataset 3
    # Set the tiept type to 2
    if ( $index == 3 ) then
        set ref_band_list = "-parm I2ICHAR:REFERENCE_BAND_LIST=(8)"
        set tiept_type = "-parm I2ICHAR:TIEPT_TYPE=2"
    endif
    # Set the reference band list to 1 for dataset 3
    # Set the search band list to 8 for dataset 3
    if ( $index == 4 ) then
        set ref_band_list = "-parm I2ICHAR:REFERENCE_BAND_LIST=(1)"
        set search_band_list = "-parm I2ICHAR:SEARCH_BAND_LIST=(8)"
    endif
    if ( $index == 5 ) then
        set cpf = "-parm DSW:CAL_PARM_FILENAME=$IAS_IT_TEST_DATA_DIR/test_case_014/tc014_L8CPF20130401_20130627.08"
    endif
    
    if ( $mode == "IT" ) then
        set output = `PWG \
            -interactive \
            -procedure_id "$procedures[$index]" \
            -scene_id $scene_ids[$index] \
            -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$index] \
            -comment "$comments[$index]" \
            $ref_images[$index] \
            $ref_band_list \
            $tiept_type \
            $store_db_char \
            $search_band_list \
            $cpf`
        set saveStatus = $status
    else
        set output = `PWG \
            -interactive \
            -procedure_id "$procedures[$index]" \
            -scene_id $scene_ids[$index] \
            -comment "$comments[$index]" \
            $ref_images[$index] \
            $ref_band_list \
            $tiept_type \
            $store_db_char \
            $search_band_list \
            $cpf`
        set saveStatus = $status
    endif

    # Check if error is thrown
    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error Loading Dataset $index" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for" \
                " dataset $index" |& tee -a $log
        else
            shift output
            set wo_id = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$wo_id "
            echo $wo_id >> $wo_id_file
        endif
    endif
end
echo ""

# Write out how many errors occured or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: Created $index Work Orders" |& tee -a $log
endif
exit 0

