#!/bin/csh -f

#***************************************************************************
# NAME:     create_wos.csh

# PURPOSE:  Creates the work orders for test_case_016 using PWG
# RETURNS:
#       Type:  Integer
#       Value: 0 / 1
#  
# USAGE:    ./create_wos.csh
#****************************************************************************

set mode = "IT"
if ( $1 == "ST" ) then
    set mode = "ST"
endif

set tc = 016
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tc} 1 - Lunar Minbox" \
    "TC${tc} 2 - Lunar Maxbox" \
    "TC${tc} 3 - Lunar Units of seconds and Band selection" \
    "TC${tc} 4 - Lunar L1G Processing flow (CR 11893)" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    LO800U0450412013204LGN00/LO800U0450412013204LGN00 \
    LO800U0450412013204LGN00/LO800U0450412013204LGN00 \
    LO800U0616342013204LGN00/LO800U0616342013204LGN00 \
    LO800U0450412013204LGN00/LO800U0450412013204LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LO800U0450412013204LGN00 \
    LO800U0450412013204LGN00 \
    LO800U0616342013204LGN00 \
    LO800U0450412013204LGN00 \
    )

# Procedures in proper order
set procedures = ( \
    "Lunar Band to Band" \
    "Lunar Band to Band" \
    "Lunar Band to Band" \
    "L1G Lunar Product" \
    )

# The optional processing datasets need special parameters.  The pixel_size
# is make larger since the default pixel size is not appropriate for the
# maxbox frame (frame_type = 10)
set wo2_parms = ( \
    "-parm L8GRID_SYS:FRAME_TYPE=10" \
    "-parm L8GRID_SYS:pixel_size='(0.00004,0.00002,0.00004)'" \
    "-parm B2BCHAR:SCA_LIST=14" \
    )
# Dataset 15: Process to gain parameters
set wo3_parms = ( \
    "-parm COMMON:BAND_LIST='(3,7)'" \
    "-parm COMMON:STORE_CHARACTERIZATION_IN_DB=0" \
    "-parm L8GRID_SYS:PROJ_UNITS=SECONDS" \
    "-parm L8GRID_SYS:pixel_size='(8.24,4.12,8.24)'" \
    )

set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++
    if ( $i == 2 ) then
        set additional_parms = `echo $wo2_parms`
    else if ( $i == 3 ) then
        set additional_parms = `echo $wo3_parms`
    else
        set additional_parms = ""
    endif

    if ( $mode == "IT" ) then
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] \
            -i -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] \
            -i -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""


if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
