--
-- This script performs two operations.  First it generates an sql script to
-- extract data from the given table.  Second it generates an sql loader
-- script which is then saved in the code repository at a later time.  The
-- calling script is used to perform clean up of any temporary files.
--
-- The script operates on a collection of hardcoded Work Order IDs.  These
-- Work Orders are set up using the OUI using particular test input scenes
-- to create the Precision Correction information used as input to the Sensor 
-- Alignment test case.  These Work Orders will be run using customized CPFs.
--
-- This file helps set up the data used by test case 017 for Sensor Alignment.
-- It is not used during the test case itself.
--
-- Setup so certain stuff is not output to the files.
--
set pagesize 0
set heading off
set wrap off
set echo off
set trimout on
set trimspool on
set termout off
set feedback off
set linesize 2000
set space 0
set colsep |
--
-- GEOMETRIC_WORK_ORDER_COMMON
-- PRECISION_MODEL_CORRECTION
--
-- Generate an sql script to extract GEOMETRIC_WORK_ORDER_COMMON data.
--
spool GEOMETRIC_WORK_ORDER_COMMON.sql
select 'select ' from sys.dual;
select decode(column_id, 1, column_name,
              '||''|''||'||column_name)
from user_tab_columns
where table_name = upper('GEOMETRIC_WORK_ORDER_COMMON')
and data_type not in ('CLOB')
order by column_id;
select 'from GEOMETRIC_WORK_ORDER_COMMON ' from sys.dual;
select 'where work_order_id in (''I2'',''I4'')' from sys.dual;
select 'order by geometric_wo_common_id;' from sys.dual;
spool off
--
-- Generate the results.
--
spool GEOMETRIC_WORK_ORDER_COMMON.db.results
@GEOMETRIC_WORK_ORDER_COMMON;
spool off
--
-- Generate an sql script to extract PRECISION_MODEL_CORRECTION data.
--
spool PRECISION_MODEL_CORRECTION.sql
select 'select ' from sys.dual;
select decode(column_id, 1, column_name,
              '||''|''||'||column_name)
from user_tab_columns
where table_name = upper('PRECISION_MODEL_CORRECTION')
and data_type not in ('CLOB')
order by column_id;
select 'from PRECISION_MODEL_CORRECTION' from sys.dual;
select 'where geometric_wo_common_id in ' from sys.dual;
select '(select geometric_wo_common_id ' from sys.dual;
select 'from GEOMETRIC_WORK_ORDER_COMMON' from sys.dual;
select 'where work_order_id in (''I2'',''I4''))' from sys.dual;
select 'order by geometric_wo_common_id;' from sys.dual;
spool off
--
-- Generate the results.
--
spool PRECISION_MODEL_CORRECTION.db.results
@PRECISION_MODEL_CORRECTION;
spool off
---
exit
