#!/bin/sh

# This script loads the specified schema with default values for the tables
# which require them.  It also generates a log file in the current directory.
# The sqlldr generated "*.log" files are placed into the "logs" directory.
# The sqlldr generated "*.bad" files are placed into the "bad" directory.

PWD=`pwd`
LOG="$PWD/load_test_case_017_data.log"
DB="$IAS_DB_L8_OLITIRS"
DATA_DIR="$IAS_IT_TEST_DATA_DIR/test_case_017"

# first delete any old data
./delete_work_orders.sh 2>&1 >> $LOG

# Initialize the log file.
DATE=`date`
echo "Created $DATE" 2>&1 >> $LOG

# Create the log and bad file directories.
mkdir -p bad logs 2>&1 >> $LOG

# Process the tables.
echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading GEOMETRIC_WORK_ORDER_COMMON ---" 2>&1 >> $LOG
NAME="GEOMETRIC_WORK_ORDER_COMMON"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad \
    2>&1 >> $LOG
echo "sqlldr " $DB " control="$DATA_DIR/$NAME.ldr log=logs/"$NAME".log \
    bad=bad/"$NAME".bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load GEOMETRIC_WORK_ORDER_COMMON table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading PRECISION_MODEL_CORRECTION ---" 2>&1 >> $LOG
NAME="PRECISION_MODEL_CORRECTION"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad \
    2>&1 >> $LOG
echo "sqlldr " $DB " control="$DATA_DIR/$NAME.ldr log=logs/"$NAME".log \
    bad=bad/"$NAME".bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PRECISION_MODEL_CORRECTION table failed."
    exit 1
fi

echo "."
echo "" 2>&1 >> $LOG
DATE=`date`
echo "Completed - $0 - $DATE" 2>&1 >> $LOG
echo "Completed - $0"

