#!/bin/csh -f

set mode = "IT"
if ( $1 == "ST" ) then
    set mode = "ST"
endif

set log = tc018.log
set woid_file = tc018_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC018 1 Geometric Supersite" \
    "TC018 2 Off-nadir" \
    "TC018 3 SOM DOQ Reference Image"\
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    LC80400332013190LGN00/LC80400332013190LGN00 \
    LC80170382013141LGN01/LC80170382013141LGN01 \
    LC80930762013146LGN00/LC80930762013146LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LC80400332013190LGN00 \
    LC80170382013141LGN01 \
    LC80930762013146LGN00 \
    )

# Procedures in proper order
set procedures = ( \
    "Focal Plane Calibration" \
    "Focal Plane Calibration" \
    "Focal Plane Calibration" \
    )

# All three datasets need the CPF_GROUP_FLAG turned on
set cpf_grp_parm = "-parm FOCALPLANE:CPF_GROUP_FLAG=1"

set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    if ( $mode == "IT" ) then
        set output = `PWG -procedure_id "$procedures[$i]" -scene_id $scene_ids[$i] \
            -i -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -comment "$comments[$i]" $cpf_grp_parm`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedures[$i]" -scene_id $scene_ids[$i] \
            -i -comment "$comments[$i]" $cpf_grp_parm`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""


if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
