#!/bin/csh -f

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

set tcnum = "019"
set log = tc${tcnum}.log
set woid_file = tc${tcnum}_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tcnum} 1 OLI Solar diffuser non-uniformity characterization" \
    "TC${tcnum} 2 TIRS blackbody non-uniformity characterization" \
    "TC${tcnum} 3 OLI earth non-uniformity characterization" \
    "TC${tcnum} 4 TIRS earth non-uniformity characterization" \
    )

# Scenes in proper order
set scene_ids = ( \
    LO800O1139142013195LGN00 \
    LT800B0134152013205LGN00 \
    LC80160042013118LGN00 \
    LC80160042013118LGN00 \
    )

# Procedures in proper order
set procedure_id = ( \
    "L1R-Nonuniformity OLI" \
    "L1R-Nonuniformity TIRS" \
    "L1R-Nonuniformity OLI" \
    "L1R-Nonuniformity TIRS" \
    )

set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++
    if ( $i < 3 ) then
        set parm1 = "-parm CHAR_NONUNIFORMITY:DUMP_FLAG=1"
        set parm2 = "-parm CHAR_NONUNIFORMITY:REPORT_FLAG=1"
    else
        set parm1 = ""
        set parm2 = ""
    endif

    if ( $mode == "IT" ) then
        set output = `PWG -i -procedure_id "$procedure_id[$i]" \
            -scene_id $scene_ids[$i] \
            -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$scene_ids[$i]/$scene_ids[$i] \
            -comment "$comments[$i]" $parm1 $parm2`
        set saveStatus = $status
    else
        set output = `PWG -i -procedure_id "$procedure_id[$i]" \
            -scene_id $scene_ids[$i] \
            -comment "$comments[$i]" $parm1 $parm2`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""


if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
