#!/usr/bin/perl -w
use File::Path;
use strict;

# This is a test script for the ias_assess_geo.pl utility running in geodetic 
# mode.
# Requirements are listed followed by executing the script in a manner which
# performs the action specified in the requirement.

# test data directory and names of output files
my $data_dir = "$ENV{IAS_IT_TEST_DATA_DIR}";
my $tc_dir = $data_dir . "/test_case_021";
my $error_counter = 0;
my @output_files;
my @test_commands;
my $i;
# set up an array of output files
for($i = 0; $i < 4; $i++)
{
    $output_files[$i] = "output$i.txt";
}
$i = 0;

# IP2348 The IAS shall implement geodetic characterization trending 
# calculations specified in the OLI geometric ADD.
# IP2349 The IAS shall retrieve geodetic characterization trending information 
# of L1T products for reporting of overall geodetic accuracy.
# IP2350 The IAS shall generate a report of the overall geodetic accuracy of 
# L1T products using the algorithm defined in the Cal/Val Algorithm Description
# Document (ADD).

# query the data for all records loaded
my $command = "ias_assess_geo.pl -d -v geodetic -w217-220,38-41 " .
              "-a14-MAY-2014,05-AUG-2017";
push(@test_commands, $command);
print "Running: $command\n";
my $rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# query the data loaded for a subset of the data, using path/row and acquisition
# dates as parameters
$command = "ias_assess_geo.pl -d -v geodetic -w219-220,40-41 " .
              "-a14-MAY-2014,05-FEB-2015";
push(@test_commands, $command);
print "Running: $command\n";
$rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# query the data loaded for a subset of the data, using roll angle (off-nadir 
# angle)
$command = "ias_assess_geo.pl -d -v geodetic -r15 -w217-220,38-41"; 
push(@test_commands, $command);
print "Running: $command\n";
$rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# query the data loaded for a subset of the data, using GCP source
$command = "ias_assess_geo.pl -d -v geodetic -gG -w217-220,38-41"; 
push(@test_commands, $command);
print "Running: $command\n";
$rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

print "Running utility passed\n";

# diff the output records
my $cutoff_str = 'Geodetic post-processing assessment';
my $cmd;
my $cmd_counter = 0;
foreach my $file (@output_files)
{
    $cmd = "sed '/$cutoff_str/,\$!'d $file | diff -q - $tc_dir/$file.verify";
    print "Running: $cmd\n";
    $rc = system($cmd);
    if ($rc != 0)
    {
        print "Diff failed: " . $test_commands[$cmd_counter] . "\n";
        $error_counter++;
    }
    $cmd_counter++;
}

if ($error_counter)
{
    print "Running diffs failed\n";
    exit 1;
}
else
{
    print "Running diffs passed\n";
}

# everything passed, delete DB entries added for this test
$rc = system("./delete_db_records.sh");
if ($rc != 0)
{
    print "Delete failed: ./delete_db_records.sh\n";
    exit 1;
}

# everything passed, remove log and output files
my @logs = qw(delete_db_records.log delete_db_records.log load_test_schema.log
              logs bad);
rmtree([@logs], 0, 1);

exit 0;
