#!/usr/bin/perl -w
use File::Path;
use strict;

# This is a test script for the ias_assess_geo.pl utility running in geometric 
# mode.
# Requirements are listed followed by executing the script in a manner which
# performs the action specified in the requirement.

# test data directory and names of output files
my $data_dir = "$ENV{IAS_IT_TEST_DATA_DIR}";
my $tc_dir = $data_dir . "/test_case_022";
my $error_counter = 0;
my @output_files;
my $i;
# set up an array of output files
for($i = 0; $i < 4; $i++)
{
    $output_files[$i] = "output$i.txt";
}
$i = 0;

# IP2352 The IAS shall retrieve geometric characterization trending 
# information of L1T products for reporting of overall geometric accuracy.
# IP2353 The IAS shall implement geometric characterization trending 
# calculations specified in the OLI geometric ADD. 
# IP2354 The IAS shall generate a report of the overall geometric accuracy 
# of L1T products as defined in the OLI geometric ADD.

# query the data for all records loaded
my $command = "ias_assess_geo.pl -d -v geometric -w217-221,37-41 " .
              "-a10-APR-2014,25-DEC-2017";
print "Running: $command\n";
my $rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# query the data loaded for a subset of the data, using path/row and acquisition
# dates as parameters
$command = "ias_assess_geo.pl -d -v geometric -w219-220,37-39 " .
              "-a10-APR-2014,25-DEC-2014";
print "Running: $command\n";
$rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# query the data loaded for a subset of the data, using roll angle (off-nadir 
# angle). use data range to limit possible results to record generated for
# this test.
$command = "ias_assess_geo.pl -d -v geometric -r10 " .
              "-a10-APR-2014,25-DEC-2017";
print "Running: $command\n";
$rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# query the data loaded for a subset of the data, using GCP source
$command = "ias_assess_geo.pl -d -v geometric -gG";
print "Running: $command\n";
$rc = system("$command > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

print "Running utility passed\n";

# diff the output records
foreach my $file (@output_files)
{
    $rc = system("diff -I '^Database' -I 'Time' -q $file $tc_dir/$file.verify");
    if ($rc != 0)
    {
        print "Diff failed: $command\n";
        $error_counter++;
    }
}

if ($error_counter)
{
    print "Running diffs failed\n";
    exit 1;
}
else
{
    print "Running diffs passed\n";
}

# everything passed, delete DB entries added for this test
$rc = system("./delete_db_records.sh");
if ($rc != 0)
{
    print "Delete failed: ./delete_db_records.sh\n";
    exit 1;
}

# everything passed, remove log and output files
my @logs = qw(delete_db_records.log delete_db_records.log load_test_schema.log
              logs bad);
rmtree([@logs], 0, 1);

exit 0;
