#!/usr/bin/perl -w
use strict;

# This is a test script for the ias_assess_x2x.pl utility running in I2I mode.
# Requirements are listed followed by executing the script in a manner which
# performs the action specified in the requirement.


# test data directory and names of output files
my $data_dir = "$ENV{IAS_IT_TEST_DATA_DIR}";
my $tc_dir = $data_dir . "/test_case_023";
my @output_files;
my $i;
my $command_opts;  # Specify the the command line parameters here

# set up an array of output files
for($i = 0; $i < 6; $i++)
{
    $output_files[$i] = "i2i_output$i.txt";
}
$i = 0;

# It's possible that some of the tests could have issues with differences
# from expected results.  The expected results are assumed to be derived
# from the test data set loaded into the database by the script
# 'load_tc023.sh'.  Use the -p option to constrain the processing date range
# such that it only includes the the test data set.  It may be necessary to
# add the -a option to constrain the acquisition date as well.

# IP2341 - The IAS shall retrieve image-to-image characterization trending 
# information for overall I2I coregistration accuracy report of L1T data 
# products.
# IP2344 - The IAS shall implement image-to-image characterization trending 
# calculations specified in the OLI geometric ADD.
# IP2346 - The IAS shall generate a report of overall image-to-image 
# co-registration accuracy of L1T products using the algorithm defined in the 
# Cal/Val Algorithm Description Document (ADD).
# (The last one refers to summary statistics which are available every time 
# it runs.)
$command_opts = "-vi2i";
print "Running: ias_assess_x2x.pl $command_opts\n";
my $rc = system("ias_assess_x2x.pl $command_opts > /dev/null");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP2342 - The IAS shall have an option to specify an effective date range 
# for image-to-image characterization trending information to be retrieved.
# -- acquisition date (using futuristic dates to limit search results)
$command_opts = "-vi2i -a01-JAN-15,02-JAN-15";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# -- processing date (using futuristic dates to limit search results)
$command_opts = "-vi2i -p03-JAN-15,05-JAN-15";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP2343 - The IAS shall have an option to specify target location for 
# image-to-image characterization trending information to be retrieved.
$command_opts = "-vi2i -p28-DEC-14,04-JAN-15 -w223-228,42-47";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP2345 - The IAS shall distinguish nadir and off-nadir trending information 
# of earth images for image-to-image characterization trending calculations.
# -- nadir (using path/row also to limit search results)
$command_opts = "-vi2i -p28-DEC-14,10-JAN-15 -nN -w223-228,42-47";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# -- off-nadir (using path/row also to limit search results)
$command_opts = "-vi2i -p28-DEC-14,10-JAN-15 -nO -w223-228,42-47";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# -- lunar 
$command_opts = "-vi2i -p28-DEC-14,28-DEC-14 -tL";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

print "Running utility passed\n";

# diff the output records
foreach my $file (@output_files)
{   
    $rc = system("sed '/Assessing image/,\$!'d $file"
               . "| diff - $tc_dir/$file.verify");
    if ($rc != 0)
    {
        print "Diff failed: diff $file $tc_dir/$file.verify\n";
        exit 1;
    } 
}

print "Output diff testing passed\n";

# everything passed, delete DB entries added for this test
$rc = system("./delete_schema.sh");
if ($rc != 0)
{
    print "Delete failed: ./delete_schema.sh\n";
    exit 1;
} 

# everything passed, remove output and log files
my @logs = qw(delete_schema.log delete_schema_sql.log load_test_schema.log
              logs bad);
foreach my $file (@logs)
{
    if (-e $file)
    {
        $rc = system("rm -r $file");
        if ($rc != 0)
        {
            print "delete failed: rm -r $file\n";
            exit 1;
        }
    }
}

exit 0;
