#!/usr/bin/perl -w
use strict;

# This is a test script for the ias_assess_x2x.pl utility running in B2B mode.
# Requirements are listed followed by executing the script in a manner which
# performs the action specified in the requirement.


# test data directory and names of output files
my $data_dir = "$ENV{IAS_IT_TEST_DATA_DIR}";
my $tc_dir = $data_dir . "/test_case_024";
my @output_files;
my $i;
my $command_opts;

# set up an array of output files
for($i = 0; $i < 9; $i++)
{
    $output_files[$i] = "b2b_output$i.txt";
}
$i = 0;

# IP2332 - The IAS shall retrieve band-to-band characterization trending 
# information of OLI and TIRS for an overall band-to-band coregistration 
# accuracy report of L1 data products.
# IP2336 - The IAS shall implement band-to-band characterization trending 
# calculations specified in the OLI geometric ADD.
# IP2339 - The IAS shall generate a report of overall band-to-band 
# co-registration accuracy of L1T products as defined in the OLI geometric ADD.
# (The last one refers to summary statistics which are available every time 
# it runs.)

$command_opts = "-vb2b";
print "Running: ias_assess_x2x.pl $command_opts\n";
my $rc = system("ias_assess_x2x.pl $command_opts > /dev/null");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP2333 - The IAS shall provide an option to retrieve band-to-band 
# characterization trending information for the cirrus band for overall 
# band-to-band coregistration accuracy report.
$command_opts = "-vb2b -b9 -p28-DEC-14,10-JAN-15";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc =
    system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP2334 - The IAS shall have an option to specify an effective date range 
# for band-to-band characterization trending information to be retrieved.
# -- acquisition date (using futuristic dates to limit search results)
$command_opts = "-vb2b -a20-DEC-14,27-DEC-14";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# -- processing date (using futuristic dates to limit search results)
$command_opts = "-vb2b -p26-DEC-14,29-DEC-14";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP2335 - The IAS shall have an option to specify the target location for 
# band-to-band characterization trending information to be retrieved.
$command_opts = "-vb2b -p28-DEC-14,10-JAN-15 -w223-228,42-47";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl -vb2b $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}


# IP2337 - The IAS shall distinguish cirrus and non-cirrus bands for 
# band-to-band characterization trending calculations.
# (using path/row also to limit search results)
$command_opts = "-vb2b -b1,2,3,4,5,6,7,8 -p28-DEC-14,10-JAN-15 ";
$command_opts = $command_opts . "-w223-228,42-47";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP2338 - The IAS shall distinguish nadir and off-nadir trending information 
# of earth images for band-to-band characterization trending calculations.
# -- nadir (using path/row also to limit search results)
$command_opts = "-vb2b -nN -p28-DEC-14,10-JAN-15 -w1-233,30-45";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# -- off-nadir (using path/row also to limit search results)
$command_opts = "-vb2b -nO -p28-DEC-14,10-JAN-15 -w35-40,1-248";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# IP4119 - The IAS shall provide an option to retrieve band-to-band 
# characterization trending information for the TIRS bands for overall 
# band-to-band coregistration accuracy report.
# (using path/row also to limit search results)
$command_opts = "-vb2b -b10,11 -p05-JAN-15,10-JAN-15 -w80-90,85-95";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

# Tracker 4446 "IAS GPS test case 15 should test the OLI-TIRS processing flow".
# Tracker 4446 notes test case 24 should cover OLI-TIRS B2B Characterization.
# "SCA 0" (i.e. SCA-combined) is used to select the input from the OLI-TIRS
# scenario that also tests SCA-combined capability.  The OLI-TIRS input data
# includes cases where OLI and TIRS bands are compared to each other.
# (using path/row also to limit search results)
$command_opts = "-vb2b -s0 -a05-JAN-01,05-JAN-01 -p29-FEB-12,29-FEB-12 ";
$command_opts = $command_opts . "-w40-40,23-23";
print "Running: ias_assess_x2x.pl $command_opts\n";
$rc = system("ias_assess_x2x.pl $command_opts > $output_files[$i++]");
if ($rc != 0)
{
    print "Application failed\n";
    exit 1;
}

print "Running utility passed\n";

# diff the output records, skipping some report header content
foreach my $file (@output_files)
{
    $rc = system("sed '/Assessing /,\$!'d $file | diff --brief - $tc_dir/$file.verify");
    if ($rc != 0)
    {
        print "Diff failed: sed '/Assessing /,\$!'d $file | diff - $tc_dir/$file.verify\n";
        exit 1;
    }
}

print "Output diff testing passed\n";

# everything passed, delete DB entries added for this test
$rc = system("./delete_schema.sh");
if ($rc != 0)
{
    print "Delete failed: ./delete_schema.sh\n";
    exit 1;
}

# everything passed, remove output and log files
my @logs = qw(delete_schema.log delete_schema_sql.log load_test_schema.log
              logs bad);
foreach my $file (@logs)
{
    if (-e $file)
    {
        $rc = system("rm -r $file");
        if ($rc != 0)
        {
            print "delete failed: rm -r $file\n";
            exit 1;
        }
    }
}

exit 0;
