#!/bin/sh

# This script loads the specified schema with default values for the tables
# which require them.  It also generates a log file in the current directory.
# The sqlldr generated "*.log" files are placed into the "logs" directory.
# The sqlldr generated "*.bad" files are placed into the "bad" directory.

PWD=`pwd`
LOG="$PWD/load_test26_modify.log"
DB="$IAS_DB_L8_OLITIRS"
DATA_DIR="$IAS_IT_SCRIPTS_DIR/test_case_026"

# Initialize the log file.
DATE=`date`
echo "Created $DATE" 2>&1 > $LOG

# Create the log and bad file directories.
mkdir -p bad logs 2>&1 >> $LOG

# Process the tables.
echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading MODULESmodify ----------------------------------" 2>&1 >> $LOG
NAME="MODULESmodify"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad \
    2>&1 >> $LOG
echo "sqlldr " $DB " control="$DATA_DIR/$NAME.ldr log=logs/"$NAME".log bad=bad/"$NAME".bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load MODULES table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading SUB_MODULESmodify ------------------------------" 2>&1 >> $LOG
NAME="SUB_MODULESmodify"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load SUB_MODULES table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading PARM_EDITSmodify -------------------------------" 2>&1 >> $LOG
NAME="PARM_EDITSmodify"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PARM_EDITS table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading PARAMETERSmodify -------------------------------" 2>&1 >> $LOG
NAME="PARAMETERSmodify"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PARAMETERS table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading DEF_PARMSmodify --------------------------------" 2>&1 >> $LOG
NAME="DEF_PARMSmodify"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load DEF_PARMS table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading PARM_LISTmodify --------------------------------" 2>&1 >> $LOG
NAME="PARM_LISTmodify"
sqlldr $DB control=$DATA_DIR/$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PARM_LIST table failed."
    exit 1
fi

echo "."
echo "" 2>&1 >> $LOG
DATE=`date`
echo "Completed - $0 - $DATE" 2>&1 >> $LOG

