#!/usr/bin/perl -w
#
# Purpose: Sets the date updated back 31 days for Test Case 36.
#
# Usage: tc036_30day_delete_date_change.pl <input_file>
#
# Documentation: No other documentation exists for this script
#

use strict;
use warnings;

use Logger;
use ias_create_work_order qw
{
    ias_create_work_order
};
use ias_const;
use ias_db;

use constant PROG     => "tc036_30day_delete_date_change.pl";

my $logger;         # The logger object to use for log messages
my %args;           # args to pass to ias_create_work_order
my $wo_id;          # work order id returned by ias_create_work_order
my $sql;            # sql query string

# Get input file name from command line argument(s)

my $numArgs = $#ARGV + 1;
if ($numArgs != 1)
{
    print "\nUsage: tc036_30day_delete_date_change.pl <input_filename>\n";
    exit FAILURE;
}

my $inputFileName = $ARGV[0];


# Initialize variables

my $pwgCallResult = "";
my $module = "";
my $sceneName = "";
my $correctedType = "";
my $productId = "";
my $comment = "";
my $woComment = undef;
my $commandStr ="";
my @fileLine;

# Open input file and populate an array with work order ids


# initialize logger
$logger = Logger->new("STDOUT", PROG);
if(!$logger)
{
    print STDERR PROG . ": ERROR: Failed to establish logger object.\n";

    exit FAILURE;
}
set_default_log($logger);

$logger->info_msg(__FILE__, __LINE__,"Processing input file:  $inputFileName");
open FILE, "<", $inputFileName or die;
my @work_order_ids = <FILE>;
close FILE;

# initialize database connection
my ($user_id, $password) = ias_db_GetDBConnectionInfo();

my $dbhcommon = ias_db_ConnectToDB($user_id, $password);
if (!$dbhcommon)
{
    $logger->fatal_msg(__FILE__, __LINE__,
                            "Error connecting to LDCM database");
    $logger->close_log();
    exit FAILURE;
}

# get date and time.
my $time = time();
my $past_time = $time - (31 * 24 * 60 * 60);
my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = 
         localtime($past_time);
$year += 1900;
$mon += 1; #add one to month to get range of 1-12 for oracle.
my $date_string = "$year-$mon-$mday" . " " . "$hour:$min:$sec";

# update date_updated for each work order

my $wo_sth;
foreach my $work_order_id ( @work_order_ids )
{
   #remove trailing newline character from file line
   chomp($work_order_id);

   $sql = qq{UPDATE work_orders SET DATE_UPDATED=to_date('$date_string',
             'YYYY-MM-DD HH24:MI:SS') where work_order_id='$work_order_id'
          };

   if (!($wo_sth = $dbhcommon->do($sql)))
   {
      $logger->fatal_msg(__FILE__, __LINE__,
                "Unable to update DATE_UPDATED for $work_order_id");
      $dbhcommon->rollback;
      $dbhcommon->disconnect;      
      $logger->close_log();
      exit FAILURE;
   }
   
}

if (!$dbhcommon->commit)
{
    $logger->fatal_msg(__FILE__, __LINE__,
                        "Commit update work orders table failed");
    $dbhcommon->disconnect;
    $logger->close_log();
    exit FAILURE;
}

$dbhcommon->disconnect;

$logger->info_msg(__FILE__, __LINE__, "Script complete.");
$logger->close_log();
