#!/usr/bin/perl -w
#
use SOAP::Lite;

if (!defined $ENV{IAS_SERVICES}
                       )
{
    print "Please set IAS_SERVICES ENV var - hostname:port\n";
    exit 1;
}

# The following BPF is expected to be the latest Active BPF 
# (effective date ends 02/25). 
my $expected_bpf = "LO8BPF20141218041947_20150225145444.02";
###################################
# Test 1 - Slighly beyond effective date with nearMatch on. Expected to return
# expected BPF.
#################################
my $parms = SOAP::Data->name(
        "getAllBpfByDateRequest" => \SOAP::Data->value(
        SOAP::Data->name("acquisitionDate" => '2015-02-25T14:54:47')->type(""),
        SOAP::Data->name("sensor" => 'OLI')->type(""),
        SOAP::Data->name("status" => 'ACTIVE')->type(""),
        SOAP::Data->name("nearMatch" => 'true')->type("")));
# Print input parms as XML
my $ser = SOAP::Serializer->new();
print $ser->envelope(freeform => $parms) . "\n";
my $soap_response;
eval
{
    $soap_response = SOAP::Lite          
                -> uri("uri:BpfQueryService")                        
                ->ns("uri:BpfQueryService","bpf")
                -> proxy($ENV{IAS_SERVICES}
                        . "/dataservices/BpfService", 
                    timeout => 99)
                ->getAllBpfNamesByDate($parms);
};
if ($@)
{
    print "Error encountered when accessing the CPF ".
        "service: ". $@;
    exit 1;
}
if ($soap_response->fault())
{
    print "SOAP Error: " . $soap_response->fault()->{faultstring};
    exit 1;
}

my $file_returned = $soap_response->result();
if (!defined $file_returned)
{
    print "No files returned for test #1\n";
    exit 1;
}
$file_returned = $file_returned->{filename};
if ($file_returned ne $expected_bpf)
{
    print "$file_returned was returned. We expected $expected_bpf\n";
    exit 1;
}
print "-------------\nCorrect response for test 1\n-------------\n";

###################################
# Test 2 - Slightly beyond effective date with nearMatch off. Expected to return
# no BPF.
#################################
$parms = SOAP::Data->name(
        "getAllBpfByDateRequest" => \SOAP::Data->value(
        SOAP::Data->name("acquisitionDate" => '2015-02-25T14:54:47')->type(""),
        SOAP::Data->name("sensor" => 'OLI')->type(""),
        SOAP::Data->name("status" => 'ACTIVE')->type(""),
        SOAP::Data->name("nearMatch" => 'false')->type("")));
# Print input parms as XML
$ser = SOAP::Serializer->new();
print $ser->envelope(freeform => $parms) . "\n";
eval
{
    $soap_response = SOAP::Lite          
                -> uri("uri:BpfQueryService")                        
                ->ns("uri:BpfQueryService","bpf")
                -> proxy($ENV{IAS_SERVICES}
                        . "/dataservices/BpfService", 
                    timeout => 99)
                ->getAllBpfNamesByDate($parms);
};
if ($@)
{
    print "Error encountered when accessing the CPF ".
        "service: ". $@;
    exit 1;
}
if ($soap_response->fault())
{
    print "SOAP Error: " . $soap_response->fault()->{faultstring};
    exit 1;
}

$file_returned = $soap_response->result();
if (defined $file_returned)
{
    print "Expected no files returned for test #2. We got " .
           $file_return->{filename} . "\n";
    exit 1;
}
print "-------------\nCorrect response for test 2\n-------------\n";

###################################
# Test 3 - Well beyond (> 24 hours) effective date with nearMatch on. Expected
# to return no BPF.
#################################
$parms = SOAP::Data->name(
        "getAllBpfByDateRequest" => \SOAP::Data->value(
        SOAP::Data->name("acquisitionDate" => '2015-02-26T14:54:47')->type(""),
        SOAP::Data->name("sensor" => 'OLI')->type(""),
        SOAP::Data->name("status" => 'ACTIVE')->type(""),
        SOAP::Data->name("nearMatch" => 'true')->type("")));
# Print input parms as XML
$ser = SOAP::Serializer->new();
print $ser->envelope(freeform => $parms) . "\n";
eval
{
    $soap_response = SOAP::Lite          
                -> uri("uri:BpfQueryService")                        
                ->ns("uri:BpfQueryService","bpf")
                -> proxy($ENV{IAS_SERVICES}
                        . "/dataservices/BpfService", 
                    timeout => 99)
                ->getAllBpfNamesByDate($parms);
};
if ($@)
{
    print "Error encountered when accessing the CPF ".
        "service: ". $@;
    exit 1;
}
if ($soap_response->fault())
{
    print "SOAP Error: " . $soap_response->fault()->{faultstring};
    exit 1;
}

$file_returned = $soap_response->result();
if (defined $file_returned)
{
    print "Expected no files returned for test #3. We got " .
            $file_return->{filename} . "\n";
    exit 1;
}
print "-------------\nCorrect response for test 3\n-------------\n";
