#!/usr/bin/perl -w
#
use strict;

##############################################################################
#        NAME: test_file_builders.pl
#
# DESCRIPTION: Requests a number of CPF files at the same time. It is intended
#              to test the number of files being built at once is properly
#              limited. This means that the files should not already be
#              cached by the service. 
#
# ARGUMENTS:   None
#
##############################################################################
use ias_const;

sub _main();

my $status = &_main();
if ($status != SUCCESS)
{
    exit FAILURE;
}

exit SUCCESS;

sub _main()
{
    my %cpf_files = (
            "L8CPF20130701_20130919.05" => "AAAA",
            "L8CPF20130920_20130930.05" => "AAAA",
            "L8CPF20131001_20131231.05" => "AAAA",
            "L8CPF20140101_20140331.05" => "AAAA",
            "L8CPF20140401_20140630.03" => "AAAA",
            "L8CPF20140701_20140930.03" => "AAAA",
            "L8CPF20141001_20141219.04" => "AAAA",
            "L8CPF20141219_20141231.09" => "AAAA",
            "L8CPF20150101_20150331.02" => "AAAA");

    if (! defined $ENV{IAS_SERVICES})
    {
        print "IAS_SERVICES Env Var is not set\n";
        return ERROR;
    }

    my ($file, $ignore);
    while (($file, $ignore) = each(%cpf_files))
    {
        my $pid = fork();

        if (! defined $pid)
        {
            print "Failed to fork\n";
            return ERROR;
        }

        # This is the child process
        if ($pid == 0)
        {
            # Call the service to download the CPF. The output is validated
            # against a "special" template inside the same dir as this script
            my $cmd = "wget -q -O - '" . $ENV{IAS_SERVICES}
                 . "/dataservices/rest/cpf?operation="
                 . "getCalParmFile&filename=$file' | cps_validate.pl --e "
                 . "--no-warnings --no-format --standardIn --type cpf $file";
            print "Running $cmd\n";
            system($cmd);
            if ($? == -1)
            {
                print "Unable to run command: $cmd\n";
                exit 1;
            }
            elsif ($? >> 8 != 0)
            {
                printf ("Command:\n$cmd\n returned %d\n", $? >> 8);
                exit 1;
            }
            exit 0;
        }
    }

    # wait for all the children to complete and check each of the return values
    # for failures
    my $failure = FALSE;
    while(1)
    {
        my $pid = wait();
        if ($pid <= 0)
        {
            last;
        }
        elsif ($? != 0)
        {
            $failure = TRUE;
        }
    }

    if ($failure == TRUE)
    {
        return ERROR;
    }
    return SUCCESS;
}
