#!/usr/bin/perl -w
#
use strict;

##############################################################################
#        NAME: test_rlut_date_query.pl
#
# DESCRIPTION: Queries for an RLUT by date and verifies the file returned is
#              valid HDF5 data.
#
# ARGUMENTS:   None
#
##############################################################################

use ias_const;

sub _main();

my $status = &_main();
if ($status != SUCCESS)
{
    exit FAILURE;
}

exit SUCCESS;

sub _main()
{
    my $baseline_rlut;

    if (! defined $ENV{IAS_SERVICES})
    {
        print "IAS_SERVICES Env Var is not set\n";
        return ERROR;
    }

    if (! defined $ENV{IAS_IT_TEST_DATA_DIR})
    {
        print "IAS_IT_TEST_DATA_DIR Env Var is not set\n";
        return ERROR;
    }

    $baseline_rlut = $ENV{IAS_IT_TEST_DATA_DIR} .
                     "/rlut/L8RLUT20130211_20150302v10.h5";
    if (! -f $baseline_rlut)
    {
        print "Unable to locate L8RLUT20130211_20150302v10.h5 in the "
            . "IAS_IT_TEST_DATA_DIR\n";
        return ERROR;
    }

    # Call the service and store the contents returned into a temp file
    my $cmd = "wget -q -O - '" . $ENV{IAS_SERVICES}
         . "/dataservices/rest/rlut?operation="
         . "getRlutParmFile&date=2015-01-01T00:00:00' | diff -q - "
         . $baseline_rlut;
    print "Running: $cmd\n";
    system($cmd);
    if ($? == -1)
    {
        print "Unable to run command: $cmd\n";
        return ERROR;
    }
    elsif ($? >> 8 != 0)
    {
        printf ("Command:\n$cmd\n returned %d\n", $? >> 8);
        return ERROR;
    }

    print "Correct RLUT returned\n";

    return SUCCESS;
}
