#!/bin/csh -f
#***************************************************************************
# NAME:     create_wos.csh
# 
#  PURPOSE:  Creates the work orders for test_case_040 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: SUCCESS / ERROR
# 
#  USAGE:    ./create_wos.csh
# ***************************************************************************

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

# Set up the created files
set log = 'tc040.log'
set wo_id_file = 'tc040_wo_ids.txt'

# Start with new files
rm -f $log $wo_id_file

# Setup the arrays for what to process
# All of the arrays must contain an equal number of items
# Comments array for PWG
set comments = ( \
    'TC040 1 Nominal Earth - New Orleans using Annealing' \
    'TC040 2 Nominal Earth - New Orleans using MultiMin' \
    'TC040 3 Bridge target spanning multiple SCAs' )

# Scene id array used in PWG
set scene_ids = ( \
    LC80220392013088LGN00 \
    LC80220392013144LGN00 \
    LC81200352015133LGN00 )

# L0R relative path
set l0r_path_dirs = ( \
    LC80220392013088LGN00/LC80220392013088LGN00 \
    LC80220392013144LGN00/LC80220392013144LGN00 \
    LC81200352015133LGN00/LC81200352015133LGN00)

# Procedure to use
set procedures = ( \
    'MTF Bridge OLI' \
    'MTF Bridge OLI' \
    'MTF Bridge OLI' )

set fit_method = ( \
    0 \
    1 \
    0 )

set index = 0
set pwg_status = 0

# Inserting the work orders
# Loop through arrays creating WOs
echo "Inserting Work Orders" |& tee -a $log
while ( $index < ${#comments} )
    @ index++
    
    # FIXME - Addition for ST testing because the BPFs retrieved in ST were
    # different than IT.  In the next release, update IT to the current BPF
    # found in ST
    if ( $index == 2 ) then
        set bpf_oli = "-parm DSW:BIAS_PARM_FILENAME_OLI=LO8BPF20130524102726_20130524103326.01"
        set bpf_tirs = "-parm DSW:BIAS_PARM_FILENAME_TIRS=LT8BPF20130524101845_20130524103825.01"
    else
        set bpf_oli = "";
        set bpf_tirs = "";
    endif
   
    # Add parameter override code here if needed
    # May also need a parameter override list above to help with things
    if ( $mode == "IT" ) then
        set output = `PWG \
          -interactive \
          -procedure_id "$procedures[$index]" \
          -scene_id $scene_ids[$index] \
          -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$index] \
          -parm MTF_ESTIMATE:STF_FIT_METHOD=$fit_method[$index] \
          $bpf_oli \
          $bpf_tirs \
          -comment "$comments[$index]"`
        set saveStatus = $status
    else
        set output = `PWG \
          -interactive \
          -procedure_id "$procedures[$index]" \
          -scene_id $scene_ids[$index] \
          -parm MTF_ESTIMATE:STF_FIT_METHOD=$fit_method[$index] \
          $bpf_oli \
          $bpf_tirs \
          -comment "$comments[$index]"`
        set saveStatus = $status
    endif

    # Check if error is thrown
    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error Loading Dataset $index" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for" \
                " dataset $index" |& tee -a $log
        else
            shift output
            set wo_id = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$wo_id "
            echo $wo_id >> $wo_id_file
        endif
    endif
end
echo ""

# Write out how many errors occured or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: Created $index Work Orders" |& tee -a $log
endif
exit 0

