#!/bin/csh -f
#
#  Usage: save_tc040_outputs.csh 
#
#  This saves the non-work order files that should be saved when running the
#  test case.  The work order files are handled by save_wo_outputs.csh.
#
#  Required: file: test_case_id, with 3-digit test case ID such as 001
#
#-----------------------------------------------------------------------

set script_name = `basename $0`

# These are the files that should be saved
set file_list = ( \
    'AT_ESF_Band1.csv' \
    'AT_ESF_Band2.csv' \
    'AT_ESF_Band3.csv' \
    'AT_ESF_Band4.csv' \
    'AT_ESF_Band5.csv' \
    'AT_ESF_Band6.csv' \
    'AT_ESF_Band7.csv' \
    'AT_ESF_Band8.csv' \
    'XT_ESF_Band1.csv' \
    'XT_ESF_Band2.csv' \
    'XT_ESF_Band3.csv' \
    'XT_ESF_Band4.csv' \
    'XT_ESF_Band5.csv' \
    'XT_ESF_Band6.csv' \
    'XT_ESF_Band7.csv' \
    'XT_ESF_Band8.csv' \
    'mtf_performance.rpt' \
    'mtfestimate_trendall.dat' \
    'output_file_1_trend_date.dat' \
    'output_file_2_trend_date.dat' \
    'output_file_3_trend_date.dat' \
    'output_file_both_trend_g_optics.dat')

# Check for command line argument and print usage if none supplied
if ( ${#argv} > 0 ) then
    echo
    echo "    Usage: $script_name "
    echo
    exit 1
endif

# Get the test case ID
if ( ! -e test_case_id ) then
    echo "File test_case_id doesn't exist"
    exit 1
endif
set id = `cat test_case_id`

set log = tc${id}.log

set test_case_name = test_case_$id

set now = `date +"%F %R"`
echo | tee -a $log
echo "----------------------------------------------------" | tee -a $log
echo "--- Running $script_name at $now" | tee -a $log
echo | tee -a $log

set final_outputs_dir = $IAS_IT_TEST_DATA_DIR/final_outputs/$test_case_name

set exit_status = 0

# This should already be done by save_wo_outputs.csh but make it just in case
# it's not there 
mkdir -p $final_outputs_dir | tee -a $log
if ( $status ) then
    echo -n "--- FAIL --- $now " | tee -a $log
    echo " Error creating save directory $final_outputs_dir" | tee -a $log
    set exit_status = 1
endif

set index = 0

# Loop over all files in the file list, saving them to the test case's 
# final_outputs top-level directory
while ( $index < ${#file_list} )
    @ index++

    mv $file_list[$index] $final_outputs_dir | tee -a $log
    if ( $status ) then
        echo -n "--- FAIL --- $now " | tee -a $log
        echo " Errors saving to $final_outputs_dir" | tee -a $log
        set exit_status = 1
    else
        echo -n "--- PASS --- $now " | tee -a $log
        echo " Saved $file_list[$index] to $final_outputs_dir" | tee -a $log
    endif
    echo | tee -a $log
end

# Make sure the directory is group writable
chmod -R g+w $final_outputs_dir | tee -a $log
if ( $status ) then
    echo -n "--- FAIL --- $now " | tee -a $log
    echo " Error changing permissions on $final_outputs_dir" | tee -a $log
    set exit_status = 1
endif


echo ""

if ( $exit_status == 1 ) then
    echo "--- FAIL --- There were failures, check $log." | tee -a $log
else
    set now = `date +"%F %R"`
    echo "--- Completed the $script_name at $now" | tee -a $log
    echo | tee -a $log
endif

exit $exit_status

