#!/bin/csh -f
#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for test_case_041 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: SUCCESS(0) / ERROR(1)
#
#  USAGE:    ./create_wos.csh
#****************************************************************************
set SUCCESS = 0
set ERROR = 1
set tc = 041
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt

# Remove old log and work order ids file
rm -f $log $woid_file

# Check if we are operating in IT or ST mode
set IS_IT_MODE = 1
if ( $1 == "ST" ) then
    set IS_IT_MODE = 0
endif

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tc} 01 Island Scene" \
    "TC${tc} 02 TIRS only" \
    "TC${tc} 03 Normal angle band" \
    "TC${tc} 04 Ascending day" \
    "TC${tc} 05 Central Meridian Crossing" \
    "TC${tc} 06 Descending 180 Degree Crossing" \
    "TC${tc} 07 North Pole" \
    "TC${tc} 08 South Pole" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    "LC80230192013231LGN00/LC80230192013231LGN00" \
    "LT80400312013126LGN01/LT80400312013126LGN01" \
    "LC81620462013341LGN00/LC81620462013341LGN00" \
    "LC80192432013085LGN01/LC80192432013085LGN01" \
    "LC81940522013133LGN01/LC81940522013133LGN01" \
    "LC80900152013204LGN00/LC80900152013204LGN00" \
    "LC80282462013234LGN00/LC80282462013234LGN00" \
    "LC80251222013101LGN01/LC80251222013101LGN01" \
    )

# Scenes in proper order
set scene_ids = ( \
    "LC80230192013231LGN00" \
    "LT80400312013126LGN01" \
    "LC81620462013341LGN00" \
    "LC80192432013085LGN01" \
    "LC81940522013133LGN01" \
    "LC80900152013204LGN00" \
    "LC80282462013234LGN00" \
    "LC80251222013101LGN01" \
    )

# Procedures in the proper order
set procedure_ids = (\
    "L1T with Quality Band" \
    "L1GT with Quality Band" \
    "L1T with Quality Band" \
    "L1T with Quality Band" \
    "L1T with Quality Band" \
    "L1T with Quality Band" \
    "L1T with Sun Correction" \
    "L1T with Sun Correction" \
    )

# Insert work orders
set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    set additional_parms = ""
    
    if ($i == 8) then
        set additional_parms = ( \
            "-parm SUN_ANGLE_CORRECTION:MINIMUM_SUN_ANGLE_THRESHOLD=-17.0" \
        )
    endif 

    # Check for the mode or the environment
    if ( $IS_IT_MODE ) then
        set output = `PWG -procedure_id "$procedure_ids[$i]" \
            -scene_id $scene_ids[$i] \
            -i -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedure_ids[$i]" \
            -scene_id $scene_ids[$i] \
            -i -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    endif

    if ( $saveStatus != $SUCCESS ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

# Check the pwg status for ERROR or SUCCESS
if ( $pwg_status != $SUCCESS ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit $ERROR
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif

exit $SUCCESS
