#!/bin/csh -f
#***************************************************************************
# NAME:     run_create_angle_bands.csh
#
#  PURPOSE:  Creates the angle bands for all the generated work orders
#  RETURNS:
#        Type:  Integer
#        Value: SUCCESS(0) / ERROR(1)
#
#  USAGE:    ./run_create_angle_bands.csh
#****************************************************************************
set SUCCESS = 0
set ERROR = 1
set current_directory = `pwd`
set log = "$current_directory/run_create_angle_bands.log"

if ( -e "./tc041_woids.txt" ) then
    set woids = `head -n 6 ./tc041_woids.txt`
else
    echo "Error: File tc041_woids.txt does not exist"
    exit $ERROR
endif

set i = 0
foreach work_order_id ($woids)
    @ i += 1
    echo "Running create_angle_bands for work order $work_order_id" \
        | tee -a $log

    # Replace text in the template file
    set odl_file = "./odl/angle_gen_${i}.odl"
    set parameter_file = "$IAS_WO/${work_order_id}/CREATE_ANGLE_BANDS.odl"    
    sed -e "s|AAAAA|$work_order_id|" $odl_file > $parameter_file

    # Create the angle bands for the current work order
    cd $IAS_WO/${work_order_id}
    $IAS_BIN/create_angle_bands CREATE_ANGLE_BANDS.odl | tee -a $log
    if ( $status ) then
        echo "Error: Work order $work_order_id failed to run" | tee -a $log
        exit $ERROR
    endif
    cd $current_directory
end

echo "SUCCESS: Angle bands created successfully" | tee -a $log
 
exit $SUCCESS
