#!/bin/csh -f

#***************************************************************************
# NAME:     create_wos.csh
# 
#  PURPOSE:  Creates the work orders for test_case_044 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: 1 / 0
# 
#  USAGE:    ./create_wos.csh
#****************************************************************************

set log = 'tc044.log'
set wo_id_file = 'tc044_wo_ids.txt'

# Start with new files
rm -f $log $wo_id_file

# Setup the arrays for what to process
# All of the arrays must contain an equal number of items
# Comment fields -- this is the order in which the folllowing list are
# dependent on
set comments = ( \
    'TC044 1 Nominal Earth - descending day' \
    'TC044 2 OLI Lamp' \
    'TC044 3 Scene that will fail in the subsetter' )

# Scene and interval id (Lamp collection) in proper order
set scene_ids = ( \
    LC80330422013173LGN00 \
    LO800L0725332013153LGN00 \
    LC80220392013144LGN00 )

# Procedure in proper order
set procedures = ( \
    'L1T with Quality Band' \
    'L1R-Lamp OLI' \
    'L1T with Quality Band' )

set index = 0
set pwg_status = 0

# Inserting the work order
echo "Inserting Work Orders" |& tee -a $log
while ( $index < ${#comments} )
    @ index++

    set output = `PWG \
      -interactive \
      -procedure_id "$procedures[$index]" \
      -scene_id $scene_ids[$index] \
      -comment "$comments[$index]"`
    set saveStatus = $status

    # Check for the status
    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error Loading Dataset $index" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for" \
                " dataset $index" |& tee -a $log
        else
            shift output
            set wo_id = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$wo_id "
            echo $wo_id >> $wo_id_file
        endif
    endif
end
echo ""

# Check for the error or succces of $pwg_status
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: Created $index Work Orders" |& tee -a $log
endif
exit 0
