#!/bin/csh -f
#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for test_case_046 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: SUCCESS / ERROR
#
#  USAGE:    ./create_wos.csh
# ***************************************************************************

set is_it_mode = 1
if ( $1 == "ST" ) then
    set is_it_mode = 0
endif

# Set up the created files
set log = 'tc046.log'
set wo_id_file = 'tc046_wo_ids.txt'
set tts = "three_tirs_scenes"

# Start with new files
rm -f $log $wo_id_file

# Setup the arrays for what to process
# All of the arrays must contain an equal number of items
# Comments array for PWG
set comments = ( \
    'TC046 1 Geometric Super Site - Winter Desert - special cpf' \
    'TC046 2 Geometric Super Site - Winter Desert' \
    )

# Scene id array used in PWG
set scene_ids = ( \
    LC80400332013318LGN00 \
    LC80400332013318LGN00 )

# L0R relative path
set l0r_path_dirs = ( \
    $tts/LC80400332013318LGN00/LC80400332013318LGN00 \
    $tts/LC80400332013318LGN00/LC80400332013318LGN00 )

# Procedure to use
set procedures = ( \
    'TIRS Alignment' \
    'TIRS Alignment' )

set index = 0
set pwg_status = 0

# Inserting the work orders
# Loop through arrays creating WOs
echo "Inserting Work Orders" |& tee -a $log
while ( $index < ${#comments} )
    @ index++
    set additional_parms = ""
    set l0r = ""

    # Only set the l0r path for IT testing
    if ( $is_it_mode ) then
        set l0r = "-l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$index]"
    endif

    if ( $index == 1 ) then
        set ds1_parms = ( \
            "-parm DSW:CAL_PARM_FILENAME=$IAS_IT_TEST_DATA_DIR/test_case_046/tc046_LC08CPF_20131001_20131231_01.05" \
            "-parm TIRS_ALIGNMENT:CPF_GROUP_FLAG=1" \
        )
        set additional_parms = `echo $ds1_parms`
    else if ( $index == 2 ) then
        # The pause flag is set on the script before the chararactization valid
        # flags are updated. This allows for determintistic expected results
        set ds2_parms = ( \
            "-script TIRS_ALIGNMENT:PAUSE " \
            "-parm TIRS_ALIGNMENT:STORE_CHARACTERIZATION_IN_DB=0" \
        )
        set additional_parms = `echo $ds2_parms`
    endif

    # Run PWG to create the work order
    set output = `PWG -interactive \
        -procedure_id "$procedures[$index]" \
        -scene_id $scene_ids[$index] \
        -comment "$comments[$index]" \
        $l0r $additional_parms`
    if ( $status ) then
        echo $output >> $log
        echo "Error Loading Dataset $index" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for" \
                " dataset $index" |& tee -a $log
        else
            shift output
            set wo_id = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$wo_id "
            echo $wo_id >> $wo_id_file
        endif
    endif
end
echo ""

# Write out how many errors occured or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
endif

echo "SUCCESS: Created $index Work Orders" |& tee -a $log
exit 0
