#!/usr/bin/perl -w
use strict;

# This is a test script for Test Case 047 - Gain Application 

#### Requirements Tests ####
#
# IP4122 The IAS shall provide the capability to optionally apply detector 
# gain corrections during radiometric correction processing of TIRS data, as 
# defined in the Cal/Val Algorithm Description Document (ADD).
#
# IP1728 The IAS shall provide the option to apply detector gain corrections 
# during radiometric correction processing of OLI data, as defined in the 
# Cal/Val Algorithm Description Document (ADD).
#
# IP1755 The IPS shall correct OLI detectors for temperature sensitivity using 
# the correction algorithm defined in the Cal/Val Algorithm Description 
# Document (ADD).
#
# IP4123 The IAS shall provide the capability to optionally apply TIRS 
# detector gain temperature sensitivity corrections during radiometric 
# correction processing using the correction algorithm defined in the Cal/Val 
# Algorithm Description Document (ADD).
#
############################


# The following benchmark L1R scenes are in the test data directory for the 
# test case:  
# - Benchmark Scene for No Gain Corrections (l1r_ngc_verify.h5) applied, 
# - Benchmark Scene for Absolute and Relative Gains (l1r_arg_verify.h5) applied
# - Benchmark Scene for Absolute Gains (l1r_ag_verify.h5) only applied,
# - Benchmark Scene for Absolute and Relative Gains applied with Temperature 
#   Sensitivity (l1r_argts_verify.h5) applied.

my $numArgs = $#ARGV + 1;
if ( $numArgs < 4 )
{
   print "\nPlease provide four input Work Order ID.\n\n";
   die;
}
my @workorderID = @ARGV[0..3];
my $woID;

# test data directory and names of output files
my $data_dir = "$ENV{IAS_IT_TEST_DATA_DIR}";
my $tc_dir = "/test_case_047";
my $tc_data_dir = $data_dir . $tc_dir;

# Work Order ID directory
my $workorderdir = "$ENV{IAS_WO}/";
my $workorderpath;

my $ext = ".h5";
my @files = qw(l1r_ngc l1r_arg l1r_argts l1r_ag);
my $error_counter = 0;

foreach my $file (@files)
{
    # Get the correct work order path
    $woID = shift @workorderID;
    $workorderpath = $workorderdir . $woID;

    # comparing the generated files with expected files
    my $command = "../tools/verify_test_results.pl $woID " .
                  "$tc_data_dir/$file \$IAS_DB_L8_OLITIRS";
    print "Running: $command\n";
    my $rc = system("$command");
    if ($rc != 0)
    {
        print "Diff failed: $command\n";
        $error_counter++;
    }
}
    
if ($error_counter)
{
    print "Running diffs failed\n";
    exit 1;
}
else
{
    print "Running diffs passed\n";
    exit 0;
}

