#!/bin/csh -f

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

set log = tc053.log
set woid_file = tc053_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC053 1 176s OLI shutter" \
    "TC053 2 176s OLI shutter with modified CPF" \
    "TC053 3 514s TIRS deep space" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    LO800S1756422013075LGN00/LO800S1756422013075LGN00 \
    LO800S1756422013075LGN00/LO800S1756422013075LGN00 \
    LT800D1435192013090LGN00/LT800D1435192013090LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LO800S1756422013075LGN00 \
    LO800S1756422013075LGN00 \
    LT800D1435192013090LGN00 \
    )

# Procedures in proper order
set procedures = ( \
    "L0R-Long Collect OLI" \
    "L0R-Long Collect OLI" \
    "L0R-Long Collect TIRS" \
    )

# Datasets 2 needs a CPF with frames to skip top and bottom modified
set modified_cpf = $IAS_IT_TEST_DATA_DIR/cpf/tc053_L8CPF20130101_20130331.18

set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++
    if ( $i == 1 ) then
        set cpf_parameter = ""
        set additional_parm = ""
    else if ( $i == 2 ) then
        set cpf_parameter = "-parm DSW:CAL_PARM_FILENAME=$modified_cpf"
        set additional_parm = ( \
            "-parm LONG_COLLECT_STATS:SENSOR_NAME=OLI" \
            "-parm LONG_COLLECT_STATS:ADJACENT_CORRELATION_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:FRAMES_PER_SEGMENT=2000" \
            "-parm LONG_COLLECT_STATS:KURTOSIS_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:MAXIMUM_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:MEAN_SQUARED_RESPONSE_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:MINIMUM_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:NUM_VALID_FRAMES_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:SKEWNESS_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:STANDARD_DEVIATION_REPORT_FLAG=1" \
            "-parm LONG_COLLECT_STATS:STORE_CHARACTERIZATION_IN_DB=1" \
            )
    else
        set cpf_parameter = ""
        set additional_parm = ( \
            "-parm LONG_COLLECT_STATS:MEAN_REPORT_FLAG=1" \
            )
    endif

    if ( $mode == "IT" ) then
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] -i \
            -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -comment "$comments[$i]" $cpf_parameter $additional_parm `
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] -i \
            -comment "$comments[$i]" $cpf_parameter $additional_parm `
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""


if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
