#!/bin/csh -f
#***************************************************************************
# NAME:     create_wos.csh
#
# PURPOSE:  Creates the work orders for test_case_059 using PWG
# RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************

set is_it_mode = 1
if ($1 == "ST") then
    set is_it_mode = 0
endif

set tc = 059
set log = tc${tc}.log
set wo_id_file = tc${tc}_wo_ids.txt
set tts = "three_tirs_scenes"
set ss = "single_scene"

# Start with new files
rm -f $log $wo_id_file

# Setup the arrays for what to process
# All four arrays must contain an equal number of items
set comments = ( \
    "TC${tc} 01 Nominal Earth - Nevada - Pre-WRS2" \
    "TC${tc} 02 Nominal Earth - Nevada" \
    "TC${tc} 03 Nominal Earth - Central SD-NE Border - Pre-WRS2" \
    "TC${tc} 04 Nominal Earth - Central SD-NE Border" \
    "TC${tc} 05 Nominal Earth - Central SD-NE Border" \
    "TC${tc} 06 Nominal Earth - Scene to test that a region center point falling just off the edge of an SCA works properly" \
    "TC${tc} 07 Nominal Earth - TIRS-only dataset (CR 11850) " \
    "TC${tc} 08 Nominal Earth - Scene to test to support the filtering out shapes which do not intersect the image (CR 11851)" \
    "TC${tc} 09 Nominal Earth - Scene to ensure zenith angles are not NANs (CR 12490)" \
    )
set scene_ids = ( \
    LO80400332013096LGN01 \
    LC80400332013110LGN01 \
    LC80310302013092LGN01 \
    LC80310302013143LGN01 \
    LC80310302013191LGN00 \
    LC81920392013183LGN00 \
    LT81392112014119LGN00 \
    LC80420332014015LGN00 \
    LC81810402014029LGN00 )

set l0r_path_dirs = ( \
    $ss/LO80400332013096LGN01/LO80400332013096LGN01 \
    $tts/LC80400332013110LGN01/LC80400332013110LGN01 \
    $tts/LC80310302013092LGN01/LC80310302013092LGN01 \
    $tts/LC80310302013143LGN01/LC80310302013143LGN01 \
    $tts/LC80310302013191LGN00/LC80310302013191LGN00 \
    $tts/LC81920392013183LGN00/LC81920392013183LGN00 \
    $tts/LT81392112014119LGN00/LT81392112014119LGN00 \
    $tts/LC80420332014015LGN00/LC80420332014015LGN00 \
    $tts/LC81810402014029LGN00/LC81810402014029LGN00 )

set procedures = ( \
    'L1T with PICS' \
    'L1T with PICS' \
    'L1T with PICS' \
    'L1T with PICS' \
    'L1T with PICS' \
    'L1T with PICS' \
    'L1T with PICS' \
    'L1T with PICS' \
    'L1T with PICS' )

set index = 0
set pwg_status = 0

echo "Inserting Work Orders" |& tee -a $log
while ( $index < ${#comments} )
    @ index++

    # Only specify the l0r path for IT test cases
    set l0r = ""
    if ( $is_it_mode ) then
        set l0r = "-l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$index]"
    endif

    # Run PWG to create the work order
    set output = `PWG -interactive $l0r \
        -procedure_id "$procedures[$index]" \
        -scene_id $scene_ids[$index] \
        -comment "$comments[$index]"`
    if ( $status ) then
        echo $output >> $log
        echo "Error Loading Dataset $index" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for" \
                " dataset $index" |& tee -a $log
        else
            shift output
            set wo_id = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$wo_id "
            echo $wo_id >> $wo_id_file
        endif
    endif
end
echo ""

if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: Created $index Work Orders" |& tee -a $log
endif
exit 0

