#!/bin/csh -f

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

set log = 'tc060.log'
set wo_id_file = 'tc060_woids.txt'

# Start with new files
rm -f $log $wo_id_file

# Setup the arrays for what to process
# All four arrays must contain an equal number of items
set comments = ( \
    'TC060 1 Nominal Earth - Nevada' \
    'TC060 2 Nominal Earth - Central SD-NE Border' )

set scene_ids = ( \
    LC80400332013110LGN01 \
    LC80310302013143LGN01 )

set l0r_path_dirs = ( \
    LC80400332013110LGN01/LC80400332013110LGN01 \
    LC80310302013143LGN01/LC80310302013143LGN01 )

set procedures = ( \
    'L1T Product' \
    'L1T Product' )

set parameters = ( \
    '' \
    '' )

set index = 0
set pwg_status = 0

echo "Inserting Work Orders" |& tee -a $log
while ( $index < ${#comments} )
    @ index++

    # Add parameter override code here if needed
    # May also need a parameter override list above to help with things
    set current_parameters = ""
    if ( "$parameters[$index]" != "" ) then
        set current_parameters = "$parameters[$index]"
    endif

    if ( $mode == "IT" ) then
        set output = `PWG \
            -interactive \
            -procedure_id "$procedures[$index]" \
            -scene_id $scene_ids[$index] \
            -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$index] \
            -comment "$comments[$index]" \
            $current_parameters`
        set saveStatus = $status
    else
        set output = `PWG \
            -interactive \
            -procedure_id "$procedures[$index]" \
            -scene_id $scene_ids[$index] \
            -comment "$comments[$index]" \
            $current_parameters`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error Loading Dataset $index" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for" \
                " dataset $index" |& tee -a $log
        else
            shift output
            set wo_id = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$wo_id "
            echo $wo_id >> $wo_id_file
        endif
    endif
end
echo ""

if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: Created $index Work Orders" |& tee -a $log
endif
exit 0

