#!/bin/csh -f
#***************************************************************************
# NAME:     create_wos.csh
#
# PURPOSE:  Creates the work orders for test_case_061 using PWG             
# RETURNS:  
#       Type:  Integer
#       Value: SUCCESS / ERROR
#
# USAGE:    ./create_wos.csh
#***************************************************************************
set SUCCESS = 0
set ERROR = 1

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

# Set up the created files
set log = 'tc061.log'
set wo_id_file = 'tc061_wo_ids.txt'

# Start with new files
rm -f $log $wo_id_file

# Setup the arrays for what to process
# All four arrays must contain an equal number of items
# Comments array for PWG
set comments = ( \
    'TC061 1 GEOID separation over water' )

# Scene id array used in PWG
set scene_ids = ( \
     LC81180652013225LGN00 )

# L0R relative path
set l0r_path_dirs = ( \
    LC81180652013225LGN00/LC81180652013225LGN00 )

# Procedure to use
set procedures = ( \
    'L1T Product' )

set index = 0
set pwg_status = 0

# Loop through arrays creating WOs
echo "Inserting Work Orders" |& tee -a $log
while ( $index < ${#comments} )
    @ index++

    # Add parameter override code here if needed
    # May also need a parameter override list above to help with things
    if ( $mode == "IT" ) then
        # Run with L0R data specified
        set output = `PWG \
            -interactive \
            -procedure_id "$procedures[$index]" \
            -scene_id $scene_ids[$index] \
            -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$index] \
            -comment "$comments[$index]"`
        set saveStatus = $status
    else
        # Run with L0R data requested
        set output = `PWG \
            -interactive \
            -procedure_id "$procedures[$index]" \
            -scene_id $scene_ids[$index] \
            -comment "$comments[$index]"`
        set saveStatus = $status
    endif

    # Check if error is thrown
    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error Loading Dataset $index" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for" \
                " dataset $index" |& tee -a $log
        else
            shift output
            set wo_id = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$wo_id "
            echo $wo_id >> $wo_id_file
        endif
    endif
end
echo ""

# Write out how many errors occured or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit $ERROR
else
    echo "SUCCESS: Created $index Work Orders" |& tee -a $log
endif

exit $SUCCESS

