#!/bin/csh -f
#***************************************************************************
# NAME:     check_work_order_logs.csh
#
#  PURPOSE:  Checks that the work order logs for L8INIT contain the correct
#            TIRS SSM encoder warnings.
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************
set SUCCESS = 0
set ERROR = 1

set tc = 062
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt

# The search fields in order according to the work order. These are 
# the fields that will be greped for 
set search = ( \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "INFO Using estimated SSM encoder data from" \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "ERROR Cannot open estimated ssm position file no_ssm_file.txt"\
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    "WARN MCE mode 0 in use, not mode 4 as expected" \
    )

# Retrieve the work order ids
set woids = `cat $woid_file`
if ( $status ) then
    exit $ERROR
endif
echo "" | tee -a $log

set i = 0
set is_error = 0

# Loop through each work order id
foreach work_order ($woids)
    @ i++
    echo "Checking Work Order Id: $work_order" | tee -a $log

    # Grep for the search field
    grep "$search[$i]" $IAS_WO/$work_order/save/$work_order.log | tee -a $log
    if ( $status ) then
        # The log for the 8th work order should be normal and should
        # error out when searching for the mode switch in the log
        if ( $i == 8 ) then
            echo "Success: Mode switch not present in log" | tee -a $log
            echo "" | tee -a $log
            continue
        endif 

        echo "Work order $work_order failed. Log should contain:" \
            | tee -a $log
        echo "   - $search[$i]" | tee -a $log
        set is_error = 1
    endif

    # If the 8th work order reaches here then a mode switch has been
    # detected for the nominal case and an error has occured 
    if ( $i == 8 ) then
        echo "Error: Mode switch was present in log" | tee -a $log
        set is_error = 1
    endif 

    echo "" | tee -a $log
end

# Check for errors
if ( $is_error ) then
    echo "Failure: Check work order logs" | tee -a $log
    exit $ERROR
else
    echo "Success: Logs have been validated" | tee -a $log
    exit $SUCCESS
endif
