#!/bin/csh -f
#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for test_case_062 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************
set SUCCESS = 0
set ERROR = 1

# Check for ST mode
set IS_IT_MODE = 1
if ( $1 == "ST" ) then
    set IS_IT_MODE = 0
endif

set tc = 062
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tc} 01 Mode Switch -- Nominal scene before SSM mode switch " \
    "TC${tc} 02 Mode Switch -- SSM mode switch at end of scene" \
    "TC${tc} 03 Mode Switch -- SSM mode switch in the middle of the scene" \
    "TC${tc} 04 Mode Switch -- SSM mode switch at the beginning of the scene" \
    "TC${tc} 05 Mode Switch -- First nominal scene after SSM mode switch " \
    "TC${tc} 06 Estimate SSM position -- SSM position is estimated " \
    "TC${tc} 07 Mode 0 encoder on -- SSM mode 0 with encoder on " \
    "TC${tc} 08 Nominal case -- Normal position data present " \
    "TC${tc} 09 Default case -- No estimated SSM data available " \
    "TC${tc} 10 Estimate SSM -- Predicted quality (0) in scene time frame" \
    "TC${tc} 11 Estimate SSM -- Predicted (0) and preliminary (1) quality" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    LC80230212014346LGN00/LC80230212014346LGN00 \
    LC80230222014346LGN00/LC80230222014346LGN00 \
    LC80230232014346LGN00/LC80230232014346LGN00 \
    LC80230242014346LGN00/LC80230242014346LGN00 \
    LC80230252014346LGN00/LC80230252014346LGN00 \
    LC82280852015009LGN00/LC82280852015009LGN00 \
    LC80230172014346LGN00/LC80230172014346LGN00 \
    LC80330422013173LGN00/LC80330422013173LGN00 \
    LC82280852015009LGN00/LC82280852015009LGN00 \
    LC82280852015009LGN00/LC82280852015009LGN00 \
    LC82280852015009LGN00/LC82280852015009LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LC80230212014346LGN00 \
    LC80230222014346LGN00 \
    LC80230232014346LGN00 \
    LC80230242014346LGN00 \
    LC80230252014346LGN00 \
    LC82280852015009LGN00 \
    LC80230172014346LGN00 \
    LC80330422013173LGN00 \
    LC82280852015009LGN00 \
    LC82280852015009LGN00 \
    LC82280852015009LGN00 \
    )

set i = 0
set pwg_status = 0

# Insert work orders
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    set additional_parms = ""
    set procedure_id = "L1T with Quality Band"
   
    if ( $i == 9 ) then
        # no_ssm_file.txt file doen't exits in wo directory
        set additional_parms = (\
        "-parm L8INIT:L8INIT:ESTIMATED_SSM_POSITION_FILENAME=no_ssm_file.txt" \
                               ) 
    endif

    if ( $i == 10 ) then
        set ssm_file = "$IAS_IT_TEST_DATA_DIR/test_case_062/estimated_ssm_positions_test_1.txt"
        set additional_parms = ( \
        "-parm L8INIT:ESTIMATED_SSM_POSITION_FILENAME=$ssm_file" \
        "-parm DFP:L1G_PACKAGE=1" \
                               )
    endif

    if ( $i == 11 ) then
        set ssm_file = "$IAS_IT_TEST_DATA_DIR/test_case_062/estimated_ssm_positions_test_2.txt"
        set additional_parms = ( \
        "-parm L8INIT:ESTIMATED_SSM_POSITION_FILENAME=$ssm_file" \
        "-parm DFP:L1G_PACKAGE=1" \
                               )
    endif

    # Check for the mode or the environment
    if ( $IS_IT_MODE ) then
        set output = `PWG -procedure_id "$procedure_id" \
            -scene_id $scene_ids[$i] \
            -i -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedure_id" \
            -scene_id $scene_ids[$i] \
            -i -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

# Check the pwg status for ERROR or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit $ERROR
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif

exit $SUCCESS
