#!/bin/csh -f

#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for test_case_064 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************

set IS_IT_MODE = 1
if ( $1 == "ST" ) then
    set IS_IT_MODE = 0
endif

set tc = 064
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tc} 01 Central (zero) meridian crossing" \
    "TC${tc} 02 180 degree crossing" \
    "TC${tc} 03 Near polar (north; as near to polar crossing as available)" \
    "TC${tc} 04 OLI only" \
    "TC${tc} 05 TIRS only" \
    "TC${tc} 06 Original SCA overlap test scene" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    LC81940522013133LGN01/LC81940522013133LGN01 \
    LC80900152013204LGN00/LC80900152013204LGN00 \
    LC80282462013234LGN00/LC80282462013234LGN00 \
    LO80670172013203LGN00/LO80670172013203LGN00 \
    LT80400312013126LGN01/LT80400312013126LGN01 \
    LC80010112013141LGN01/LC80010112013141LGN01 \
    )

# Scenes in proper order
set scene_ids = ( \
    LC81940522013133LGN01 \
    LC80900152013204LGN00 \
    LC80282462013234LGN00 \
    LO80670172013203LGN00 \
    LT80400312013126LGN01 \
    LC80010112013141LGN01 \
    )

set i = 0
set pwg_status = 0

# Insert work orders
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    set procedure_id = "L1T with Quality Band"
    set overwrite = "-parm DSC:OVERWRITE_RPS_CHARACTERIZATION=1"

    if ( $i == 5 ) then
        set procedure_id = "L1GT with Quality Band"
    endif

    # Check for the mode or the environment
    set l0r_path = ""
    if ( $IS_IT_MODE ) then
        set l0r_path = "-l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i]"
    endif

    # Create the work order
    set output = `PWG -procedure_id "$procedure_id" \
        -scene_id $scene_ids[$i] \
        -i $l0r_path \
        -comment "$comments[$i]" \
        $overwrite`
    set saveStatus = $status

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

# Check the pwg status for ERROR or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
