#!/usr/bin/perl

##############################################################################
#
# Purpose:
#    The purpose of this script is to display the records of the
#    database tables subsetter_request_view and work_orders 
#
# Usage:
#    ./view_database work_order_id
#
##############################################################################

use warnings;
use strict;
use DBI;

use ias_const;

# Subroutine Declarations
sub initDb();
sub closeDb();
sub executeQuery($);

# Database Configuration
my $woDbh;

##############################################################################
# Main
##############################################################################

if (not defined $ARGV[0])
{
    print ("Error: Missing work_order_id command line argument.\n");
    exit FAILURE;
}

# Open database connections
if (initDb() == ERROR)
{
    print "ERROR: could not connect to database\n";
    exit FAILURE;
}

while (@ARGV)
{
    my $work_order_id = shift @ARGV;

    # SQL to get the data from the work order table
    my $sql1 = "SELECT scene_id, state, priority, l0r_data_path, l0r_data_status"
            . " FROM work_orders"
            . " WHERE work_order_id = '$work_order_id'";

    # SQL to get the data from the subsetter_request_view
    my $sql2 = "SELECT requesting_subsystem, landsat_interval_id," 
            . " landsat_scene_id, priority, l0r_location, status"
            . " FROM subsetter_request_view"
            . " WHERE work_order_id = '$work_order_id'";

    print "Work Order ID = $work_order_id\n";

    # Call subroutine to display the database records
    print "WORK_ORDERS TABLE \n";
    print "Scene_id State Priority L0r_data_path L0r_data_status\n";
    executeQuery($sql1);

    print "SUBSETTER_REQUEST_VIEW TABLE \n";
    print "Requesting_subsystem Landsat_interval_id Landsat_scene_id, ";
    print "Priority, L0r_location, Status\n";
    executeQuery($sql2);
}

# Close the database connection
closeDb();
exit 0;


##############################################################################
# Subroutines
##############################################################################

##############################################################################
# Name: executeQuery
# Purpose: Executes database query
# Returns: SUCCESS - database query were successfully
#          FAILURE - error occurred
# Parameters: SQL query string
##############################################################################
sub executeQuery($)
{
    my $sql = shift(@_);

    my $dbError = "";

    my $selectSth = $woDbh->prepare($sql);

    if (not defined $selectSth)
    {
        print "ERROR: SQL PREPARE ERROR : $DBI::errstr\n";
        closeDb();
        exit FAILURE;
    }
    elsif (!$selectSth->execute())
    {
        print "ERROR: SQL EXECUTE ERROR : $DBI::errstr\n";
        $selectSth->finish();
        closeDb();
        exit FAILURE;
    }
   
    my @row = ();
    my $r;
    while(@row = $selectSth->fetchrow_array)
    {
        foreach $r (@row)
        {
            if (not defined $r)
            {
                $r = "NULL";
            }
        }
        print "@row";
        print "\n";
    }
    $selectSth->finish();

    return SUCCESS;
}

##############################################################################
# Name: initDb
# Purpose: Initiate database connections to TRAM and WO_COMMON
# Returns: SUCCESS - database connections were successfully opended
#          ERROR - error occurred
# Parameters: None
##############################################################################
sub initDb()
{
    my $woEnv = $ENV{"IAS_DB_COM"};
    my $sid = $ENV{"ORACLE_SID"};
    my $username;
    my $password;

    # verfiy environment variables were set
    if (not defined $woEnv)
    {
        print "ERROR: IAS_DB_COM not defined\n";
        return ERROR;
    }

    if (not defined $sid)
    {
        print "ERROR: ORACLE_SID not defined\n";
        return ERROR;
    }

    ## Open work order database connection
    ($username, $password) = split(/\//,$woEnv);

    $woDbh = DBI->connect("DBI:Oracle:$sid", $username, $password,
                           {AutoCommit => 0, PrintError =>0});

    if (!$woDbh)
    {
        print "ERROR: could not connect to WO_COMMON: $DBI::errstr\n";
        return ERROR;
    }
    
    return SUCCESS;
}

##############################################################################
# Name: closeDb
# Purpose: Close database connections to TRAM and WO_COMMON
# Returns: None
# Parameters: None
##############################################################################
sub closeDb()
{
    $woDbh->disconnect();
}

