#!/bin/csh -f

#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for test_case_068 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************

set mode = "IT"
if ($1 == "ST") then
    set mode = "ST"
endif

set tc = 068
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tc} 01 - Scene 1, Mode 0" \
    "TC${tc} 02 - Scene 2, Mode 0" \
    "TC${tc} 03 - Scene 3, Mode 0" \
    "TC${tc} 04 - Scene 4, Mode 4" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    three_tirs_scenes/LC80400352014353LGN00/LC80400352014353LGN00 \
    three_tirs_scenes/LC80400362014353LGN00/LC80400362014353LGN00 \
    three_tirs_scenes/LC82320572015005LGN00/LC82320572015005LGN00 \
    three_tirs_scenes/LC81400442016084LGN00/LC81400442016084LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LC80400352014353LGN00 \
    LC80400362014353LGN00 \
    LC82320572015005LGN00 \
    LC81400442016084LGN00 \
    )

# Procedures in proper order
set procedures = ( \
    "TIRS SSM Calibration" \
    "TIRS SSM Calibration" \
    "TIRS SSM Calibration" \
    "TIRS SSM Calibration" \
    )

set i = 0
set pwg_status = 0
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    set additional_parms = ""
 
    if ( $mode == "IT" ) then
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] \
            -i -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedures[$i]" \
            -scene_id $scene_ids[$i] \
            -i -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""


if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
