#!/usr/local/bin/python3
""" Script that cleans up switch event (and children) added in 
    test case 69
"""

from ias.db import database as db
from ias.misc.const import EXIT_SUCCESS, EXIT_FAILURE
from ias.misc import satellite_attributes as sat_attr
from ssm_utilities import connect_to_database
import argparse

def parse_args():
    argparser = argparse.ArgumentParser(
        description='Switch Event Cleanup')

    argparser.add_argument(
        '--event_id', type=int, required=True,
        help='Delete for this switch event id.')

    return argparser.parse_args()

def main():
    status = EXIT_SUCCESS
    conn = None
    args = parse_args()
    try:
        sat_attr.set_default(sat_attr.get_satellite_id_from_number(8))
        conn = connect_to_database()
        sql = ("select model_id from tirs_ssm_pos_model_params where "
               "switch_event_id = {0}".format(args.event_id))
        cur = conn.execute(sql)
        results = cur.fetchall()
        if (len(results) == 0):
            raise Exception("No models found for switch event {0}".
                            format(args.event_id))
        model_ids = [r[0] for r in results]

        for model_id in model_ids:
            sql = ("delete from tirs_ssm_pos_estimates where model_id = {0}".
                  format(model_id))
            conn.execute(sql)

            sql = ("delete from tirs_ssm_pos_model_params where model_id "
                   "= {0}".format(model_id))
            conn.execute(sql)

        sql = ("delete from tirs_ssm_mode_switch_events where switch_event_id "
               " = {0}".format(args.event_id))
        conn.execute(sql)

        conn.commit()
        print("Cleanup successful")
    finally:
        if conn is not None:
            conn.close(db.DISCONNECT_ROLLBACK)

# Run the main routine if called from command line
if __name__ == "__main__":
    main()
