#!/bin/csh -f

#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for Albers test_case_071 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************

set mode = "IT"
if ( $1 == "ST" ) then
    set mode = "ST"
endif

set tc = 071
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = (\
        "TC${tc} 01 Albers Alaska - OLI Only"  \
        "TC${tc} 02 Albers US - Combined" \
        "TC${tc} 03 Albers US - OLI Only" \
        "TC${tc} 04 Albers US - TIRS Only" \
        "TC${tc} 05 Albers Hawaii - Combined" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = (\
        single_scene/LO80670172013203LGN01/LO80670172013203LGN01 \
        three_tirs_scenes/LC80310302013092LGN01/LC80310302013092LGN01 \
        single_scene/LO80340342015042LGN00/LO80340342015042LGN00 \
        three_tirs_scenes/LT80150432013127LGN01/LT80150432013127LGN01 \
        three_tirs_scenes/LC80630462013143LGN01/LC80630462013143LGN01 \
    )

# Scenes in proper order
set scene_ids = (\
        LO80670172013203LGN01 \
        LC80310302013092LGN01 \
        LO80340342015042LGN00 \
        LT80150432013127LGN01 \
        LC80630462013143LGN01 \
    )

set i = 0
set pwg_status = 0

# Insert work orders
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    set additional_parms = ""
    set procedure_id = "L1T Albers Product"
    set l0r = ""

    if ( $i == 4 ) then
        # The correct BPFs to use from production are the following:  	
        #  	LT8BPF20130507153530_20130507155825.01 
        # FIXME after the 3.7.0 release 
      	set parm_files = ( LT8BPF20130507053836_20130507060107.01 )

        set additional_parms = ( \
            "-parm DSW:BIAS_PARM_FILENAME_TIRS=$parm_files[1]" \
        )

    else if ( $i == 5 ) then
        # The correct BPFs to use from production are the following:  	
        #  	LO8BPF20130523203017_20130523210047.01
        #       LT8BPF20130523202623_20130523210139.01
        # FIXME after the 3.7.0 release 
      	set parm_files = ( LO8BPF20130523171230_20130523173327.01 \
                           LT8BPF20130523170837_20130523173419.01 )

        set additional_parms = ( \
            "-parm DSW:BIAS_PARM_FILENAME_OLI=$parm_files[1]" \
            "-parm DSW:BIAS_PARM_FILENAME_TIRS=$parm_files[2]" \
        )
    endif

    if ( $mode == "IT" ) then
        set l0r = "-l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] "
    endif

    # Check for the mode or the environment
    set output = `PWG -procedure_id "$procedure_id" \
        -scene_id $scene_ids[$i] -i $l0r -comment "$comments[$i]" \
	$additional_parms`
    if ( $status ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

# Check the pwg status for ERROR or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
endif

echo "SUCCESS: created $i work orders" |& tee -a $log
exit 0
