#!/usr/bin/perl -w
#
use SOAP::Lite;

if (!defined $ENV{IAS_SERVICES}
                       )
{
    print "Please set IAS_SERVICES ENV var - hostname:port\n";
    exit 1;
}

my $parms = SOAP::Data->name(
        "getAllCpfByDateRequest" => \SOAP::Data->value(
        SOAP::Data->name("acquisitionDate" => '2007-01-25T14:54:47')->type(""),
        SOAP::Data->name("sensor" => 'OLI_TIRS')->type(""),
        SOAP::Data->name("satellite" => 'LANDSAT_8')->type(""),
        SOAP::Data->name("status" => 'ACTIVE')->type(""),
        SOAP::Data->name("nearMatch" => 'true')->type("")));
# Print input parms as XML
my $ser = SOAP::Serializer->new();
print $ser->envelope(freeform => $parms) . "\n\n";
my $soap_response;
eval
{
    $soap_response = SOAP::Lite          
                -> uri("uri:CpfQueryService")                        
                ->ns("uri:CpfQueryService","cpf")
                -> proxy($ENV{IAS_SERVICES}
                        . "/dataservices/CpfService", 
                    timeout => 99)
                ->getAllCpfNamesByDate($parms);
};
if ($@)
{
    print "Error encountered when accessing the CPF ".
        "service: ". $@;
    exit 1;
}
if ($soap_response->fault())
{
    print "SOAP Error: " . $soap_response->fault()->{faultstring};
    exit 1;
}
my @found_cpfs;
foreach my $record (@{$soap_response->body()->{getAllCpfNamesByDateResponse}->
                    {cpf}})
{
    push(@found_cpfs, $record->{filename});
}
my @expected_cpfs = ("LC08CPF_20070101_20070331_01.04",
                     "LC08CPF_20070101_20070129_01.03",
                     "LC08CPF_20070101_20070331_01.02",
                     "LC08CPF_20070101_20070331_01.01");
if (@found_cpfs ~~ @expected_cpfs)
{
    print "Correct CPFs returned: " . join(" ", @found_cpfs) . "\n";
}
else
{
    print "Expected: " . join(" ", @expected_cpfs) . " Got: " .
            join(" ", @found_cpfs) . "\n";
    exit 1;
}
print "--------------------------\n";

$parms = SOAP::Data->name(
        "getAllCpfRequest" => \SOAP::Data->value(
        SOAP::Data->name("source" => 'EVAL')->type(""),
        SOAP::Data->name("sensor" => 'OLI_TIRS')->type(""),
        SOAP::Data->name("satellite" => 'LANDSAT_8')->type("")));
# Print input parms as XML
$ser = SOAP::Serializer->new();
print $ser->envelope(freeform => $parms) . "\n\n";
eval
{
    $soap_response = SOAP::Lite          
                -> uri("uri:CpfQueryService")                        
                ->ns("uri:CpfQueryService","cpf")
                -> proxy($ENV{IAS_SERVICES}
                        . "/dataservices/CpfService", 
                    timeout => 99)
                ->getAllCpfNames($parms);
};
if ($@)
{
    print "Error encountered when accessing the CPF ".
        "service: ". $@;
    exit 1;
}
if ($soap_response->fault())
{
    print "SOAP Error: " . $soap_response->fault()->{faultstring};
    exit 1;
}
@found_cpfs = ();
foreach my $record (@{$soap_response->body()->{getAllCpfNamesResponse}->
                    {return}})
{
    my $filename = $record->{filename};

    # Filter out EVAL Jan 2007 CPFs (only avaiable from the getAll method)
    if ($filename =~ m/eval_LC08CPF_200701/)
    {
        push(@found_cpfs, $filename);
    }
}
@expected_cpfs = ("eval_LC08CPF_20070101_20070129_01.03",
                  "eval_LC08CPF_20070101_20070331_01.01",
                  "eval_LC08CPF_20070101_20070331_01.04",
                  "eval_LC08CPF_20070130_20070331_01.03");
if (@found_cpfs ~~ @expected_cpfs)
{
    print "Correct CPFs returned: " . join(" ", @found_cpfs) . "\n";
}
else
{
    print "Expected: " . join(" ", @expected_cpfs) . " Got: " .
          join(" ", @found_cpfs) . "\n";
    exit 1;
}

#Call the service via REST with for a date just past the Jan 30 split
# (see the Verify merging of split CPFs section in the test case)
my $rest_cmd = "wget -q -O - " . $ENV{IAS_SERVICES} . "/dataservices/rest/"
  . "cpf?operation=getCalParmFile\\&date=2007-02-01T00:01:00\\&satellite="
  . "LANDSAT_8\\&sensor=OLI_TIRS";
my $rest_output = `$rest_cmd`;
if ($? >> 8 != 0)
{
    print "REST command failed\n";
    exit 1;
}
my @lines = split('\n', $rest_output);

foreach my $line (@lines)
{
    if($line =~ m/File_Name/)
    {
        if ($line =~ m/LC08CPF_20070101_20070331_01.04/)
        {
            print "Correct CPF return from REST reqest\n";
            exit 0;
        }
        else
        {
            print "Incorrect CPF returned: $line\n";
            exit 1;
        }
    }
}

# If we get here we ran out of lines to check
print "Failed to find File_Name in response returned from service\n";
exit 1;

