#!/usr/bin/perl -w
#
##############################################################################
#        NAME: test_rlut_date_query.pl
#
# DESCRIPTION: Queries for an RLUT by date and verifies the file returned is
#              the correct RLUT.
#
# ARGUMENTS:   None
#
##############################################################################

use strict;
use SOAP::Lite;
use ias_const;
use Data::Dumper;

sub _main();

my $status = &_main();
if ($status != SUCCESS)
{
    exit FAILURE;
}

exit SUCCESS;

sub _main()
{
    my $baseline_rlut;
    my $rlut_basename;

    if (! defined $ENV{IAS_SERVICES})
    {
        print "IAS_SERVICES Env Var is not set\n";
        return ERROR;
    }

    if (! defined $ENV{IAS_IT_TEST_DATA_DIR})
    {
        print "IAS_IT_TEST_DATA_DIR Env Var is not set\n";
        return ERROR;
    }

    $rlut_basename = "LC08RLUT_20150303_20431231_01_12.h5";
    $baseline_rlut = $ENV{IAS_IT_TEST_DATA_DIR} .
                     "/rlut/collection1/$rlut_basename";
    if (! -f $baseline_rlut)
    {
        print "Unable to locate $rlut_basename in the "
            . "IAS_IT_TEST_DATA_DIR\n";
        return ERROR;
    }

    # Call the service and store the contents returned into a temp file
    my $cmd = "wget -q -O - '" . $ENV{IAS_SERVICES}
         . "/dataservices/rest/rlut?operation="
         . "getRlutParmFile&date=2015-08-01T00:00:00' | diff -q - "
         . $baseline_rlut;
    print "Running: $cmd\n";
    system($cmd);
    if ($? == -1)
    {
        print "Unable to run command: $cmd\n";
        return ERROR;
    }
    elsif ($? >> 8 != 0)
    {
        printf ("Command:\n$cmd\n returned %d\n", $? >> 8);
        return ERROR;
    }

    print "Correct RLUT returned via REST\n--------\n";

    print "Querying via SOAP\n";
    my $parms = SOAP::Data->name(
            "getAllRlutByDateRequest" => \SOAP::Data->value(
            SOAP::Data->name("acquisitionDate" =>
                             '2015-08-01T00:00:00')->type("")));
    my $soap_response;
    eval
    {
        $soap_response = SOAP::Lite          
                    -> uri("uri:RlutQueryService")                        
                    ->ns("uri:RlutQueryService","cpf")
                    -> proxy($ENV{IAS_SERVICES}
                            . "/dataservices/RlutService", 
                        timeout => 99)
                    ->getAllRlutNamesByDate($parms);
    };
    if ($@)
    {
        print "Error encountered when accessing the CPF ".
            "service: ". $@;
        exit 1;
    }
    if ($soap_response->fault())
    {
        print "SOAP Error: " . $soap_response->fault()->{faultstring};
        return ERROR;;
    }
    my $rlut_returned = $soap_response->body()->{getAllRlutNamesByDateResponse}
                                              ->{rlut}->{filename};
    if (!defined $rlut_returned)
    {
        print "No RLUT returned from service\n";
        return ERROR;
    }
    elsif ($rlut_returned ne $rlut_basename)
    {
        print "Expected $rlut_basename to returned via SOAP. Got "
            . "$rlut_returned\n";
        return ERROR;
    }
    print "Correct RLUT returned via SOAP\n";

    return SUCCESS;
}
