#!/bin/csh -f

#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for test_case_073 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************

set mode = "IT"
if ( $1 == "ST" ) then
    set mode = "ST"
endif

set tc = 073
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt
set tts = "three_tirs_scenes"
set ss = "single_scene"
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tc} 01 Descending day -- equatorial crossing" \
    "TC${tc} 02 Geometric supersite -- mountainous" \
    "TC${tc} 03 Off-nadir to the east (10.082) target path 131 row 034" \
    "TC${tc} 04 Off-nadir to the west (-11.316) target path 018 row 039" \
    "TC${tc} 05 Central (zero) meridian crossing" \
    "TC${tc} 06 180 degree crossing" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    $tts/LC82280832016012LGN00/LC82280832016012LGN00 \
    $ss/LC82280832016012LGN00/LC82280832016012LGN00 \
    $tts/LC81320342013131LGN01/LC81320342013131LGN01 \
    $tts/LC80170392013141LGN01/LC80170392013141LGN01 \
    $ss/LC81940522015091LGN00/LC81940522015091LGN00 \
    $tts/LC80900152013204LGN00/LC80900152013204LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LC82280832016012LGN00 \
    LC82280832016012LGN00 \
    LC81320342013131LGN01 \
    LC80170392013141LGN01 \
    LC81940522015091LGN00 \
    LC80900152013204LGN00 \
    )

# Collection
set collections = (\
    Collection1 \
    "Pre-Collection" \
    Collection1 \
    Collection1 \
    "Pre-Collection" \
    Collection1 \
    )

# Make sure the radiometric_work_order_common entry for any existing records
# are set to 'N' for consistency in the results.  For IAS, the
# geometric_work_order_common valid flag is always set to "Y", so nothing to
# do to get consistent results for that. Setting the evaluation flag to N so
# it doesn't update EVAL
set output = `../tools/set_wo_common_state.csh RPS N N $scene_ids`
if ($status != 0) then
    echo "Error setting the RADIOMETRIC_WORK_ORDER_COMMON VALID flags" \
        |& tee -a $log
    exit 1;
endif

# Use the run_in_instance script to update the Pre-Collection
# radiometric_work_order_common records
set output = `run_in_instance.csh -a Pre-Collection \
    ../tools/set_wo_common_state.csh RPS N N $scene_ids`
if ($status != 0) then
    echo "Error setting the RADIOMETRIC_WORK_ORDER_COMMON VALID flags" \
        |& tee -a $log
    exit 1;
endif


set i = 0
set pwg_status = 0

# Insert work orders
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    set additional_parms = ""
    set procedure_id = "L1T with Quality Band"
    set collection = $collections[$i]

    # Check for the mode or the environment
    if ( $mode == "IT" ) then
        set output = `PWG -procedure_id "$procedure_id" \
            -scene_id $scene_ids[$i] \
            -i -l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i] \
            -processing_instance $collection \
            -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    else
        set output = `PWG -procedure_id "$procedure_id" \
            -scene_id $scene_ids[$i] \
            -processing_instance $collection \
            -i -comment "$comments[$i]" $additional_parms`
        set saveStatus = $status
    endif

    if ( $saveStatus ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

# Check the pwg status for ERROR or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
