#!/bin/csh -f

#***************************************************************************
# NAME:     create_wos.csh
#
#  PURPOSE:  Creates the work orders for test_case_076 using PWG
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./create_wos.csh
#****************************************************************************

set mode = "IT"
if ( $1 == "ST" ) then
    set mode = "ST"
endif

set tc = 076
set log = tc${tc}.log
set woid_file = tc${tc}_woids.txt
set ss = "single_scene"
rm -f $log $woid_file

# Comment fields -- this is the order in which the following lists are
# dependent on
set comments = ( \
    "TC${tc} 01 L1T Product #1" \
    "TC${tc} 02 L1T with Quality Band #1" \
    "TC${tc} 03 L1T with Sun Correction #1" \
    "TC${tc} 04 L1T with Sun Correction #2" \
    "TC${tc} 05 L1T with Quality Band #2" \
    "TC${tc} 06 L1T Product #2" \
    "TC${tc} 07 L1GT Product #1" \
    "TC${tc} 08 L1GT Product #2" \
    "TC${tc} 09 L1GT Product #3" \
    "TC${tc} 10 L1GT Product #4" \
    "TC${tc} 11 L1GT Product, with L1T already created" \
    )

# L0R data paths in proper order
# $IAS_IT_TEST_DATA_DIR/l0r/ must be pre-pended for them to be complete
set l0r_path_dirs = ( \
    $ss/LC81210602013182LGN00/LC81210602013182LGN00 \
    $ss/LT80400312013126LGN01/LT80400312013126LGN01 \
    $ss/LC81320342013131LGN01/LC81320342013131LGN01 \
    $ss/LC81320342013131LGN01/LC81320342013131LGN01 \
    $ss/LT80400312013126LGN01/LT80400312013126LGN01 \
    $ss/LC81210602013182LGN00/LC81210602013182LGN00 \
    $ss/LC80282462013234LGN00/LC80282462013234LGN00 \
    $ss/LC80282462013234LGN00/LC80282462013234LGN00 \
    $ss/LC80282462013234LGN00/LC80282462013234LGN00 \
    $ss/LC80282462013234LGN00/LC80282462013234LGN00 \
    $ss/LC81210602013182LGN00/LC81210602013182LGN00 \
    )

# Scenes in proper order
set scene_ids = ( \
    LC81210602013182LGN00 \
    LT80400312013126LGN01 \
    LC81320342013131LGN01 \
    LC81320342013131LGN01 \
    LT80400312013126LGN01 \
    LC81210602013182LGN00 \
    LC80282462013234LGN00 \
    LC80282462013234LGN00 \
    LC80282462013234LGN00 \
    LC80282462013234LGN00 \
    LC81210602013182LGN00 \
    )

# Update any existing scenes to "N". Setting the evaluation flag to N so
# it doesn't update EVAL
set output = `../tools/set_wo_common_state.csh GPS N N $scene_ids`
if ($status != 0) then
    echo "Error setting the RADIOMETRIC_WORK_ORDER_COMMON VALID flags" \
        |& tee -a $log
    exit 1;
endif

set i = 0
set pwg_status = 0

# Insert work orders
echo "Inserting work orders" |& tee -a $log
while ( $i < ${#comments} )
    @ i++

    # Set the l0r path for IT
    set l0r = ""
    if ( $mode == "IT" ) then
        set l0r = "-l0r_data_path $IAS_IT_TEST_DATA_DIR/l0r/$l0r_path_dirs[$i]"
    endif

    set additional_parms = (\
        "-script DFP:PAUSE " \
        )
    set procedure_id = "L1GT Product"

    # Set addtional parms and procedure by work order number
    if ( $i == 1) then
        set procedure_id = "L1T Product"
    else if ( $i == 2 ) then
        set procedure_id = "L1T with Quality Band"
    else if ( $i == 3 || $i == 4 ) then
        set procedure_id = "L1T with Sun Correction"
    else if ( $i == 5 ) then
        set procedure_id = "L1T with Quality Band"
    else if ( $i == 6 ) then
        set procedure_id = "L1T Product"
    else if ( $i > 6 || $i <= 11 ) then
        set procedure_id = "L1GT Product"
    endif

    set output = `PWG -procedure_id "$procedure_id" \
        -scene_id $scene_ids[$i] \
        -i  $l0r \
        -comment "$comments[$i]" $additional_parms`
    if ( $status ) then
        echo $output >> $log
        echo "Error loading dataset $i" |& tee -a $log
        @ pwg_status++
    else
        echo $output >> $log
        while ( $output[1] != "Work" )
            shift output
        end
        shift output
        if ( $output[1] != "Order" ) then
            echo "Error parsing work order ID from PWG command for dataset $i"\
                |& tee -a $log
        else
            shift output
            set woid = `echo $output[1] | sed 's/,//'`
            /bin/echo -n "$woid "
            echo $woid >> $woid_file
        endif
    endif
end
echo ""

# Check the pwg status for ERROR or SUCCESS
if ( $pwg_status ) then
    echo "ERROR: $pwg_status errors creating work orders with PWG" \
        |& tee -a $log
    exit 1
else
    echo "SUCCESS: created $i work orders" |& tee -a $log
endif
exit 0
