#!/bin/csh -f
#***************************************************************************
# NAME:     verify_tc076_valid_flags
#
#  PURPOSE:  Verifies that the geometric work order common ''Valid'' flags
#            are set correctly
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./verify_tc003_valid_flag.csh product_request_WOs.txt
#                  optional {product_request_secondary_WOs.txt}
#****************************************************************************
set SUCCESS = 0
set ERROR = 1

if ( -e test_case_id ) then
    set tcnum = `cat test_case_id`
    set log = tc${tcnum}.log
    set woid_file = tc${tcnum}_woids.txt
else
    echo "Error: The test_case_id file is missing"
    exit $SUCCESS
endif

# Must have one argument
if ( ${#argv} < 1 ) then
    echo "" |& tee -a $log
    echo "    Usage: $0 STEP_{1-12}" |& tee -a $log
    echo "" |& tee -a $log
    exit $ERROR
else
    set STEP = $1
endif

# Retrieve the work order ids
set woids = `cat $woid_file`

# A variable to store the message to output, if the test passes
set success_msg = ""

# Set up the valid flag verification by step
if ( $STEP == "STEP_1" ) then
    set valid_flags = (N N N N N N N N N N N)
    set success_msg  = "Verified all orders are initially marked invalid"
else if ( $STEP == "STEP_2" ) then
    set valid_flags = (Y N N N N N N N N N N)
    set success_msg =  "Verified only first order is marked valid"
else if ( $STEP == "STEP_3" ) then
    set valid_flags = (Y Y N N N N N N N N N)
    set success_msg =  "Verified orders 1 and 2 are marked valid"
else if ( $STEP == "STEP_4" ) then
    set valid_flags = (Y Y Y N N N N N N N N)
    set success_msg =  "Verified orders 1, 2, and 3 are marked valid"
else if ( $STEP == "STEP_5" ) then
    set valid_flags = (Y Y N Y N N N N N N N)
    set success_msg =  "Verified running order 4 makes order 3 invalid"
else if ( $STEP == "STEP_6" ) then
    set valid_flags = (Y N N Y Y N N N N N N)
    set success_msg =  "Verified running order 5 makes order 2 invalid"
else if ( $STEP == "STEP_7" ) then
    set valid_flags = (N N N Y Y Y N N N N N)
    set success_msg =  "Verified running order 6 makes order 1 invalid"
else if ( $STEP == "STEP_8" ) then
    set valid_flags = (N N N Y Y Y Y N N N N)
    set success_msg =  "Verified running order 7 marks no others invalid"
else if ( $STEP == "STEP_9" ) then
    set valid_flags = (N N N Y Y Y N Y N N N)
    set success_msg =  "Verified running order 8 makes order 7 invalid"
else if ( $STEP == "STEP_10" ) then
    set valid_flags = (N N N Y Y Y N N Y N N)
    set success_msg =  "Verified running order 9 makes order 8 invalid"
else if ( $STEP == "STEP_11" ) then
    set update_woids = "'$woids[7]', '$woids[8]'"
    set output = `sqlplus -s ${IAS_DB_L8_OLITIRS}` << END
        set head off; 
        UPDATE GEOMETRIC_WORK_ORDER_COMMON SET VALID = 'Y'
            WHERE work_order_id in ($update_woids);
        exit;
END

    set valid_flags = (N N N Y Y Y Y Y Y N N)
    set success_msg =  ("Verified orders 8 and 9 are valid after a manual "\
                        "update")
else if ( $STEP == "STEP_12" ) then
    set valid_flags = (N N N Y Y Y N N N Y N)
    set success_msg =  ("Verified orders 8 and 9 are invalid whereas 10 is "\
                       "valid after rerunning the scene")
else if ( $STEP == "STEP_13" ) then
    set valid_flags = (N N N Y Y Y N N N Y Y)
    set success_msg =  ("Verified orders 1 and 6 are not affected by running"\
                       " a new procedure on the same scene")
else
    echo "ERROR: Unknown step $STEP valid steps are STEP_{1-12}"
    exit $ERROR
endif

set i = 0
set error = 0
foreach work_order_id ($woids)
    @ i++
    set valid_flag = `sqlplus -s ${IAS_DB_L8_OLITIRS}` << END
        set head off; 
        SELECT VALID FROM GEOMETRIC_WORK_ORDER_COMMON
            WHERE work_order_id='$work_order_id';
        exit;
END

    # Ensure only 1 record is found (or "no rows selected")
    if ( $#valid_flag > 1 ) then
        echo "$work_order_id is not valid in the GEOMETRIC_WORK_ORDER_COMMON"\
              "table"
        set error = 1
    endif

    # Compare the valid flags
    echo "$work_order_id was Expected = $valid_flags[$i], Actual = $valid_flag"
    if ( $valid_flags[$i] != "$valid_flag" ) then
        echo "$work_order_id valid flag should be set to $valid_flags[$i] "
        set error = 1
    endif
end
echo ""
echo ""

if ( $error != 0 ) then
    echo "There were errors during validation"
    exit $ERROR
endif

echo $success_msg
exit $SUCCESS
