#!/bin/csh -f
#
# The purpose of this script is to easily complete or abort workorders in an
# automated fashion.  There are no protections for sending a Pending or
# Halted work order to the complete state.  It wasn't deemed important
# enough at this time.
#
# Usage: change_wo_state.csh AW|CW WOID ...
#---------------------------------------------------------------------------
# Create a log file
if ( -e test_case_id ) then
    set id = `cat test_case_id`
    set log = tc${id}.log
else
    set script = $0:t
    set log = ${script:r}.out
endif

# Must have at least two arguments
if ( ${#argv} < 2 ) then
    echo "" |& tee -a $log
    echo "    Usage: $0 AW|CW WOID ... " |& tee -a $log
    echo "" |& tee -a $log
    exit 1
endif

set wo_state = $argv[1]
shift

# Ensure the state is correct
if ( $wo_state == "AW" ) then
    set state_text = "Abort WO"
else if ( $wo_state == "CW" ) then
    set state_text = "Complete WO"
else
    echo "" |& tee -a $log
    echo "Error: $wo_state is not valid for this script" |& tee -a $log
    echo "Usage: $0 AW|CW WOID ... " |& tee -a $log
    echo "" |& tee -a $log
    exit 1
endif

# Issue a message
echo "" |& tee -a $log
echo "Setting wo: $argv" |& tee -a $log
echo "to $state_text" |& tee -a $log
echo "" |& tee -a $log

while (${#argv})
    /bin/echo -n $argv[1] |& tee -a $log
    (sqlplus -s $IAS_DB_COM | tee -a $log) <<END
        update work_orders set state='$wo_state'
        where work_order_id='$argv[1]';
        exit;
END

    shift
end

exit 0
