#!/usr/bin/perl
##############################################################################
#        NAME: clean_cpf.pl
#
# DESCRIPTION: Removes the specified CPF Name from the database table.
#              If the name of the CPF begins with eval_, the EVAL DB
#              is used. 
#
#       USAGE: clean_cpf.pl CPF_NAME 
#
##############################################################################
use strict;
use warnings; 

use ias_const;
use ias_db;

my $cpf;
my ($username, $password);

if ($#ARGV != 0)
{
    print_usage();
    exit FAILURE;
}

if ($ARGV[0] =~ m/^LC08CPF_\d{8}_\d{8}_\d\d\.\d\d/)
{
    if (!defined $ENV{IAS_DB_L8_OLITIRS})
    {
        print "Error: IAS_DB_L8_OLITIRS is not set\n";
        exit FAILURE;
    }
    ($username, $password) = split '/', $ENV{IAS_DB_L8_OLITIRS};
}
elsif ($ARGV[0] =~ m/^eval_LC08CPF_\d{8}_\d{8}_\d\d\.\d\d/)
{
    if (!defined $ENV{IAS_DB_L8_OLITIRS_EVAL})
    {
        print "Error: IAS_DB_L8_OLITIRS_EVAL is not set\n";
        exit FAILURE;
    }
    ($username, $password) = split '/', $ENV{IAS_DB_L8_OLITIRS_EVAL};
}
else
{
    print_usage();
    exit FAILURE;
}
$cpf = $ARGV[0];

my $dbh = ias_db_ConnectToDB($username, $password);
if (not defined $dbh)
{
    print "Error: unable to connect to database: $DBI::errstr\n";
    exit 1;
}

my $sql = "DELETE FROM cpf_main_group WHERE cpf_main_id IN ("
        . " SELECT cpf_main_id FROM cpf_main WHERE file_name = '$cpf' "
        . ")";

my $rows = $dbh->do($sql);
if (not defined $rows)
{
    print "Error: error remove from cpf_main_group: $DBI::errstr\n";
    $dbh->rollback();
    $dbh->disconnect();
    exit 1;
}

$sql = "DELETE FROM cpf_main WHERE file_name = '$cpf'";

$rows = $dbh->do($sql);
if (not defined $rows)
{
    print "Error: error remove from cpf_main: $DBI::errstr\n";
    $dbh->rollback();
    $dbh->disconnect();
    exit 1;
}

$dbh->commit();
$dbh->disconnect();

exit SUCCESS;

sub print_usage
{
    print STDERR "usage: clean_cpf.pl CPF_NAME\n"
}
