#!/usr/bin/perl -w
#
# Purpose: Delete specified WOs from the database.  This is only ment to be
#          used by developers or I&T scripts/procedures.
#
#
# Process:  1. Open input file containing Work Order IDs
#           2. For each WO:
#              a. Generate and call SQL to delete it 
#
#  Inputs:  1. The name of the input file
#
# Outputs:  1. None
#
# System Requirements:
#           1. IAS system installed.
#
# Input File Format:
#           1. Text file with a Work Order IDst on each line.
#           2. Example: (lines should NOT start with spaces)
#
#           I1
#           I2
#           I3
#           I4
#           I5
#           I6
#
# Documentation: No other documentation exists for this script
#

use strict;
use warnings;

use DBI;

use Logger;
use ias_const;
use ias_processing_system;
use ias_db;

use constant PROG     => "delete_wos.pl";

my $g_Logger;         # The logger object to use for log messages
my $wo_id;            # work order id returned by ias_create_work_order

# initialize logger
$g_Logger = Logger->new("STDOUT", PROG);
if(!$g_Logger)
{
    print STDERR PROG . ": ERROR: Failed to establish logger object.\n";

    exit FAILURE;
}
set_default_log($g_Logger);

# Get input file name from command line argument(s)

my $numArgs = $#ARGV + 1;
if ( $numArgs < 1 )
{
   print "\nPlease provide an input file name.\n\n";
   die;
}

my $inputFileName = $ARGV[0];

# Initialize variables

my $msg = "";

# Open input file and populate an array with Work Order IDs

print "\nOpening input file:  $inputFileName\n";
open FILE, "<", $inputFileName or die;
my @sceneNames = <FILE>;
close FILE;

# get the username and password for the database
my ($user_id, $password) = ias_db_GetDBConnectionInfo();

# connect to the database
my $dbh = ias_db_ConnectToDB($user_id, $password);
if(!$dbh)
{
    $g_Logger->fatal_msg(__FILE__, __LINE__, $ias_db_error);
    $g_Logger->close_log();

    exit FAILURE;
}


# Call SQL for each Work Order ID

foreach (@sceneNames)
{
    # remove trailing newline character from file line
    chomp($_);

    $g_Logger->info_msg(__FILE__, __LINE__, "Deleting $_");

    my $sql = "delete from events where work_order_id = '$_'";

    my $sth = $dbh->prepare($sql);
    if(!$sth)
    {
        $msg = "LINE:" . __LINE__ . " SQL PREPARE ERROR: " . $DBI::errstr;
        $g_Logger->warn_msg(__FILE__, __LINE__, $msg);
        exit FAILURE;
    }

    if(!$sth->execute())
    {
        $msg = "LINE:".__LINE__." SQL EXECUTE ERROR: ".$DBI::errstr;
        $g_Logger->warn_msg(__FILE__, __LINE__, $msg);
        exit FAILURE;
    }

    $sql = "delete from work_orders where work_order_id = '$_'";

    $sth = $dbh->prepare($sql);
    if(!$sth)
    {
        $msg = "LINE:" . __LINE__ . " SQL PREPARE ERROR: " . $DBI::errstr;
        $g_Logger->warn_msg(__FILE__, __LINE__, $msg);
        exit FAILURE;
    }

    if(!$sth->execute())
    {
        $msg = "LINE:".__LINE__." SQL EXECUTE ERROR: ".$DBI::errstr;
        $g_Logger->warn_msg(__FILE__, __LINE__, $msg);
        exit FAILURE;
    }

    $sth->finish();
}

# Disconnect from the database.
if(!ias_db_DisconnectFromDB($dbh, IAS_DB_DISCONNECT_COMMIT))
{
    $msg = "WARNING: Unable to disconnect from DBase: ". $ias_db_error;
    $g_Logger->warn_msg(__FILE__, __LINE__, $msg);
}

print "\nScript complete.\n\n";

