#!/usr/bin/perl

##########################################################################
#
#      UNIT NAME:  make_data_invalid.pl
#
#      PURPOSE:    Checks the RADIOMETRIC_WORK_ORDER_COMMON database
#                  table for duplicate entries matching the
#                  current L0R interval ID, then sets the 'valid' flag
#                  to 'N' just for those entries where the 'valid' flag
#                  is 'Y'.  It is (at this point) intended to be used
#                  for TIRS background response characterization and/or
#                  gain determination, in order to ensure a unique set
#                  of histogram statistics for each interval that is
#                  selected.
#
#########################################################################
use warnings;
use strict;

my $num_args = @ARGV;
#print "Number of arguments:  $num_args\n";
if ( $num_args < 1 )
{
    die "Usage:  $0 <l0r_id1> [<l0r_id2> <l0r_id3> ... ]\n";
}


# Verify the environment variables for connecting to the DB
unless (defined($ENV{ORACLE_SID}) || defined($ENV{TWO_TASK}))
{
    die "ERROR:  ORACLE instance (ORACLE_SID and/or TWO_TASK) isn't set.\n";
}
unless (defined($ENV{IAS_DB_L8_OLITIRS}))
{
    die "ERROR:  IAS_DB_L8_OLITIRS isn't set.\n";
}

# Update the RADIOMETRIC_WORK_ORDER_COMMON table
my $curr_arg;
my $curr_l0r_id;
my $script_output;
for ( $curr_arg = 0; $curr_arg < $num_args; $curr_arg++ )
{
    $curr_l0r_id = $ARGV[$curr_arg];
    $script_output = `sqlplus -L -S $ENV{IAS_DB_L8_OLITIRS} 2>&1 <<END
       WHENEVER SQLERROR EXIT FAILURE;
       update radiometric_work_order_common
       set valid = 'N'
       where landsat_interval_id = '$curr_l0r_id' and valid = 'Y';
END
    `;
    if ( $? != 0 )
    {
        die "ERROR updating RADIOMETRIC_WORK_ORDER_COMMON table:\n$script_output\n";
    }
}

# Show output, which includes the number of rows successfully updated.
print "$script_output\n";

# Done
exit 0;
