#!/bin/csh -f
#  The purpose of this script is to automatically monitor the input list of
#  work order IDs until all WOs go to the Evaluate or Halted state.  It
#  exits with the number of halted work orders.  Its main intent is for
#  automated scripting of regression tests but would be just fine for any IT
#  test case instead of monitoring WO state in the OUI.
#
#  Usage: monitor_wo_state.csh WOID WOID ... 
#----------------------------------------------------------------------------
# Create a log file
if ( -e test_case_id ) then
    set id = `cat test_case_id`
    set log = tc${id}.log
else
    set script = $0:t
    set log = ${script:r}.out
endif

# Must have at least one argument
if ( ${#argv} < 1 ) then
    echo "  Usage: $0 WOID WOID ..." |& tee -a $log
    exit 1
endif

set num_wos = ${#argv}
set num_complete = 0
set num_halted = 0
set wo_eval
set wo_halt
set not_done = 1

echo "" |& tee -a $log
echo "Monitoring work orders..." |& tee -a $log
set wos = ($argv)
while ( $not_done )
    set i = 0
    set temp_wos
    foreach wo ($wos)
        @ i++
        if ( $wo == "" ) then
            continue
        endif
        set wostate = `sqlplus -s $IAS_DB_COM` << END 
            set head off;
            select state from work_orders where work_order_id='$wo';
            exit;
END

        # The states that are probably important are Pending, Running, Halted
        # and Evaluate.  We want all to go to E.
        if ( $wostate == "E" ) then
            echo "`date` $wo state=$wostate" |& tee -a $log
            set wo_eval = ($wo_eval $wo)
            set argv[$i] = ""
            @ num_complete++
        else if ( $wostate == "H" ) then
            echo "`date` $wo state=$wostate" |& tee -a $log
            set wo_halt = ($wo_halt $wo)
            set argv[$i] = ""
            @ num_complete++
            @ num_halted++
        else
            set temp_wos = ($temp_wos $wo)
        endif
    end
    set wos = ($temp_wos)

    # The stopping condition is that all work orders either halt or complete
    # We may need another stopping condition but for now just keep going
    if ( $num_complete == $num_wos ) then
        set not_done = 0
        continue
    endif
    sleep 60
end

echo "" |& tee -a $log
if ( $num_halted ) then
    echo "ERROR: $num_halted work order(s) didn't complete:" |& tee -a $log
    echo "    $wo_halt" |& tee -a $log
    echo "" |& tee -a $log
endif
echo "These work orders completed:" |& tee -a $log
echo "    $wo_eval" |& tee -a $log
echo "" |& tee -a $log

exit $num_halted
