#!/bin/csh -f
#
#  Usage: save_test_results.csh <work order ID> <work order ID> ...
#
#  Required: file: test_case_id, with 3-digit test case ID such as 001
#
#-----------------------------------------------------------------------
# Create a log file
set script_name = `basename $0`
if ( -e test_case_id ) then
    set id = `cat test_case_id`
    set log = tc${id}.log
else
    set log = ${script_name:r}.out
endif

# Check for command line argument and print usage if none supplied
if ( ${#argv} < 1 ) then
    echo
    echo "    Usage: $script_name <work order ID> ... "
    echo
    exit 1
endif

# Get the test case ID and directories
if ( ! -e test_case_id ) then
    echo "File test_case_id doesn't exist"
    exit 1
endif
set id = `cat test_case_id`

set test_case_name = test_case_$id

set now = `date +"%F %R"`
echo | tee -a $log
echo "----------------------------------------------------" | tee -a $log
echo "--- Running $script_name at $now" | tee -a $log
echo | tee -a $log

set final_outputs_dir = $IAS_IT_TEST_DATA_DIR/final_outputs/$test_case_name
if ( ! -e $final_outputs_dir ) then
    mkdir -p $final_outputs_dir | tee -a $log
    if ( $status ) then
        echo -n "--- FAIL --- $now - $woid -" | tee -a $log
        echo " Error creating save directory $final_outputs_dir" | tee -a $log
        exit 1
    endif
    chmod g+w $final_outputs_dir
endif

set exit_status = 0
while ( $#argv )

    # Get the work order comment field and verify it is a valid work order for
    # this test case
    set woid = $argv[1]
    set wo_save_dir = $final_outputs_dir/$woid
    set select = \
        "select wo_comment from work_orders where work_order_id='$woid';"
    set wo_comment = `echo $select | sqlplus $IAS_DB_COM | grep ^TC$id `
    if ( "$wo_comment" == "" ) then
        echo
        echo -n "--- FAIL --- $now - $woid -" | tee -a $log
        echo -n " Error in the Work Order $woid comment field:" | tee -a $log
        echo -n " Doesn't start with TC$id." | tee -a $log
        echo "  It's possible that the Work Order is not from this test case" \
            | tee -a $log
        echo

        # Get the next command line argument and skip saving
        shift
        continue
    endif

    # Set a path to the work order
    set work_order_path = $IAS_WO/$woid

    cp -r $work_order_path $wo_save_dir | tee -a $log
    if ( $status ) then
        echo -n "--- FAIL --- $now - $woid -" | tee -a $log
        echo " Errors saving to $wo_save_dir" | tee -a $log
        set exit_status = 1
    else
        echo -n "--- PASS --- $now - $woid -" | tee -a $log
        echo " Saved to $wo_save_dir" | tee -a $log
    endif
    echo | tee -a $log
    chmod -R g+w $final_outputs_dir/$woid

    # Get the next command line argument
    shift
end

if ( $exit_status == 1 ) then
    echo "--- FAIL --- There were failures, check $log." | tee -a $log
endif

set now = `date +"%F %R"`
echo "--- Completed the $script_name at $now" | tee -a $log
echo | tee -a $log

exit $exit_status

