#!/bin/csh -f

# Load I&T CPFs, BPFs, and RLUTs into the database.
# Files are assumed to be in $IAS_IT_TEST_DATA_DIR/<file_type>.
# Files named "eval_*" are loaded into the EVAL schema; others
# are loaded into the PROD schema.

# To delete the previously-loaded CPFs from the database:
# delete from cpf_main_group where cpf_main_id in 
#   (select cpf_main_id from cpf_main 
#    where status = 'ACTIVE' and description like 'Built%');
# delete from cpf_main where status = 'ACTIVE' and description like 'Built%';

if ($#argv != 1) then
    echo "Usage: $0 cpf|replace_cpf|bpf|rlut"
    exit 1
endif

# Ensure the test code is built
make tests

# Update the db connection in the test.properties file
set dbconn = `grep -iw -A4 ${TWO_TASK}1 $TNS_ADMIN/tnsnames.ora | grep ADDRESS | head -1 | tr -d ' '`"(CONNECT_DATA=(SID=${TWO_TASK}1))"

set file_type = $argv[1]
if ("$file_type" == "cpf") then
    set script = "insertCpfTest.sh"
    set file_pattern = "L8CPF*"
    set prod_dest = "PROD"
    set eval_dest = "EVAL"
    echo "Updating CPF db connection to $dbconn"
    sed -i.bak -e "/^test-sys-prop.CPF_TEST_DB/ s/(LOAD_BALANCE=.*/\${dbconn})/" test.properties
else if ("$file_type" == "replace_cpf") then
    set file_type = "cpf"
    set script = "replaceCpfTest.sh"
    set file_pattern = "L8CPF*"
    set prod_dest = "PROD"
    set eval_dest = "EVAL"
    echo "Updating CPF db connection to $dbconn"
    sed -i.bak -e "/^test-sys-prop.CPF_TEST_DB/ s/(LOAD_BALANCE=.*/\${dbconn})/" test.properties
else if ("$file_type" == "bpf") then
    set script = "insertBpfTest.sh"
    set file_pattern = "L?8BPF*"
    set prod_dest = "PROD"
    set eval_dest = "EVAL"
    sed -i.bak -e "/^test-sys-prop.BPF_TEST_DB/ s/(LOAD_BALANCE=.*/\${dbconn})/" test.properties
else if ("$file_type" == "rlut") then
    set script = "insertRlutTest.sh"
    set file_pattern = "L8RLUT*h5.ldr"
    set prod_dest = $IAS_DB_L8_OLITIRS
    set eval_dest = $IAS_DB_L8_OLITIRS_EVAL
else
    echo "Usage: $0 cpf|bpf|rlut"
    exit 1
endif

setenv ENABLE_DB_TESTS 1

set num_errors = 0

set nonomatch
set pattern = "$IAS_IT_TEST_DATA_DIR/$file_type/$file_pattern"
echo "Loading into PROD: $pattern"
foreach file ( $pattern )
    if ("$file" == "$pattern") continue
    echo "Loading PROD file $file"
    test/$script $file $prod_dest
    if ($status != 0) @ num_errors = $num_errors + 1
    #set x=$<
end

set pattern = "$IAS_IT_TEST_DATA_DIR/$file_type/eval_$file_pattern"
echo "Loading into EVAL: $pattern"
foreach file ( $pattern )
    if ("$file" == "$pattern") continue
    echo "Loading EVAL file $file"
    test/$script $file $eval_dest
    if ($status != 0) @ num_errors = $num_errors + 1
    #set x=$<
end

if ($num_errors != 0) then
    echo ""
    echo "$num_errors files failed to load"
endif

exit $num_errors
