/*
 * Constants
 *
 * Commonly-used constants.  A final class with only static public variables.
 */
package gov.usgs.ias.constant;
import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import org.apache.log4j.Logger;

public final class Constants {

    /** 
     * private default no-arg constructor
     */
    private Constants() {
    }

    // -------------------------------------------------------------------------
    //  MESSAGE ROUTER + HTTP + XML CONSTANTS
    //  used in soap messaging
    // -------------------------------------------------------------------------
    public static final String MIME_TYPE_XML = "text/xml";

    // -------------------------------------------------------------------------
    // Define the names of our loggers for log4j.  This covers all the loggers
    // used in the library and application (i.e., services or gui) code.
    // -------------------------------------------------------------------------
    public static final String LOGGER_CACHE = "Cache";
    public static final String LOGGER_CONFIG = "Config";
    public static final String LOGGER_ESB = "Bus";
    public static final String LOGGER_DATA = "Data";
    public static final String LOGGER_MBEAN = "MBean";
    public static final String LOGGER_UTILITY = "Utility";
    public static final String LOGGER_CPF = "CPF";
    public static final String LOGGER_BPF = "BPF";
    public static final String LOGGER_RLUT = "RLUT";

    //--------------------------------------------------------------------------
    // Names of properties for the database schema connection strings
    //--------------------------------------------------------------------------
    public static final String DAO_ESB_CONNECTION =
            "gov.usgs.ias.dao.connectionstring.esb";
    public static final String DAO_IAS_CONNECTION =
            "gov.usgs.ias.dao.connectionstring.ias";

    //--------------------------------------------------------------------------
    // Environment Variables used for database connections
    //--------------------------------------------------------------------------
    public static final String DAO_AUTH_IAS_PROD = "IAS_DB_L8_OLITIRS";
    public static final String DAO_AUTH_IAS_EVAL = "IAS_DB_L8_OLITIRS_EVAL";
    public static final String DAO_AUTH_IAS_COMMON = "IAS_DB_COM";
    
    //--------------------------------------------------------------------------
    // Misc. Property Names used by services
    // -- tolerances used by 'near match' queries and disk cache location
    // -- concurrent requests for CPFs
    //--------------------------------------------------------------------------
    public static final String NEAR_MATCH_BPF_TOLERANCE_DAYS =
            "gov.usgs.ias.nearmatch.bpf.tolerance.days";
    public static final String NEAR_MATCH_BPF_TOLERANCE_ORBIT =
            "gov.usgs.ias.nearmatch.bpf.tolerance.orbit";
    public static final String NEAR_MATCH_CPF_TOLERANCE =
            "gov.usgs.ias.nearmatch.cpf.tolerance";
    public static final String DISK_CACHE_LOCATION_RLUT =
            "gov.usgs.ias.cacheloc.rlut";
    public static final String CONCURRENT_CPF_REQUESTS =
            "gov.usgs.ias.cpf.concurrent.requests";

    //--------------------------------------------------------------------------
    // Return the IAS software version
    public static String getIasSoftwareVersion() {
        String version = "unknown";
        
        // Locate the ias_version utility program
        String versionUtility = System.getenv("IAS_BIN") 
            + File.separator + "ias_version";
        
        BufferedReader in = null;
        Process p = null;
        try {
            ProcessBuilder pb = new ProcessBuilder(versionUtility);
            p = pb.start();
            // read from the process's stdout
            in = new BufferedReader(new InputStreamReader(p.getInputStream()));
            version = in.readLine();
            p.waitFor();
        } catch (IOException ex) { // problem running the utility
            Logger.getLogger(Constants.LOGGER_DATA).error(
                "Could not determine IAS version", ex);
            // leave version with its initial unknown value
        } catch (InterruptedException ex) { // if interrupted during waitFor
            // already got the version, so just end the process
            if (p != null) {
                p.destroy();
            }
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException ex) {
                    // no recourse if the close fails
                }
            }
        }
        return version;
    }
}
