/*
 * AttributeMap
 *
 * A map to hold the names & values of parameters within a group.
 * Placed in a wrapper class that implements the Serializable
 * interface to support web service XML messages.
 */
package gov.usgs.ias.dao;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

@XmlType
@XmlRootElement
public class AttributeMap implements Serializable {

    // Universal version ID required for a Serializable class
    private static final long serialVersionUID = 7240753610205801036L;
    // Dictionary of parameter name and value pairs
    private Map<String, String> dict;

    /**
     * Default constructor.  Creates the initial, empty underlying hash map.
     */
    public AttributeMap() {
        this.dict = new HashMap<String, String>();
    }

    /**
     * Get the key names of the entries in the attribute map.
     * @return a set of key name strings
     */
    public Set<String> getNames() {
        return this.dict.keySet();
    }

    /**
     * Add an item to the attribute map.
     * @param name   the key name
     * @param value  the value to associate with the key name
     */
    public void put(final String name, final String value) {
        if (name != null) {
            this.dict.put(name, value);
        }
    }

    /**
     * Get an item contained in the attribute map.
     * @param name  the key name
     * @return      the value associated with the key name
     */
    public String get(final String name) {
        return this.dict.get(name);
    }

    /**
     * Gets the number of items contained in the attribute map.
     * @return  the number of key-value mappings in this map.
     */
    public int size() {
        return this.dict.size();
    }

    /**
     * Get all the attributes contained in the attribute map
     * @return  a map of key-value pairs
     */
    public Map<String, String> getAttributes() {
        return this.dict;
    }

    /**
     * Define all the attributes to be contained in the attribute map
     * @param map  a map of key-value pairs
     */
    public void setAttributes(Map<String, String> map) {
        this.dict = map;
    }
}
