package gov.usgs.ias.gui.common_library;

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * Panel containing a labeled JComboBox that is used for filter criteria
 * selection.
 */
public class FilterItemPanel extends JPanel implements ActionListener {
    private JComboBox<String> filterComboBox = null;
    private String filterValue;
    private final PropertyChangeSupport pcs = new PropertyChangeSupport(this);
    
    /**
     * Constructor of a combo box list Filter Item Panel.
     * @param filterLabel    string to display above the selection
     * @param list           list of strings to populate the combo box with
     */
    public FilterItemPanel(String filterLabel, String[] list) {
        super(new BorderLayout());
        
        //Create the main panel to display all of the components
        JPanel mainPanel = new JPanel();
        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        mainPanel.setLayout(gridbag);

        //Create a label for the filter being setup
        JLabel label = new JLabel(filterLabel);
        mainPanel.add(label, gbc);
        
        //Setup a combo box and setup the list of selection items from param
        filterComboBox = new JComboBox<String>(list);
        filterComboBox.setSelectedIndex(0);
        filterValue = (String)filterComboBox.getSelectedItem(); // init filter
        
        //Add the action listener after setting the value to avoid
        //triggering the listener during panel construction
        filterComboBox.addActionListener(this);
        mainPanel.add(filterComboBox, gbc);
        
        //Add the main panel to the dialog window
        add(mainPanel, BorderLayout.CENTER);
    }
    
    /**
     * Add a property change listener so parents can be notified when
     * a component has been modified.
     * @param propertyName
     * @param listener
     */
    @Override
    public void addPropertyChangeListener(String propertyName,
            PropertyChangeListener listener) {
         pcs.addPropertyChangeListener(propertyName, listener);
     }
    
    /**
     * Reset the filter selection to its default value.
     */
    public void resetValue(){
        filterComboBox.setSelectedIndex(0);
    }
    
    /**
     * Get the filter value currently selected in the panel.
     * @return selected filter string value
     */
    public String getValue() {
        return filterValue;
    }
    
    /** Set the filter value.
     * @param value filter value to set
     */
    public void setValue(String value){
        filterComboBox.setSelectedItem(value);
    }
    
    /** Enable/Disable the filter field.
     * @param enable flag to enable the combobox
     */
    @Override
    public void setEnabled(boolean enable) {
        filterComboBox.setEnabled(enable);
    }

    /**
     * Event handler for the ActionListener interface on the combo box list.
     * @param event the action event that happened
     */
    @Override
    public void actionPerformed(ActionEvent event) {
        filterValue = (String)filterComboBox.getSelectedItem();
        pcs.firePropertyChange("filterModified", false, true);
    }
}
