package gov.usgs.ias.gui.common_library;

import java.text.DateFormatSymbols;

/**
 * A class to setup the list of months.
 * All the months of the year are loaded using locale-specific names.
 * For consistency with the java Calendar.MONTH month definitions,
 * month numbers are 0-relative (in the range of 0 to 11).
 */
public class MonthList {
    private static String[] monthNames;
    
    /**
     * Default constructor to create list of month names
     */
    MonthList() {
        String[] months = DateFormatSymbols.getInstance().getMonths();

        /* getMonths can return an array that has an empty entry at the 
           last index, so check whether that is true and eliminate the
           last entry if it is the case */
        int lastIndex = months.length - 1;
        if (months[lastIndex] == null || months[lastIndex].length() <= 0) {
            // last item empty, so declare a new array one smaller than the 
            // original and copy the entries to it
            String[] monthStrings = new String[lastIndex];
            System.arraycopy(months, 0, monthStrings, 0, lastIndex);
            monthNames = monthStrings;
        } 
        else {
            // last item not empty so it can be used directly
            monthNames = months;
        }
    }
    
    /**
     * Accessor method to get the list of month names.
     * @return  String list of month names
     */
    public String[] getMonthStrings() {
        return monthNames;
    }
    
    /**
     * Get the currently selected month.  
     * @param month The month name to convert to an index
     * @return  0-relative number of the currently selected month (which is
     *          also the index in the months list of the selected item) or -1
     */
    public int getMonthIndex(String month) {
        for (int i = 0; i < monthNames.length; i++) {
            if (monthNames[i].equals(month)) {
                return i;
            }
        }
        return -1; // error condition to catch
    }
}
