package gov.usgs.ias.gui.common_library;

import java.io.IOException;
import java.util.logging.LogManager;
import java.util.Properties;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

/**
 * This is a class designed to be used as the
 * java.util.logging.config.class which will configure packages that use the
 * java.util.logging system to use a Log4j handler instead.  Currently the only
 * java libraries used by IAS that use util logging are the 
 * NASA PDS tools (gov.nasa.pds).
 * Using this configuration, the util and log4j
 * log messages can go to the same destination, and logging levels
 * for java.util logging can be configured in the log4j properties file.
 */
public class RouteToLog4jConfig {

    /**
     * The constructor for this class programmatically configures
     * java.util.logging, which is used by the gov.nasa.pds library,
     * to use a log4j handler.  See LogManager javadoc for details.
     */
    public RouteToLog4jConfig() {
        LogManager logManager = LogManager.getLogManager();
        Properties utilLoggingProperties = new Properties();
        // Set up the log manager properties to set the handler & log level
        utilLoggingProperties.setProperty("gov.nasa.pds.handlers",
            "gov.usgs.ias.gui.common_library.RouteToLog4jHandler");
        utilLoggingProperties.setProperty("gov.nasa.pds.useParentHandlers",
            "false");
        utilLoggingProperties.setProperty("gov.nasa.pds.level",
            "FINEST");
        // Read the properties into the LogManager
        ByteArrayOutputStream os = new ByteArrayOutputStream();
        try {
            utilLoggingProperties.store(os, "Java Util Logging Properties");
            logManager.readConfiguration(
                new ByteArrayInputStream(os.toByteArray()));
        } catch (IOException ex) {
            // If the log manager configuration fails, do nothing and let it
            // use its default configuration.
        }
    }
}
