package gov.usgs.ias.gui.common_library;

import java.io.File;
import java.io.IOException;
import org.apache.log4j.Logger;
import javax.swing.JFileChooser;
import javax.swing.JFrame;

/**
 * Uses a file chooser dialog to allow the user to
 * save a file and specify its name & location.
 */
public class SaveDialog {

    private static File savedDirectory = null;  // the last directory selected

    /**
     * Get the name to save the file as.  The file chooser dialog is initially
     * populated with a default file name.
     * @param    parentFrame      the parent frame of this dialog
     * @param    defaultFileName  default name to save the file as
     * @return   full path & file name of the file to save
     */
    public static String SaveAs(JFrame parentFrame, String defaultFileName) {
        // create a swing file chooser to allow the user to select the file
        // to load
        JFileChooser fc = new JFileChooser();
        fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
        fc.setDialogTitle("Save File As");

        // if there is a previously saved directory and that directory
        // exists, start the file chooser there
        if ((savedDirectory != null) && savedDirectory.exists()) {
            fc.setCurrentDirectory(savedDirectory);
        }

        // set the default file name, if provided
        if (defaultFileName != null) {
            File sel = new File(defaultFileName);
            fc.setSelectedFile(sel);
        }

        // show the file chooser dialog
        int result = fc.showSaveDialog(parentFrame);
        if (result == JFileChooser.APPROVE_OPTION) {
            // save the directory too so it can be defaulted next time
            savedDirectory = fc.getCurrentDirectory();

            // a file was chosen, so set it
            File sourceFile = fc.getSelectedFile();
            String sourceFilePath = null;
            try {
                sourceFilePath = sourceFile.getCanonicalPath();
            } catch (IOException ex) {
                Logger.getLogger(SaveDialog.class.getName()).error(
                        "Unable to get name of file to save", ex);
            }
            return sourceFilePath;
        }
        return null;
    }

    /**
     * Get the name to save the file as, without providing a default file name
     * @param   parentFrame   parent of this dialog
     * @return  full path & file name of the file to save
     */
    public static String SaveAs(JFrame parentFrame) {
        return SaveAs(parentFrame, null);
    }
}
