package gov.usgs.ias.gui.common_library;

import javax.swing.SpinnerListModel;

/**
 * Custom spinner list model that allows values to wraparound.
 */
public class WraparoundSpinnerListModel extends SpinnerListModel
{
    Object firstValue;      // First item in the list
    Object lastValue;       // Last item in the list

    /**
     * Constructor for the WraparoundSpinnerListModel
     * @param values  Array of objects to use
     */
    public WraparoundSpinnerListModel(Object[] values)
    {
        super(values);
        // remember the first and last values to allow wrapping around
        firstValue = values[0];
        lastValue = values[values.length - 1];
    }

    /**
     * Get the next value in the sequence, wrapping around to the start
     * when the end is reached.
     */
    public Object getNextValue()
    {
        Object value = super.getNextValue();

        // The next value will be null when trying to go past the end
        if (value == null)
        {
            value = firstValue;
        }
        return value;
    }

    /**
     * Get the previous value in the sequence, wrapping around to the end
     * when the start is reached.
     */
    public Object getPreviousValue()
    {
        Object value = super.getPreviousValue();

        // The next value will be null when trying to go before the start
        if (value == null)
        {
            value = lastValue;
        }
        return value;
    }
}
