package gov.usgs.ias.gui.common_library;

import javax.swing.SpinnerNumberModel;

/**
 * Custom spinner number model that allows values to wraparound.
 */
public class WraparoundSpinnerNumberModel extends SpinnerNumberModel
{
    Number firstValue;      // First value in the sequence
    Number lastValue;       // Last value in the sequence

    /**
     * Constructs a WraparoundSpinnerNumberModel with the specified value,
     * minimum/maximum bounds, and stepSize.
     * @param value the current value of the model
     * @param minimum the first number in the sequence
     * @param maximum the last number in the sequence
     * @param stepSize the difference between elements of the sequence
     */
    public WraparoundSpinnerNumberModel(int value, int minimum, int maximum,
        int stepSize)
    {
        super(value, minimum, maximum, stepSize);
        // remember the first and last values to allow wrapping around
        firstValue = minimum;
        lastValue = maximum;
    }

    /**
     * Get the next value in the sequence, wrapping around to the start
     * when the end is reached.
     */
    public Object getNextValue()
    {
        Object value = super.getNextValue();

        // The next value will be null when trying to go past the end
        if (value == null)
        {
            value = firstValue;
        }
        return value;
    }

    /**
     * Get the previous value in the sequence, wrapping around to the end
     * when the start is reached.
     */
    public Object getPreviousValue()
    {
        Object value = super.getPreviousValue();

        // The next value will be null when trying to go before the start
        if (value == null)
        {
            value = lastValue;
        }
        return value;
    }
}
