/**
 * BpfInsertTest
 *
 * JUnit test of the insertFile method of the BpfDAO class.  This class provides
 * a way to run a BPF insert from the command line.
 * Testing properties are in two locations and prefixed with test-sys-prop
 * Build Automated Testing: test.properties
 * Developer Testing:  nbproject/private/private.properties
 */
package gov.usgs.ias.dao.bpf;

import gov.usgs.ias.cps.CpsStatusEnum;
import gov.usgs.ias.dao.ParseODL;
import gov.usgs.ias.dao.TestSupport;
import gov.usgs.ias.dao.DataConnection;
import gov.nasa.pds.tools.label.Label;
import gov.usgs.ias.constant.Constants;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

public class BpfInsertTest {

    private DataConnection conn;
    private String daoAuth = null;
    private CpsStatusEnum defaultBpfStatus = null;

    public BpfInsertTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception {
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }

    @Before
    public void setUp() {
        String bpfDbProperty = "BPF_TEST_DB";
        this.conn = new DataConnection(bpfDbProperty);

        // Set up the authentication string for the proper schema
        if (System.getProperty("SCHEMA") != null &&
            System.getProperty("SCHEMA").equals("PROD")) {
            System.out.println("Inserting file into PROD database");
            daoAuth = Constants.DAO_AUTH_IAS_PROD;
            defaultBpfStatus = CpsStatusEnum.ACTIVE;
        } else {
            System.out.println("Inserting file into EVAL database");
            daoAuth = Constants.DAO_AUTH_IAS_EVAL;
            defaultBpfStatus = CpsStatusEnum.ACTIVE;
        }
    }

    @After
    public void tearDown() {
        this.conn.close();
    }

    /**
     * Test of insertBpf method, of class BpfDAO.
     */
    @Test
    public void testInsertBpf() throws Exception {

        // This test will be a no-op unless a file name is provided
        if (System.getProperty("BPF_INSERT_FILE") == null) {
            System.out.println("No insert file specified, skipping test");
            return;
        }

        System.out.println("Parsing ODL file" +
                System.getProperty("BPF_INSERT_FILE"));
        Label bpfLabel = ParseODL.parseOdlFile(
                System.getProperty("BPF_INSERT_FILE"));
        System.out.println(" Done Parsing ODL file");

        assertNotNull("Error parsing " + System.getProperty("BPF_INSERT_FILE"),
                bpfLabel);
        BpfDAO instance = new BpfDAO(this.conn, this.daoAuth);
        System.out.println(" Inserting file into DB");
        int result = instance.insertFile(bpfLabel, defaultBpfStatus);
        System.out.println(" Done Inserting file into DB");
        assertTrue("Error inserting " + System.getProperty("BPF_INSERT_FILE"),
                result != -1);
    }
 
    /**
     * Test suite, for running the tests with an old version of junit/ant
     **/
    public static junit.framework.Test suite() {
        if (System.getenv("ENABLE_DB_TESTS") == null) {
            System.out.println("Database tests are disabled");
            return new junit.framework.JUnit4TestAdapter(TestSupport.class);
        } else {
            return new junit.framework.JUnit4TestAdapter(BpfInsertTest.class);
        }
    }

    /**
     * Method to allow for running from the command-line, specifying the
     * name of the file to load
     */
    public static void main(String args[]) {
        if (args.length < 2) {
            System.err.println("Usage: java <classpath> " +
                    "gov.usgs.ias.dao.bpf.BpfInsertTest <filename> <schema>");
            System.exit(1);
        }
        System.setProperty("BPF_INSERT_FILE", args[0]);
        System.setProperty("SCHEMA", args[1]);
        org.junit.runner.JUnitCore.main(BpfInsertTest.class.getName());
    }

}
