/**
 * CpfInsertTest
 *
 * JUnit test of the insertFile method of the CpfDAO class.  This class provides
 * a way to run a CPF insert from the command line.
 */
package gov.usgs.ias.dao.cpf;

import gov.usgs.ias.cps.CpsStatusEnum;
import gov.usgs.ias.dao.ParseODL;
import gov.usgs.ias.dao.TestSupport;
import gov.usgs.ias.dao.DataConnection;
import gov.nasa.pds.tools.label.Label;
import gov.usgs.ias.constant.Constants;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

public class CpfInsertTest {

    private DataConnection conn;
    private String daoAuth = null;
    private CpsStatusEnum defaultCpfStatus = null;
    // This test uses a different property than CpfDAOTest.java for the
    // name of the file to insert.  The file loaded here will not get
    // deleted after the test is done.
    private static final String FILE_PROPERTY = "CPF_INSERT_TEST_FILE";

    public CpfInsertTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception {
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }

    @Before
    public void setUp() {
        this.conn = new DataConnection("CPF_TEST_DB");

        // Set up the authentication string for the proper schema
        if (System.getProperty("SCHEMA") != null &&
            System.getProperty("SCHEMA").equals("PROD")) {
            System.out.println("Inserting file into PROD database");
            daoAuth = Constants.DAO_AUTH_IAS_PROD;
            defaultCpfStatus = CpsStatusEnum.ACTIVE;
        } else {
            System.out.println("Inserting file into EVAL database");
            daoAuth = Constants.DAO_AUTH_IAS_EVAL;
            defaultCpfStatus = CpsStatusEnum.ACTIVE;
        }
    }

    @After
    public void tearDown() {
        if (this.conn != null) {
            this.conn.close();
        }
    }

    /**
     * Test of insertCpf method, of class CpfDAO.
     */
    @Test
    public void testInsertCpf() throws Exception {
        
        // This test will be a no-op unless a file name is provided
        if (System.getProperty(FILE_PROPERTY) == null) {
            return;
        }

        System.out.println(" Parsing ODL file " +
                System.getProperty(FILE_PROPERTY));
        Label cpfLabel = ParseODL.parseOdlFile(
                System.getProperty(FILE_PROPERTY));
        System.out.println(" Done Parsing ODL file");

        assertNotNull("Error parsing " + System.getProperty(FILE_PROPERTY),
                cpfLabel);
        CpfDAO instance = new CpfDAO(this.conn, this.daoAuth);
        System.out.println(" Inserting file into DB");
        int result = instance.insertFile(cpfLabel, defaultCpfStatus);
        System.out.println(" Done Inserting file into DB");
        assertTrue("Error returned from insert", result != -1);
    }

    /**
     * Test suite, for running the tests with an old version of junit/ant
     **/
    public static junit.framework.Test suite() {
        if (System.getenv("ENABLE_DB_TESTS") == null) {
            System.out.println("Database tests are disabled");
            return new junit.framework.JUnit4TestAdapter(TestSupport.class);
        } else {
            return new junit.framework.JUnit4TestAdapter(CpfInsertTest.class);
        }
    }

    /**
     * Method to allow for running from the command-line, specifying the
     * name of the file to load
     **/
    public static void main(String args[]) {
        if (args.length < 2) {
            System.err.println("Usage: java <classpath> " +
                    "gov.usgs.ias.dao.cpf.CpfInsertTest <filename> <schema>");
            System.exit(1);
        }
        System.setProperty(FILE_PROPERTY, args[0]);
        System.setProperty("SCHEMA", args[1]);
        org.junit.runner.JUnitCore.main(CpfInsertTest.class.getName());
    }
}
