/**
 * CpfSummaryDAOTest
 *
 * JUnit tests for CpfSummaryDAO class.  All methods with a @Test annoation
 * will be run by the junit 4 test framework.
 */
package gov.usgs.ias.dao.cpf;

import gov.usgs.ias.dao.TestSupport;
import gov.usgs.ias.constant.Constants;
import gov.usgs.ias.cps.CpsSummary;
import gov.usgs.ias.cps.CpsStatusEnum;
import gov.usgs.ias.dao.DataConnection;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

public class CpfSummaryDAOTest {

    private DataConnection conn;
    private String daoAuth = null;

    public CpfSummaryDAOTest() {
        conn = null;
    }

    @BeforeClass
    public static void setUpClass() throws Exception {
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }

    /**
     * Setup to be done before each test.
     * N.B.: these unit tests assume the standard set of test CPFs
     * have been loaded into the database.
     */
    @Before
    public void setUp() {
        this.conn = new DataConnection("CPF_TEST_DB");

        // Set up the authentication string for the proper schema, PROD default
        if (System.getProperty("SCHEMA") != null &&
            System.getProperty("SCHEMA").equals("EVAL")) {
            System.out.println("Using EVAL database");
            daoAuth = Constants.DAO_AUTH_IAS_EVAL;
        } else {
            System.out.println("Using RPOD database");
            daoAuth = Constants.DAO_AUTH_IAS_PROD;
        }
    }

    @After
    public void tearDown() {
    }

    /**
     * Test of searchCpfMain method, of class CpfSummaryDAO.
     */
    @Test
    public void testSearchCpfMain() throws Exception {
        System.out.println("searchCpfMain");
        SimpleDateFormat formatter = new SimpleDateFormat("MM/dd/yyyyzzz");
        Date startDate = formatter.parse(
                System.getProperty("cpf.summary.daterange1.start"));
        Date endDate = formatter.parse(
                System.getProperty("cpf.summary.daterange1.end"));
        Integer version = Integer.parseInt(
                System.getProperty("cpf.summary.version1"));
        CpsStatusEnum status = CpsStatusEnum.valueOf("ACTIVE");
        CpfSummaryDAO instance = new CpfSummaryDAO(this.conn, this.daoAuth);
        
        // Set the near match tolerance property
        System.setProperty(Constants.NEAR_MATCH_CPF_TOLERANCE, 
                System.getProperty("cpf.summary.tolerance"));
        boolean nearMatch = true;
       
        // Using a version will disable the near match, expect 0 matches
        List<CpsSummary> result = instance.searchCpsMain(startDate, endDate, 
                version, status, nearMatch);
        assertNotNull("Null returned from date range search", result);
        assertTrue("Unexpected matches found for date range",
                result.size() == 0);

        // Don't query on version, expect a near match
        result = instance.searchCpsMain(startDate, endDate, 
                null, status, nearMatch);
        assertNotNull("Null returned from near match search", result);
        assertTrue("No matches found for near match search", result.size() > 0);
        System.out.println("Found " + result.size() + " matches, first one: "
                + result.get(0).getFilename());        
    }

    /**
     * Test of getCpfSummary method, of class CpfSummaryDAO.
     */
    @Test
    public void testGetCpfSummary() throws Exception {
        System.out.println("getCpfSummary");
        CpfSummaryDAO instance = new CpfSummaryDAO(this.conn, this.daoAuth);
        Long cpfMainId = instance.getCpsMainId(System.getProperty("CPF_FILE"));
        assertNotNull("No ID found for " + System.getProperty("CPF_FILE"),
                cpfMainId);
        CpsSummary result = instance.getCpsSummary(cpfMainId);
        assertNotNull("Null returned for summary of " + cpfMainId, result);
        assertEquals("Invalid file name in summary",
                result.getFilename(), System.getProperty("CPF_FILE"));
    }

    /**
     * Test of getAllCpfList method, of class CpfSummaryDAO.
     */
    @Test
    public void testGetAllCpfList() throws Exception {
        System.out.println("getAllCpfList");
        CpfSummaryDAO instance = new CpfSummaryDAO(this.conn, this.daoAuth);
        List<CpsSummary> result = instance.getAllCpsList();
        assertNotNull("Unable to get list of all CPF files", result);
        assertTrue("No CPF files found", result.size() > 0);
    }

    /**
     * Test of getCpfMainId method, of class CpfSummaryDAO.
     */
    @Test
    public void testGetCpfMainId() throws Exception {
        System.out.println("getCpfMainId");
        String filename = System.getProperty("CPF_FILE");
        CpfSummaryDAO instance = new CpfSummaryDAO(this.conn, this.daoAuth);
        Long result = instance.getCpsMainId(filename);
        assertNotNull("Null returned getting ID for " + filename, result);
        assertTrue("Invalid ID returned for " + filename, result > 0);
    }

    /**
     * Test of updateCpfStatus method, of class CpfDAO.
     */
    @Test
    public void testUpdateCpfStatus() throws Exception {
        System.out.println("updateCpfStatus");
        String cpfName = System.getProperty("CPF_FILE");
        String status = "ACTIVE";
        CpfSummaryDAO instance = new CpfSummaryDAO(this.conn, this.daoAuth);
        instance.updateCpsStatus(cpfName, status);
    }

    /**
     * Test suite, for running the tests with an old version of junit/ant
     **/
    public static junit.framework.Test suite() {
        if (System.getenv("ENABLE_DB_TESTS") == null) {
            System.out.println("Database tests are disabled");
            return new junit.framework.JUnit4TestAdapter(TestSupport.class);
        } else {
            return new junit.framework.JUnit4TestAdapter(
                    CpfSummaryDAOTest.class);
        }
    }
}
