/**
 * RlutDAOTest
 *
 * JUnit tests for RlutDAO class.  All methods with a @Test annoation
 * will be run by the junit 4 test framework.
 */
package gov.usgs.ias.dao.rlut;

import gov.usgs.ias.dao.TestSupport;
import gov.usgs.ias.constant.Constants;
import gov.usgs.ias.dao.DataConnection;
import java.io.File;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

public class RlutDAOTest {

    private DataConnection conn;
    private String daoAuth = null;

    public RlutDAOTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception {
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }

    @Before
    public void setUp() {
        this.conn = new DataConnection("RLUT_TEST_DB");

        // Set up the authentication string for the proper schema, default PROD
        if (System.getProperty("SCHEMA") != null &&
            System.getProperty("SCHEMA").equals("EVAL")) {
            System.out.println("Using EVAL database");
            daoAuth = Constants.DAO_AUTH_IAS_EVAL;
        } else {
            System.out.println("Using PROD database");
            daoAuth = Constants.DAO_AUTH_IAS_PROD;
        }
    }

    @After
    public void tearDown() {
    }

    /**
     * Test of getRlutData method, of class RlutDAO.
     */
    @Test
    public void testGetRlutData() throws Exception {
        System.out.println("getRlutData");
        String rlutFilename = System.getProperty("RLUT_FILE");
        File cacheFile = new File("CachedRlut");
        cacheFile.setWritable(true);
        cacheFile.delete(); // ensure the file doesn't already exist

        RlutDAO instance = new RlutDAO(conn, daoAuth);
        
        // Test with an expected file
        int expectedSize = Integer.parseInt(
            System.getProperty("rlut.expected_size"));
        try {
            instance.getRlutData(rlutFilename, cacheFile);
        } catch (Exception e) {
            assertTrue("Unable to cache " + rlutFilename, false);
        }
        assertTrue("Cannot read cache file " + cacheFile.getPath(),
                cacheFile.canRead());
        assertTrue("Unexpected cache file size",
            cacheFile.length() == expectedSize);
        cacheFile.setWritable(true);
        cacheFile.delete();

        // Test with a non-existent file, should throw an exception
        try {
            instance.getRlutData("DOESNOTEXIST", cacheFile);
        } catch (Exception e) {
            // ignore the exception
        }
        // If the test failed, there will be a file that needs to be deleted
        // If the test succeeded, there should be no file
        if (cacheFile.canRead()) {
            cacheFile.delete();
            assertTrue("Cache file for non-existent RLUT was created", false);
        } else {
            assertTrue("Test failed", true);
        }             
    }

    /**
     * Test suite, for running the tests with an old version of junit/ant
     */
    public static junit.framework.Test suite() {
        if (System.getenv("ENABLE_DB_TESTS") == null) {
            System.out.println("Database tests are disabled");
            return new junit.framework.JUnit4TestAdapter(TestSupport.class);
        } else {
            return new junit.framework.JUnit4TestAdapter(RlutDAOTest.class);
        }
    }
}
