/**
 * RlutSummaryDAOTest
 *
 * JUnit tests for RlutSummaryDAO class.  All methods with a @Test annoation
 * will be run by the junit 4 test framework.
 */

package gov.usgs.ias.dao.rlut;

import gov.usgs.ias.dao.TestSupport;
import gov.usgs.ias.constant.Constants;
import gov.usgs.ias.dao.DataConnection;
import gov.usgs.ias.cps.CpsStatusEnum;
import gov.usgs.ias.cps.CpsSummary;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

public class RlutSummaryDAOTest {

    private DataConnection conn;
    private String daoAuth = null;

    public RlutSummaryDAOTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception {
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }

    @Before
    public void setUp() {

        this.conn = new DataConnection("RLUT_TEST_DB");

        // Set up the authentication string for the proper schema, default PROD
        if (System.getProperty("SCHEMA") != null &&
            System.getProperty("SCHEMA").equals("EVAL")) {
            System.out.println("Using EVAL database");
            daoAuth = Constants.DAO_AUTH_IAS_EVAL;
        } else {
            System.out.println("Using PROD database");
            daoAuth = Constants.DAO_AUTH_IAS_PROD;
        }
    }

    @After
    public void tearDown() {
    }

    /**
     * Test of searchCpsMain method, of class RlutSummaryDAO.
     */
    @Test
    public void testSearchCpsMain() throws Exception {
        System.out.println("searchCpsMain");
        SimpleDateFormat formatter = new SimpleDateFormat("MM/dd/yyyyzzz");
        Date startDate = formatter.parse(
                System.getProperty("rlut.summary.daterange1.start"));
        Date endDate = formatter.parse(
                System.getProperty("rlut.summary.daterange1.end"));
        Integer version = Integer.parseInt(
                System.getProperty("rlut.summary.version1"));
        CpsStatusEnum status = CpsStatusEnum.ACTIVE;
        boolean nearMatch = false;
        RlutSummaryDAO instance = new RlutSummaryDAO(conn, daoAuth);

        List result = instance.searchCpsMain(startDate, endDate, version,
                status, nearMatch);
        assertNotNull("Null returned on date range search", result);
        assertTrue("No matches found for date range", result.size() > 0);

        // test with non-existent version
        version = 199;
        result = instance.searchCpsMain(startDate, endDate, version,
                status, nearMatch);
        assertNotNull("Null returned on non-existent version search", result);
        assertTrue("Unexpected matches found for non-existent version",
                result.size() == 0);

        // test with date range where no files exist
        version = Integer.parseInt(System.getProperty("rlut.summary.version2"));
        startDate = formatter.parse(
                System.getProperty("rlut.summary.daterange2.start"));
        endDate = formatter.parse(
                System.getProperty("rlut.summary.daterange2.end"));
        result = instance.searchCpsMain(startDate, endDate, version,
                status, nearMatch);
        assertNotNull("Null returned on empty date range search",
                result);
        assertTrue("Unexpected matches found for empty date range",
                result.size() == 0);

    }

    /**
     * Test of getCpsSummary method, of class RlutSummaryDAO.
     */
    @Test
    public void testGetCpsSummary() throws Exception {
        System.out.println("getCpsSummary");
        RlutSummaryDAO instance = new RlutSummaryDAO(conn, daoAuth);
        
        // get the summary for our expected file
        String filename = System.getProperty("RLUT_FILE");
        Long rlutMainId = instance.getCpsMainId(filename);
        assertNotNull("ID not found for " + filename, rlutMainId);
        
        CpsSummary result = instance.getCpsSummary(rlutMainId);
        assertNotNull("Unable to get summary information for " + filename,
                result);
        assertEquals("Unexpected file name in summary",
                result.getFilename(), filename);
    }

    /**
     * Test of getAllCpsList method, of class RlutSummaryDAO.
     */
    @Test
    public void testGetAllCpsList() throws Exception {
        System.out.println("getAllCpsList");
        RlutSummaryDAO instance = new RlutSummaryDAO(conn, daoAuth);
        List result = instance.getAllCpsList();
        assertNotNull("Unable to get list of all RLUT files", result);
        // there should be at least 1 file found
        assertTrue("No RLUT files found", result.size() > 0);
    }

    /**
     * Test of getCpsMainId method, of class RlutSummaryDAO.
     */
    @Test
    public void testGetCpsMainId() throws Exception {
        System.out.println("getCpsMainId");
        RlutSummaryDAO instance = new RlutSummaryDAO(conn, daoAuth);

        // search for the expected file
        String filename = System.getProperty("RLUT_FILE");
        Long result = instance.getCpsMainId(filename);
        assertNotNull("Unable to get summary information for " + filename,
                result);

        // test with a non-existent file
        result = instance.getCpsMainId("DOESNOTEXIST");
        assertNull("Found unexpected ID for DOESNOTEXIST", result);
    }

    public static junit.framework.Test suite() {
        if (System.getenv("ENABLE_DB_TESTS") == null) {
            System.out.println("Database tests are disabled");
            return new junit.framework.JUnit4TestAdapter(TestSupport.class);
        } else {
            return new junit.framework.JUnit4TestAdapter(
                    RlutSummaryDAOTest.class);
        }
    }
}
