#!/bin/csh -f
#
# Load test CPFs, BPFs, RLUTs
# This script must be run from the 'ias' directory
# 

if (! $?ENABLE_DB_TESTS) then
    echo "Database load is disabled"
    exit 0
endif

set nonomatch
set avail = "available_files.$$"
set this_dir = `dirname $0`     # the location of this script
set test_data_dir = "$this_dir" # test files are assumed to be in the same 
                                # directory as the scripts

# For each type of file, do a query to find what's already loaded
# in the DB.  Then check if each of the files in the test directory is
# listed -- if not, load it.


# Load PROD BPFs
echo "Loading PROD BPFs"
$ORACLE_HOME/bin/sqlplus -S $IAS_DB_L8_OLITIRS > $avail << EOF
 select file_name from bpf_main;
 exit;
EOF

set file_pattern = 'LO8BPF*'
foreach file ($test_data_dir/$file_pattern)
    set filename = `basename $file`
    if ($filename == $file_pattern) break
    if ( { grep -q ^${filename}$ $avail } ) then
        echo " $filename is already loaded"
    else
        echo " loading $filename"
        $this_dir/insertBpfTest.sh $file PROD
        if ($status != 0) exit 1
    endif
end

# Load EVAL BPFs
echo "Loading EVAL BPFs"
$ORACLE_HOME/bin/sqlplus -S $IAS_DB_L8_OLITIRS_EVAL > $avail << EOF
 select file_name from bpf_main;
 exit;
EOF

set file_pattern = 'eval_LO8BPF*'
foreach file ($test_data_dir/$file_pattern)
    set filename = `basename $file`
    if ($filename == $file_pattern) break
    if ( { grep -q ^${filename}$ $avail } ) then
        echo " $filename is already loaded"
    else
        echo " loading $filename"
        $this_dir/insertBpfTest.sh $file EVAL
        if ($status != 0) exit 1
    endif
end

# Load PROD CPFs
echo "Loading PROD CPFs"
$ORACLE_HOME/bin/sqlplus -S $IAS_DB_L8_OLITIRS > $avail << EOF
 select file_name from cpf_main;
 exit;
EOF

set file_pattern = 'L8CPF*'
foreach file ($test_data_dir/$file_pattern)
    set filename = `basename $file`
    if ($filename == $file_pattern) break
    if ( { grep -q ^${filename}$ $avail } ) then
        echo " $filename is already loaded"
    else
        echo " loading $filename"
        $this_dir/insertCpfTest.sh $file PROD
        if ($status != 0) exit 1
    endif
end

# Load EVAL CPFs
echo "Loading EVAL CPFs"
$ORACLE_HOME/bin/sqlplus -S $IAS_DB_L8_OLITIRS_EVAL > $avail << EOF
 select file_name from cpf_main;
 exit;
EOF

set file_pattern = 'eval_L8CPF*'
foreach file ($test_data_dir/$file_pattern)
    set filename = `basename $file`
    if ($filename == $file_pattern) break
    if ( { grep -q ^${filename}$ $avail } ) then
        echo " $filename is already loaded"
    else
        echo " loading $filename"
        $this_dir/insertCpfTest.sh $file EVAL
        if ($status != 0) exit 1
    endif
end

# Load PROD RLUTs
echo "Loading PROD RLUTs"
$ORACLE_HOME/bin/sqlplus -S $IAS_DB_L8_OLITIRS > $avail << EOF
 select file_name from rlut_main;
 exit;
EOF

set file_pattern = 'L8RLUT*h5'
foreach file ($test_data_dir/$file_pattern)
    set filename = `basename $file`
    if ($filename == $file_pattern) break
    if ( { grep -q ^${filename}$ $avail } ) then
        echo " $filename is already loaded"
    else
        echo " loading $filename"
        $this_dir/insertRlutTest.sh $file $IAS_DB_L8_OLITIRS
        if ($status != 0) exit 1
    endif
end


/bin/rm $avail

exit 0
