/***************************************************************************
 NAME:                      all_solarcal_tests

 PURPOSE:  "Driver" for CGreen unit testing of the solarcal_oli application
           (detector response characterization of the OLI solar diffuser
           data)

 RETURNS:  CGreen status

***************************************************************************/
#include <stdio.h>
#include <stdlib.h>

#include "cgreen.h"

#include "ias_logging.h"
#include "ias_db.h"
#include "ias_satellite_attributes.h"

#include "solarcal_oli_tests.h"

int main(int argc, char *argv[])
{
    int status;

    char *enable_db_tests = NULL;

    /* Suppress IAS_LOG_DEBUG messages */
    ias_log_initialize("solarcal_test_suite");

    /* Initialize the Satellite Attributes Library */
    status = ias_sat_attr_initialize(IAS_L8);
    if (status != SUCCESS)
    {
        printf("Failure initializing satellite attributes\n");
        exit(100);
    }

    /* Set up the master test suite */
    TestSuite *suite = create_test_suite();

    /* Add the tests to the master suite */
    solarcal_oli_parameter_test(suite);
    solarcal_oli_validate_data_test(suite);
    solarcal_oli_get_cpf_data_test(suite);
    solarcal_oli_calculate_angles_test(suite);
    solarcal_oli_calculate_gains_test(suite);
    solarcal_oli_write_reports_test(suite);

    /* Check to make sure database testing is enabled.  If it is,
       add the database tests; if not, go on */
    enable_db_tests = getenv("ENABLE_DB_TESTS");
    if (enable_db_tests)
        solarcal_oli_dbaccess_test(suite);

    /* Run the tests */
    if (argc > 1)
        status = run_single_test(suite, argv[1], create_text_reporter());
    else
        status = run_test_suite(suite, create_text_reporter());

    /* Done */
    return status;
}



