#!/bin/csh -f
#
# Usage: ./check_or_insert_end2end_woid.csh [Work Order ID]
#

# Ensure there is a database environment variable defined
if ( ! $?IAS_DB_L8_OLITIRS ) then
    echo "IAS_DB_L8_OLITIRS isn't set"
    exit 1
endif

if ( ${#argv} != 1 ) then
    echo "Usage: $0 [Work Order ID]"
    exit 1
endif

# Get the RWOCID for the WOID passed in
set common_id = `sqlplus -s ${IAS_DB_L8_OLITIRS}` << END
    set head off;
    SELECT radiometric_wo_common_id FROM radiometric_work_order_common
    WHERE work_order_id = '$1';
    exit;
END
if ( "$common_id" == "no rows selected" ) then
    set id_count = 0
else
    set id_count = ${#common_id}
endif

# Exactly 0 -- log that it's currently not found
if ( $id_count == 0 ) then
    echo "radiometric_wo_common_id not found for work order '$1', inserting "
    echo "into database..."

# Exactly 1 -- clean out the tables so that they can be reloaded with the
#              current test data set.  Removing the entry in the
#              RADIOMETRIC_WORK_ORDER_COMMON table should 'cascade'
#              delete everything associated with that ID

#echo $common_id, $id_count
else if ( $id_count == 1 ) then
    echo "$1 entered in database, removing previous data..."
    echo "delete from radiometric_work_order_common " > delete_woid.sql
    echo "where work_order_id='$1';" >> delete_woid.sql
    $ORACLE_HOME/bin/sqlplus $IAS_DB_L8_OLITIRS < delete_woid.sql \
        >& /dev/null
    if ( $status != 0 ) then
        echo "Error executing sqlplus work order data deletion."
        /bin/rm delete_woid.sql
        exit 1
    endif
    echo "Data deletion completed."
    /bin/rm delete_woid.sql


# Given the current database design/implementation,
# this code should NEVER execute.  In case we get here for some oddball
# reason, however, log an error message and exit out--this will catch
# something needing further investigation...
else
    echo "Should not have reached this code block given the current DB "
    echo "design and implementation.  This needs to be checked..."
    exit 1
endif


# (Re)load the radiometric_work_order_common information.
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0, silent=ALL, \
   control = rad_woid_for_DB_simdiffuser.ldr_original
if ($status) then
    echo "Error loading radiometric workorder common table information \
         for nonuniformity characterization"
    exit 1
endif


# The radiometric_wo_common_id from the previous load isn't readily
# available here.  So... we'll have to query
# RADIOMETRIC_WORK_ORDER_COMMON to get it.
set common_id = `sqlplus -s ${IAS_DB_L8_OLITIRS}` << END2
    set head off;
    SELECT radiometric_wo_common_id FROM radiometric_work_order_common
    WHERE work_order_id = '$1';
    exit;
END2


# Load the data for bands 1, 7, and 8
set datadir = $IAS_UNIT_TEST_DATA_DIR/ias/rps/det_response_diffuser/nonuniformity
echo "Loading band 1 test data for ID $common_id..."
sed -e "s/XXX/$common_id/" \
$datadir/diffuser_stats_DB_B01.ldr_original > diffuser_stats_DB_B01.ldr
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0 silent=ALL \
    control = diffuser_stats_DB_B01.ldr
if ( $status ) then
    echo "Error loading band 1 gain test data"
    rm diffuser_stats_DB_B01.ldr
    exit 1
endif
rm diffuser_stats_DB_B01.ldr

echo "Loading band 7 test data for ID $common_id..."
sed -e "s/XXX/$common_id/" \
$datadir/diffuser_stats_DB_B07.ldr_original > diffuser_stats_DB_B07.ldr
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0 silent=ALL \
    control = diffuser_stats_DB_B07.ldr
if ( $status ) then
    echo "Error loading band 7 gain test data"
    rm diffuser_stats_DB_B07.ldr
    exit 1
endif
rm diffuser_stats_DB_B07.ldr

echo "Loading band 8 test data for ID $common_id..."
sed -e "s/XXX/$common_id/" \
$datadir/diffuser_stats_DB_B08.ldr_original > diffuser_stats_DB_B08.ldr
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0 silent=ALL \
    control = diffuser_stats_DB_B08.ldr
if ( $status ) then
    echo "Error loading band 8 gain test data"
    rm diffuser_stats_DB_B08.ldr
    exit 1
endif
rm diffuser_stats_DB_B08.ldr

exit 0
