#!/bin/csh -f
#
# Usage: ./check_or_insert_woid.csh [Work Order ID]
#

# Ensure there is a database environment variable defined
if ( ! $?IAS_DB_L8_OLITIRS ) then
    echo "IAS_DB_L8_OLITIRS isn't set"
    exit 1
endif

if ( ${#argv} != 1 ) then
    echo "Usage: $0 [Work Order ID]"
    exit 1
endif

# Get the RWOCID for the WOID passed in
set common_id = `sqlplus -s ${IAS_DB_L8_OLITIRS}` << END
    set head off;
    SELECT radiometric_wo_common_id FROM radiometric_work_order_common
    WHERE work_order_id = '$1';
    exit;
END
if ( "$common_id" == "no rows selected" ) then
    set id_count = 0
else
    set id_count = ${#common_id}
endif


# Exactly 0 -- log that it's currently not found
if ( $id_count == 0 ) then
    echo "radiometric_wo_common_id not found for work order '$1', inserting "
    echo "into database..."


# Exactly 1 -- clean out the tables so that they can be reloaded with the
#              current test data set.  Removing the entry in the
#              RADIOMETRIC_WORK_ORDER_COMMON table should 'cascade'
#              delete everything associated with that ID
else if ( $id_count == 1 ) then
    echo "$1 entered in database, removing previous data..."
    echo "delete from radiometric_work_order_common " > delete_woid.sql
    echo "where work_order_id='$1';" >> delete_woid.sql
    $ORACLE_HOME/bin/sqlplus $IAS_DB_L8_OLITIRS < delete_woid.sql \
        >& /dev/null
    if ( $status != 0 ) then
        echo "Error executing sqlplus work order data deletion."
        /bin/rm delete_woid.sql
        exit 1
    endif
    echo "Data deletion completed."
    /bin/rm delete_woid.sql


# Given the current database design/implementation,
# this code should NEVER execute.  In case we get here for some oddball
# reason, however, log an error message and exit out--this will catch
# something needing further investigation...
else
    echo "Should not have reached this code block given the current DB "
    echo "design and implementation.  This needs to be checked..."
    exit 1
endif


# 
echo "insert into radiometric_work_order_common " > insert_woid.sql
echo "(work_order_id) values ('$1');" >> insert_woid.sql
$ORACLE_HOME/bin/sqlplus $IAS_DB_L8_OLITIRS < insert_woid.sql >& /dev/null
if ( $status ) then
    echo "Error executing sqlplus"
    /bin/rm insert_woid.sql
    exit 1
endif
/bin/rm insert_woid.sql


# The radiometric_wo_common_id from the previous load isn't readily
# available here.  So... we'll have to query
# RADIOMETRIC_WORK_ORDER_COMMON to get it.
set common_id = `sqlplus -s ${IAS_DB_L8_OLITIRS}` << END2
    set head off;
    SELECT radiometric_wo_common_id FROM radiometric_work_order_common
    WHERE work_order_id = '$1';
    exit;
END2

# Load the test data for this work order
echo "Loading test data for ID $common_id..."
sed -e "s/XXX/$common_id/" simulated_hist_stats_for_DB.ldr_original > \
    simulated_hist_stats_for_DB.ldr

# Run SQL Loader with this test data
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0 silent=ALL \
    control = simulated_hist_stats_for_DB.ldr
if ($status != 0) then
    echo "Error loading test data"
    /bin/rm simulated_hist_stats_for_DB.ldr
    exit 1
endif

# Cleanup
/bin/rm simulated_hist_stats_for_DB.ldr

exit 0
