/**********************************************************************
                     initialize_tests

 PURPOSE:      Module containing routines to initialize data structures
               for nonuniformity characterization unit testing

 NOTES:        Initialization routines are intended to work independently
               of the specific metrics to be calculated

***********************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "ias_const.h"

#include "solarcal_oli_tests.h"


/*-----------------------------------------------------------------------
 NAME:             initialize_radiance_statistics_data

 PURPOSE:    Reads the histogram statistics and diffuser radiance or
             reflectance data from the specified text files

 RETURNS:    Integer status code of SUCCESS or ERROR
-------------------------------------------------------------------------*/
int initialize_radiance_statistics_data
(
    const char *rad_data_filename,        /* I: Name of file with histogram
                                             stats and simulated radiances
                                             used in the prototype
                                             implementation */
    int        num_band_detectors,        /* I: # detectors in the band */
    double     *hist_stats_mean,          /* O: Populated histogram
                                             statistics arrays for the
                                             band */
    double     *hist_stats_stdev,
    double     *diffuser_stats            /* O: Radiance or reflectance
                                             statistics array for the
                                             band */
)
{
    FILE  *data_fptr = NULL;

    int   detector_index = 0;
    int   dummy_int = 0;

    /* Open the file for reading */
    data_fptr = fopen(rad_data_filename, "rt");
    if (data_fptr == NULL)
    {
        printf("Cannot open simulated histogram statistics and radiance "
               "statistics data file %s\n", rad_data_filename);
        return ERROR;
    }
    for (detector_index = 0;
         detector_index < num_band_detectors;
         detector_index++)
    {
        fscanf(data_fptr, "%d%lf%lf%lf", &dummy_int,
               &hist_stats_mean[detector_index],
               &hist_stats_stdev[detector_index],
               &diffuser_stats[detector_index]);
    }
    fclose(data_fptr);

    /* Finished */
    return SUCCESS;
}
