#ifndef LONG_COLLECT_SEGMENT_STATS_H
#define LONG_COLLECT_SEGMENT_STATS_H

/* System Includes */
#include <stdlib.h>

/* IAS Includes */
#include "ias_logging.h"
#include "ias_db_insert.h"
#include "ias_ancillary.h"

/* Local Includes */
#include "get_parameters.h"
#include "report.h"

/* Local funtion prototpyes */

int remove_stats
(
    struct ias_db_connection * db, /* IO: Database connection */
    char rwoid[IAS_CHAR_ID_SIZE]   /* I: Radiometric work order ID */
);

int remove_stats
(
    struct ias_db_connection * db, /* IO: Database connection */
    char rwoid[IAS_CHAR_ID_SIZE]   /* I: Radiometric work order ID */
);

void free_detector_offsets
(
    int * spatialOffsets[IAS_MAX_NSCAS],/* IO: Array of buffers */
    int number_scas                          /* I: */
);

int save_stats
(
    struct ias_db_connection * db, /* IO: Database connection */
    char rwoid[IAS_CHAR_ID_SIZE],  /* I: Radiometric work order ID */
    int framesPerSegment,          /* I: Number of frames/segment requested */
    int bandNum,    /* I: Band number */
    int isPanBand,  /* I: Is this the PAN band? */
    int scaNum,     /* I: SCA number */
    int nDetectors, /* I: Number of detectors per SCA in the band */
    int nFrames,    /* I: Number of frames in the segment */
    double aTime,   /* I: Acquisition time of first frame in segment */
    IAS_RPS_DB_HISTOGRAM_CHARACTERIZATION_RESULTS * stats
                    /* I: histogram results */
);

int get_detector_offsets
(
    IAS_CPF * cpf,  /* I: An opened CPF */
    int bandIndex,  /* I: Band index to retrieve offsets for */
    int nScas,      /* I: Number of SCAs for this band */
    int nDetectors, /* I: Number of detectors per SCA for bandNum */
    int * spatialOffsets[IAS_MAX_NSCAS] /* O: Array of buffers */
);

int process_image
(
    struct ias_db_connection * db, /* IO: Database connection */
    L0RIO * fdL0r,                 /* I:  Open L0R image to be read */
    IAS_CPF * cpf,                 /* I:  CPF opened for reading */
    int framesPerSegment,          /* I:  Number of frames in each segment */
    int framesSkipTop,             /* I:  Frames to skip at top of image */
    int framesSkipBottom,          /* I:  Frames to skip at bottom of image */
    char rwoid[IAS_CHAR_ID_SIZE],  /* I:  Radiometric work order ID */
    int reportsRequested[NUM_REPORTS]/* I: Flags indicating reports to create */
);

/* Frame Header Utility function prototypes */
int open_frame_header
(
    int framesPerSegment        /* I:  Number of frames in each segment */
);

int read_frame_header
(
    L0RIO * fdL0r,              /* I:  Open L0R image to be read */
    int segmentStartFrame,      /* I:  First record to read */
    int segmentNFrames          /* I:  Number of frames to read */
);

int get_start_stop_frame_time
(
    int segmentNFrames,         /* I: Number of OLI frame header records */
    double *acquisitionTime,    /* O: Start frame time */
    double *stop_frame_time,    /* O: Stop frame time */
    int *start_frame_index,     /* O: Start frame time */
    int *stop_frame_index       /* O: Stop frame time */
);

int dropped_frame_characterization
(
    int  bandNum,                   /* I: 1-based band number */
    int  nDetectors,                /* I: # of detectors per SCA */
    int  segmentNFrames,            /* I: Number of frames of image data */
    IAS_PIXEL_MASK  *pixelMask      /* I: Pixel mask for the current
                                          band/SCA (could be
                                          populated with other artifact
                                          information)
                                       O: Pixel mask populated with
                                          dropped frame locations */
);

void free_frame_header();

#endif
