/***************************************************************************
 NAME:                      all_nonuniformity_tests

 PURPOSE:  "Driver" for CGreen unit testing of the char_nonuniformity
           application

 RETURNS:  CGreen status

***************************************************************************/
#include <stdio.h>
#include <stdlib.h>

#include "cgreen.h"

#include "ias_logging.h"
#include "ias_db.h"
#include "ias_satellite_attributes.h"

#include "nonuniformity_tests.h"

int main(int argc, char *argv[])
{
    IAS_SATELLITE_ID satellite_id;

    int status;

    char *enable_db_tests = NULL;

    /* Check how the driver routine is called.  If there aren't any
       other command line arguments, the whole test suite is run.
       If there's one command line argument (the name of a single test),
       that test is run */
    if (argc > 2)
    {
        printf("USAGE:  all_nonuniformity_tests       OR\nUSAGE:  " 
               "all_nonuniformity_tests <name of single test>\n");
        exit(100);
    }


    /* Suppress any IAS_LOG_DEBUG messages */
    ias_log_initialize("nonuniformity_test_suite");

    /* Initialize the Satellite Attributes Library */
    satellite_id = ias_sat_attr_get_satellite_id_from_satellite_number(8);
    if (satellite_id != IAS_L8)
    {
        printf("Cannot obtain satellite ID number\n");
        exit(100);
    }

    status = ias_sat_attr_initialize(satellite_id);
    if (status != SUCCESS)
    {
        printf("Failure initializing satellite attributes\n");
        exit(100);
    }

    /* Set up the master test suite */
    TestSuite *suite = create_test_suite();

    nonuniformity_read_parameters_test(suite);
    nonuniformity_determine_radiances_test(suite);
    nonuniformity_sca_summary_test(suite);
    nonuniformity_write_header_test(suite);
    nonuniformity_reporting_test(suite);
    nonuniformity_cleanup_test(suite);

    /* Check to make sure database testing is enabled.  If it is,
       setup the database library and add the test.  If it isn't,
       skip it */
    enable_db_tests = getenv("ENABLE_DB_TESTS");
    if (enable_db_tests != NULL)
        nonuniformity_dbaccess_test(suite);

    /* Run the tests */
    if (argc > 1)
        return run_single_test(suite, argv[1], create_text_reporter());
    else
        return run_test_suite(suite, create_text_reporter());

}
