#!/bin/csh -f
#
# Usage: ./check_or_insert_woid.csh [Work Order ID]
#

# Ensure there is a database environment variable defined
if ( ! $?IAS_DB_L8_OLITIRS ) then
    echo "IAS_DB_L8_OLITIRS isn't set"
    exit 1
endif

if ( ${#argv} != 1 ) then
    echo "Usage: $0 [Work Order ID]"
    exit 1
endif

# First check to see if the Work order ID is already in the database
# Get the radiometric common ID
set sql_script = "retrieve_woid.sql"
echo "set term off" > $sql_script
echo "set echo on" >> $sql_script
echo "set trimout on" >> $sql_script
echo "set trimspool on" >> $sql_script
echo "set heading off" >> $sql_script
echo "set feedback off" >> $sql_script
echo "set pause off" >> $sql_script
echo "set pagesize 0" >> $sql_script
echo "set linesize 500" >> $sql_script
echo "set space 0" >> $sql_script
echo "set colsep |" >> $sql_script
echo "set tab off" >> $sql_script
echo "set verify off" >> $sql_script
echo "spool ./woid.txt" >> $sql_script
echo "select work_order_id, radiometric_wo_common_id " >> $sql_script
echo "from radiometric_work_order_common " >> $sql_script
echo "where work_order_id='"$1"';" >> $sql_script
echo "spool off" >> $sql_script
echo "exit" >> $sql_script
 
# Query the database
echo "Performing initial check..."
$ORACLE_HOME/bin/sqlplus $IAS_DB_L8_OLITIRS @$sql_script > & /dev/null
rm $sql_script

# Squeeze out the white space and select the lines beginning with the 
# work order ID 
set common_id = `sed 's/  *//g' ./woid.txt | grep ^$1 | \
    awk -F'|' '{print $2}'`

# How many ID numbers do we have?  In principle, there should be only 1.
# If there are more than 1, that needs to be dealt with...
set id_count = 0
foreach id ($common_id)
    @ id_count += 1
end

# Exactly 0 -- log that it's currently not found
if ( $id_count == 0 ) then
    echo "radiometric_wo_common_id not found for work order '$1', inserting "
    echo "into database..."

# Exactly 1 -- clean out the tables so that they can be reloaded with the
#              current test data set.  Removing the entry in the
#              RADIOMETRIC_WORK_ORDER_COMMON table should 'cascade'
#              delete everything associated with that ID
#echo $common_id, $id_count
else if ( $id_count == 1 ) then
    echo "$1 entered in database, removing previous data..."
    echo "delete from radiometric_work_order_common " > delete_woid.sql
    echo "where work_order_id='$1';" >> delete_woid.sql
    $ORACLE_HOME/bin/sqlplus $IAS_DB_L8_OLITIRS < delete_woid.sql \
        >& /dev/null
    if ( $status != 0 ) then
        echo "Error executing sqlplus work order data deletion."
        /bin/rm delete_woid.sql
        /bin/rm woid.txt
        exit 1
    endif
    echo "Data deletion completed."
    /bin/rm woid.txt
    /bin/rm delete_woid.sql

# Given the current database design/implementation,
# this code should NEVER execute.  In case we get here for some oddball
# reason, however, log an error message and exit out--this will catch
# something needing further investigation...
else
    echo "Should not have reached this code block given the current DB "
    echo "design and implementation.  This needs to be checked..."
    exit 1
endif


# (Re)load the radiometric_work_order_common information.
echo "insert into radiometric_work_order_common (work_order_id) values ('$1');" > insert_woid.sql
$ORACLE_HOME/bin/sqlplus $IAS_DB_L8_OLITIRS < insert_woid.sql >& /dev/null
if ( $status ) then
    echo "Error executing sqlplus work order ID insertion"
    /bin/rm insert_woid.sql
    exit 1
endif
/bin/rm insert_woid.sql


# The radiometric_wo_common_id from the previous load isn't readily
# available here.  So... we'll have to query
# RADIOMETRIC_WORK_ORDER_COMMON to get it.

# Run the query
set sql_script = "get_rad_common_id.sql"
echo "set heading off" > $sql_script
echo "select radiometric_wo_common_id" >> $sql_script
echo "from radiometric_work_order_common" >> $sql_script
echo "where work_order_id='"$1"';" >> $sql_script
echo "exit" >> $sql_script

set common_id = `$ORACLE_HOME/bin/sqlplus -S $IAS_DB_L8_OLITIRS \
    @get_rad_common_id.sql`
echo "radiometric_wo_common_id is $common_id for work order $1..."
/bin/rm get_rad_common_id.sql

# Load the test data for this work order
echo "Loading test data for ID $common_id..."
sed -e "s/XXX/$common_id/" simulated_hist_stats_for_DB.ldr_original > \
    simulated_hist_stats_for_DB.ldr

# Run SQL Loader with this test data
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0 silent=ALL \
    control = simulated_hist_stats_for_DB.ldr
if ( $status != 0 ) then
    echo "Error loading test data"
    /bin/rm simulated_hist_stats_for_DB.ldr
    exit 1
endif

# Cleanup
/bin/rm simulated_hist_stats_for_DB.ldr


exit 0
