/*************************************************************************

 NAME:         DEBUG_PARAMETER_IO

 PURPOSE:      Prints out contents of populated RPS_NUCHAR_WO_PARAMS
               and RPS_NUCHAR_OMF_PARAMS data structures when
               C debugging pragma "#ifdef DEBUG" is set.

**************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "../char_nonuniformity.h"

#include "nonuniformity_tests.h"


/* Declare a debugging function to print out contents of the
   RPS_NUCHAR_WO_PARAMS and RPS_NUCHAR_OMF_PARAMS data structures. */
void print_wo_params_struct(RPS_NUCHAR_WO_PARAMS wo_params)
{
    int *band_ptr = NULL;

    printf("WORK ORDER PARAMETERS:\n\n");
    printf("IAS work order id:  %s\n", wo_params.work_order_id);

    /* Print the band list */
    printf("Bands to process:\n");
    band_ptr = wo_params.bands;
    while (*band_ptr != 0)
    {
        printf("%d ", *band_ptr);
        band_ptr++;
    }
    printf("\n");

    /* Print the processing options.  */
    printf("\n\nCHARACTERIZATION OPTIONS\n\n");
    printf("Radiance source (0=DB 1=IAS):  %d\n",
           wo_params.calculate_radiance);
    if (wo_params.calculate_radiance == RPS_NUCHAR_CALCULATE_RADIANCE)
    {
        printf("Relative gain source (0=prelaunch, 1=postlaunch, "
               "2=current):  %d\n", wo_params.relgain_option);
    }
    printf("Panel/blackbody source correction (0=no, 1=yes):  %d\n",
           wo_params.correct_flag);

    /* Print the RPS processing levels.  */
    printf("OLI RPS processing level:   '%s'", wo_params.oli_rps_proc_level);
    printf("TIRS RPS processing level:  '%s'", wo_params.tirs_rps_proc_level);

    /* Print the characterization options.  */
    printf("Selected characterizations:\n");
    printf("RMS banding (0=no, 1=yes):    %d\n",
           wo_params.rms_banding_flag);
    printf("Stdev banding (0=no, 1=yes):  %d\n",
           wo_params.stdev_banding_flag);
    printf("Streaking (0=no, 1=yes):      %d\n\n",
           wo_params.streaking_flag);
    printf("Number of contiguous banding detectors: %d\n\n",
           wo_params.num_contiguous_detectors);

    /* Print the output options.  */
    printf("\n\nOUTPUT OPTIONS\n\n");
    printf("Database Trending (0=no, 1=yes):  %d\n",
           wo_params.store_char_in_db);
    printf("Summary Report (0=no, 1=yes):     %d\n", wo_params.report_flag);
    printf("Dump File (0=no, 1=yes):          %d\n", wo_params.dump_flag);
}



void print_omf_params_struct(RPS_NUCHAR_OMF_PARAMS omf_params)
{
    printf("\n\n\n OMF PARAMETERS\n\n");
    printf("Satellite number :\t%d\n", omf_params.satellite_number);
    printf("Source L0R interval name:\t%s\n", omf_params.l0r_filename);
    printf("CPF name:\t%s\n", omf_params.cpf_filename);
    printf("Pixel mask file name:\t%s\n", omf_params.pmask_filename);
}
