#ifndef NONUNIFORMITY_TESTS_H
#define NONUNIFORMITY_TESTS_H

#include "ias_satellite_attributes.h"

#include "cgreen.h"

#include "../char_nonuniformity.h"


                       /* Function prototypes */
void free_summary_report_buffers
(
    RPS_NUCHAR_REPORT_SUMMARY *summary    /* I/O: Report summary
                                             data structure */
);


void free_detector_metrics_buffers
(
    RPS_NUCHAR_METRICS *metrics,   /* I/O:  Metrics data structure */
    int num_scas                   /* I: # of SCAs in the current band */
);


double *initialize_band_metrics
(
    const char *radiance_filename,         /* I: Name of radiance data
                                              file */
    int num_band_detectors,                /* I: # of detectors in the
                                              band */
    int num_contiguous_detectors,          /* I: Total # of contiugous
                                              detectors (used in RMS
                                              and stdev banding
                                              characterization) */
    const char *metrics_calculation_name,  /* I: Name of function to
                                              call to calculate the
                                              desired nonuniformity
                                              metrics */
    double *band_radiance_mean,            /* O: Mean radiance for the
                                              current band */
    double *band_radiance_stdev,           /* O: Standard dev of radiances
                                              in the band */
    int *num_samples,                      /* O: Total # of samples used
                                              to calculate the mean */
    int *invalid_results_flags   /* O: Detector list flagged with
                                              invalid characterization
                                              results */
);


void initialize_metrics_data
(
    int rms_banding_flag,          /* I: RMS characterization flag */
    int stdev_banding_flag,        /* I: Stdev characterization flag */
    int streaking_flag,            /* I: Streaking characterization flag */
    double *band_rms_metrics,      /* I: RMS metrics data buffer */
    double *band_stdev_metrics,    /* I: Stdev metrics data buffer */
    double *band_streaking_metrics,/* I: Streaking metrics data buffer */
    double radiance_mean,          /* I: Mean radiance for all operable
                                      detectors in the current band */
    double radiance_stdev,         /* I: Stdev of operable detector
                                      radiances in the current band */
    int band_number,               /* I: Current 1-based band number */
    int num_scas,                  /* I: # of SCAs in the current band */
    int num_detectors_per_sca,     /* I: # of detectors in an SCA */
    RPS_NUCHAR_METRICS *metrics    /* O: Metrics data structure to
                                      populate */
);


int initialize_summary_report_data_structures
(
    RPS_NUCHAR_WO_PARAMS wo_params,              /* I: Work order
                                                    parameters */
    int rms_banding_flag,                        /* I: Flag indicating
                                                    whether RMS banding
                                                    characterization is
                                                    performed */
    int stdev_banding_flag,                      /* I: Flag indicating
                                                    whether stdev banding
                                                    characterization is
                                                    performed */
    int streaking_flag,                          /* I: Flag indicating
                                                    whether streaking
                                                    characterization is
                                                    performed */
    RPS_NUCHAR_METRICS metrics,                  /* I: Populated metrics
                                                    data structure */
    const RPS_NUCHAR_INVALID_FLAGS *invalid_flags,
                                                 /* I: Characterization
                                                    invalid flags for all
                                                    detectors in the
                                                    current band */
    RPS_NUCHAR_REPORT_SUMMARY *summary           /* O: Populated summary
                                                    report data
                                                    structures */
);


/*                DEBUGGING FUNCTION PROTOYTPES           */
void print_wo_params_struct
(
    RPS_NUCHAR_WO_PARAMS wo_params
);

void print_omf_params_struct
(
    RPS_NUCHAR_OMF_PARAMS omf_params
);


/* Prototypes of functions used to construct the CGREEN unit test suite.
   In all cases, the *suite parameter is an input AND output parameter,
   and represents the entire set of unit tests to be run.

   Without these, the compiler warns about implicit function
   declarations...*/
void nonuniformity_read_parameters_test(TestSuite *suite);
void nonuniformity_determine_radiances_test(TestSuite *suite);
void nonuniformity_calculate_rms_metrics_test(TestSuite *suite);
void nonuniformity_calculate_stdev_metrics_test(TestSuite *suite);
void nonuniformity_calculate_streaking_metrics_test(TestSuite *suite);
void nonuniformity_populate_detector_metrics_test(TestSuite *suite);
void nonuniformity_sca_summary_test(TestSuite *suite);
void nonuniformity_write_header_test(TestSuite *suite);
void nonuniformity_reporting_test(TestSuite *suite);
void nonuniformity_cleanup_test(TestSuite *suite);
void nonuniformity_dbaccess_test(TestSuite *suite);


#endif


