#!/bin/csh -f
#
# Remove data from the database that has been populated by the populate.csh
# script.  The user may specify individual sets of Radiometric Work Order ID's
# or they can have the script remove all of the ID's saved by the populate.csh
# script in the cleanup.ids file.

set idsRWO = ""
set tables = ( \
    BIAS_FRAME_AVERAGES \
    HISTOGRAM_STATISTICS_CAL \
    RADIOMETRIC_WORK_ORDER_COMMON \
    )

# Process the arguments
if ($#argv == 0) then
    goto USAGE
else if (($#argv == 1) && ($argv[1] == "-all")) then
    if (-e cleanup.ids) then
        set idsRWO = `cat cleanup.ids`
    else
        echo "does not exist: cleanup.ids"
        exit 1
    endif
else
    # All of the arguments must be a numeric value representing radiometric work
    # order common IDs.  If the user specifies a non-numeric value we'll get a 0
    # value for the variable "num".
    while ($#argv > 0)
        set num = `echo $argv[1] | awk '{printf "%d",$1}'`
        if (${num} < 1) then
            goto USAGE
        endif
        set idsRWO = (${idsRWO} ${num})
        shift
    end
endif
echo "Removing:"
echo "  ${idsRWO}"
echo ""

rm -f cleanup.log

set errorStatus = 0
foreach table (${tables})
    foreach id (${idsRWO})
        set sql = "DELETE FROM ${table} WHERE RADIOMETRIC_WO_COMMON_ID=${id};"
        echo "${sql}"
        echo "${sql}" | sqlplus ${IAS_DB_L8_OLITIRS} >>& cleanup.log
        if (${status}) then
            echo "ERROR: ${sql}"
            set errorStatus = 1
        endif
    end
end

foreach id (${idsRWO})
    set sql = \
        "DELETE FROM LMD_MISSION WHERE MISSION_DATA_LOCATION='RWOID="${id}"';"
    echo "${sql}"
    echo "${sql}" | sqlplus ${IAS_DB_L8_OLITIRS} >>& cleanup.log
    if (${status}) then
        echo "ERROR: ${sql}"
        set errorStatus = 1
    endif
end

if (${errorStatus}) then
    echo ""
    echo "Errors occurred.  See cleanup.log for more information."
    exit 1
endif

# If all of the data has been removed, remove the file containing the IDs.  You
# must be careful here though, if there are no arguments left in argv you cannot
# put both of these conditions in the same if statement.
if ($#argv == 1) then
    if ($argv[1] == "-all") then
        rm -f cleanup.ids cleanup.year
    endif
endif
exit 0


USAGE:
    echo ""
    echo "cleanup.csh [-all] <n1> <n2> ..."
    echo ""
    echo "    This script will remove a set of shutter collects and histogram"
    echo "    statistics that were populated for testing the bias model"
    echo "    calibration application.  The user may specify any number of"
    echo "    radiometric work order common IDs or use the -all command line"
    echo "    option to remove all test data sets."
    echo ""
    exit 1
