
#ifndef IAS_SHAPE_H
#define IAS_SHAPE_H

/*****************************************************************************
 NAME:  ias_shape.h

 DESCRIPTION:  Provides I/O routines for shapefiles.

 NOTE:  To maintain consistency with Landsat, not all variable names have been
        updated to our coding standards or to reflect a generic shape
        convention.

*****************************************************************************/

typedef enum ias_shape_type
{
   IAS_SHAPE_POLYGON, /* */
   IAS_SHAPE_BOX      /* A box defined by a central point along with
                         height and width dimensions */
} IAS_SHAPE_TYPE;

#define MAX_SHAPE_ID_SIZE 31 /* Maximum string size for shape identifiers */

typedef struct ias_shape
{
    char region_id[MAX_SHAPE_ID_SIZE]; /* Shape identifier */
    IAS_SHAPE_TYPE type;     /* Shape type (e.g., polygon, centered box) */
    unsigned int npts;       /* Number of shape vertices */
    double *lat;             /* Shape vertex latitudes
                                (center latitude for box shape) */
    double *lon;             /* Shape vertex longitudes
                                (center longitude for box shape) */
    unsigned int width;      /* Box width: in pixels */
    unsigned int height;     /* Box height: in pixels */
    struct ias_shape *next;  /* Pointer to next shape in the linked list */
} IAS_SHAPE;

int ias_read_shapefile
(
    const char *filename,  /* I: Shape file name */
    int *number_of_shapes, /* O: Number of shapes */
    IAS_SHAPE **head       /* O: First shape in list */
);

void ias_shape_free
(
    IAS_SHAPE *head /* I: First shape in list */
);

#endif /* IAS_SHAPE_H */

