/***************************************************************************
 NAME:  shapefile_read_test

 PURPOSE:  CGreen unit testing of the ias_read_shapefile routine

 RETURNS:  CGreen status

***************************************************************************/
#include <stdio.h>

#include "ias_const.h"
#include "cgreen.h"

#include "../ias_shape.h"

Ensure test_read_wrs2_038_038_shapefile()
{
    char shapefile_name[] = "wrs2_038_038.shp";
    int status;
    int count;
    IAS_SHAPE *head;

    printf("Testing reading %s ...\n", shapefile_name);

    /* Read the shape file */
    status = ias_read_shapefile(shapefile_name, &count, &head);
    assert_equal(status, SUCCESS);

    assert_equal(count, 1);

    assert_equal(head->type, IAS_SHAPE_POLYGON);
    assert_string_equal(head->region_id, "Region_1");
    assert_equal(head->npts, 4);
    assert_double_equal(head->lat[0], 32.065);
    assert_double_equal(head->lon[0], -114.517);
    assert_double_equal(head->lat[1], 31.950);
    assert_double_equal(head->lon[1], -113.757);
    assert_double_equal(head->lat[2], 31.680);
    assert_double_equal(head->lon[2], -113.831);
    assert_double_equal(head->lat[3], 31.794);
    assert_double_equal(head->lon[3], -114.585);

    /* Free the allocated memory */
    ias_shape_free(head);
}

Ensure test_read_wrs2_039_037_shapefile()
{
    char shapefile_name[] = "wrs2_039_037.shp";
    int status;
    int count;
    IAS_SHAPE *head;

    printf("Testing reading %s ...\n", shapefile_name);

    /* Read the shape file */
    status = ias_read_shapefile(shapefile_name, &count, &head);
    assert_equal(status, SUCCESS);

    assert_equal(count, 2);

    assert_equal(head->type, IAS_SHAPE_BOX);
    assert_string_equal(head->region_id, "SaltonSea");
    assert_string_equal(head->next->region_id, "Region_1");

    assert_equal(head->npts, 1);
    assert_double_equal(head->lat[0], 33.2253);
    assert_double_equal(head->lon[0], -115.8242);
    assert_double_equal(head->width, 17);
    assert_double_equal(head->height, 17);

    /* Free the allocated memory */
    ias_shape_free(head);
}

Ensure test_read_wrs2_043_033_shapefile()
{
    char shapefile_name[] = "wrs2_043_033.shp";
    int status = SUCCESS;
    int count;
    IAS_SHAPE *head;

    printf("Testing reading %s ...\n", shapefile_name);

    /* Read the shape file */
    status = ias_read_shapefile(shapefile_name, &count, &head);
    assert_equal(status, SUCCESS);

    assert_equal(count, 4);

    assert_equal(head->type, IAS_SHAPE_BOX);
    assert_string_equal(head->region_id, "TD4");
    assert_string_equal(head->next->region_id, "TD3");
    assert_string_equal(head->next->next->region_id, "TD2");
    assert_string_equal(head->next->next->next->region_id, "TD1");

    assert_equal(head->npts, 1);
    assert_double_equal(head->width, 17);
    assert_double_equal(head->height, 17);

    /* Free the allocated memory */
    ias_shape_free(head);
}

/*-----------------------------------------------------------------------
           Define a test suite to add to the "master" test suite
-------------------------------------------------------------------------*/
void shapefile_read_test(TestSuite *suite)
{
    add_test(suite, test_read_wrs2_038_038_shapefile);
    add_test(suite, test_read_wrs2_039_037_shapefile);
    add_test(suite, test_read_wrs2_043_033_shapefile);
}

