/***************************************************************************
 NAME:            rad_stability_write_report_test

 PURPOSE:  CGreen unit testing of the rad_stability_write_rpt_data_file
           routines used by the char_rad_stability application

 RETURNS:  CGreen status
***************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>
#include <unistd.h>

#include "ias_miscellaneous.h"
#include "ias_radiometry.h"
#include "cgreen.h"

#include "../char_rad_stability.h"

#include "rad_stability_tests.h"


Ensure test_write_bias_stability_report_file()
{
    char *test_data_path = NULL;
    char reportfile_name[PATH_MAX] = "";
    char l0r_filename[PATH_MAX] = "";
    char wo_params_filename[PATH_MAX] = "";
    char system_command[1000] = "";
    char work_order_id[] = "RST1002";

    FILE *rpt_fptr = NULL;

    const IAS_BAND_ATTRIBUTES *band_attributes = NULL;

    RPS_RADSTABILITY_WO_PARAMS wo_params;
    RPS_RADSTABILITY_OMF_PARAMS omf_params;
    RPS_RADSTABILITY_DNRAD_BAND_SUMMARY band_summary;

    RPS_RADSTABILITY_REPORT_HEADER header_info;

    int status = SUCCESS;
    int sca_index = 0;
    int size;

    printf("Testing creation of summary report file...\n");

    /* Get the test data path */
    test_data_path = getenv("IAS_UNIT_TEST_DATA_DIR");
    assert_true(test_data_path != NULL);
    if (test_data_path == NULL)
    {
        printf("Cannot find test data directory\n");
        return;
    }

    /* Replace the $IAS_UNIT_TEST_DATA_DIR placeholder in the OMF file with
       its actual value */
    size = snprintf(system_command, sizeof(system_command), 
        "sed 's|$IAS_UNIT_TEST_DATA_DIR|%s|' %s_template.omf > %s.omf", 
        test_data_path, work_order_id, work_order_id);
    if ((size < 0) || (size >= sizeof(system_command)))
    {
        assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
        return;
    }
    status = system(system_command);
    assert_equal_with_message(status, 0, "Cannot edit OMF template");
    if (status != 0)
    {
        return;
    }

    /* Rename the template ODL file as the actual ODL file */
    size = snprintf(wo_params_filename, sizeof(wo_params_filename), 
        "%s.odl", work_order_id);
    if ((size < 0) || (size >= sizeof(wo_params_filename)))
    {
        assert_true_with_message(FALSE, "Filename string too short, "
               "it needs %d bytes", size);
        return;
    }
    size = snprintf(system_command, sizeof(system_command), 
        "cp %s_template.odl %s", work_order_id, wo_params_filename);
    if ((size < 0) || (size >= sizeof(system_command)))
    {
        assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
        return;
    }

    status = system(system_command);
    assert_equal_with_message(status, 0, "Cannot rename template "
        "parameter file");
    if (status != 0)
    {
        size = snprintf(system_command, sizeof(system_command), 
                 "rm %s.omf", work_order_id);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }

    /* Get the band attributes */
    band_attributes = ias_sat_attr_get_band_attributes(1);
    if (band_attributes == NULL)
    {
        assert_true_with_message(FALSE, "Cannot obtain IAS band attributes "
            "information");
        size = snprintf(system_command, sizeof(system_command), 
            "rm %s.omf %s.odl", work_order_id, work_order_id);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }

    /* Construct the parameter file name, and get the required parameters */
    memset(&wo_params, 0, sizeof(RPS_RADSTABILITY_WO_PARAMS));
    memset(&omf_params, 0, sizeof(RPS_RADSTABILITY_OMF_PARAMS));
    memset(&header_info, 0, sizeof(RPS_RADSTABILITY_REPORT_HEADER));

    status = get_parameters(wo_params_filename, &wo_params, &omf_params);
    if (status != SUCCESS)
    {
        assert_true_with_message(FALSE, "Cannot obtain IAS band attributes "
            "information");
        size = snprintf(system_command, sizeof(system_command), 
            "rm %s.omf %s.odl", work_order_id, work_order_id);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }

    strcpy(l0r_filename, omf_params.l0r_filename);
    header_info.common_header = ias_misc_initialize_report_header(
        l0r_filename, wo_params.work_order_id,
        "rad_stability_write_report_test");
    if (!header_info.common_header)
    {
        assert_true_with_message(FALSE, "Cannot initialize standard "
            "IAS header information");
        size = snprintf(system_command, sizeof(system_command), 
            "rm %s.omf %s.odl", work_order_id, work_order_id);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }

    /* Update the CPF in the header to reflect what is in the OMF file. */
    ias_misc_set_header_cpf_name(header_info.common_header,
        omf_params.cpf_filename);

    status = ias_misc_initialize_rps_report_header(l0r_filename,
        &header_info.rps_header);
    if (status != SUCCESS)
    {
        assert_true_with_message(FALSE, "Cannot initialize RPS report "
            "sub-header with available test data");
        size = snprintf(system_command, sizeof(system_command), 
            "rm %s.omf %s.odl", work_order_id, work_order_id);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }

    /* Manually gin up some information */
    header_info.rps_header.oli_fpa_window_start_temp  = 205.0;
    header_info.rps_header.oli_fpa_window_stop_temp   = 205.0;
    header_info.rps_header.oli_fpe_chassis_start_temp = 210.0;
    header_info.rps_header.oli_fpe_chassis_stop_temp  = 210.0;
    header_info.rps_header.ms_integration_time = 311;
    header_info.rps_header.pan_integration_time = 155;
    header_info.rps_header.current_detector_select_table = 1;

    /* Set the collection type to "OLI SHUTTER."  The original test data
       initializes the collect type to "SOLAR" as read from the test
       L0R metadata.  The application code has been updated to use the
       string values currently defined in the L0Ra DFCB for the L0R
       interval metadata member collection_type, so from here forward,
       these should be used (unless/until they change for some reason).

       This should be considered a temporary "kludge" until an updated
       L0R test data set using these values can be obtained */
    ias_misc_set_header_collection_type(header_info.common_header,
        IAS_RPS_OLI_SHUTTER_COLLECT);

    /* Set the stability_delta_t and stability_period values in the
       extended header */
    header_info.stability_delta_t = wo_params.stability_delta_t;
    header_info.stability_period =
        header_info.rps_header.acq_datetime.total_time_oli;

    /* Set the RPS processing level for bias stability characterization
       to "0" (indicating 'raw' L0R shutter statistics).*/
    strncpy(header_info.proc_level, RPS_RADSTABILITY_SHUTTER_PROC_LEVEL,
        sizeof(header_info.proc_level));
    header_info.proc_level[sizeof(header_info.proc_level) - 1] = '\0';


    /* Try to create the file */
    size = snprintf(reportfile_name, sizeof(reportfile_name), 
            "%s_test_bias_stability_summary_report.txt", 
            wo_params.work_order_id);
    if ((size < 0) || (size >= sizeof(reportfile_name)))
    {
        assert_true_with_message(FALSE, "Filename string too short, "
               "it needs %d bytes", size);
        return;
    }

    rpt_fptr = fopen(reportfile_name, "w");
    if (rpt_fptr == NULL)
    {
        assert_true_with_message(FALSE, "Cannot create test summary "
            "report %s", reportfile_name);
        ias_misc_free_report_header(header_info.common_header);
        size = snprintf(system_command, sizeof(system_command), 
            "rm %s.omf %s.odl", work_order_id, work_order_id);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }

    /* Write the RPS report header information to the file */
    status = write_header_to_summary_report(header_info, rpt_fptr);
    assert_true(status == SUCCESS);
    if (status != SUCCESS)
    {
        assert_true_with_message(FALSE, "Cannot write header info to "
            "summary report %s", reportfile_name);
        fclose(rpt_fptr);
        remove(reportfile_name);
        ias_misc_free_report_header(header_info.common_header);
        size = snprintf(system_command, sizeof(system_command), 
            "rm %s.omf %s.odl %s", work_order_id, work_order_id, 
            reportfile_name);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }

    /* Initialize the band summary data buffers */
    memset(&band_summary, 0, sizeof(RPS_RADSTABILITY_DNRAD_BAND_SUMMARY));

    band_summary.band_number = band_attributes->band_number;
    strcpy(band_summary.band_name, band_attributes->band_name);
    band_summary.num_scas = band_attributes->scas;

    band_summary.summary_stats = calloc(band_summary.num_scas,
            sizeof(RPS_RADSTABILITY_DNRAD_SCA_SUMMARY_STATS));

    band_summary.siglevel_change = calloc(band_summary.num_scas,
            sizeof(RPS_RADSTABILITY_DNRAD_SCA_SUMMARY_SIGLEVEL_CHANGE));

    if ((band_summary.summary_stats == NULL)
            || (band_summary.siglevel_change == NULL))
    {
        assert_true_with_message(FALSE, "Cannot initialize band summary "
            "data buffers");
        free(band_summary.summary_stats);
        free(band_summary.siglevel_change);
        fclose(rpt_fptr);
        remove(reportfile_name);
        ias_misc_free_report_header(header_info.common_header);
        size = snprintf(system_command, sizeof(system_command), 
            "rm %s.omf %s.odl %s", work_order_id, work_order_id, 
            reportfile_name);
        if ((size < 0) || (size >= sizeof(system_command)))
        {
            assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
            return;
        }
        system(system_command);
        return;
    }


    /* Populate the SCA test data buffers with some values */
    for (sca_index = 0;
         sca_index < band_summary.num_scas;
         sca_index++)
    {
        band_summary.summary_stats[sca_index].sca_number = (sca_index + 1);
        band_summary.siglevel_change[sca_index]
            .sca_number = (sca_index + 1);

        band_summary.summary_stats[sca_index].sca_max_dn   = 400.50;
        band_summary.summary_stats[sca_index].sca_min_dn   = 300.50;
        band_summary.summary_stats[sca_index].sca_mean_dn  = 350.50;
        band_summary.summary_stats[sca_index].sca_stdev_dn = 1.50;

        band_summary.siglevel_change[sca_index].sca_two_sigma_dn
            = 0.857143;
    }

    /* Write the SCA results to the dump file */
    status = write_data_to_summary_report(&band_summary, "BIAS",
        1, header_info.rps_header.acq_datetime.total_time_oli,
        rpt_fptr);
    assert_true(status == SUCCESS);
    if (status != SUCCESS)
    {
        assert_true_with_message(FALSE, "Cannot write results to bias "
           "stability summary report %s", reportfile_name);
    }
 
    /* Clean up */
    fclose(rpt_fptr);
    free(band_summary.summary_stats);
    free(band_summary.siglevel_change);
    ias_misc_free_report_header(header_info.common_header);

    size = snprintf(system_command, sizeof(system_command), 
        "rm %s.odl %s.omf %s", work_order_id, work_order_id, reportfile_name);
    if ((size < 0) || (size >= sizeof(system_command)))
    {
        assert_true_with_message(FALSE, "Command string too short, "
               "it needs %d bytes", size);
        return;
    }
    status = system(system_command);
}




/*-----------------------------------------------------------------------
           Define a test suite to add to the "master" test suite
-------------------------------------------------------------------------*/
void rad_stability_write_report_test(TestSuite *suite)
{
    add_test(suite, test_write_bias_stability_report_file);
}
