#!/bin/csh -f

# This C shell script allows a test program to be run from a remote
# directory.  If specified as a target in the test program's Makefile,
# the program will be run as part of the "make check" command entered at
# command line in the test code source directory

# Get directory locations and name of test to run
set srcdir = $PWD

set testdatadir = $IAS_UNIT_TEST_DATA_DIR/ias_base/rps/rad_stability
if (! -e $testdatadir) then
  echo "Test data directory $testdatadir not found"
  exit 1
endif

set testname = $1
if ("x$testname" == "x") then
  echo "No test specified"
  exit 1
endif
if (! -e $srcdir/$testname) then
  echo "Test program $srcdir/$testname not found"
  exit 1
endif

# Get the next radiometric_wo_common_id
echo "Getting new radiometric WO common ID"
set rad_wo_id =  `$ORACLE_HOME/bin/sqlplus -S $IAS_DB_L8_OLITIRS \
    @get_next_id.sql`

# Put the ID into the loader data file
echo "Loading data for ID $rad_wo_id"
sed -e "s/XXX/$rad_wo_id/" simulated_work_order_common_for_DB.ldr_original > \
    simulated_work_order_common_for_DB.ldr
sed -e "s/XXX/$rad_wo_id/" simulated_hist_stats_for_DB.ldr_original > \
    simulated_hist_stats_for_DB.ldr

# Run SQL Loader with this test data
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0 silent=ALL \
    control=simulated_work_order_common_for_DB.ldr
if ($status != 0) then
  echo "Error loading work order table"
  exit 1
endif
$ORACLE_HOME/bin/sqlldr userid=$IAS_DB_L8_OLITIRS errors=0 silent=ALL \
    control=simulated_hist_stats_for_DB.ldr
if ($status != 0) then
  echo "Error loading histogram statistics table"
  exit 1
endif

# Go to the test data directory and run the test.  Clean out any leftover
# output files before running the test
echo "Executing $srcdir/$testname from $testdatadir"
cd $testdatadir
rm -f *test*stability*dumpfile_B0*txt
rm -f *test*stability_summary_report.txt
$srcdir/$testname

# Exit with the test's exit status
exit $status

