#include <stdio.h>
#include <stdlib.h>
#include "ias_logging.h"
#include "ias_const.h"
#include "cgreen.h"
#include "../tirs_background_response_determination.h"


/***************************************************************************
 NAME:     test_allocate_free_running_sums_buffer

 PURPOSE:  Unit test for allocate_response_data and
           free_background_repsonse_buffer

 RETURNS:  Nothing
****************************************************************************/
Ensure test_allocate_free_running_sums_buffer()
{
    RUNNING_SUMS_DATA ****test_rsd = NULL;
    double test_sum;
    double test_sum_sqr;
    int num_cpfs = 3;
    int num_bands = 3;
    int num_scas = 3;
    int num_detectors = 640;
    int cpf_index;
    int band_index = 1;
    int sca_index = 2;
    int det_index;
    int test_count;


    printf("Testing running sums data buffer processing...\n");

    /* Allocate the data buffer */
    test_rsd = allocate_running_sums_buffer(num_cpfs, num_bands,
        num_scas, num_detectors);
    assert_not_equal_with_message(test_rsd, NULL, "Buffer should have been "
        "allocated");
    if (test_rsd == NULL)
    {
        return;
    }

    /* Make sure everything is initialized to 0 for the selected band and
       SCA indices */
    for (cpf_index = 0; cpf_index < num_cpfs; cpf_index++)
    {
        for (det_index = 0; det_index < num_detectors; det_index++)
        {
            if (test_rsd[cpf_index][band_index][sca_index][det_index].count
                != 0)
            {
                assert_true_with_message(FALSE, "Running sums count "
                    "should be 0 for detector %d in band index %d SCA %d "
                    "for CPF %d", (det_index + 1), band_index,
                    (sca_index + 1), (cpf_index + 1));
            }
            if (test_rsd[cpf_index][band_index][sca_index][det_index].sum
                != 0)
            {
                 assert_true_with_message(FALSE, "Running sums sum should "
                     "be 0 for detector %d in band index %d SCA %d for "
                     "CPF %d", (det_index + 1), band_index, (sca_index + 1),
                     (cpf_index + 1));
            }
            if (test_rsd[cpf_index][band_index][sca_index][det_index].sum_sqr
                != 0)
            {
                 assert_true_with_message(FALSE, "Running sums sum_sqr "
                     "should be 0 for detector %d in band index %d SCA %d "
                     "for CPF %d", (det_index + 1), band_index,
                     (sca_index + 1), (cpf_index + 1));
            }
        }
    }

    /* Try assigning to and reading from this buffer */
    for (cpf_index = 0; cpf_index < num_cpfs; cpf_index++)
    {
        for (det_index = 0; det_index < num_detectors; det_index++)
        {
            test_rsd[cpf_index][band_index][sca_index][det_index].count =
                10000*cpf_index + 1000*band_index + 100*sca_index +
                det_index;
            test_rsd[cpf_index][band_index][sca_index][det_index].sum =
                10100*cpf_index + 1100*band_index + 110*sca_index +
                det_index;
            test_rsd[cpf_index][band_index][sca_index][det_index].sum_sqr =
                10200*cpf_index + 1200*band_index + 120*sca_index +
                det_index;

            test_count = 10000*cpf_index + 1000*band_index + 100*sca_index
                + det_index;
            test_sum = 10100*cpf_index + 1100*band_index + 110*sca_index
                + det_index;
            test_sum_sqr = 10200*cpf_index + 1200*band_index + 120*sca_index
                + det_index;
            if (test_count != test_rsd[cpf_index][band_index][sca_index]
                                      [det_index].count)
            {
               assert_true_with_message(FALSE, "Calculated count %d does "
                   "not equal test count %d for detector %d in band index "
                   "%d SCA %d for CPF %d", test_count,
                   test_rsd[cpf_index][band_index][sca_index][det_index]
                       .count, (det_index + 1), band_index, (sca_index + 1),
                   (cpf_index + 1));
            }
            if (test_sum != test_rsd[cpf_index][band_index][sca_index]
                                    [det_index].sum)
            {
                assert_true_with_message(FALSE, "Calculated sum %lf does "
                    "not equal test sum %lf for detector %d in band index "
                    "%d SCA %d for CPF %d", test_sum,
                    test_rsd[cpf_index][band_index][sca_index][det_index]
                        .sum, (det_index + 1), band_index, (sca_index + 1),
                    (cpf_index + 1));
            }
            if (test_sum_sqr != test_rsd[cpf_index][band_index][sca_index]
                                        [det_index].sum_sqr)
            {
                assert_true_with_message(FALSE, "Calculated sum_sqr %lf "
                    "not equal test sum_sqr %lf for detector %d in band "
                    "index %d SCA %d for CPF %d", test_sum_sqr,
                    test_rsd[cpf_index][band_index][sca_index][det_index]
                        .sum_sqr, (det_index + 1), band_index,
                        (sca_index + 1),
                    (cpf_index + 1));
            }
        }
    }

    /* Free the data buffer */
    free_running_sums_buffer(test_rsd, num_cpfs, num_bands, num_scas);

}   /* END test_allocate_free_running_sums_buffer */



/***************************************************************************
 NAME:     test_allocate_free_response_data_buffer

 PURPOSE:  Unit test for allocate_response_data and
           free_background_repsonse_buffer

 RETURNS:  Nothing
****************************************************************************/
Ensure test_allocate_free_response_data_buffer()
{
   BACKGROUND_RESPONSE_DATA ***response_data = NULL;
   double test_value;
   int num_bands = 3;
   int num_scas = 3;
   int num_detectors = 640;
   int band_index = 2;
   int sca_index = 2;
   int det_index;


   printf("Testing background response data buffer processing...\n");

   response_data = allocate_background_response_buffer(num_bands, num_scas,
       num_detectors);
   assert_not_equal_with_message(response_data, NULL, "Buffer should have "
       "been allocated");
   if (response_data == NULL)
   {
       return;
   }

   /* Test writing to this buffer */
   for (det_index = 0; det_index < num_detectors; det_index++)
   {
       response_data[band_index][sca_index][det_index].mean =
           1000 * band_index + 100 * sca_index + det_index;
       response_data[band_index][sca_index][det_index].stdev =
           0.001 * band_index + 0.01 * sca_index + det_index;
       response_data[band_index][sca_index][det_index].valid_count =
           (det_index + 1);

       /* Test reading from this buffer */
       test_value = 1000 * band_index + 100 * sca_index + det_index;
       if (test_value != response_data[band_index][sca_index][det_index]
          .mean)
       {
           assert_true_with_message(FALSE, "Test value %lf does not equal "
               "buffer value %lf", test_value,
               response_data[band_index][sca_index][det_index].mean);
       }

       test_value = 0.001 * band_index + 0.01 * sca_index + det_index;
       if (test_value != response_data[band_index][sca_index][det_index]
          .stdev)
       {
           assert_true_with_message(FALSE, "Test value %lf does not equal "
               "buffer value %lf", test_value,
               response_data[band_index][sca_index][det_index].stdev);
       }

       if ((det_index + 1) !=
           response_data[band_index][sca_index][det_index].valid_count)
       {
           assert_true_with_message(FALSE,  "Test valid count %d does not "
               "equal buffer value %d", (det_index + 1),
               response_data[band_index][sca_index][det_index].valid_count);
       }
   }

   free_background_response_buffer(response_data, num_bands, num_scas);
}  /* END test_allocate_free_response_data */



int main(int argc, char *argv[])
{
    /* Suppress IAS_LOG_DEBUG messages */
    ias_log_initialize("tirs_background_mem_test");

    /* Check the command line */
    if (argc > 2)
    {
       printf("USAGE:  background_response_mem_test "
           "<name of single test>\n");
       return 1;
    }

    /* Set up the test suite */
    TestSuite *suite = create_test_suite();

    add_test(suite, test_allocate_free_running_sums_buffer);
    add_test(suite, test_allocate_free_response_data_buffer);

    /* Run the test(s) */
    if (argc > 1)
        return run_single_test(suite, argv[1], create_text_reporter());
    else
        return run_test_suite(suite, create_text_reporter());
}
