#!/usr/local/bin/python3
""" Support class and functions for storing the SNR_CHARACTERIZATION queries
    into easy to use numpy arrays
"""
import numpy as np
from ias.log import logger as lg


class SnrCharList():
    """ Lists of queried data from the SNR_CHARACTERIZATION table
        which is arranged by detector
    """
    def __init__(self, rows):
        self.size = len(rows)
        self.band_id = np.empty(self.size, dtype=int)
        self.sca = np.empty(self.size, dtype=int)
        self.det = np.empty(self.size, dtype=int)
        self.signal = np.empty(self.size, dtype=int)
        self.noise = np.empty(self.size, dtype=float)
        self.dark_noise = np.empty(self.size, dtype=float)

        for i in range(len(rows)):
            self.band_id[i] = rows[i][0]
            self.sca[i] = rows[i][1]
            self.det[i] = rows[i][2]
            self.signal[i] = rows[i][3]
            self.noise[i] = rows[i][4]
            self.dark_noise[i] = rows[i][5]


def get_snr_char_stats(db, rad_id, date, band, type, unit_test=None):
    """ Returns SnrCharList object which contains the queried data
        for the input radiometric wo common id
    """
    # Use the dev table if unit test is run
    snr_table = "SNR_CHARACTERIZATION"
    if unit_test:
        snr_table = "DEV_SNR_CHARACTERIZATION"

    query = """Select BAND_ID, SENSOR_CHIP_ASSEMBLY_ID, DETECTOR_ID,
               SIGNAL_LEVEL, NOISE, DARK_NOISE from {0}
               WHERE RADIOMETRIC_WO_COMMON_ID = :RADID
               AND BAND_ID = :BAND
               order by band_id, sensor_chip_assembly_id, detector_id
            """.format(snr_table)

    parameters = {'BAND': str(band), 'RADID': str(rad_id)}
    cursor = db.execute(query, parameters)
    all_rows = cursor.fetchall()
    cursor.close()

    return SnrCharList(all_rows)
