#!/usr/local/bin/python3
""" SNR Trend

    SNR Trend database helper module
"""


def insert_row(db, band_id, snr_at_ltypical, snr_at_lhigh,
               uncertainty_ltypical, uncertainty_lhigh, a, b, uncertainty_a,
               uncertainty_b, number_of_collects, start_date, end_date,
               stdev_ltypical, stdev_lhigh, unit_test=None):
    """ Insert a single row of trending data """

    # Use the DEV table if unit test is being run
    trenddb = "SNR_TREND"
    if unit_test:
        trenddb = "DEV_SNR_TREND"

    query = """ INSERT into {0}
                    (BAND_ID, SNR_AT_LTYPICAL, SNR_AT_LHIGH,
                     UNCERTAINTY_LTYPICAL, UNCERTAINTY_LHIGH,
                     A, B, UNCERTAINTY_A, UNCERTAINTY_B,
                     NUMBER_OF_COLLECTS, START_DATE, END_DATE,
                     STDEV_LTYPICAL, STDEV_LHIGH, VALID)
                VALUES
                    (:BAND_ID, :SNR_AT_LTYPICAL, :SNR_AT_LHIGH,
                     :UNCERTAINTY_LTYPICAL, :UNCERTAINTY_LHIGH,
                     :A, :B, :UNCERTAINTY_A, :UNCERTAINTY_B,
                     :NUMBER_OF_COLLECTS, :START_DATE, :END_DATE,
                     :STDEV_LTYPICAL, :STDEV_LHIGH, :VALID)""".format(trenddb)

    valid = "Y"
    params = {
        "BAND_ID": band_id, "SNR_AT_LTYPICAL": snr_at_ltypical,
        "SNR_AT_LHIGH": snr_at_lhigh,
        "UNCERTAINTY_LTYPICAL": uncertainty_ltypical,
        "UNCERTAINTY_LHIGH": uncertainty_lhigh, "A": a,
        "B": b, "UNCERTAINTY_A": uncertainty_a,
        "UNCERTAINTY_B": uncertainty_b,
        "NUMBER_OF_COLLECTS": number_of_collects,
        "START_DATE": start_date, "END_DATE": end_date,
        "STDEV_LTYPICAL": stdev_ltypical,
        "STDEV_LHIGH": stdev_lhigh, "VALID": valid}

    cursor = db.execute(query, params)
    row_count = cursor.rowcount
    cursor.close()
    if row_count != 1:
        raise Exception("Row was not inserted correctly for band number "
                        "{0}".format(band_id))
