set termout off;
set pagesize 50000;
set linesize 1000;
set echo off;
set feedback off;
set verify off;
set null '-1'
set trimspool on
set tab off;

--input variables:
-- &1 spool output name
-- &2 band number
-- &3 landsat interval id / work order id in Kelly's DB

col relative_gain format A15;
col absolute_gain format A15;
col collection_type format A15;
--col bulb_pair format A15;
--col sca format A5;
--col det format A5;

spool &1;


with dhs as ( -- dark shutter stats
    select radiometric_work_order_common.image_start_time,
		to_char( radiometric_work_order_common.date_acquired, 'yyyy-mm-yy hh24:mi:ss'),
		dark_histogram_statistics.band_id, 
		dark_histogram_statistics.processing_level,
		dark_histogram_statistics.sensor_chip_assembly_id,
		dark_histogram_statistics.detector_id,
		avg(dark_histogram_statistics.scene_pixel_mean) as scene_pixel_mean,
		avg(dark_histogram_statistics.scene_pixel_stdev) as scene_pixel_stdev,
		dark_histogram_statistics.nbr_of_frames as n_frames
	  from radchar.histogram_statistics dark_histogram_statistics,
		radchar.radiometric_work_order_common radiometric_work_order_common
	  where radiometric_work_order_common.radiometric_wo_common_id = dark_histogram_statistics.radiometric_wo_common_id
		AND dark_histogram_statistics.band_id = &2
                AND dark_histogram_statistics.processing_level = '0'
                AND radiometric_work_order_common.radiometric_wo_common_id = 
                   (select max(radiometric_wo_common_id) from radchar.radiometric_work_order_common where collection_type = 'OLI_SHUTTER' AND valid = 'Y' and
                   ((select max(date_acquired) from radchar.radiometric_work_order_common where landsat_interval_id = '&3' and valid = 'Y') - date_acquired) between 0.000001 and 0.002)
	group by radiometric_work_order_common.image_start_time, radiometric_work_order_common.date_acquired, 
		dark_histogram_statistics.band_id, dark_histogram_statistics.processing_level, dark_histogram_statistics.sensor_chip_assembly_id, 
		dark_histogram_statistics.detector_id, dark_histogram_statistics.nbr_of_frames
),
   relgains as ( -- relative gains from cpf
        select to_number(substr(cpfp.name,18,2),'99') as sca_id, 
		relgain_cpf.value_order as detector_id,
		relgain_cpf.value as relative_gain
		FROM cpf.cpf_group_parameter cpfgp
        	INNER JOIN cpf.cpf_parameter_values relgain_cpf
        	ON cpfgp.cpf_group_parameter_id = relgain_cpf.cpf_group_parameter_id
        	INNER JOIN cpf.cpf_parameter cpfp
        	ON cpfgp.cpf_parameter_id = cpfp.cpf_parameter_id
		WHERE cpfp.name LIKE 'Rel_Gains_B0&2%'
        	AND cpfgp.cpf_group_id in (
        	select grp.cpf_group_id 
		from cpf.cpf_main cpf, cpf.cpf_main_group cmg, cpf.cpf_group grp
                 where cpf.file_name = (select max(cpf_name) from radchar.radiometric_work_order_common where landsat_interval_id = '&3' )
                	and grp.name = 'OLI_RELATIVE_GAINS'
                	and cpf.cpf_main_id = cmg.cpf_main_id
                	and cmg.cpf_group_id = grp.cpf_group_id )
),
  absgains as  ( -- absolute gains from cpf
          SELECT cv.value_order as sca_id, cv.value as absolute_gain
		FROM cpf.cpf_group_parameter cpfgp
		INNER JOIN cpf.cpf_parameter_values cv
		ON cpfgp.cpf_group_parameter_id = cv.cpf_group_parameter_id
		INNER JOIN cpf.cpf_parameter cpfp
		ON cpfgp.cpf_parameter_id = cpfp.cpf_parameter_id
		WHERE cpfp.name = 'Gain_B0&2'
		AND cpfgp.cpf_group_id in (
  		select grp.cpf_group_id 
		from cpf.cpf_main cpf, cpf.cpf_main_group cmg, cpf.cpf_group grp
  			where cpf.file_name = (select max(cpf_name) from radchar.radiometric_work_order_common where landsat_interval_id = '&3' )
  			and grp.name = 'OLI_ABSOLUTE_GAINS'
  			and cpf.cpf_main_id = cmg.cpf_main_id
  			and cmg.cpf_group_id = grp.cpf_group_id )
)
select  lamp_response_detector.band_id,
	--to_char(radiometric_work_order_common.date_acquired, 'yyyy/mm/dd hh24:mi:dd'),
	radiometric_work_order_common.date_acquired, 
	radiometric_work_order_common.image_start_time,
	radiometric_work_order_common.collection_type,  
	lamp_response.lamp_pair_id as bulb_pair, 			
	lamp_response_detector.sensor_chip_assembly_id as sca, 
	lamp_response_detector.detector_id as det,
	lamp_response.interval_stop_line - lamp_response.interval_start_line as n_frames, 		
	dhs.n_frames as n_dark_frames,					
	relgains.relative_gain,
	absgains.absolute_gain,								
	lamp_response_detector.mean,
	lamp_response_detector.stdev,
	dhs.scene_pixel_mean as dark_mean,				
	dhs.scene_pixel_stdev as dark_stdev,
	radiometric_work_order_common.image_data_truncation_setting AS TRUNCATION
	--dhs.image_start_time,
	--to_char( dhs.date_acquired, 'yyyy/mm/dd hh24:mi:dd'),
	--radiometric_work_order_common.image_start_time,
	--radiometric_work_order_common.date_acquired-dhs.date_acquired
from
	radchar.radiometric_work_order_common radiometric_work_order_common,
	radchar.lamp_response lamp_response,
	radchar.lamp_response_detector lamp_response_detector,
  	dhs,
  	relgains,
  	absgains
where   radiometric_work_order_common.radiometric_wo_common_id = lamp_response.radiometric_wo_common_id
	AND lamp_response.radiometric_wo_common_id = lamp_response_detector.radiometric_wo_common_id
	AND lamp_response_detector.band_id = &2
	-- join in the dark histogram stats
	AND lamp_response_detector.band_id = dhs.band_id AND lamp_response_detector.sensor_chip_assembly_id = dhs.sensor_chip_assembly_id AND lamp_response_detector.detector_id = dhs.detector_id
	-- join in the relative gains
	AND lamp_response_detector.sensor_chip_assembly_id = relgains.sca_id AND lamp_response_detector.detector_id = relgains.detector_id
	-- join in the absolute gains
	AND lamp_response_detector.sensor_chip_assembly_id = absgains.sca_id
	AND radiometric_work_order_common.landsat_interval_id = '&3'
  	AND ( lamp_response_detector.processing_level = 'CTBL' OR lamp_response_detector.processing_level = '0TBL' )
	AND radiometric_work_order_common.valid = 'Y'
	AND radiometric_work_order_common.image_data_truncation_setting <= &4
order by lamp_response_detector.sensor_chip_assembly_id, 
	lamp_response_detector.detector_id;

spool off;

set echo on;
set verify on;

exit;


