set termout off;
set pagesize 50000;
set linesize 1000;
set echo off;
set feedback off;
set verify off;
set null '-1'
set trimspool on
set tab off;

--input variables:
-- &1 spool output name
-- &2 band number
-- &3 landsat interval id

col relative_gain format A15;
col absolute_gain format A15;
col collection_type format A15;
col diffuser format A10;
--col sca format A10;
--col det format A10;

spool &1;

with dhs as ( -- dark shutter stats
    select dark_histogram_statistics.band_id, dark_histogram_statistics.processing_level,
		dark_histogram_statistics.sensor_chip_assembly_id,
		dark_histogram_statistics.detector_id,
		avg(dark_histogram_statistics.scene_pixel_mean) as scene_pixel_mean,
		avg(dark_histogram_statistics.scene_pixel_stdev) as scene_pixel_stdev,
		avg(dark_histogram_statistics.nbr_of_frames) as n_frames
	  from radchar.histogram_statistics_cal dark_histogram_statistics,
		radchar.radiometric_work_order_common radiometric_work_order_common
	  where radiometric_work_order_common.radiometric_wo_common_id = dark_histogram_statistics.radiometric_wo_common_id
		AND dark_histogram_statistics.band_id = &2
                AND dark_histogram_statistics.processing_level = '0'
                AND radiometric_work_order_common.radiometric_wo_common_id =
                   (select (radiometric_wo_common_id) from radchar.radiometric_work_order_common where collection_type LIKE 'OLI_SHUTTER%' and
			radiometric_work_order_common.work_order_id LIKE '%IS' AND
			 radiometric_work_order_common.integration_time_oli_ms = 3.6 and
			 radiometric_work_order_common.valid = 'Y' and
                   	((select max(date_acquired) from radchar.radiometric_work_order_common where landsat_interval_id = '&3' and valid = 'Y') - date_acquired) between 0 and 0.0030) 
	group by dark_histogram_statistics.band_id, dark_histogram_statistics.processing_level, dark_histogram_statistics.sensor_chip_assembly_id,
		dark_histogram_statistics.detector_id 
),
   relgains as ( -- relative gains from cpf
        select to_number(substr(cpfp.name,18,2),'99') as sca_id, relgain_cpf.value_order as detector_id,
		relgain_cpf.value as relative_gain
		FROM cpf.cpf_group_parameter cpfgp
        	INNER JOIN cpf.cpf_parameter_values relgain_cpf
        	ON cpfgp.cpf_group_parameter_id = relgain_cpf.cpf_group_parameter_id
        	INNER JOIN cpf.cpf_parameter cpfp
        	ON cpfgp.cpf_parameter_id = cpfp.cpf_parameter_id
		WHERE cpfp.name LIKE 'Rel_Gains_B0&2%'
        	AND cpfgp.cpf_group_id in (
        	select grp.cpf_group_id from 
			cpf.cpf_main cpf, cpf.cpf_main_group cmg, cpf.cpf_group grp
                 where cpf.file_name = (select max(cpf_name) from radchar.radiometric_work_order_common where landsat_interval_id = '&3' AND valid = 'Y' AND work_order_id LIKE 'I%' )
                	and grp.name = 'OLI_RELATIVE_GAINS'
                	and cpf.cpf_main_id = cmg.cpf_main_id
                	and cmg.cpf_group_id = grp.cpf_group_id )
),
  absgains as  ( -- absolute gains from cpf
          SELECT cv.value_order as sca_id, cv.value as absolute_gain
		FROM cpf.cpf_group_parameter cpfgp
		INNER JOIN cpf.cpf_parameter_values cv
		ON cpfgp.cpf_group_parameter_id = cv.cpf_group_parameter_id
		INNER JOIN cpf.cpf_parameter cpfp
		ON cpfgp.cpf_parameter_id = cpfp.cpf_parameter_id
		WHERE cpfp.name = 'Gain_B0&2'
		AND cpfgp.cpf_group_id in (
  		select grp.cpf_group_id from cpf.cpf_main cpf, cpf.cpf_main_group cmg, cpf.cpf_group grp
  			where cpf.file_name = (select max(cpf_name) from radchar.radiometric_work_order_common where landsat_interval_id = '&3' AND valid = 'Y' AND work_order_id LIKE 'I%' )
  			and grp.name = 'OLI_ABSOLUTE_GAINS'
  			and cpf.cpf_main_id = cmg.cpf_main_id
  			and cmg.cpf_group_id = grp.cpf_group_id )
)
select  histogram_statistics.band_id,
	radiometric_work_order_common.date_acquired,
	radiometric_work_order_common.image_start_time,
	radiometric_work_order_common.collection_type,  
	--solar_response.diffuser_collect_type as diffuser, 
	--replace( replace( solar_response.diffuser_collect_type, 'PRISTINE', '1' ), 'WORKING', '0') as diffuser,
	decode(solar_response.diffuser_collect_type,'PRISTINE','1','WORKING','0','-1') as diffuser,
	histogram_statistics.sensor_chip_assembly_id as sca, 
	histogram_statistics.detector_id as det,
	histogram_statistics.nbr_of_frames as n_frames,
	dhs.n_frames as n_dark_frames,					
	relgains.relative_gain,
	absgains.absolute_gain,								
	avg(histogram_statistics.scene_pixel_mean) as mean,
	avg(histogram_statistics.scene_pixel_stdev) as stdev,
	dhs.scene_pixel_mean as dark_mean,				
	dhs.scene_pixel_stdev as dark_stdev,
	radiometric_work_order_common.image_data_truncation_setting AS TRUNCATION
from 	radchar.radiometric_work_order_common radiometric_work_order_common,
	radchar.solar_response solar_response,
	radchar.histogram_statistics_cal histogram_statistics,
  	dhs,
  	relgains,
  	absgains
where   radiometric_work_order_common.radiometric_wo_common_id = solar_response.radiometric_wo_common_id
	AND solar_response.radiometric_wo_common_id = histogram_statistics.radiometric_wo_common_id
	AND histogram_statistics.band_id = &2
	-- join in the dark histogram stats
	AND histogram_statistics.band_id = dhs.band_id AND histogram_statistics.sensor_chip_assembly_id = dhs.sensor_chip_assembly_id AND histogram_statistics.detector_id = dhs.detector_id
	-- join in the relative gains
	AND histogram_statistics.sensor_chip_assembly_id = relgains.sca_id AND histogram_statistics.detector_id = relgains.detector_id
	-- join in the absolute gains
	AND histogram_statistics.sensor_chip_assembly_id = absgains.sca_id
  	--AND radiometric_work_order_common.radiometric_wo_common_id = (select max(radiometric_wo_common_id) from radchar.radiometric_work_order_common where 
	AND radiometric_work_order_common.landsat_interval_id = '&3' 
	AND radiometric_work_order_common.valid = 'Y'
  	AND histogram_statistics.processing_level = 'CTBL' 
group by histogram_statistics.band_id, radiometric_work_order_common.date_acquired, radiometric_work_order_common.image_start_time,
        radiometric_work_order_common.collection_type, solar_response.diffuser_collect_type,
        histogram_statistics.sensor_chip_assembly_id, histogram_statistics.detector_id, histogram_statistics.nbr_of_frames,
        dhs.n_frames, 
	relgains.relative_gain, absgains.absolute_gain,
        dhs.scene_pixel_mean, dhs.scene_pixel_stdev,
	radiometric_work_order_common.image_data_truncation_setting
order by histogram_statistics.sensor_chip_assembly_id, 
	histogram_statistics.detector_id;

spool off;

set echo on;
set verify on;

exit;


