#!/usr/local/bin/python3
""" SNR per Band module
"""


class BandSnr():
    """ SNR Object for single band """
    def __init__(self, band_number, data, rad_id):
        self.rad_id = rad_id
        self.band_number = band_number
        self.unc_b = list()
        self.snr_at_ltyp = list()
        self.snr_at_lhigh = list()
        self.a = list()
        self.b = list()
        self.unc_a = list()
        self.rel_unc_a = list()
        self.rel_unc_b = list()
        self.mean = data.mean
        self.sca = data.sca
        self.detector = data.det
        self.n_frames = data.n_frames
        self.n_dark_frames = data.n_dark_frames
        self.stdev = data.stdev
        self.dark_stdev = data.dark_stdev


    def insert_snr_rows(self, my_db, unit_test=None):
        """ Inserts a single band of data into the SNR charactization table

            Exceptions:
                Exception thrown if the number of rows inserted does not match
                    the number of total rows passed in
        """

        # Determine the correct table to use
        snr_tbl = "SNR_CHARACTERIZATION"
        if unit_test:
            snr_tbl = "DEV_SNR_CHARACTERIZATION"
        total_rows = len(self.detector)

        insert_statement = """
            Insert into {0}
                (RADIOMETRIC_WO_COMMON_ID,BAND_ID,SENSOR_CHIP_ASSEMBLY_ID,
                 DETECTOR_ID, SIGNAL_LEVEL,N_FRAMES,N_DARK_FRAMES,A,B,
                 UNCERTAINTY_A,UNCERTAINTY_B,
                 MODELED_SNR_LTYP,MODELED_SNR_LHIGH,
                 SNR_UNCERTAINTY_LTYP, SNR_UNCERTAINTY_LHIGH,NOISE,DARK_NOISE)
            values (:1, :2, :3, :4, :5, :6, :7, :8, :9, :10, :11, :12, :13, :14,
                    :15, :16, :17)""".format(snr_tbl)

        insert_rows = []
        for i in range(total_rows):
            insert_rows.append(
                (int(self.rad_id), int(self.band_number), int(self.sca[i]),
                 int(self.detector[i]), float(self.mean[i]),
                 float(self.n_frames[i]), float(self.n_dark_frames[i]),
                 float(self.a[i]), float(self.b[i]), float(self.unc_a[i]),
                 float(self.unc_b[i]), float(self.snr_at_ltyp[i]),
                 float(self.snr_at_lhigh[i]), float(self.unc_snr_at_ltyp[i]),
                 float(self.unc_snr_at_lhigh[i]), float(self.stdev[i]),
                 float(self.dark_stdev[i])))

        cursor = my_db.get_cursor()
        cursor.prepare(insert_statement)
        ret = cursor.executemany(None, insert_rows)
        rowcount = cursor.rowcount
        cursor.close()
        if rowcount != total_rows:
            raise Exception("Total inserted rows ({0}) does not match actual "
                            "{1}".format(cursor.rowcount, total_rows))
