BEGIN
    BEGIN
        EXECUTE IMMEDIATE 'DROP TABLE DEV_HISTOGRAM_STATISTICS_CAL';
    EXCEPTION WHEN OTHERS THEN
        NULL;
    END;
    BEGIN
        EXECUTE IMMEDIATE 'DROP TABLE DEV_RAD_WORK_ORDER_COMMON';
    EXCEPTION WHEN OTHERS THEN
        NULL;
    END;
    BEGIN
        EXECUTE IMMEDIATE 'DROP TABLE DEV_SNR_CHARACTERIZATION';
    EXCEPTION WHEN OTHERS THEN
        NULL;
    END;
    BEGIN
        EXECUTE IMMEDIATE 'DROP TABLE DEV_SOLAR_RESPONSE';
    EXCEPTION WHEN OTHERS THEN
        NULL;
    END;
    BEGIN
        EXECUTE IMMEDIATE 'DROP TABLE DEV_LAMP_RESPONSE';
    EXCEPTION WHEN OTHERS THEN
        NULL;
    END;
    BEGIN
        EXECUTE IMMEDIATE 'DROP TABLE DEV_LAMP_RESPONSE_DETECTOR';
    EXCEPTION WHEN OTHERS THEN
        NULL;
    END;
    COMMIT;
END;
/
  
CREATE TABLE "DEV_HISTOGRAM_STATISTICS_CAL" 
   ("RADIOMETRIC_WO_COMMON_ID" NUMBER(20,0), 
	"BAND_ID" NUMBER(2,0), 
	"SENSOR_CHIP_ASSEMBLY_ID" NUMBER(2,0), 
	"DETECTOR_ID" NUMBER(4,0), 
	"SCENE_PIXEL_MIN" NUMBER, 
	"SCENE_PIXEL_MAX" NUMBER, 
	"SCENE_PIXEL_STDEV" NUMBER, 
	"SCENE_PIXEL_MEAN" NUMBER, 
	"SCENE_PIXEL_SKEWNESS" NUMBER, 
	"SCENE_PIXEL_KURTOSIS" NUMBER, 
	"NBR_OF_FRAMES" NUMBER, 
	"MEAN_SQUARED_RESPONSE" NUMBER, 
	"PROCESSING_LEVEL" VARCHAR2(20 BYTE), 
	"ADJACENT_CORRELATION" NUMBER, 
	"LINESET" NUMBER(1,0)
   );

  CREATE TABLE "DEV_SNR_CHARACTERIZATION" 
   ("RADIOMETRIC_WO_COMMON_ID" NUMBER(20,0), 
	"BAND_ID" NUMBER(2,0), 
	"SENSOR_CHIP_ASSEMBLY_ID" NUMBER(2,0), 
	"DETECTOR_ID" NUMBER(4,0), 
	"SIGNAL_LEVEL" NUMBER, 
	"N_FRAMES" NUMBER, 
	"N_DARK_FRAMES" NUMBER, 
	"A" NUMBER, 
	"B" NUMBER, 
	"UNCERTAINTY_A" NUMBER, 
	"UNCERTAINTY_B" NUMBER, 
	"MODELED_SNR_LTYP" NUMBER, 
	"MODELED_SNR_LHIGH" NUMBER, 
	"SNR_UNCERTAINTY_LTYP" NUMBER, 
	"SNR_UNCERTAINTY_LHIGH" NUMBER, 
	"NOISE" NUMBER, 
	"DARK_NOISE" NUMBER
   );

  CREATE TABLE "DEV_SOLAR_RESPONSE" 
   (	"RADIOMETRIC_WO_COMMON_ID" NUMBER(20,0), 
	"INTERVAL_START_TIME" DATE, 
	"INTERVAL_STOP_TIME" DATE, 
	"LINES_AVERAGED" NUMBER, 
	"DIFFUSER_COLLECT_TYPE" VARCHAR2(20 BYTE), 
	"DEPLOYMENT_ANGLE" NUMBER, 
	"SOURCE" VARCHAR2(3 BYTE) DEFAULT 'IAS', 
	"INCIDENT_SOLAR_ZENITH_MEAN" NUMBER, 
	"INCIDENT_SOLAR_ZENITH_STDEV" NUMBER, 
	"VIEW_SOLAR_ZENITH_MEAN" NUMBER, 
	"VIEW_SOLAR_ZENITH_STDEV" NUMBER, 
	"VIEW_SOLAR_AZIMUTH_MEAN" NUMBER, 
	"VIEW_SOLAR_AZIMUTH_STDEV" NUMBER
   );

  CREATE TABLE "DEV_RAD_WORK_ORDER_COMMON" 
   (	"RADIOMETRIC_WO_COMMON_ID" NUMBER(20,0), 
	"COLLECTION_TYPE" VARCHAR2(35 BYTE), 
	"CPF_NAME" VARCHAR2(256 BYTE), 
	"DATE_ACQUIRED" DATE, 
	"DATE_PROCESSED" DATE, 
	"OLI_DETECTOR_SELECT_TABLE" NUMBER(3,0), 
	"INTEGRATION_TIME_OLI_MS" NUMBER, 
	"INTEGRATION_TIME_OLI_PAN" NUMBER, 
	"INTEGRATION_TIME_TIRS" NUMBER, 
	"LANDSAT_INTERVAL_ID" VARCHAR2(24 BYTE), 
	"LANDSAT_SCENE_ID" VARCHAR2(21 BYTE), 
	"L0RP_IMAGE_FILE" VARCHAR2(100 BYTE), 
	"PROCESSING_CENTER" VARCHAR2(20 BYTE) DEFAULT 'EROS', 
	"SENSOR_ID" VARCHAR2(8 BYTE), 
	"SOFTWARE_VERSION_IAS" VARCHAR2(15 BYTE), 
	"SOFTWARE_VERSION_IS" VARCHAR2(15 BYTE), 
	"SOFTWARE_VERSION_LPGS" VARCHAR2(15 BYTE), 
	"VALID" VARCHAR2(1 BYTE) DEFAULT 'N', 
	"WORK_ORDER_ID" VARCHAR2(12 BYTE), 
	"IMAGE_START_TIME" NUMBER, 
	"IMAGE_STOP_TIME" NUMBER, 
	"IMAGE_DATA_TRUNCATION_SETTING" NUMBER(1,0), 
	"TIRS_DETECTOR_MAP_ID" NUMBER(10,0), 
	"OLI_DETECTOR_SELECT_TABLE_ID" NUMBER(10,0), 
	"TARGET_WRS_PATH" NUMBER(3,0), 
	"TARGET_WRS_ROW" NUMBER(3,0), 
	"STATION_ID" VARCHAR2(3 BYTE)
   );

  CREATE TABLE "DEV_LAMP_RESPONSE" 
   (	"RADIOMETRIC_WO_COMMON_ID" NUMBER(20,0), 
	"LAMP_PAIR_ID" NUMBER(1,0), 
	"LAMP_ON_TIME" NUMBER, 
	"INTERVAL_START_TIME" NUMBER, 
	"INTERVAL_STOP_TIME" NUMBER, 
	"INTERVAL_START_LINE" NUMBER, 
	"INTERVAL_STOP_LINE" NUMBER, 
	"LAMP_WARMUP_TIME" NUMBER, 
	"LAMP_WARMUP_START_LINE" NUMBER, 
	"LAMP_WARMUP_STOP_LINE" NUMBER
   );

   CREATE TABLE "DEV_LAMP_RESPONSE_DETECTOR" 
   (	"RADIOMETRIC_WO_COMMON_ID" NUMBER(20,0), 
	"BAND_ID" NUMBER(2,0), 
	"SENSOR_CHIP_ASSEMBLY_ID" NUMBER(2,0), 
	"DETECTOR_ID" NUMBER(4,0), 
	"MEAN" NUMBER, 
	"STDEV" NUMBER, 
	"SKEWNESS" NUMBER, 
	"KURTOSIS" NUMBER, 
	"CORRECTED" NUMBER, 
	"PROCESSING_LEVEL" VARCHAR2(20 BYTE)
   );

exit;
