#!/bin/csh -f
#  Create a file that is compatible as an input for create_3q_tables
#  The input file is in the form:
#
#  Input: Comma delimited ASCII input file of the following form:
#       - one line per detector
#       - field 1: ASCII band
#       - fields 2, 3 and 4 are: integer sca, detector and running
#         number of detectors
#       - fields 5 and 6: floating point low and high cutoff points
#       - fields 7, 8 and 9: floating point low coefficients - C0, C1, C2
#       - fields 10, 11 and 12: floating point mid coefficients - C0, C1, C2
#       - fields 13, 14 and 15: floating point high coefficients - C0, C1, C2
#
#  Output: Same as input except the ASCII band is changed to an integer and
#    it's sorted by band number

if ( ${#argv} != 2 ) then
    echo ""
    echo "    Usage: $0 <input file> <output file>"
    echo ""
    exit 1
endif

set ifile = $1
set ofile = $2
set mod = mod_$ifile:t

# Replace ASCII band with integer band number
sed -e 's/^CA,/1,/' -e 's/^B,/2,/' -e 's/^G,/3,/' -e 's/^R,/4,/' \
    -e 's/^NIR,/5,/' -e 's/^1SW,/6,/' -e 's/^2SW,/7,/' -e 's/^P,/8,/' \
    -e 's/^CRS,/9,/' $ifile > temporary

# Extract the individual bands 
sed -n '/^1,/p' temporary > temporary1
sed -n '/^2,/p' temporary > temporary2
sed -n '/^3,/p' temporary > temporary3
sed -n '/^4,/p' temporary > temporary4
sed -n '/^5,/p' temporary > temporary5
sed -n '/^6,/p' temporary > temporary6
sed -n '/^7,/p' temporary > temporary7
sed -n '/^8,/p' temporary > temporary8
sed -n '/^9,/p' temporary > temporary9

# Put them in band number order and add the TIRS 3Q
cat temporary1 temporary2 temporary3 temporary4 temporary5 temporary6 \
    temporary7 temporary8 temporary9 tirs_3q_paramters.txt > $mod
rm temporary*

# Run the tool to create the OLI 3Q file
./create_3q_tables $mod

# The tool creates evaluation_rlut.h5, move it to the desired file name
mv evaluation_rlut.h5 $ofile

# Add the TIRS second linearization group
./import_tirs_2ndlin.csh $ofile

rm $mod config_file
