#!/usr/bin/perl
###############################################################################
# NAME: launch_cpf_service.pl
#
# PURPOSE: This launches the script cpf_server.pl located at
#    IAS_SERVICE_DIR/bin using a random port between 8,000 and 10,000.
#    Should the first attempt see a currently used port, it will try again.
#    In the unlikely event all ports 8-10k inclusive are being used, this script
#    will loop infinitely.
#
# INPUT: path to valid cpf service configuartion file
###############################################################################

# Port that finally launches service
my $port;
my $num_args= $#ARGV + 1; # Hold number of command line arguments
my $cpf_server; # Hold command to start cpf server
my $config; # Config file name passed in via command line
my $status;
if ($num_args != 1)
{
    die "Usage: $0 <config file>\n";
}

$config = $ARGV[0];

# Find an open port between 8k and 10k
$port = 8000 + int(rand(2000));
while (!system("nc -zd $ENV{HOST} $port"))
{
    $port = 8000 + int(rand(2000));
}

# Call service
print "Attempting to start cpf service\n";
$cpf_server = "$ENV{IAS_SERVICE_DIR}/bin/cpf_server.pl "
    . "--config $config "
    . "--override IAS_SERVICE_PORT=$port ";

$status = system($cpf_server);

if ($status != 0)
{
    die "Could not start server at port $port\n";
}
else
{
    print "URL:  http://$ENV{HOST}:$port\n";
    print "Port: $port\n";
}

exit 0;
