#ifndef DFP_LOCAL_H
#define DFP_LOCAL_H

#include <limits.h>
#include "ias_l1g.h"
#include "ias_l0r.h"
#include "dfp_metadata.h"

/* ----------------------------------------------------------------------- */
/* ------------------------- Function Prototypes ------------------------- */
int convert_band
(
    L1GIO *l1g_ptr,                         /* I: L1G image pointer */
    const IAS_L1G_FILE_METADATA *l1g_meta,  /* I: L1G file metadata */
    int band_number,                        /* I: L1G band number to convert
                                                  or 0 if quality band */
    IAS_L1G_BAND_METADATA *band_meta,       /* I: L1G metadata for band */
    char filename[MAX_FILE_LENGTH],         /* O: Filename saved for package */
    DFP_METADATA *dfp_meta                  /* O: Filename added for L1G meta */
);

int create_gtiff
(
    L1GIO *l1g_ptr,                         /* I: L1G image pointer */
    const IAS_L1G_FILE_METADATA *l1g_meta,  /* I: L1G file metadata */
    const char *input_filename,             /* I: L1G band filename to make */
    int band_number,                        /* I: L1G band number converting */
    IAS_L1G_BAND_METADATA *band_meta        /* I: L1G metadata for GeoTIFF */
);

int create_packages
(
    char l1g_file_list[][MAX_FILE_LENGTH],  /* I: L1G product files list */
    int number_l1g_files,                   /* I: Number files in files list */
    DFP_METADATA *dfp_meta                  /* I/O: dfp metadata structure */
);

int read_parameters
(
    const char *parm_file,              /* I: Name of the parameter file */
    DFP_METADATA *dfp_meta,             /* O: Meta for L1G from misc sources */
    IAS_L0R_SCENE_METADATA *l0r_scene_meta,  /* O: For L1G meta file setup */
    IAS_L0R_INTERVAL_METADATA *l0r_int_meta, /* O: For L1G meta file setup */
    int *l0r_meta_available             /* O: Flag indicating if L0R metadata
                                              was successfully retrieved */
);

int write_metadata
(
    const IAS_L0R_SCENE_METADATA *l0r_scene_meta,   /* I: L0R scene meta */
    const IAS_L0R_INTERVAL_METADATA *l0r_int_meta,  /* I: L0R interval meta */
    int l0r_meta_available,                         /* I: Flag */
    const IAS_L1G_FILE_METADATA *l1g_meta,          /* I: L1G file meta */
    const L1G_BAND_METADATA *l1g_band_meta,         /* I: L1G band meta */
    DFP_METADATA *dfp_meta,                         /* I: Misc sources meta */
    const struct tm *curr_time,                     /* I: Current Time */
    int *band_index,                                /* O: control band index */
    char *l1g_meta_filename                         /* O: Metadata filename */
);

int write_product_metadata
(
    const IAS_L0R_SCENE_METADATA *l0r_scene_meta,   /* I: L0R scene meta */
    const IAS_L1G_FILE_METADATA *l1g_meta,          /* I: L1G file meta */
    const L1G_BAND_METADATA *l1g_band_meta,         /* I: L1G band meta */
    DFP_METADATA *dfp_meta,                         /* I: Misc sources meta */
    int band_index                                  /* I: Index of band to */
                                                    /*    use for reported */
                                                    /*    metadata */
);

int build_product_id
(
    const DFP_METADATA *dfp_meta,       /* I: Meta for L1G from misc sources */
    const IAS_L0R_SCENE_METADATA *l0r_scene_meta,  /* I: L0R scene metadata
                                                         structure */
    const IAS_L1G_FILE_METADATA *l1g_meta,   /* I: L1G file meta */
    const struct tm *curr_time,              /* I: Current Time */
    char *product_id       /* O: The Product ID. Provided buffer should be at
                                  least PRODUCT_ID_LENGTH + 1 bytes */
);

const char *determine_l1_basename
(
    const DFP_METADATA *dfp_meta     /* I: Meta for L1G from misc sources */
);

void determine_tier
(
    const DFP_METADATA *dfp_meta, /* I: Meta for L1G from misc sources */
    const IAS_L1G_FILE_METADATA *l1g_meta, /* I: L1G file metadata */
    char *tier                    /* O: The tier determined basd on metadata */
);

/* Functions used to access parameters from the parameter and OMF files */
int get_l0r_package_flag(void);
int get_l1g_product_flag(void);
int get_l1g_package_flag(void);
int get_md5_checksum_flag(void);
int get_include_angle_coeff_file_flag(void);
int get_named_with_prod_id(void);
const int *get_l1g_bands(void);
int get_l1g_nbands(void);
int get_processing_pass(void);
const char *get_l0r_basename(void);
const char *get_l0r_path(void);
const char *get_l1g_input_filename(void);
const char *get_project(void);
const char *get_sun_angle_corrected_l1g_input_filename(void);
const char *get_l1g_output_basename(void);
const char *get_omf_filename(void);
const char *get_quality_band_filename(void);
double get_tier_1_rmse_threshold(void);
int get_satellite(void);
int get_want_directory_synced(void);

#endif
