/****************************************************************************
Name: sync_directory

Purpose: Perform an fsync on the requested directory.  This is an attempt to
    work around an issue in Lustre where a heavy load on the system sometimes
    results in tar commands failing with an error that the files included in
    the tarball changed time stamps during the tarring process.  The theory
    is the Lustre metadata servers are not in sync and this is an attempt to
    force them to synchronize.

Returns:
    SUCCESS/ERROR

****************************************************************************/
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>

#include "ias_const.h"          /* SUCCESS/ERROR definition */
#include "ias_logging.h"
#include "sync_directory.h"

int sync_directory
(
    const char *dir     /* I: Name of the directory to sync */
)
{
    int fd;

    /* Open the directory that will be sync'ed */
    fd = open(dir, O_RDONLY);
    if (fd == -1)
    {
        IAS_LOG_ERROR("Error opening file: %s\n", strerror(errno));
        return ERROR;
    }

    /* Perform the sync call on the directory to force the directory metadata
       to get flushed to disk */
    if (fsync(fd) != 0)
    {
        IAS_LOG_ERROR("Error syncing: %s\n", strerror(errno));
        return ERROR;
    }

    /* Close the directory now that the sync is completed */
    if (close(fd) != 0)
    {
        IAS_LOG_ERROR("Error closing dir: %s\n", strerror(errno));
        return ERROR;
    }

    return SUCCESS;
}
