#ifndef _GCPRESAMPLE_H_
#define _GCPRESAMPLE_H_

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <limits.h>              /* PATH_MAX definition */
#include "ias_const.h"
#include "ias_gcp.h"

/* Local types & defines */
#define GCPLIB_NAME                "GCPLib"
#define TEMP_GCP_DIR               "resampled_gcps"
#define PROJECTION_SOURCE_LENGTH   4

/* Application parameter ODL file parameters */
typedef struct app_parms {
    char work_order_id[IAS_WORKORDER_ID_SIZE]; /* work order ID */
    char img_name[PATH_MAX];     /* Name of input 1G image */
    char gcp_dir[PATH_MAX];      /* GCP chip directory */
    char projection_source[PROJECTION_SOURCE_LENGTH]; /* Source of projection
                                                         either L1G or OMF */
    char omf_filename[PATH_MAX]; /* OMF filename */
    int target_projection;       /* Target projection */
    int utm_zone;                /* UTM zone */
    int use_tarball;             /* Flag that image chips are tarred */
} APP_PARMS;

/* Local functions */
int get_gcpresample_parameters
(
    const char *parm_filename,   /* I: Parameter filename */
    APP_PARMS *parm_data         /* O: Parameters retrieved from 
                                       parameter file or OMF */
);

int resample_gcps
(
    char *img_name,              /* I: L1G image name */
    char *gcp_dir,               /* I: Input GCP directory */ 
    char *projection_source,     /* I: Source of projection (OMF or L1G) */
    int target_projection,       /* I: Target projection from OMF */
    int utm_zone,                /* I: UTM zone from OMF */
    int use_tarball              /* I: Flag to write chips to a tarball */

);

int dump_GCPLib(
    char *in_gcp_filename,       /* I: Input GCPLib file */
    char *out_gcp_filename,      /* I: Output GCPLib file */
    IAS_GCP_RECORD *gcp_lib,     /* I: IAS_GCP_RECORD struct */
    int numgcp                   /* I: Number of GCPs */
);

int resample_chip
(
    IAS_GCP_IMAGE_CHIP_IO *in_chip_io, /* I: Input image chip container */
    IAS_GCP_IMAGE_CHIP_IO *out_chip_io,/* I: Output image chip container */
    int izone,                   /* I: Input UTM Zone */
    int icode,                   /* I: Input projection code */
    double *iparm,               /* I: Input projection parameters */
    int ispheroid,               /* I: Input spheroid code */
    int iunit,                   /* I: Input projection units */
    int ocode,                   /* I: Input projection code */
    int ozone,                   /* I: Output UTM Zone */
    double *oparm,               /* I: Output projection parameters */
    int ospheroid,               /* I: Output spheroid code */
    int ounit,                   /* I: Output projection units */
    IAS_GCP_RECORD *gcp_lib      /* I/O: GCP libarary */
);

#endif
