/***************************************************************************
 NAME:                     find_minmax_elevation

 PURPOSE:      Determines the minimum and maximum elevation from the
               scene-subsetted DEM data

 RETURNS:      Integer status code of SUCCESS or ERROR

****************************************************************************/
#include "ias_logging.h"
#include "ias_const.h"

#include "retrieve_elevation.h"
#include "find_minmax_elevation.h"

#define DMS_DRE_SHORT_MIN_INIT  32765
#define DMS_DRE_SHORT_MAX_INIT -32766

int find_minmax_elevation
(
    const short *dem_data_ptr,    /* I: Pointer to DEM data */
    int   nl,                     /* I: Number of lines in DEM image */
    int   ns,                     /* I: Number of samples in DEM image */
    short *min_elevation,         /* O: Minimum DEM elevation */
    short *max_elevation          /* O: Maximum DEM elevation */
)
{
    int line;                     /* Current line number */
    int sample;                   /* Current sample number */


    /* Initialize min/max starting values */
    short current_max  = DMS_DRE_SHORT_MAX_INIT;
    short current_min  = DMS_DRE_SHORT_MIN_INIT;

    const short *current_line = NULL;  /* Pointer to start of a DEM data
                                          line */

    /* Search the DEM data line-by-line for the min/max elevations */
    for (line = 0; line < nl; line++)
    {
        current_line = &(dem_data_ptr[line * ns]);
        for (sample = 0; sample < ns; sample++)
        {
            current_max
                = IAS_MAX(current_max, current_line[sample]);
            current_min
                = IAS_MIN(current_min, current_line[sample]);
        }
    }

    /* Check to make sure we don't have the same values we started with */
    if ((current_max == DMS_DRE_SHORT_MAX_INIT)
        || (current_min == DMS_DRE_SHORT_MIN_INIT))
    {
        IAS_LOG_ERROR("Final elevation min/max values unchanged from "
                      "pre-search initialization");
        return ERROR;
    }

    /* Save the minimum and maximum elevation values */
    *max_elevation = current_max;
    *min_elevation = current_min;

    /* Done */
    return SUCCESS;
}
