#ifndef GET_PARAMETERS_H
#define GET_PARAMETERS_H

#include <limits.h>              /* PATH_MAX definition */

#include "ias_const.h"

#define MAX_NUM_WO_PARAMS   3
#define MAX_NUM_OMF_PARAMS  7           /* Includes name of DEM file and
                                           elevation range information to be
                                           added during processing */

/* New parameter data structures */
typedef struct dms_dre_wo_params
{
    char work_order_id[IAS_WORKORDER_ID_SIZE]; /* IAS work order ID  */
    char work_order_directory[PATH_MAX];
    char dem_filename[PATH_MAX];
} DMS_DRE_WO_PARAMS;


typedef struct dms_dre_omf_params
{
    /* Scene boundary information (as written to the OMF by
                                   setup_work_order) */
    double upper_left_lat_lon[2];
    double upper_right_lat_lon[2];
    double lower_left_lat_lon[2];
    double lower_right_lat_lon[2];
} DMS_DRE_OMF_PARAMS;


/* Function prototypes */

int get_parameters
(
    const char *parameter_filename,      /* I: Name of WO parameter
                                            file */
    DMS_DRE_WO_PARAMS *wo_params,        /* O: Populated work
                                            parameters */
    DMS_DRE_OMF_PARAMS *omf_params       /* O: Populated OMF
                                            parameters */
);


#endif
