/******************************************************************************
  GPS include file
     this file includes:
       HDF include file
       GPS HDF IO constants and structures
       function prototypes for the IAS HDF IO library
*******************************************************************************/
#ifndef _XXX_HDF_IO_H_
#define _XXX_HDF_IO_H_

#include <string.h>
#include "mfhdf.h"
#include "xxx_const.h"
#include "xxx_structures.h"
#include "xxx_image.h"

#define IMAGE_CLASS "Image"

#define SDS_BAND1       "B10"
#define SDS_BAND2       "B01"
#define SDS_BAND3       "B02"
#define SDS_BAND4       "B03"
#define SDS_BAND5       "B04"
#define SDS_BAND6       "B05"
#define SDS_BAND7       "B06"
#define SDS_BAND8       "B07"
#define SDS_BAND9       "B09"

#define OUTSIDE 99                /* code for a point outside the image   */
#define LINES_TO_BUFFER 2
/* defines the number of lines to buffer at a time for exx_gpyramid. */

#ifndef _AXX_HDF_IO_H_
typedef struct HDFIO {
    int32 file_id;              /* HDF file id                  */
    int32 group_id;             /* HDF group id                 */
    int32 sd_id;                /* HDF SDS interface id         */
    int32 sds_id[NSCA*NBANDS];       /* HDF SDS id per band          */
    char  sds_name[NSCA*NBANDS][STRLEN];/* HDF SDS name per band        */
    char  hdf_dir_name[STRLEN]; /* name of HDF directory file   */
    char  extdir[STRLEN];       /* external file directory      */
    } HDFIO;
#endif

int32 xxx_open_1g_band ( HDFIO *hdfid,     BandNumber bandno);

HDFIO *xxx_open_1g_image ( const char *image_filename, AccessMode access_mode, int  *nbands,
        BandNumber bandno[NBANDS], DataType dtype[NBANDS], int  nl[NBANDS], int  ns[NBANDS]);

int xxx_create_1g_band (
        HDFIO *hdfid,           /* I/O-SDS id for the band added to structure */
        BandNumber bandno,      /* I-Enumerated band number     */
        DataType dtype,         /* I-Data type of the band      */
        int  nl,                /* I-Number of lines for the band*/
        int  ns);               /* I-Number of samples for the band*/

int xxx_close_1g_image ( HDFIO *hdfid);

int xxx_read_1g_image (
        const HDFIO *hdfid,     /* I-HDF IO structure                   */
        BandNumber band,        /* I-ETM+ (enumerated) band number to read*/
        int  sl,                /* I-Line to start reading (0-rel)      */
        int  ss,                /* I-Sample to start reading (0-rel)    */
        int  nl,                /* I-Number of lines to read            */
        int  ns,                /* I-Number of samples to read          */
        int  subsamp,           /* I-Subsampling factor                 */
        void *data);            /* O-Data buffer                        */

void xxx_create_band_name (
    const char *HDF_name,   /* I: HDF name to form band file name from */
    const char *type,       /* I: SDS or FILE name ("SDS" or "FILE")   */
    BandNumber bandno,      /* I: enumerated band number               */
    char *band_name);       /* O: constructed band file name           */

int exx_extract_chip(const char *chip_name, const int chip_size[2], void *chip_buf);

void *xxx_get_elev (
        const char *dem_name,   /* I-name of the dem image file */
        int *dem_nl,            /* O-nl in dem image            */
        int *dem_ns,            /* O-ns in dem image            */
        DataType *dem_dtype);   /* O-data type of dem image     */

int xxx_get_dem
(
    const char *DEM_name,        /* INPUT: name of DEM to read */
    const struct CORNERS *image_corners_ptr, /* INPUT: corners of image */
    int  lines_in_image,         /* INPUT: lines in image */
    int  samples_per_image_line, /* INPUT: samples in an image line */
    double image_pixsize,        /* INPUT: input image pixel size */
    IMAGE *dem_ptr               /* OUTPUT: data read from the DEM file */
);

#endif
