#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>

#include "cgreen.h"

#include "ias_const.h"
#include "ias_logging.h"

#include "../retrieve_elevation.h"
#include "../get_gls_tile_list.h"
#include "../make_gls_tile_name.h"
#include "../get_gtopo30_tile_list.h"
#include "../modulus.h"
#include "../get_parameters.h"

/*
#define DEBUG_PRINT 
*/

Ensure test_get_gls_tile_list()
{
    const char wo_params_basename[] = "I1003.odl";
    char *path = NULL;

    DMS_DRE_WO_PARAMS wo_params;
    DMS_DRE_OMF_PARAMS omf_params;

    char **gls_tile_list = NULL;

    int current_tile;
    int tile;
    int tile_count = 0;
    int status;

    /* Get the path for the test data directory */
    path = getenv("IAS_UNIT_TEST_DATA_DIR");
    if (path == NULL)
    {
        printf("Cannot find test data directory path\n");
        return;
    }


    /* Clean slate */
    memset(&wo_params, 0, sizeof(DMS_DRE_WO_PARAMS));
    memset(&omf_params, 0, sizeof(DMS_DRE_OMF_PARAMS));

    /* Get the WO and OMF parameters */
    status
        = get_parameters(wo_params_basename, &wo_params, &omf_params);
    assert_true(status == SUCCESS);
    if (status != SUCCESS)
    {
        printf("Parameter read failed\n");
        return;
    }

    printf("Now creating GLS tile_list based on OMF lat/lon "
           "coords...\n");

    gls_tile_list = get_gls_tile_list(omf_params.upper_left_lat_lon[0],
                                      omf_params.upper_left_lat_lon[1],
                                      omf_params.lower_right_lat_lon[0],
                                      omf_params.lower_right_lat_lon[1],
                                      &tile_count);
    assert_true(gls_tile_list != NULL);
    if (gls_tile_list == NULL)
    {
        printf("Check get_gls_tile_list() code\n");
        return;
    }
    assert_true(tile_count > 0);
    if (tile_count == 0)
    {
        printf("Check get_gls_tile_list() count\n");
        free(gls_tile_list);
        return;
    }

    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        assert_true(gls_tile_list[current_tile] != NULL);
        if (gls_tile_list[current_tile] == NULL)
        {
            for (tile = 0; tile < current_tile; tile++)
            {
                free(gls_tile_list[tile]);
            }
            printf("Tile name string %d is NULL\n", (current_tile + 1));
            free(gls_tile_list);
            return;
        }
    }

#ifdef DEBUG_PRINT
    printf("Specified scene lat/lon coordinates:\n");
    printf("UL:  lat=%lf\tlon=%lf\n", omf_params.upper_left_lat_lon[0],
           omf_params.upper_left_lat_lon[1]);
    printf("UR:  lat=%lf\tlon=%lf\n", omf_params.upper_right_lat_lon[0],
           omf_params.upper_right_lat_lon[1]);
    printf("LL:  lat=%lf\tlon=%lf\n", omf_params.lower_left_lat_lon[0],
           omf_params.lower_left_lat_lon[1]);
    printf("LR:  lat=%lf\tlon=%lf\n", omf_params.lower_right_lat_lon[0],
           omf_params.lower_right_lat_lon[1]);
    printf("\n\nTile List\n\n");
    printf("Tile #\t\tTile Name\n");
    printf("-------------------------\n");
    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        printf("Tile %0d\t\t%s\n", (current_tile + 1),
               gls_tile_list[current_tile]);
    }
    printf("\n\n");
#endif

    /* Clean up */
    for (tile = 0; tile < tile_count; tile++)
    {
        free(gls_tile_list[tile]);
    }
    free(gls_tile_list);
}

Ensure test_get_gls_tile_list_180()
{
    const char wo_params_basename[] = "I1004.odl";
    char *path = NULL;

    DMS_DRE_WO_PARAMS wo_params;
    DMS_DRE_OMF_PARAMS omf_params;

    char **gls_tile_list = NULL;

    int current_tile;
    int tile;
    int tile_count = 0;
    int status;

    /* Get the path for the test data directory */
    path = getenv("IAS_UNIT_TEST_DATA_DIR");
    if (path == NULL)
    {
        printf("Cannot find test data directory path\n");
        return;
    }


    /* Clean slate */
    memset(&wo_params, 0, sizeof(DMS_DRE_WO_PARAMS));
    memset(&omf_params, 0, sizeof(DMS_DRE_OMF_PARAMS));

    /* Get the WO and OMF parameters */
    status
        = get_parameters(wo_params_basename, &wo_params, &omf_params);
    assert_true(status == SUCCESS);
    if (status != SUCCESS)
    {
        printf("Parameter read failed\n");
        return;
    }

    printf("Now creating GLS tile_list based on OMF lat/lon "
           "coords...\n");

    gls_tile_list = get_gls_tile_list(omf_params.upper_left_lat_lon[0],
                                      omf_params.upper_left_lat_lon[1],
                                      omf_params.lower_right_lat_lon[0],
                                      omf_params.lower_right_lat_lon[1],
                                      &tile_count);
    assert_true(gls_tile_list != NULL);
    if (gls_tile_list == NULL)
    {
        printf("Check get_gls_tile_list() code\n");
        return;
    }
    assert_true(tile_count > 0);
    if (tile_count == 0)
    {
        printf("Check get_gls_tile_list() count\n");
        free(gls_tile_list);
        return;
    }

    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        assert_true(gls_tile_list[current_tile] != NULL);
        if (gls_tile_list[current_tile] == NULL)
        {
            for (tile = 0; tile < current_tile; tile++)
            {
                free(gls_tile_list[tile]);
            }
            printf("Tile name string %d is NULL\n", (current_tile + 1));
            free(gls_tile_list);
            return;
        }
    }

    /* we should have gotten ten tiles for this test */
    assert_equal(strcmp("s19e177",gls_tile_list[0]),0);
    assert_equal(strcmp("s19e178",gls_tile_list[1]),0);
    assert_equal(strcmp("s19e179",gls_tile_list[2]),0);
    assert_equal(strcmp("s19w180",gls_tile_list[3]),0);
    assert_equal(strcmp("s19w179",gls_tile_list[4]),0);
    assert_equal(strcmp("s20e177",gls_tile_list[5]),0);
    assert_equal(strcmp("s20e178",gls_tile_list[6]),0);
    assert_equal(strcmp("s20e179",gls_tile_list[7]),0);
    assert_equal(strcmp("s20w180",gls_tile_list[8]),0);
    assert_equal(strcmp("s20w179",gls_tile_list[9]),0);

#ifdef DEBUG_PRINT
    printf("Specified scene lat/lon coordinates:\n");
    printf("UL:  lat=%lf\tlon=%lf\n", omf_params.upper_left_lat_lon[0],
           omf_params.upper_left_lat_lon[1]);
    printf("UR:  lat=%lf\tlon=%lf\n", omf_params.upper_right_lat_lon[0],
           omf_params.upper_right_lat_lon[1]);
    printf("LL:  lat=%lf\tlon=%lf\n", omf_params.lower_left_lat_lon[0],
           omf_params.lower_left_lat_lon[1]);
    printf("LR:  lat=%lf\tlon=%lf\n", omf_params.lower_right_lat_lon[0],
           omf_params.lower_right_lat_lon[1]);
    printf("\n\nTile List\n\n");
    printf("Tile #\t\tTile Name\n");
    printf("-------------------------\n");
    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        printf("Tile %0d\t\t%s\n", (current_tile + 1),
               gls_tile_list[current_tile]);
    }
    printf("\n\n");
#endif

    /* Clean up */
    for (tile = 0; tile < tile_count; tile++)
    {
        free(gls_tile_list[tile]);
    }
    free(gls_tile_list);
}



Ensure test_get_gtopo30_tile_list()
{
    const char wo_params_basename[] = "I1003.odl";

    char *path = NULL;


    DMS_DRE_WO_PARAMS wo_params;
    DMS_DRE_OMF_PARAMS omf_params;

    char **gtopo30_tile_list = NULL;

    int current_tile;
    int tile;
    int tile_count = 0;
    int status;

    /* Get the path for the test data directory */
    path = getenv("IAS_UNIT_TEST_DATA_DIR");
    if (path == NULL)
    {
        printf("Cannot find test data directory path\n");
        return;
    }

    /* Clean slate */
    memset(&wo_params, 0, sizeof(DMS_DRE_WO_PARAMS));
    memset(&omf_params, 0, sizeof(DMS_DRE_OMF_PARAMS));

    /* Get the WO and OMF parameters */
    status
        = get_parameters(wo_params_basename, &wo_params, &omf_params);
    assert_true(status == SUCCESS);
    if (status != SUCCESS)
    {
        printf("Parameter read failed\n");
        return;
    }

    printf("Now creating GTOPO30 tile_list based on OMF lat/lon "
           "coords...\n");

    gtopo30_tile_list
        = get_gtopo30_tile_list(omf_params.upper_left_lat_lon[0],
                                omf_params.upper_left_lat_lon[1],
                                omf_params.lower_right_lat_lon[0],
                                omf_params.lower_right_lat_lon[1],
                                &tile_count);

    assert_true(gtopo30_tile_list != NULL);
    if (gtopo30_tile_list == NULL)
    {
        printf("Check get_gtopo30_tile_list() code\n");
        return;
    }
    assert_true(tile_count > 0);
    if (tile_count == 0)
    {
        printf("Check get_gtopo30_tile_list() count\n");
        free(gtopo30_tile_list);
        return;
    }

    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        assert_true(gtopo30_tile_list[current_tile] != NULL);
        if (gtopo30_tile_list[current_tile] == NULL)
        {
            for (tile = 0; tile < current_tile; tile++)
            {
                free(gtopo30_tile_list[tile]);
            }
            printf("Tile name string %d is NULL\n",
                   (current_tile + 1));
            free(gtopo30_tile_list);
            return;
        }
    }

#ifdef DEBUG_PRINT
    printf("Specified scene lat/lon coordinates:\n");
    printf("UL:  lat=%lf\tlon=%lf\n", omf_params.upper_left_lat_lon[0],
           omf_params.upper_left_lat_lon[1]);
    printf("UR:  lat=%lf\tlon=%lf\n", omf_params.upper_right_lat_lon[0],
           omf_params.upper_right_lat_lon[1]);
    printf("LL:  lat=%lf\tlon=%lf\n", omf_params.lower_left_lat_lon[0],
           omf_params.lower_left_lat_lon[1]);
    printf("LR:  lat=%lf\tlon=%lf\n", omf_params.lower_right_lat_lon[0],
           omf_params.lower_right_lat_lon[1]);
    printf("\n\nTile List\n\n");
    printf("Tile #\t\tTile Name\n");
    printf("-------------------------\n");
    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        printf("Tile %0d\t\t%s\n", current_tile+1,
               gtopo30_tile_list[current_tile]);
    }
    printf("\n\n");
#endif

    /* Clean up */
    for (tile = 0; tile < tile_count; tile++)
    {
        free(gtopo30_tile_list[tile]);
    }
    free(gtopo30_tile_list);
}


Ensure test_get_gtopo30_tile_list_180()
{
    const char wo_params_basename[] = "I1004.odl";

    char *path = NULL;


    DMS_DRE_WO_PARAMS wo_params;
    DMS_DRE_OMF_PARAMS omf_params;

    char **gtopo30_tile_list = NULL;

    int current_tile;
    int tile;
    int tile_count = 0;
    int status;

    /* Get the path for the test data directory */
    path = getenv("IAS_UNIT_TEST_DATA_DIR");
    if (path == NULL)
    {
        printf("Cannot find test data directory path\n");
        return;
    }

    /* Clean slate */
    memset(&wo_params, 0, sizeof(DMS_DRE_WO_PARAMS));
    memset(&omf_params, 0, sizeof(DMS_DRE_OMF_PARAMS));

    /* Get the WO and OMF parameters */
    status
        = get_parameters(wo_params_basename, &wo_params, &omf_params);
    assert_true(status == SUCCESS);
    if (status != SUCCESS)
    {
        printf("Parameter read failed\n");
        return;
    }

    printf("Now creating GTOPO30 tile_list based on OMF lat/lon coords...\n");

    gtopo30_tile_list
        = get_gtopo30_tile_list(omf_params.upper_left_lat_lon[0],
                                omf_params.upper_left_lat_lon[1],
                                omf_params.lower_right_lat_lon[0],
                                omf_params.lower_right_lat_lon[1],
                                &tile_count);

    assert_true(gtopo30_tile_list != NULL);
    if (gtopo30_tile_list == NULL)
    {
        printf("Check get_gtopo30_tile_list() code\n");
        return;
    }
    assert_true(tile_count > 0);
    if (tile_count == 0)
    {
        printf("Check get_gtopo30_tile_list() count\n");
        free(gtopo30_tile_list);
        return;
    }

    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        assert_true(gtopo30_tile_list[current_tile] != NULL);
        if (gtopo30_tile_list[current_tile] == NULL)
        {
            for (tile = 0; tile < current_tile; tile++)
            {
                free(gtopo30_tile_list[tile]);
            }
            printf("Tile name string %d is NULL\n",
                   (current_tile + 1));
            free(gtopo30_tile_list);
            return;
        }
    }

    /* we should have gotten two tiles for this test */
    assert_equal(strcmp("e140s10",gtopo30_tile_list[0]),0);
    assert_equal(strcmp("w180s10",gtopo30_tile_list[1]),0);

#ifdef DEBUG_PRINT
    printf("Specified scene lat/lon coordinates:\n");
    printf("UL:  lat=%lf\tlon=%lf\n", omf_params.upper_left_lat_lon[0],
           omf_params.upper_left_lat_lon[1]);
    printf("UR:  lat=%lf\tlon=%lf\n", omf_params.upper_right_lat_lon[0],
           omf_params.upper_right_lat_lon[1]);
    printf("LL:  lat=%lf\tlon=%lf\n", omf_params.lower_left_lat_lon[0],
           omf_params.lower_left_lat_lon[1]);
    printf("LR:  lat=%lf\tlon=%lf\n", omf_params.lower_right_lat_lon[0],
           omf_params.lower_right_lat_lon[1]);
    printf("\n\nTile List\n\n");
    printf("Tile #\t\tTile Name\n");
    printf("-------------------------\n");
    for (current_tile = 0; current_tile < tile_count; current_tile++)
    {
        printf("Tile %0d\t\t%s\n", current_tile+1,
               gtopo30_tile_list[current_tile]);
    }
    printf("\n\n");
#endif

    /* Clean up */
    for (tile = 0; tile < tile_count; tile++)
    {
        free(gtopo30_tile_list[tile]);
    }
    free(gtopo30_tile_list);
}



int main(int argc, char *argv[])
{
    /* Set the logging level to IAS_LOG_INFO for the internal
       routines to keep the IAS_LOG_DEBUG messages from printing */
    ias_log_initialize("dre_make_tilelist_test");

    TestSuite *suite = create_test_suite();

    add_test(suite, test_get_gls_tile_list);
    add_test(suite, test_get_gls_tile_list_180);
    add_test(suite, test_get_gtopo30_tile_list);
    add_test(suite, test_get_gtopo30_tile_list_180);

    if (argc > 1)
    {
        return run_single_test(suite, argv[1], create_text_reporter());
    }
    return run_test_suite(suite, create_text_reporter());
}

