/***************************************************************************
 NAME:                     update_omf

 PURPOSE:   Writes to the OMF:
            a.  name of DEM data file (L1G-compatible image data file
                for GTOPO30/GLS data, symbolic link for RAMP data)
            b.  elevation information obtained from the scene-specific
                DEM dataset

 RETURNS:   Integer status code of SUCCESS or ERROR

****************************************************************************/
#include <string.h>

#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "ias_logging.h"
#include "ias_const.h"

#include "retrieve_elevation.h"
#include "update_omf.h"

int update_omf
(
    const char *omf_filename,  /* I: Name of OMF file */
    const char *dem_filename,  /* I: Name of DEM data file
                                  (link for RAMP data) */
    int max_elevation,         /* I: Maximum DEM elevation */
    int min_elevation          /* I: Minimum DEM elevation */
)
{
    int write_count;              
    int write_status;

    /* Set up the parameter table */
    IAS_PARM_DECLARE_TABLE(omf_param_out_table, 3);

    IAS_PARM_ADD_STRING(omf_param_out_table, DEM_FILENAME,
                        "DEM data file", IAS_PARM_REQUIRED,
                        0, NULL, 0, NULL, (char *)dem_filename,
                        sizeof(dem_filename), 0);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, DEM_FILENAME, 1);

    /* Write out the min and max elevation values obtained from the DEM */
    IAS_PARM_MIN_ELEVATION(omf_param_out_table, IAS_PARM_REQUIRED, 0,
        NULL, &min_elevation, sizeof(min_elevation), 1);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, MIN_ELEVATION, 1);

    IAS_PARM_MAX_ELEVATION(omf_param_out_table, IAS_PARM_REQUIRED, 0,
        NULL, &max_elevation, sizeof(max_elevation), 1);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, MAX_ELEVATION, 1);

    /* Write the information to the OMF */
    write_count = IAS_PARM_GET_TABLE_SIZE(omf_param_out_table);
    write_status = ias_parm_update(omf_filename, omf_param_out_table,
                                   write_count);
    if (write_status != SUCCESS)
    {
        IAS_LOG_ERROR("Cannot write DEM filename and/or elevation range "
                      "information to OMF file %s", omf_filename);
        return ERROR;
    }

    /* Done */
    return SUCCESS;
}


