/******************************************************************
Name: assign_cpf_name

Purpose: Renames the CPF on disk to match the name that was found in the 
         CPF file attributes. 

Notes: The CPF is currently a temporary name based on the day/time. The CPF
       name will change from the temporary name to this new file name.

Returns: SUCCESS or ERROR
*******************************************************************/

#include <string.h>
#include <stdlib.h>
#include "setup_work_order.h"
#include "ias_logging.h"

int assign_cpf_name
(
    const char *target_cpf_name,/* I: File name to use for the renamed CPF */
    char *path                  /* I/O: Path to the CPF */
)
{
    /* If the CPF name is different, rename it */
    if (strcmp(path, target_cpf_name) != 0)
    {
        if (strlen(target_cpf_name) >= PATH_MAX)
        {
            long int my_size = (long int) strlen(target_cpf_name);
            IAS_LOG_ERROR(
                "CPF file name exceeds buffer size, requires %lu characters",
                my_size);
            return ERROR;
        }
        IAS_LOG_DEBUG("Rename CPF %s -> %s", path, target_cpf_name);
        if (rename(path, target_cpf_name))
        {
            IAS_LOG_ERROR("Unable to rename CPF %s -> %s", path,
                target_cpf_name);
            return ERROR;
        }

        /* This strcpy() is protected by the if statement above.  If the new
           path is too long, the rename action shouldn't be attempted either. */
        strcpy(path, target_cpf_name);
    }
    return SUCCESS;
}
