/******************************************************************
Name: retreive_utm_zone

Purpose: Retrieve the UTM zone from the database using path and row.

Returns: SUCCESS or ERROR
*******************************************************************/

#include "gctp.h"                      /* For UTM definition */
#include "ias_logging.h"
#include "ias_db.h"
#include "setup_work_order.h"

int retrieve_utm_zone
(
    DSW_DATA *dsw_data,                /* I/O: Parameters and values retrieved 
                                             from parameter file and L0R */
    struct ias_db_connection *db       /* I: Database connection */
)
{
    char sql[82];                      /* Buffer for sql commands */
    char buffer[IAS_SQL_RTN_MSGLEN];   /* Buffer for sql return messages */
    int utm_zone = 0;                  /* UTM zone to return */
    int status = 0;                    /* Status returned from function call */
    struct ias_db_query *query = NULL; /* DB query struct */

    /* Retrieve UTM zone from IAS database using path and row */
    sprintf(sql, "SELECT ZONE_NBR FROM PATH_ROW_TO_UTM_ZONE WHERE "
              "WRS_PATH = %d AND WRS_ROW = %d",
              dsw_data->path, dsw_data->row);

    /* Perform the query */
    query = ias_db_perform_query(db, sql);
    if (!ias_db_query_was_successful(query))
    {
        ias_db_query_get_error_message(query, buffer, sizeof(buffer));
        IAS_LOG_ERROR("DB query to retrieve UTM failed: %s", buffer);
        /* Close the query */
        ias_db_query_close(query);
        query = NULL;
        return ERROR;
    }
    /*  Get the first row returned to get the UTM zone */
    if (ias_db_query_next(query))
    {
        /* A row was returned, so read the UTM zone */
        status = ias_db_query_int_value(query, &utm_zone, 0);
        if (status != SUCCESS)
        {
            IAS_LOG_ERROR("Reading query value");
            /* Close the query */
            ias_db_query_close(query);
            query = NULL;
            return ERROR;
        }
        dsw_data->utm_zone = utm_zone;
    }
    else
    {
        IAS_LOG_ERROR("Cannot locate start of queried record");
        /* Close the query */
        ias_db_query_close(query);
        query = NULL;
        return ERROR;
    }

    /* Close the query */
    ias_db_query_close(query);
    query = NULL;

    return SUCCESS;
}
