#include <dirent.h>
#include <limits.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include "ias_logging.h"
#include "ias_types.h"
#include "ias_l0r.h"
#include "ias_satellite_attributes.h"

typedef struct L0R_Information
{
    L0RIO* l0r_data;
    char l0r_prefix[PATH_MAX];
    char l0r_location[PATH_MAX];
    int read_write_status;
} L0R_Information;


double convert_time
(const uint32_t day,
const uint32_t milliseconds,
const uint16_t microseconds
);

int copy_ancillary_data
(
    L0RIO* l0ra_data, 
    L0RIO* l0rp_data
);

int copy_offsets
(
    L0RIO* l0ra_data, 
    L0RIO* l0rp_data, 
    int band_number,
    const IAS_BAND_ATTRIBUTES* band_attributes
);

int create_l0rp_metadata
(    
    struct L0R_Information l0ra_metadata,
    struct L0R_Information l0rp_metadata,
    int start_line, 
    int stop_line
);

int generate_checksum_file
(
    const char* l0rp_location,
    const char* l0r_prefix
);

int get_file_metadata
(
    L0RIO* l0ra_data, 
    L0RIO* l0rp_data,
    const char* l0rp_location,
    const char* l0rp_prefix
);

int get_interval_metadata
(
    L0RIO* l0ra_data,
    L0RIO* l0rp_data
);

int get_read_write_status(int l0ra);

int get_scene_metadata
(
    L0RIO* l0ra_data,
    L0RIO* l0rp_data,
    int start_line, 
    int stop_line
);

int get_start_stop_lines_from_scene
(
    L0RIO* l0r_data, 
    char* scene_id, 
    int* start_line, 
    int* stop_line
);

char* get_version_number
(
);


int initialize_and_open_metadata_file
(
    struct L0R_Information *struct_l0r_metadata
);


int initialize_l0r_data
(   
    struct L0R_Information *struct_l0r_data
);

int interval_request
(
    const char* l0ra_location, 
    const char* l0rp_location, 
    char* interval_id
);

int subset_band_image_data
(
    L0RIO* l0r_data, 
    L0RIO* l0rp_data, 
    char* interval_id, 
    int start_line, 
    int stop_line,
    int remove_tirs_secondary_bands
);

int subset_by_scene
(
    const char* l0ra_prefix,
    const char* l0rp_prefix,
    const char* l0ra_location,
    const char* l0rp_location,
    char* interval_id, 
    char* scene_id,
    int remove_tirs_secondary_bands
);

int terminate_l0r_access(struct L0R_Information *struct_l0r_data);

int terminate_metadata_access(struct L0R_Information *struct_l0r_data);

void initialize_L0R_information
(
    struct L0R_Information *l0r_info,
    const char* l0r_prefix,
    const char* l0r_location,
    int l0ra
);
