#!/usr/bin/perl -w

# temporary instructions for setting up the environment:
# need to source the setup_db file with a parameter for this to work:
# source oli_dev/setup/setup_db olidev


#  -- tests
#    -- setup some L0R and ODL parameter files for testing
#    -- test conditions of:
#      -- retrieving CPF/BPF based on name and date
#      -- retrieving RLUT name, creating link
#      -- reading OMF for correct L0R filename, scene, path/row, utm, etc
#      -- inserting into RPS/GPS tables

# start by 1 run getting CPF, BPF, RLUT by name
#  next by 1 run getting CPF, BPF, RLUT by date
#  both cases check omf afterward

use strict;
use ias_const;

my $data_dir = "$ENV{IAS_UNIT_TEST_DATA_DIR}";

# "Repoint" the test data directory to a more local directory to ensure
# files don't get read from the cache.  In this case, it should be the
# setup_work_order unit test data directory.
$ENV{'IAS_DATA_DIR'} =
    $ENV{'IAS_UNIT_TEST_DATA_DIR'} . '/ias_base/dms/setup_work_order';

my $parm_file_ref_1 = "testWO_1.odl.ref";
my $parm_file_1 = "testWO_1.odl";
my $parm_file_ref_2 = "testWO_2.odl.ref";
my $parm_file_2 = "testWO_2.odl";
my $parm_file_ref_3 = "testWO_3.odl.ref";
my $parm_file_3 = "testWO_3.odl";
my $parm_file_ref_4 = "testWO_4.odl.ref";
my $parm_file_4 = "testWO_4.odl";
my $parm_file_ref_5 = "testWO_5.odl.ref";
my $parm_file_5 = "testWO_5.odl";
my $omf_file_1 = "WO1234.omf";
my $omf_file_ref_1 = "WO1234.omf.ref";
my $omf_file_2 = "WO5678.omf";
my $omf_file_ref_2 = "WO5678.omf.ref";
my $omf_file_3 = "WO6789.omf";
my $omf_file_ref_3 = "WO6789.omf.ref";
my $omf_file_4 = "WO1011.omf";
my $omf_file_ref_4 = "WO1011_4.omf.ref";
my $omf_file_5 = "WO1012.omf";
my $omf_file_ref_5 = "WO1012.omf.ref";
my $db_dump_file_g1 = "GEOMETRIC_WORK_ORDER_COMMON.db.results";
my $db_dump_file_verify_g1 = "GEOMETRIC_WORK_ORDER_COMMON.db.results.verify";
my $db_dump_file_g2 = "GEOMETRIC_WORK_ORDER_COMMON.db.results2";
my $db_dump_file_verify_g2 = "GEOMETRIC_WORK_ORDER_COMMON.db.results2.verify";
my $db_dump_file_g3 = "GEOMETRIC_WORK_ORDER_COMMON.db.results3";
my $db_dump_file_verify_g3 = "GEOMETRIC_WORK_ORDER_COMMON.db.results3.verify";
my $db_dump_file_g4 = "GEOMETRIC_WORK_ORDER_COMMON.db.results4";
my $db_dump_file_verify_g4 = "GEOMETRIC_WORK_ORDER_COMMON.db.results4.verify";
my $db_dump_file_r1 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results";
my $db_dump_file_verify_r1 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results.verify";
my $db_dump_file_r2 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results2";
my $db_dump_file_verify_r2 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results2.verify";
my $db_dump_file_r3 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results3";
my $db_dump_file_verify_r3 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results3.verify";
my $db_dump_file_r4 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results4";
my $db_dump_file_verify_r4 = "RADIOMETRIC_WORK_ORDER_COMMON.db.results4.verify";
my $db_dump_file_s1 = "SCENES.db.results";
my $db_dump_file_verify_s1 = "SCENES.db.verify";

# clean up old files
unlink ("$omf_file_1");
unlink ("$omf_file_2");
unlink ("$omf_file_3");
unlink ("$omf_file_4");
unlink ("$omf_file_5");

# Running this test requires access to the database.  If the environment
# variable ENABLE_DB_TESTS is not defined, skip this test and return a
# successful status.
if (!defined $ENV{ENABLE_DB_TESTS})
{
    print "\n";
    print __FILE__ . ": Tests not performed, database tests are disabled.\n";
    print "\n";
    exit SUCCESS;
}

# cleanup the DB before exiting
system ("./update_schema.sh 1");

# make parameter files usable, inserting test data directory
system ("cp", $parm_file_ref_1, $parm_file_1);
system ("cp", $parm_file_ref_2, $parm_file_2);
system ("cp", $parm_file_ref_3, $parm_file_3);
system ("cp", $parm_file_ref_4, $parm_file_4);
system ("cp", $parm_file_ref_5, $parm_file_5);

# escape the backslashes
$data_dir =~ s/\//\\\//g;
my $sed_replace_string = "s/IAS_UNIT_TEST_DATA_DIR/$data_dir/";
# call sed to replace the string with the actual test data directory
system("sed", "-i", $sed_replace_string, $parm_file_1);
system("sed", "-i", $sed_replace_string, $parm_file_2);
system("sed", "-i", $sed_replace_string, $parm_file_3);
system("sed", "-i", $sed_replace_string, $parm_file_4);
system("sed", "-i", $sed_replace_string, $parm_file_5);

# set up the environment for running the application
#  -set $IAS_SERVICES to be the current directory
#  -alter the path so that the local 'wget' script is used instead
#     of the system command.  The local wget script does a simple
#     copy instead of retrieving via http/ftp.
my $test_env = 'PROCESSING_SYSTEM=IAS_LDCM IAS_SERVICES=$PWD PATH=.:${PATH}';

# run the dsw with the first test odl file
$ENV{'IAS_VERSION_OVERRIDE'}='Y'; # Sets the IAS_VERSION to 12.34.56


print "=========================\n";
print "Testing with testWO_1.odl\n";
print "=========================\n";

# Create a zero length CPF named LC08CPF_20090101_20090331_01.03 to make sure
# the retrieval process overwrites it instead of skipping the retrieval
my $rc = system("touch LC08CPF_20090101_20090331_01.03");
if ($rc)
{
    print "Failed touching LC08CPF_20090101_20090331_01.03\n";
    exit FAILURE;
}

$rc = system ("$test_env ../setup_work_order testWO_1.odl");
if ($rc)
{
    print "First setup_work_order call failed\n";
    exit FAILURE;
}
check_and_remove_files("LC08CPF_20090101_20090331_01.03",
    "eval_LO8BPF20110112184351_20110112201351.01",
    "eval_LT8BPF20110112184351_20110112201351.02",
    "L8RLUT20090301_20090331v01.h5");

# run the dsw with the second test odl file
print "=========================\n";
print "Testing with testWO_2.odl\n";
print "=========================\n";
$rc = system ("$test_env ../setup_work_order testWO_2.odl");
if ($rc)
{
    print "Second setup_work_order call failed\n";
    exit FAILURE;
}
check_and_remove_files("eval_LO8BPF20110112184351_20110112201351.02",
    "eval_LT8BPF20110112184351_20110112201351.02",
    "LC08CPF_20000701_20000930_01.01", "L8RLUT20090301_20090331v01.h5");

# run the dsw with the third test odl file
print "=========================\n";
print "Testing with testWO_3.odl\n";
print "=========================\n";
$rc = system ("$test_env ../setup_work_order testWO_3.odl");
if ($rc)
{
    print "Third setup_work_order call failed\n";
    exit FAILURE;
}
check_and_remove_files("eval_LT8BPF20110112184351_20110112201351.01",
    "LC08CPF_20090101_20090331_01.03", "L8RLUT20090301_20090331v01.h5");

# set PROCESSING_SYSTEM to LPGS_LDCM
$test_env = 'PROCESSING_SYSTEM=LPGS_LDCM IAS_SERVICES=$PWD PATH=.:${PATH}';

# run the dsw with the first test odl file with LPGS
print "=========================\n";
print "Testing with testWO_4.odl\n";
print "=========================\n";
$rc = system ("$test_env ../setup_work_order testWO_4.odl");
if ($rc)
{
    print "Fourth setup_work_order call failed\n";
    exit FAILURE;
}
check_and_remove_files("eval_LO8BPF20110112184351_20110112201351.01",
  "eval_LT8BPF20110112184351_20110112201351.02",
  "LC08CPF_20090101_20090331_01.03", "L8RLUT20090301_20090331v01.h5");

# run the dsw test for checking that no records have been inserted into the
# SCENES table
print "=========================\n";
print "Testing with testWO_5.odl\n";
print "=========================\n";
$rc = system ("$test_env ../setup_work_order $parm_file_5");
if ($rc)
{
    print "Fifth setup_work_order call failed\n";
    exit FAILURE;
}
check_and_remove_files("eval_LO8BPF20110112184351_20110112201351.01",
  "eval_LT8BPF20110112184351_20110112201351.02",
  "LC08CPF_20090101_20090331_01.03", "L8RLUT20090301_20090331v01.h5");

# compare omf files.
$rc = system ("diff --brief $omf_file_1 $omf_file_ref_1");
if ($rc != 0)
{
    print "First DSW OMF diff test failed\n";
    # cleanup the DB before exiting
    system ("./update_schema.sh");
    exit FAILURE;
}

$rc = system ("diff --brief $omf_file_2 $omf_file_ref_2");
if ($rc != 0)
{
    print "Second DSW OMF diff test failed\n";
    # cleanup the DB before exiting
    system ("./update_schema.sh");
    exit FAILURE;
}

$rc = system ("diff --brief $omf_file_3 $omf_file_ref_3");
if ($rc != 0)
{
    print "Third DSW OMF diff test failed\n";
    # cleanup the DB before exiting
    system ("./update_schema.sh");
    exit FAILURE;
}

$rc = system ("diff --brief $omf_file_4 $omf_file_ref_4");
if ($rc != 0)
{
    print "Fourth DSW OMF diff test failed\n";
    # cleanup the DB before exiting
    system ("./update_schema.sh");
    exit FAILURE;
}

$rc = system ("diff --brief $omf_file_5 $omf_file_ref_5");
if ($rc != 0)
{
    print "Fifth DSW OMF diff test failed\n";
    # cleanup the DB before exiting
    system ("./update_schema.sh");
    exit FAILURE;
}

print "DSW OMF diffs test passed\n";

# dump the database records
$rc = system ("./dump_schema.sh");
if ($rc != 0)
{
    print "DSW dump schema failed\n";
    # cleanup the DB before exiting
    system ("./update_schema.sh");
    exit FAILURE;
}
print "DSW database dump passed\n";

# delete the database records
$rc = system ("./update_schema.sh");
if ($rc != 0)
{
    print "DSW delete schema failed\n";
    exit FAILURE;
}
print "DSW database cleanup passed\n";

# diff the database records
$rc = system ("diff --brief $db_dump_file_g1 $db_dump_file_verify_g1");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_g1 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_g2 $db_dump_file_verify_g2");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_g2 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_g3 $db_dump_file_verify_g3");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_g3 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_g4 $db_dump_file_verify_g4");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_g4 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_r1 $db_dump_file_verify_r1");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_r1 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_r2 $db_dump_file_verify_r2");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_r2 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_r3 $db_dump_file_verify_r3");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_r3 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_r4 $db_dump_file_verify_r4");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_r4 failed\n";
    exit FAILURE;
}

$rc = system ("diff --brief $db_dump_file_s1 $db_dump_file_verify_s1");
if ($rc != 0)
{
    print "DSW diff $db_dump_file_s1 failed\n";
    exit FAILURE;
}

print "DSW database diffs passed\n";

print "All DSW tests passed\n";

exit SUCCESS;


#############################################################################
# Name: check_and_remove_files
#
# Purpose: Verifies a list of files are present and cleans them up if they are.
#   Exits with an error if any file is missing or zero sized.
# ###########################################################################
sub check_and_remove_files
{
    my @files = @_;

    foreach my $filename (@files)
    {
        if (!(-s $filename))
        {
            print "DSW file: $filename missing or zero bytes in size\n";
            print "DSW file existence test failed\n";
            # cleanup the DB before exiting
            system ("./update_schema.sh");
            exit FAILURE;
        }
    }
    foreach my $filename (@files)
    {
        my $rc = system("/bin/rm $filename");
        if ($rc)
        {
            print "Failed removing $filename\n";
            # cleanup the DB before exiting
            system ("./update_schema.sh");
            exit FAILURE;
        }
    }
}
