#!/usr/bin/perl -w

##############################################################################
#
# This script retrieves the subsetter_interface_state from the sys_parms
# table 
#
# Usage:
#     ./get_subsetter_state
#
#     <db connection info> == typically $IAS_DB_COM
#
# Return:
#       Failure
#       2 - UP
#       3 - DOWN
#       4 - NO_NEW_REQUESTS
#
##############################################################################

use strict;

use Switch;

use ias_const;
use ias_db;

my $dbh;
my $sth;
my $config_filename;

my $db_env_var_value = $ENV{IAS_DB_COM};

my ($userID, $password) = split('/', $db_env_var_value);

# connect to the database
$dbh = ias_db_ConnectToDB($userID, $password);
if (not $dbh)
{
    print "Error connecting to database: $ias_db_error\n";
    exit FAILURE;
}

# prepare the sql
my $sql = "SELECT subsetter_interface_state FROM sys_parms";

$sth = $dbh->prepare($sql);
if (!$sth)
{
    print "Error failed to prepare sql [$sql]: $DBI::errstr\n";
    exit FAILURE;
}

# execute the sql
if (!$sth->execute())
{
    print "Error failed to execute sql [$sql]: $DBI::errstr\n";
    exit FAILURE;
}

my ($subset_inter_state) = $sth->fetchrow_array();

$sth->finish();

# disconnect from the database

if (not ias_db_DisconnectFromDB($dbh, IAS_DB_DISCONNECT_COMMIT))
{
    print "Warning: Failed disconnect from database: $ias_db_error\n";
    exit FAILURE;
}

# return a certain numeric value for the state that was retrieved
switch ($subset_inter_state)
{
    case "UP"
    {
        exit 2;
    }
    case "DOWN"
    {
        exit 3;
    }
    case "NO_NEW_REQUESTS"
    {
        exit 4;
    }
    else
    {
        print "ERROR: Unknown Subsetter Interface State: " .
            $subset_inter_state . "\n";
        exit FAILURE;
    }
}

# terminate the application. If we get to here, then this program failed
exit FAILURE;

