#!/bin/sh

# This test requires the database, so verify that we are doing database tests.
# "crash_test_dummy" ????  What does that mean.....
# It doesn't have to be crash_test_dummy, it can be anything.
# if $ENABLE_DB_TESTS is unset:
#     ${ENABLE_DB_TESTS+crash_test_dummy} expands to NULL
# if $ENABLE_DB_TESTS is set (including set to NULL):
#     ${ENABLE_DB_TESTS+crash_test_dummy} expands to 1
#
if [ ! ${ENABLE_DB_TESTS+crash_test_dummy} ]; then
    # If it isn't defined then issue a warning and exit successfully.
    echo "subsetter_interface testing not performed. Requires database."
    exit 0
fi

# If the IAS/LPGS-specific setup script was sourced, the IAS_SYSTEM_ID
# environment variable will be defined.  It's possible that these scripts
# won't be sourced; if they haven't been the test work order directories
# can't be created, and this script will error out.  If IAS_SYSTEM_ID isn't
# set, default to the IAS system ID.
if [ ! ${IAS_SYSTEM_ID+crash_test_dummy} ]; then
    echo "IAS/LPGS-specific setup not sourced.  Defaulting to IAS."
    export IAS_SYSTEM_ID="I"
fi

# Change to the data directory.
cd data

# Clean up the database to start test.
./delete_schema.sh

# Update all of the loader and scripts with the value of IAS_UNIT_TEST_DATA_DIR.
sed "s!IAS_UNIT_TEST_DATA_DIR!$IAS_UNIT_TEST_DATA_DIR!" \
    SUBSETTER_REQUEST_orig_verify_set_DR.records > \
    SUBSETTER_REQUEST_verify_set_DR.records
sed "s!IAS_UNIT_TEST_DATA_DIR!$IAS_UNIT_TEST_DATA_DIR!" \
    SUBSETTER_REQUEST_orig_verify_set_P.records > \
    SUBSETTER_REQUEST_verify_set_P.records
sed "s!IAS_UNIT_TEST_DATA_DIR!$IAS_UNIT_TEST_DATA_DIR!" \
    SUBSETTER_REQUEST_orig_verify_set_CA.records > \
    SUBSETTER_REQUEST_verify_set_CA.records

sed -e "s!IAS_UNIT_TEST_DATA_DIR!$IAS_UNIT_TEST_DATA_DIR!" \
    -e "s!IAS_WO!$IAS_WO!" \
    WORK_ORDERS_orig_verify_set_DR.records > \
    WORK_ORDERS_verify_set_DR.records
sed -e "s!IAS_UNIT_TEST_DATA_DIR!$IAS_UNIT_TEST_DATA_DIR!" \
    -e "s!IAS_WO!$IAS_WO!" \
    WORK_ORDERS_orig_verify_set_P.records > \
    WORK_ORDERS_verify_set_P.records
sed -e "s!IAS_UNIT_TEST_DATA_DIR!$IAS_UNIT_TEST_DATA_DIR!" \
    -e "s!IAS_WO!$IAS_WO!" \
    WORK_ORDERS_orig_verify_set_CA.records > \
    WORK_ORDERS_verify_set_CA.records

# Retrieve the subsetter interface state to use when quitting the test.  The
# subsetter_interface state will be set back to this upon completion.
./get_subsetter_state.pl
ret=$?

if [ $ret ==  2 ]; then
    state="UP"
elif [ $ret == 3 ]; then
    state="DOWN"
elif [ $ret == 4 ]; then
    state="NO_NEW_REQUESTS"
else
    echo "Retrieving Subsetter Interface State from SYS_PARMS failed."
    ./delete_schema.sh
    exit 1
fi

# Set the subsetter_interface_state row in the sys_parms table to "DOWN"
./update_sys_parms.sh "DOWN"
if [ ! $? == 0 ]; then
    echo "Load database failed."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Load the database with new work orders.
./load_schema_new.sh
if [ ! $? == 0 ]; then
    echo "Load database failed."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change back up to the source directory.
cd ../..

# Put the kill command into the background and let it sleep before executing
# to allow the subsetter_interface some time to work.
(sleep 3; pkill -u $USER -f ./subsetter_interface)&

# Start the subsetter_interface and capture any execution failures.
./subsetter_interface; ecode=$?
if [ ! $ecode == 0 ]; then
    echo "subsetter_interface failed to execute."
    cd tests/data/
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change to the data directory.
cd tests/data

# Dump the work orders table to verify that it has not started
./dump_records.pl dump_records_set_new.cfg
if [ ! $? == 0 ]; then
    echo "Dump database failed for new work orders."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change the subsetter_interface_state to "UP"
./update_sys_parms.sh "UP"
if [ ! $? == 0 ]; then
    echo "Load database failed."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change back up to the source directory.
cd ../..

# Stop and start subsetter interface to give it a chance to pick up the new
# state.
(sleep 3; pkill -u $USER -f ./subsetter_interface)&

# Start the subsetter_interface and capture any execution failures.
./subsetter_interface; ecode=$?
if [ ! $ecode == 0 ]; then
    echo "subsetter_interface failed to execute."
    cd tests/data/
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Dump the database after state is changed to L0r Requested (DR) state.
cd tests/data
./dump_records.pl dump_records_set_DR.cfg
if [ ! $? == 0 ]; then
    echo "Dump database failed for L0r Requested state."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change the subsetter_interface_state to "NO_NEW_REQUESTS"
# This will ensure that the current work orders continue along in this state.
# Later in the test a new work order will be added and tested that it does not
# start.
./update_sys_parms.sh "NO_NEW_REQUESTS"
if [ ! $? == 0 ]; then
    echo "Load database failed."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Update the subsetter request table.  This process is necessary as long as
# the subsetter is not working.  It will move the process along to the next
# step.
./update_records_DR.sh
if [ ! $? == 0 ]; then
    echo "Failed to update the database records."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change back up to the source directory.
cd ../..

# Put the kill command into the background and let it sleep before executing
# to allow the subsetter_interface some time to work.
(sleep 3; pkill -u $USER -f ./subsetter_interface)&

# Start the subsetter_interface and capture any execution failures.
./subsetter_interface; ecode=$?
if [ ! $ecode == 0 ]; then
    echo "subsetter_interface failed to execute."
    cd tests/data/
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Start subsetter interface again.  there are two steps that have to be
# executed before the final pending state.  Not knowing what the polling
# intervals are set to, starting subsetter inteface twice will guarentee that
# both steps will have completed.
# Put the kill command into the background and let it sleep before executing
# to allow the subsetter_interface some time to work.
(sleep 3; pkill -u $USER -f ./subsetter_interface)&

# Start the subsetter_interface and capture any execution failures.
./subsetter_interface; ecode=$?
if [ ! $ecode == 0 ]; then
    echo "subsetter_interface failed to execute."
    cd tests/data/
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Dump the database again.  Work orders should be in the Pending (P)
# state.  They will move from DR to L0R Ready (LR) then changed to P.
cd tests/data
./dump_records.pl dump_records_set_P.cfg
if [ ! $? == 0 ]; then
    echo "Dump database failed for Pending state."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change the states of the D2050* records to Release Abort (RA) and D2051* to
# Release Complete (RC).
./update_records_Rel.sh
if [ ! $? == 0 ]; then
    echo "Failed to update the database records."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Load a work order while the interface is down. This work order will stay in
# the NEW state since the subsetter is in the no new requests state.
./load_records.pl $IAS_DB_COM WORK_ORDERS_pending.records IAS_UNIT_TEST_DATA_DIR
if [ ! $? == 0 ]; then
    echo "Load New WORK_ORDERS failed."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change back up to the source directory.
cd ../..

# Put the kill command into the background and let it sleep before executing
# to allow the subsetter_interface some time to work.
(sleep 6; pkill -u $USER -f ./subsetter_interface)&

# Start the subsetter_interface and capture any execution failures.
./subsetter_interface; ecode=$?
if [ ! $ecode == 0 ]; then
    echo "subsetter_interface failed to execute."
    cd tests/data/
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Dump the database again.  Work orders should be in the Pending (P)
# state.  They will move from DR to L0R Ready (LR) then changed to P.
cd tests/data
./dump_records.pl dump_records_set_CA.cfg
if [ ! $? == 0 ]; then
    echo "Dump database failed for Complete and Abort states."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# get the current date to find in the dump records to substitute the default
# in the date_statused so the diffs will be successful
today=`date '+%d-%h-%y' | tr '[:lower:]' '[:upper:]'`

## Diff the results for the work_orders table.
diff -u WORK_ORDERS_verify_set_DR.records WORK_ORDERS_dumped_set_DR.records
if [ ! $? == 0 ]; then
    echo "WORK_ORDERS table failed difference check for set Data Requested."
    exit 1
fi
rm -f WORK_ORDERS_verify_set_DR.records
rm -f WORK_ORDERS_dumped_set_DR.records

## Diff the results for the subsetter_request table.
diff -u SUBSETTER_REQUEST_verify_set_DR.records \
    SUBSETTER_REQUEST_dumped_set_DR.records
if [ ! $? == 0 ]; then
    echo "SUBSETTER_REQUEST table failed difference check for Data Requested."
    exit 1
fi
rm -f SUBSETTER_REQUEST_verify_set_DR.records
rm -f SUBSETTER_REQUEST_dumped_set_DR.records

# Diff the results for the work_orders table.
diff -u WORK_ORDERS_verify_set_P.records WORK_ORDERS_dumped_set_P.records
if [ ! $? == 0 ]; then
    echo "WORK_ORDERS table failed difference check for Pending state."
    exit 1
fi
rm -f WORK_ORDERS_verify_set_P.records
rm -f WORK_ORDERS_dumped_set_P.records

## Diff the results for the subsetter_request table.
diff -u SUBSETTER_REQUEST_verify_set_P.records \
    SUBSETTER_REQUEST_dumped_set_P.records
if [ ! $? == 0 ]; then
    echo "SUBSETTER_REQUEST table failed difference check for Pending state."
    exit 1
fi
rm -f SUBSETTER_REQUEST_verify_set_P.records
rm -f SUBSETTER_REQUEST_dumped_set_P.records

# Diff the results for the work_orders table.
diff -u WORK_ORDERS_verify_set_CA.records WORK_ORDERS_dumped_set_CA.records
if [ ! $? == 0 ]; then
    echo "WORK_ORDERS table failed difference check for Final state."
    exit 1
fi
rm -f WORK_ORDERS_verify_set_CA.records
rm -f WORK_ORDERS_dumped_set_CA.records

# Diff the results for the subsetter_request table.
diff -u SUBSETTER_REQUEST_verify_set_CA.records \
    SUBSETTER_REQUEST_dumped_set_CA.records
if [ ! $? == 0 ]; then
    echo "SUBSETTER_REQUEST table failed difference check for final state."
    exit 1
fi
rm -f SUBSETTER_REQUEST_verify_set_CA.records
rm -f SUBSETTER_REQUEST_dumped_set_CA.records

# Diff the results for the work_orders table.
diff -u WORK_ORDERS_orig_verify_set_new.records WORK_ORDERS_dumped_set_new.records
if [ ! $? == 0 ]; then
    echo "WORK_ORDERS table failed difference check for new state."
    exit 1
fi
rm -f WORK_ORDERS_dumped_set_new.records

# Diff the results for the subsetter_request table.
diff -u SUBSETTER_REQUEST_orig_verify_set_new.records \
    SUBSETTER_REQUEST_dumped_set_new.records
if [ ! $? == 0 ]; then
    echo "SUBSETTER_REQUEST table failed difference check for new state."
    exit 1
fi
rm -f SUBSETTER_REQUEST_dumped_set_new.records

# Delete the records from the database.
./delete_schema.sh

################# Local Work Order ###############
# Enter a local work order.  The work order will automatically be set to
# release abort (RA) or release complete (RC).  The subsetter interface 
# will move the state from RA to abort (A) and from RA to complete (C).

# Load the database with new work orders.
./load_schema_local.sh
if [ ! $? == 0 ]; then
    echo "Load database failed."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Change back up to the source directory.
cd ../..

# Put the kill command into the background and let it sleep before executing
# to allow the subsetter_interface some time to work.
(sleep 3; pkill -u $USER -f ./subsetter_interface)&

# Start the subsetter_interface and capture any execution failures.
./subsetter_interface; ecode=$?
if [ ! $ecode == 0 ]; then
    echo "subsetter_interface failed to execute."
    cd tests/data/
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

# Dump the database again.  Work orders should be in the Pending (P)
# state.  They will move from DR to L0R Ready (LR).  Ingest will be called and
# then changed to P.
cd tests/data
./dump_records.pl dump_records_set_local.cfg
if [ ! $? == 0 ]; then
    echo "Dump database failed for the local scene."
    ./update_sys_parms.sh $state
    ./delete_schema.sh
    exit 1
fi

## Diff the results for the subsetter_request table.
diff -u WORK_ORDERS_orig_verify_set_local.records \
    WORK_ORDERS_dumped_set_local.records
if [ ! $? == 0 ]; then
    echo "Work orders table with local l0r failed difference check."
    exit 1
fi
rm -f WORK_ORDERS_dumped_set_local.records

# Testing complete
# ----------------
# Return subsetter_interface state to the original value.  
./update_sys_parms.sh $state

# Delete the test data from the database and disk.
./delete_schema.sh

exit 0
