#ifndef _ANCILLARY_DATA_PREPROCESSOR_H_
#define _ANCILLARY_DATA_PREPROCESSOR_H_

#include <limits.h>

#include "ias_math.h"
#include "ias_l0r.h"
#include "ias_cpf.h"

/* OMF, CPF, L0R ancillary data, and parameter file data */
typedef struct adp_data 
{
    char work_order_id[IAS_WORKORDER_ID_SIZE]; /* Uniquely identifies the
                                                  work order */
    int characterization_flag;       /* Characterization on/off switch */
    char omf_filename[PATH_MAX];     /* OMF filename */
    char anc_filename[PATH_MAX];     /* ancillary filename */
    char cpf_filename[PATH_MAX];     /* CPF filename */
    char l0r_filename[PATH_MAX];     /* L0R product location */
    int number_of_attitude_points;   /* Number of attitude points */
    double attitude_start_time[3];   /* Attitude start time (year, DOY, SOD) */
    int number_of_bad_attitude_points;  /* Number of bad attitude points */
    int number_ephemeris_points;     /* Number ephemeris points */
    double ephemeris_start_time[3];  /* Ephemeris start time (year, DOY, SOD) */
    int number_of_bad_ephemeris_points; /* Number of bad ephemeris points */
    double image_start_time[3];      /* Image start time (year, DOY, SOD) */
    double image_stop_time[3];       /* Image stop time (year, DOY, SOD) */
    IAS_ACQUISITION_TYPE acquisition_type; /* image acquisition type */
    IAS_SATELLITE_ID satellite_id;  
} ADP_DATA;


/* Local functions */
int read_parameters
(
    const char *parm_filename, /* I: Parameter filename */
    ADP_DATA *adp_data         /* O: Parameters retrieved from parameter file,
                                     OMF, and CPF */
);

int read_l0r
(
    const char *l0r_filename,           /* I: Name of the L0R file */
    const IAS_MATH_LEAP_SECONDS_DATA *leap_seconds_data, /* I: Leap seconds */
    IAS_L0R_EPHEMERIS **ephemeris_data, /* O: Pointer to ephemeris data
                                              structure */
    IAS_L0R_ATTITUDE **attitude_data,   /* O: Pointer to attitude data
                                              structure */
    IAS_L0R_IMU **l0r_imu,              /* O: Pointer to IRU data structure */
    int *ephemeris_size,                /* O: Number of ephemeris records */
    int *attitude_size,                 /* O: Number of attitude records */
    int *imu_size,                      /* O: Number of IMU records */
    ADP_DATA *adp_data                  /* O: Parameters retrieved from 
                                              parameter file and L0R */
);

int insert_characterization_data
(
    const ADP_DATA *adp_data   /* I: Parameters retrieved from parameter file,
                                     OMF, and CPF */
);

#endif /* _ANCILLARY_DATA_PREPROCESSOR_H_ */

