#!/bin/sh

# This script takes the "dump_XXXXXX.sql" sql script and creates a copy of it
# which has been updated for a particular table.  The script is then ran
# through sqlplus to generate a loader file for the specified table.  The
# temporary files created during this process are then removed.  A log file
# is generated in the current directory.

PWD=`pwd`
LOG="$PWD/dump_schema.log"
DB="$IAS_DB_L8_OLITIRS"

VER="_$1"
if [ "$1" == "" ]; then
    VER="";
fi

# Initialize the log file.
DATE=`date`
echo "Created $DATE" 2>&1 > $LOG

today=`echo \`date +%d-%b-%y\` | tr a-z A-Z`

# Process the tables.
echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Dumping DB Results ------------------------------------" 2>&1 >> $LOG
sqlplus $DB @dump_db.sql 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Dump GEOMETRIC_WORK_ORDER_COMMON failed."
    exit 1
fi
rm YYYYYY.sql 2>&1 >> $LOG
sed 's/^\([0-9]\+\)|/99999|/' GEOMETRIC_WORK_ORDER_COMMON.db.results > tmp.db
mv tmp.db GEOMETRIC_WORK_ORDER_COMMON.db.results

sed "s/$today/01-JAN-10/g" GEOMETRIC_WORK_ORDER_COMMON.db.results > tmp.db
mv tmp.db GEOMETRIC_WORK_ORDER_COMMON.db.results

sed 's/^\([0-9]\+\)|/99999|/' MODEL_GENERATION.db.results > tmp.db
mv tmp.db MODEL_GENERATION.db.results

echo "."
echo "" 2>&1 >> $LOG
DATE=`date`
echo "Completed - $0 - $DATE" 2>&1 >> $LOG

exit 0

