
#ifndef _B2B_CHAR_H_
#define _B2B_CHAR_H_

#include "ias_l1g.h"                /* L1G I/O library               */
#include "ias_gcp.h"                /* GCP library                   */
#include "ias_grid_io.h"            /* Grid I/O library              */
#include "ias_math_parallel_corr.h" /* Parallel correlator           */

#define REDUCE_FILE "REDUCE.img"  /* Name of downsampled file */

enum TIEPT_TYPE {REGULAR_SPACED, GRID_BASED}; /* Tiepoint type choices */

#define OLI_NORMAL_PIXEL_RESOLUTION 30.0 /* non-PAN OLI bands */
#define OLI_PAN_PIXEL_RESOLUTION 15.0    /* PAN OLI band */

/* Prototype definitions for the B2B_CHAR routines.  */
int b2b_corr 
(
    IAS_GCP_RECORD *sca_gcp[IAS_MAX_NSCAS], /* I: Array of GCP points for
                                        30m band resolution                  */
    const int *numgcps,           /* I: Number of GCPs                       */
    const const char *l1g_img_name, /* I: Name of 1G image                   */
    const const char *l0r_img_name, /* I: Name of 0R image                   */
    const int *band_indexes,      /* I: Bands indexes for the correlation    */
    const int nbands,             /* I: Number of band indexes               */
    const IAS_L1G_BAND_METADATA band_metadata[IAS_MAX_NBANDS],
                                  /* I: Array of band data                   */
    const int sca_indexes[IAS_MAX_NSCAS], /* I: SCA indexes to search        */
    const int nscas,              /* I: Number of SCA indexes                */
    const char *output_filename,  /* I: Name of output data file             */
    const float min_corr,         /* I: Minimum correlation strength         */
    const float max_disp,         /* I: Maximum correlation displacement     */
    const IAS_CORRELATION_FIT_TYPE fit_method, /* I: Correlation result fit 
                                        method                               */
    const int abs_corr_coeff,     /* I: flag to use abs value the correlation
                                        coefficients in grey correlation     */
    const float invalid_threshold,/* I: Invalid threshold percentage for 
                                        buffer                               */
    const float valid_image_max,  /* I: DNs above this are invalid           */
    const float valid_image_min,  /* I: DNs below this are invalid           */
    const char *work_order_id     /* I: Work Order ID for report header      */
);

int grid_det_tiepts
(
    const IAS_L1G_BAND_METADATA *band_metadata, /* I: band data              */
    const int nline_pts,          /* I: Number of line tiepoints to create   */
    const int nsamp_pts,          /* I: Number of sample tiepoints to create */
    const struct IAS_LNG_LS *chip_size, /* I: Chip size of the tiepoints to 
                                        create                               */
    const int sca_index,          /* I: SCA index                            */
    const int band_index,         /* I: band index                           */
    const IAS_GRID_TYPE *grid,    /* I: OLI grid structure                   */
    int *numgcps,                 /* O: Number of GCPs                       */
    IAS_GCP_RECORD *gcps          /* O: GCP structure                        */
);

int compare_metadata
(
    const char *l1g_filename,     /* I: L1G filename                          */
    const int *band_indexes,      /* I: Array of band indexes                 */
    const int nbands,             /* I: Number of bands in band index array   */
    IAS_L1G_BAND_METADATA band_metadata[IAS_MAX_NBANDS], /* O: Array of band 
                                        data                                  */
    int *nl,                      /* O: Number of lines                       */
    int *ns                       /* O: Number of samples                     */
);

int create_tiepts_grid
(
    const int *band_indexes,    /* I: Band indexes                          */
    const int nbands,           /* I: Number of band indexes                */
    const int sca_indexes[IAS_MAX_NSCAS], /* I: SCA indexes to search       */
    const int nscas,            /* I: Number of SCA indexes                 */
    const IAS_L1G_BAND_METADATA band_metadata[IAS_MAX_NBANDS], /* I: Array 
                                      of band data                          */
    const int nline_pts,        /* I: Number of line tiepoints to create    */
    const int nsamp_pts,        /* I: Number of sample tiepoints to create  */
    struct IAS_LNG_LS chip_size, /* I: Chip size of the tiepoints to create */
    const char *grid_filename,  /* I: Name of grid file to read             */ 
    int pan_band_index,         /* I: Index of the PAN band                 */
    int *num_gcps,              /* O: Number of GCPs per SCA                */
    IAS_GCP_RECORD *sca_gcp[IAS_MAX_NSCAS] /* O: Array of GCPLib tiepoints 
                                      in row-major form for 30m band 
                                      resolutions                           */
);

int create_tiepts 
(
    const int *band_indexes,    /* I: Band indexes                          */
    const int nbands,           /* I: Number of bands                       */
    const IAS_L1G_BAND_METADATA band_metadata[IAS_MAX_NBANDS], /* I: Array 
                                      of band data                          */
    const int nl,               /* I: Number of lines                       */
    const int ns,               /* I: Number of samples                     */
    const int nline_pts,        /* I: Number of line tiepoints to create    */
    const int nsamp_pts,        /* I: Number of sample tiepoints to create  */
    const struct IAS_LNG_LS chip_size, /* I: Chip size of the tiepoints to 
                                      create                                */
    int pan_band_index,         /* I: Index of the PAN band                 */
    IAS_GCP_RECORD **gcp30      /* O: Array of GCPLib tiepoints in row-major
                                      form for 30m band resolutions         */
);

int det_tiepts 
(
    const IAS_L1G_BAND_METADATA *band_metadata, /* I: band data             */
    const int nl,                     /* I: Number of lines                 */
    const int ns,                     /* I: Number of samples               */
    const int nline_pts,              /* I: Number of line tiepoints to 
                                            create                          */
    const int nsamp_pts,              /* I: Number of sample tiepoints to 
                                            create                          */
    const struct IAS_LNG_LS *chip_size, /* I: Chip size of tiepoints to 
                                            create                          */
    IAS_GCP_RECORD *gcps              /* O: Array of GCPLib tiepoints in 
                                            row-major format                */
);

int downsample 
(
    const char *in_name,   /* I: Original image                           */
    const int band_indexes[IAS_MAX_NBANDS], /* Band indexes               */
    const int nbands       /* I: Number of bands                          */

);

int get_parms 
(
    const char *param_filename,   /* I: Parameter file name                   */
    char *file_name_1G,           /* O: file name for the 1G image            */
    char *file_name_0R,           /* O: file name for the 0R image            */
    char *output_file_name,       /* O: Name of the output file               */
    char *grid_file_name,         /* O: Grid file name                        */
    char *cpf_file_name,          /* O: CPF file name                         */
    int *reduce_flag,             /* O: Flag to indicate reduced image should 
                                        be created                            */
    int band_indexes[IAS_MAX_NBANDS], /* O: Band indexes                      */
    int *nbands,                  /* O: Number of band indexes                */
    int sca_indexes[IAS_MAX_NSCAS], /* O: SCA indexes to search               */
    int *nscas,                   /* O: Number of SCA indexes                 */
    int *nline_pts,               /* O: Number of line tiepoints              */
    int *nsamp_pts,               /* O: Number of samp tiepoints              */
    struct IAS_LNG_LS *chip_size, /* O: Height and width of the chips         */
    enum TIEPT_TYPE *tiept_type,  /* O: Type of tiepts to use.                */
    float *min_corr,              /* O: Minimum correlation strength          */
    float *max_disp,              /* O: Maximum correlation displacement      */
    float *range,                 /* O: Range of valid pixels                 */
    float *threshold,             /* O: Percentage of valid pixels            */
    IAS_CORRELATION_FIT_TYPE *fit_method, /* O: Correlation result fit method */
    int *abs_corr_coeff,          /* O: Flag to use abs value of correlation 
                                        coefficients in grey correlation      */
    char *wo_id,                  /* O: Work order ID string                  */
    char *omf_file_name           /* O: omf file name                         */
);

int process_gcp 
(
    const IAS_GCP_RECORD *gcp_lib,/* I: List of GCPs                       */
    const int numgcps,            /* I: Number of GCPs                     */
    L1GIO *ref_img_ptr1,          /* I: Reference 1G image pointer         */
    L1GIO *srch_img_ptr1,         /* I: Search 1G image pointer            */
    const int ref_band_index,     /* I: Reference band index               */
    const int srch_band_index,    /* I: Search band index                  */
    const int sca_index,          /* I: SCA index to extract imagery from  */
    const IAS_DATA_TYPE ref_dtype,/* I: Data type of reference image       */
    const IAS_DATA_TYPE srch_dtype,/* I: Data type of search image         */
    const int nl,                 /* I: Number of lines in both images     */
    const int ns,                 /* I: Number of samples in both images   */
    const float min_corr,         /* I: Minimum correlation strength       */
    const float max_disp,         /* I: Maximum correlation displacement   */
    const IAS_CORRELATION_FIT_TYPE fit_method, /* I: Correlation result fit 
                                        method                             */
    IAS_GCP_RESULTS *gcp,         /* O: GCP data structures (1 per pt)
                                        for the correlation results        */
    const int abs_corr_coeff,     /* I: flag to use the value for correlation 
                                        coefficients in grey correlation   */
    const float invalid_threshold,/* I: Invalid threshold percentage for 
                                        buffer                             */
    const float valid_image_max,  /* I: DNs above this are invalid         */
    const float valid_image_min,  /* I: DNs below this are invalid         */
    IAS_PARALLEL_CORRELATOR_TYPE *correlator_ptr, /* I: Pointer to the
                                        parallel correlator structure      */
    IAS_CORRELATION_RESULT_TYPE *result_ptr /* O: Pointer to the
                                        correlation results                */
);

int read_metadata 
(
    const char *l1g_filename,    /* I: L1G file name                         */
    const int *band_indexes,     /* I: Array of band indexes to read         */
    const int nbands,            /* I: Number of bands in band index array   */
    IAS_L1G_FILE_METADATA *file_metadata, /* O: file metadata                */
    IAS_L1G_BAND_METADATA band_metadata[IAS_MAX_NBANDS], /* O: Array of band 
                                        data                                 */
    int *nl,                      /* O: Number of lines                      */
    int *ns                       /* O: Number of samples                    */
);

int reduce 
(
    const char *in_name,   /* I: Original image                          */
    const char *out_name,  /* I: Output image name                       */
    const int band_index,  /* I: index of band to process                */
    const int down_scale,  /* I: Scaling of imagery                      */
    const double *weights, /* I: A value for kernel weight construction  */
    const int number_of_weights  /* I: Size of convolving function       */
);

int get_output_ls
(
    const IAS_GRID_BAND_TYPE *grid_band_ptr,  /* I: grid info for a band */
    const double elev,                        /* I: elevation            */
    const double iline,                       /* I: line of input image  */
    const double isamp,                       /* I: samp of input image  */
    double *oline,                            /* O: line of output image */
    double *osamp);                           /* O: samp of output image */

int update_omf
(
    char *omf_file_name,        /* I: omf file name */
    char *output_file_name      /* I: b2bchar output file name */
);

#endif

