/******************************************************************************
NAME:           update_omf

PURPOSE:
Update the omf file with the output file name.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

NOTES:

ALGORITHM REFERENCES:
******************************************************************************/
#include <stdlib.h>
#include <string.h>
#include "b2b_char.h"
#include "ias_parm.h"                      /* parameter library */
#include "ias_parm_standard_parameters.h"  /* parameter table standard fields */

int update_omf
(
   char *omf_file_name,           /* I: work order id to build omf file name */
   char *output_file_name         /* I: b2bchar output file name */
)
{

    char local_output_file_name[PATH_MAX];

    strncpy(local_output_file_name, output_file_name, 
            sizeof(local_output_file_name));

    /* update the omf file with the output file name */

    IAS_PARM_DECLARE_TABLE(omf_update_parms, 1);

    IAS_PARM_B2B_CHAR_OUTPUT_FILENAME(omf_update_parms, local_output_file_name,
       sizeof(local_output_file_name), 1);

    IAS_PARM_SET_COUNT_WRITE(omf_update_parms, B2B_CHAR_OUTPUT_FILENAME, 1);

    if (ias_parm_update(omf_file_name, omf_update_parms, 1) != SUCCESS)
    {
        IAS_LOG_ERROR("Updating omf file with output file name");
        return ERROR;
    }

    return SUCCESS;
}
