#ifndef RESIDUALS_STATS_H
#define RESIDUALS_STATS_H

typedef struct
{
    double mean;             /* Mean value */
    double sum;              /* Sum */
    double sum_sqr_err;      /* Sum error of squares */
    double rmse;             /* Root mean squared value */
    double stdev;            /* Standard deviation */
} STATS_TYPE;

/* Holds the pre and post fit residual statistics information */
typedef struct
{
    int points;              /* Number of points used to generate statistics */
    STATS_TYPE pre_fit_x;    /* X (sample) */
    STATS_TYPE pre_fit_y;    /* Y (line) */
    STATS_TYPE post_fit_x;   /* X (sample) */
    STATS_TYPE post_fit_y;   /* Y (line) */
} FIT_RESIDUAL_STATS_TYPE;

/* Structure to hold offsets between the search and reference locations
   between two bands */
typedef struct RESIDUALS_PNTS
{
   int point_id;             /* Point ID */
   int sca_number;           /* SCA number */
   int ref_band;             /* Reference band */
   int search_band;          /* Search band */
   double ref_output_samp;   /* Reference output sample location */
   double ref_output_line;   /* Reference output line location */
   double ref_input_samp;    /* Reference input sample location */
   double ref_input_line;    /* Reference input line location */
   double search_input_samp; /* Search input sample location */
   double search_input_line; /* Search input line location */
   double dy;                /* Measured offset in line direction */
   double dx;                /* Measured offset in sample direction */
   double pre_los_err_line;  /* Pre-fit LOS error in line direction */
   double pre_los_err_samp;  /* Pre-fit LOS error in sample direction */
   double post_los_err_line; /* Post-fit LOS error in line direction */
   double post_los_err_samp; /* Post-fit LOS error in sample direction */
} RESIDUALS_PNTS;

#endif
