#ifndef SAVE_TO_DATABASE_H
#define SAVE_TO_DATABASE_H

#include "ias_const.h"
#include "ias_satellite_attributes.h" /* Used for IAS_MAX_NBANDS and 
                                         IAS_MAX_NSCAS */

/* Define a structure for the information to be collected and inserted into
   the BAND_CALIBRATION table */
typedef struct MAIN_DB_SAVE_INFO
{
    char wo_id[IAS_WORKORDER_ID_SIZE]; /* This one isn't in the database */
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    int nbr_of_legendre_coefficients;
} MAIN_DB_SAVE_INFO;

/* Define a structure for the information to be collected and inserted into
   table BAND_CALIBRATION_BAND_SCA table */
typedef struct BAND_SCA_DB_SAVE_INFO
{
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    int band_id[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    int sensor_chip_assembly_id[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    int nbr_of_pnts_used[IAS_MAX_NBANDS * IAS_MAX_NSCAS];

    double upds_alng_trk_leg_poly_0[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double upds_alng_trk_leg_poly_1[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double upds_alng_trk_leg_poly_2[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double upds_alng_trk_leg_poly_3[IAS_MAX_NBANDS * IAS_MAX_NSCAS];

    double upds_acrss_trk_leg_poly_0[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double upds_acrss_trk_leg_poly_1[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double upds_acrss_trk_leg_poly_2[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double upds_acrss_trk_leg_poly_3[IAS_MAX_NBANDS * IAS_MAX_NSCAS];

    double new_alng_trk_leg_poly_0[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double new_alng_trk_leg_poly_1[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double new_alng_trk_leg_poly_2[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double new_alng_trk_leg_poly_3[IAS_MAX_NBANDS * IAS_MAX_NSCAS];

    double new_acrss_trk_leg_poly_0[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double new_acrss_trk_leg_poly_1[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double new_acrss_trk_leg_poly_2[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
    double new_acrss_trk_leg_poly_3[IAS_MAX_NBANDS * IAS_MAX_NSCAS];
} BAND_SCA_DB_SAVE_INFO;

/* Define a structure for the information to be collected and inserted into
   table BAND_CAL_PREPST_FIT_DETAIL table */
typedef struct PRE_POST_FIT_DB_SAVE_INFO
{
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    int sensor_chip_assembly_id[IAS_MAX_NSCAS];
    double pre_fit_res_alng_trk_mean[IAS_MAX_NSCAS];
    double pre_fit_res_alng_trk_std_dev[IAS_MAX_NSCAS];
    double pre_fit_res_alng_trk_rmse[IAS_MAX_NSCAS];
    double pre_fit_res_acrss_trk_mean[IAS_MAX_NSCAS];
    double pre_fit_res_acrss_trk_std_dev[IAS_MAX_NSCAS];
    double pre_fit_res_acrss_trk_rmse[IAS_MAX_NSCAS];
    double pst_fit_res_alng_trk_mean[IAS_MAX_NSCAS];
    double pst_fit_res_alng_trk_std_dev[IAS_MAX_NSCAS];
    double pst_fit_res_alng_trk_rmse[IAS_MAX_NSCAS];
    double pst_fit_res_acrss_trk_mean[IAS_MAX_NSCAS];
    double pst_fit_res_acrss_trk_std_dev[IAS_MAX_NSCAS];
    double pst_fit_res_acrss_trk_rmse[IAS_MAX_NSCAS];
} PRE_POST_FIT_DB_SAVE_INFO;

int save_to_database
(
    struct MAIN_DB_SAVE_INFO *main_db_save, /* I/O: Main table data */
    struct BAND_SCA_DB_SAVE_INFO *band_sca_db_save, /* I/O: Band/SCA level 
                                      table data */
    int num_band_sca_db_records, /* I: The number of band/SCA DB records */
    struct PRE_POST_FIT_DB_SAVE_INFO *pre_post_fit_db_save, /* I/O: Pre and
                                      post fit table data */
    int num_pre_post_fit_db_records /* I: The number of pre/post fit DB 
                                      records */
);

#endif
