/* Standard Library Includes */
#include <string.h>

/* IAS Library Includes */
#include "ias_logging.h"
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"

/* Local Includes */
#include "create_angle_bands.h"

/***************************************************************************
 NAME:                     update_omf

 PURPOSE:   Writes the generated sun angle filename to the OMF
 
 RETURNS:   SUCCESS or ERROR

****************************************************************************/
int update_omf
(
    const char *omf_filename,       /* I: Name of OMF */
    char *sun_angle_filename,       /* I: Sun Angle filename */
    int processing_pass             /* I: Number of WO processing flow pass */
)
{
    /* Set up the parameter table */
    IAS_PARM_DECLARE_TABLE(omf_param_out_table, 1);

    IAS_PARM_SUN_ANGLE_FILENAME_FROM_PASS(omf_param_out_table, 
        IAS_PARM_REQUIRED, sun_angle_filename, sizeof(sun_angle_filename), 0,
        processing_pass);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, SUN_ANGLE_FILENAME, 1);
                               
    /* Write the information to the OMF */
    if (ias_parm_update(omf_filename, omf_param_out_table, 1) != SUCCESS)
    {
        IAS_LOG_ERROR("Cannot write updates to OMF %s\n", omf_filename);
        return ERROR;
    }

    return SUCCESS;
}

