/******************************************************************************
NAME:           calc_map_coefs

PURPOSE:
Calculate the forward and inverse mapping coefficients for the grid.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

NOTES:
This routine will find the forward and inverse mapping coefficients for the
grid.  The library routines ias_geo_compute_forward_mappings and 
ias_geo_compute_inverse_mappings are called for the provided grid band.  The
forward and inverse mapping coefficients are stored in the grid structure for
the appropriate band.

ALGORITHM REFERENCES:
See ias_grid.h for a description of the grid structure.

******************************************************************************/
#include "create_grid.h"
#include "ias_geo.h"                  /* Geometric library */
#include "ias_logging.h"              /* Logging library   */


int calc_map_coefs 
(
    IAS_GRID_BAND_TYPE *gridband /* I/O: Grid band structure */
)
{
    int rows;             /* Number of rows in the grid */
    int cols;             /* Number of columns in the grid */
    int stat;             /* Return status */

    rows = gridband->ngrid_lines - 1;
    cols = gridband->ngrid_samps - 1;

    /* Calculate the forward mappings for the current band. */
    stat = ias_geo_compute_forward_mappings(gridband->nzplanes, 
            gridband->in_lines, gridband->in_samps, gridband->out_lines, 
            gridband->out_samps, rows, cols, gridband->sattoproj);
    if (stat != SUCCESS)
    {
        IAS_LOG_ERROR("In the compute_forward_mappings routine");
        return ERROR;
    }

    /* Calculate the inverse mappings for the current band. */
    stat = ias_geo_compute_inverse_mappings(gridband->nzplanes, 
            gridband->in_lines, gridband->in_samps, gridband->out_lines, 
            gridband->out_samps, rows, cols, gridband->projtosat);
    if (stat != SUCCESS)
    {
        IAS_LOG_ERROR("In the compute_inverse_mappings routine");
        return ERROR;
    }

    return SUCCESS;
}
