/******************************************************************************
NAME:           set_number_grid_lines_samples

PURPOSE:
Determine the number of grid lines and samples in the image.

ALGORITHM REFERENCES:
See ias_grid.h for a description of the grid structure.
******************************************************************************/
#include "create_grid.h"

void set_number_grid_lines_samples 
(
    const int num_lines[IAS_MAX_NBANDS],    /* I: Number of input lines */
    const int num_samples[IAS_MAX_NBANDS],  /* I: Number of input samples */ 
    IAS_GRID_TYPE *grid                     /* I/O: Grid structure */
)
{
    int sca_index;             /* SCA index */
    int band_index;            /* Reference band index */
    int number_lines;          /* Number of lines for current band */
    int number_samples;        /* Number of samples for current band */
    IAS_GRID_BAND_TYPE *grid_band; /* Pointer to the current grid band */

    /* Loop through the bands in the grid and calculate the number of lines
     * and samples in the grid.  */
    for (band_index = 0; band_index < grid->nbands; band_index++)
    {
        grid_band = grid->gridbands[band_index];
        number_lines = num_lines[band_index];
        number_samples = num_samples[band_index];

        for (sca_index = 0; sca_index < grid->scas_per_band[band_index];
             sca_index++)
        {
            /* populate the ngrid_lines and ngrid_samps for the bands that
               have input imagery, otherwise set them to zero */
            if (number_lines != 0)
            {
                grid_band[sca_index].ngrid_lines = number_lines
                    / grid_band[sca_index].grid_cell_size.line + 1;
                if ((number_lines % grid_band[sca_index].grid_cell_size.line)
                    != 0)
                {
                    grid_band[sca_index].ngrid_lines++;
                }

                grid_band[sca_index].ngrid_samps = number_samples
                    / grid_band[sca_index].grid_cell_size.samp + 1;
                if ((number_samples % grid_band[sca_index].grid_cell_size.samp) 
                    != 0)
                {
                    grid_band[sca_index].ngrid_samps++;
                }
            }
            else
            {
                grid_band[sca_index].ngrid_lines = 0;
                grid_band[sca_index].ngrid_samps = 0;
            }
        }
    }
}
