/******************************************************************************
NAME:           set_number_lines_samples 

PURPOSE:
The set_number_lines_samples routine returns the number of lines and samples 
for each band, as recorded in the model structure.  All bands are populated, 
regardless of whether there is grid data for them or not.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

NOTES:
The number of lines and samples will be returned in their respective arrays,
in band-referenced order.  This is similar to the manner in which the grid
is stored.  Thus the nlines and nsamps arrays MUST be of size IAS_MAX_NBANDS.
******************************************************************************/
#include "create_grid.h"

void set_number_lines_samples 
(
    const IAS_LOS_MODEL *model, /* I: Model structure */
    int nlines[IAS_MAX_NBANDS], /* O: Number of lines in image in band-
                                      referenced order */
    int nsamps[IAS_MAX_NBANDS]  /* O: Number of samples in image in band-
                                      reference order */
)
{
    int i;                  /* loop counter */

    for (i = 0; i < IAS_MAX_NBANDS; i++)
    {
        nlines[i] = model->sensor.bands[i].frame_count *
            model->sensor.bands[i].sampling_char.lines_per_frame;

        /* All SCAs should have the same number of detectors; just pick 1.  */
        nsamps[i] = model->sensor.bands[i].scas[0].detectors;
    }
}
