/***************************************************************************
 NAME:                     update_omf

 PURPOSE:   Writes the generated Grid filename and the lunar SCA number
            (if available for a lunar collect) to the OMF
 
 RETURNS:   SUCCESS or ERROR
****************************************************************************/
#include <string.h>                   /* String functions     */

#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "create_grid.h"

int update_omf
(
    const char *omf_filename,   /* I: Name of OMF */
    const char *grid_filename,  /* I: Name of the generated grid data file */
    int processing_pass,        /* I: Number of WO processing flow pass */
    int lunar_sca_number        /* I: SCA number containing image of the
                                   moon; pass in -1 if not available */
)
{
    int write_count;
    int write_status;


    /* Set up the parameter table. */
    IAS_PARM_DECLARE_TABLE(omf_param_out_table, 1);

    IAS_PARM_GRID_FILENAME_FROM_PASS(omf_param_out_table, IAS_PARM_REQUIRED,
        (char *)grid_filename, sizeof(grid_filename), 0, processing_pass);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, GRID_FILENAME, 1); 
                             
    /* Write the information to the OMF. */
    write_count = IAS_PARM_GET_TABLE_SIZE(omf_param_out_table);
    write_status = ias_parm_update(omf_filename, omf_param_out_table,
                                   write_count);
    if (write_status != SUCCESS)
    {
        IAS_LOG_ERROR("Cannot write grid filename to OMF %s", omf_filename);
        return ERROR;
    }

    /* Write the SCA number to the OMF if it is available */
    if (lunar_sca_number > 0)
    {
        /* Set up the parameter table. */
        IAS_PARM_DECLARE_TABLE(omf_param_out_table, 1);

        IAS_PARM_LUNAR_SCA_NUMBER(omf_param_out_table, &lunar_sca_number,
            sizeof(lunar_sca_number));
        IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, LUNAR_SCA_NUMBER, 1);

        /* Write the information to the OMF. */
        write_count = IAS_PARM_GET_TABLE_SIZE(omf_param_out_table);
        write_status = ias_parm_update(omf_filename, omf_param_out_table,
            write_count);

        if (write_status != SUCCESS)
        {
            IAS_LOG_ERROR("Cannot write lunar SCA number to OMF %s",
                omf_filename);
            return ERROR;
        }
    }

    return SUCCESS;
}

