#ifndef CREATE_LOS_MODEL_H
#define CREATE_LOS_MODEL_H

#include <limits.h>         /* PATH_MAX */
#include "ias_l0r_constants.h" /* L0R Scene ID length */
#include "ias_los_model.h"  /* model structures */

typedef enum l0r_file_type
{
    L0RA,
    L0RP
} L0R_FILE_TYPE;

typedef struct model_app_params
{
    /* The actual application parameter file name */
    char parameter_filename[PATH_MAX];

    /* Values retrieved from the application parameter file */
    char work_order_id[IAS_WORKORDER_ID_SIZE];
    int characterization_flag;
    char model_filename[PATH_MAX];

    /* Precision parameters */
    int precision_flag;  /* Set if precision values provided in param file */
    IAS_SC_PRECISION_MODEL precision_model; /* Precision parameters */

    /* Mode 0 SSM parameters */
    int ssm_encoder_value;  /* Nominal encoder value to use */

    char omf_filename[PATH_MAX];       /* derived from work order ID */

    /* Values retrieved from the OMF */
    char cpf_filename[PATH_MAX];
    char l0r_filename[PATH_MAX];
    char anc_filename[PATH_MAX];
    char ssm_position_filename[PATH_MAX];
    IAS_ACQUISITION_TYPE acquisition_type;
    IAS_SATELLITE_ID satellite_id;
    int processing_pass;
    char landsat_scene_id[IAS_L0R_SCENE_ID_LENGTH + 1]; /* Unique Landsat scene 
                                                         identifier */
    int use_three_tirs_scenes_flag; /* Flag to indicate use of 3 TIRS scenes */
} MODEL_APP_PARAMS;

/* ----------------------------------------------------------------------- */
/* ------------------------- Function Prototypes ------------------------- */
int read_parameters
(
    MODEL_APP_PARAMS *app_params  /* I: parameter and OMF file names
                                     O: parameters listed in input files */
);

int read_l0r
(
    const MODEL_APP_PARAMS *app_params, /* I: Parameter file and OMF values */
    IAS_LOS_MODEL_L0R_DATA *l0r_data    /* O: Compiled L0R data for model */
);

int write_characterization_data
(
    const IAS_LOS_MODEL *model,         /* I: completely populated model */
    const MODEL_APP_PARAMS *app_params, /* I: parameter file and OMF values */
    const IAS_SENSOR_L0R_DATA *l0r_data /* I: L0R file values */
);

int update_omf
(
    MODEL_APP_PARAMS *app_params,   /* I: file names and pass # for OMF */
    int ssm_position_quality,       /* I: TIRS SSM position  quality */
    const char *tirs_ssm_position   /* I: TIRS SSM position status */ 
);

#endif
