#!/usr/bin/perl
#------------------------------------------------------------------------------
# NAME: convert_ssm_encoder_file.pl
#     Helper script to convert the quality in the SSM file to the
#     quality provided.  
# PARAMETERS: 
#     SSM estimated encoder position file in which to adjust quality
#     Quality to use when updating the position file
#     How to change: ie ALL records or every other record
#     NOTE: If no amount to change is specified, every record
#           in the file will be updated to use the new quality
#     
#------------------------------------------------------------------------------
use strict;
use warnings;

my $count = 0;
# Get SSM filename
my $file = $ARGV[0];
if (!defined($file))
{
    print "Please provide an ssm estimated encoder file with qualities ".
        " convert.\n";
    exit(1);
}
# New quality to use in ssm filename
my $new_quality = $ARGV[1];
# Number of records to change
my $amount_to_change = $ARGV[2];
# If not specified, every record in the ssm file will be updated with the
# new quality
$amount_to_change = "ALL" if (!defined($amount_to_change));

open (FILE, $file) or die ("Can't open $file\n");
# Open new file
my $new_file = $file."_new";
open (NEW, ">$new_file") or die ("Can't open $new_file\n");
while(<FILE>)
{
    # Skip blank lines
    next if (/^\s+&/);
    # If this is a header line simply print to file and continue
    if (/FORMAT/ || /CREATION/ || /START/ || /END/ || /NUM/ || /YEAR/)
    {
        print NEW $_;
        next;
    }

    # Remove leading and trailing whitespace
    s/^\s+|\s+$//g;
 
    # At this point, we are at the actual record lines
    my ($year, $doy, $seconds, $position, $old_quality) = split(/\s+/, $_);
    last if (!defined($year) || !defined($doy) || !defined($seconds) ||
        !defined($position));

    # Print the parameters we do not care about
    print NEW "$year $doy $seconds  $position ";

    # Update the quality as directed
    if ($amount_to_change eq "ALL")
    {
        print NEW "$new_quality\n";
    }
    elsif(defined($new_quality) && $amount_to_change ne "ALL")
    {
        if ($count % 2 == 0)
        {
            print NEW "$new_quality\n";
        }
        else
        {
            print NEW "$old_quality\n";
        }
    }
    else
    {
        print NEW "$old_quality\n";
    }
    $count++;
}
return 1 if (!close(FILE));
return 1 if (!close(NEW));
