/**************************************************************************
 NAME:          update_omf

 PURPOSE:       Adds the model file name to the OMF file.

 RETURNS:       SUCCESS or ERROR
***************************************************************************/
#include <string.h>     /* no needed locally, but required by ias_parm.h */
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "create_los_model.h"

int update_omf
(
    MODEL_APP_PARAMS *app_params,   /* I: file names and pass # for OMF */
    int ssm_position_quality,       /* I: TIRS SSM estimated position quality */
    const char *tirs_ssm_position   /* I: TIRS SSM position status */ 
)
{
    int write_count;
    int write_status;

    /* Setup the structure for the library for the parameter to add to OMF */ 
    IAS_PARM_DECLARE_TABLE(omf_param_out_table, 3);

    IAS_PARM_MODEL_FILENAME_FROM_PASS(omf_param_out_table, IAS_PARM_REQUIRED,
            (char *)app_params->model_filename,
            sizeof(app_params->model_filename), 0, app_params->processing_pass);

    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, MODEL_FILENAME, 1);

    IAS_PARM_SSM_POSITION_QUALITY(omf_param_out_table,
        &ssm_position_quality, sizeof(ssm_position_quality), 1);

    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, SSM_POSITION_QUALITY, 1);

    /* Since the TIRS SSM position does not get written if it isn't passed
       need to make sure it is the last parameter in the list to write */
    IAS_PARM_TIRS_SSM_POSITION_STATUS(omf_param_out_table, IAS_PARM_REQUIRED,
        (char *)tirs_ssm_position, IAS_SENSOR_SSM_POSITION_STATUS_SIZE);

    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, TIRS_SSM_POSITION_STATUS, 1);

    /* Use the Parameter File I/O library to update the OMF file */
    write_count = IAS_PARM_GET_TABLE_SIZE(omf_param_out_table);

    /* If the TIRS SSM position is not passed then do not write it out to the
       OMF file */
    if (strlen(tirs_ssm_position) <= 0) 
        write_count--;

    write_status = ias_parm_update(app_params->omf_filename,
            omf_param_out_table, write_count);
    if (write_status != SUCCESS)
    {
        IAS_LOG_ERROR("Writing model file name to OMF file: %s",
                app_params->omf_filename);
        return ERROR;
    }

    return SUCCESS;
}
