/******************************************************************************
NAME:           calculate_point_weights

PURPOSE:
calculate_point_weights calculates the weight associated with each correlation
point for doing the legendre polynomial fit.

RETURNS:
Type = void

NOTES:
Currently, this routine assigns the weight passed in to each point, effectively
assigning each point an equal weight.  Originally it was thought that the 
correlation strength would factor into the weight, but that was determined 
to not be needed.  This routine was left in to allow some additional weight
factor to be added at a later date.

ALGORITHM REFERENCES:
OLI Focal Plane Alignment Calibration ADD
******************************************************************************/

#include "calculate_point_weights.h"  /* Prototype for this routine */

void calculate_point_weights
(
    double weight,       /* I: Constant weight associated with each point */
    int corr_points,     /* I: Number of focal plane correlation points */
    CORR_PT_INFO *fp_corr_pts_ptr /* I/O: Focal plane correlation points */
)
{
    int index;   /* Loop counter */

    /* Assign the constant weight to each of the points, ignoring the active
       flag since it doesn't hurt to set the weight if it isn't used */
    for (index = 0; index < corr_points; index++)
    {
        fp_corr_pts_ptr[index].pt_weight = weight;
    }
}
