
#ifndef _CALCULATE_POST_FIT_RESIDUALS_H_
#define _CALCULATE_POST_FIT_RESIDUALS_H_

#include "focal_plane.h"     /* CORR_PT_INFO definition */

typedef struct
{
    double mean;    /* Mean value */
    double rms;     /* Root mean squared value */
    double stdev;   /* Standard deviation */
} STATS_TYPE;

/* Holds the post fit residual statistics information */
typedef struct
{
    int points;             /* Number of points used to generate statistics */
    STATS_TYPE delta_x;     /* Delta stats X (sample) */
    STATS_TYPE delta_y;     /* Delta stats Y (line) */
    STATS_TYPE residual_x;  /* Residual stats X (sample) */
    STATS_TYPE residual_y;  /* Residual stats Y (line) */
    
} POST_FIT_RESIDUAL_STATS_TYPE;

int calculate_post_fit_residuals
(
    const double *error_legendre_coeffs_x, /* I: IAS_LOS_LEGENDRE_TERMS error
                              Legendre coefficients line direction */
    const double *error_legendre_coeffs_y, /* I: IAS_LOS_LEGENDRE_TERMS error
                              Legendre coefficients sample direction */
    int points,         /* I: Number of correlation points */
    int sca_num,        /* I: SCA number for calculating residuals */
    int sca_num_det,    /* I: Number of detectors in each SCA */
    CORR_PT_INFO *fp_corr_pts_ptr, /* I/O: Focal plane correlation points to
                              calculate post-fit residuals on */
    POST_FIT_RESIDUAL_STATS_TYPE *residuals_ptr, /* O: Calculated residual
                              information */
    double db_save_threshold_x, /* I: Threshold to limit saving data to DB */
    double db_save_threshold_y, /* I: Threshold to limit saving data to DB */
    int *store_in_database_flag /* O: Flag used to indicate whether results 
                              should be stored in the database */
);

#endif
