#ifndef SAVE_TO_DATABASE_H
#define SAVE_TO_DATABASE_H

#include <limits.h>      /* PATH_MAX */

#include "ias_satellite_attributes.h" /* Used for IAS_MAX_NSCAS */
#include "calculate_post_fit_residuals.h" /* POST_FIT_RESIDUAL_STATS_TYPE
                               definition */

/* Define a structure for the information to be collected and inserted into
   the FOCAL_PLANE_CALIBRATION table */
struct main_db_save_info
{
    char wo_id[IAS_WORKORDER_ID_SIZE]; /* This one isn't in the database */
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    char reference_image[PATH_MAX + 1];
    double outlier_threshold;
    int fit_order;
    int number_of_scas;
    double mean_alng_trk_upd;
    double mean_acrss_trk_upd;
};

/* Define a structure for the information to be collected and inserted into
   table FOCAL_PLANE_CALIBRATION_SCA */
typedef struct sca_db_save_info
{
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    int sensor_chip_assembly_id[IAS_MAX_NSCAS];
    int nbr_of_pnts_used[IAS_MAX_NSCAS];
    double upds_alng_trk_leg_poly_0[IAS_MAX_NSCAS]; /* Updates to Legendre
        polynomials: original + updates = new */
    double upds_alng_trk_leg_poly_1[IAS_MAX_NSCAS];
    double upds_alng_trk_leg_poly_2[IAS_MAX_NSCAS];
    double upds_acrss_trk_leg_poly_0[IAS_MAX_NSCAS];
    double upds_acrss_trk_leg_poly_1[IAS_MAX_NSCAS];
    double upds_acrss_trk_leg_poly_2[IAS_MAX_NSCAS];
    double new_alng_trk_leg_poly_0[IAS_MAX_NSCAS];
    double new_alng_trk_leg_poly_1[IAS_MAX_NSCAS];
    double new_alng_trk_leg_poly_2[IAS_MAX_NSCAS];
    double new_acrss_trk_leg_poly_0[IAS_MAX_NSCAS];
    double new_acrss_trk_leg_poly_1[IAS_MAX_NSCAS];
    double new_acrss_trk_leg_poly_2[IAS_MAX_NSCAS];
    double original_alng_trk_leg_poly_0[IAS_MAX_NSCAS];
    double original_alng_trk_leg_poly_1[IAS_MAX_NSCAS];
    double original_alng_trk_leg_poly_2[IAS_MAX_NSCAS];
    double original_acrss_trk_leg_poly_0[IAS_MAX_NSCAS];
    double original_acrss_trk_leg_poly_1[IAS_MAX_NSCAS];
    double original_acrss_trk_leg_poly_2[IAS_MAX_NSCAS];
    double pre_fit_res_alng_trk_mean[IAS_MAX_NSCAS];
    double pre_fit_res_alng_trk_std_dev[IAS_MAX_NSCAS];
    double pre_fit_res_alng_trk_rmse[IAS_MAX_NSCAS];
    double pre_fit_res_acrss_trk_mean[IAS_MAX_NSCAS];
    double pre_fit_res_acrss_trk_std_dev[IAS_MAX_NSCAS];
    double pre_fit_res_acrss_trk_rmse[IAS_MAX_NSCAS];
    double pst_fit_res_alng_trk_mean[IAS_MAX_NSCAS];
    double pst_fit_res_alng_trk_std_dev[IAS_MAX_NSCAS];
    double pst_fit_res_alng_trk_rmse[IAS_MAX_NSCAS];
    double pst_fit_res_acrss_trk_mean[IAS_MAX_NSCAS];
    double pst_fit_res_acrss_trk_std_dev[IAS_MAX_NSCAS];
    double pst_fit_res_acrss_trk_rmse[IAS_MAX_NSCAS];
} db_save_info;

void prepare_for_database_save
(
    double sca_coef_x[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Existing X
                                        Legendre coefficients */
    double sca_coef_y[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Existing Y
                                        Legendre coefficients */
    double error_coef_x[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Error X
                                        Legendre coefficients */
    double error_coef_y[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Error Y
                                        Legendre coefficients */
    double new_coef_x[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Updated X
                                        coefficients */
    double new_coef_y[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Updated Y
                                        coefficients */
    const POST_FIT_RESIDUAL_STATS_TYPE *residual_stats, /* I: Calculated
                                        residual information */
    const char *work_order_id,    /* I: Work Order ID for report header */
    const char *ref_image_name,   /* I: Name of reference image */
    double confidence_level,      /* I: Confidence level used for outlier
                                        rejection */
    int fit_order,                /* I: Flag that indicates the polynomial
                                        order that was used in the solution */
    double mean_x_fit,            /* I: Mean best-fit x offset */
    double mean_y_fit,            /* I: Mean best-fit y offset */
    int number_records,           /* I: The number of DB records */
    struct main_db_save_info* main_db_save, /* O: Populated main table data */
    struct sca_db_save_info* sca_db_save /* O: Populated SCA table data */
);

int save_to_database
(
    struct main_db_save_info* main_db_save, /* I/O: Main table data */
    struct sca_db_save_info* sca_db_save, /* I/O: SCA table data */
    int number_records            /* I: The number of DB records */
);

#endif
