#ifndef _FOCAL_PLANE_SETUP_H_
#define _FOCAL_PLANE_SETUP_H_

/* Local types & defines */
#include "ias_grid_io.h"       /* Grid I/O library */
#include "focal_plane.h"       /* Focal plane calibration structures */

/* Local functions */
int calc_input_space_errors
(
    const char *ref_img_name,  /* I: Name of the reference image */
    const char *terr_img_name, /* I: Name of the 1T (search) image */
    const char *dem_name,      /* I: Name of the DEM image */
    int corr_win_nl,           /* I: # of lines in correlation window */
    int corr_win_ns,           /* I: # of samples in correlation window */
    int abs_corr_coeff,        /* I: Flag to use abs of correlation coeff */
    float min_corr,            /* I: Minimum correlation strength */
    float max_disp,            /* I: Maximum correlation displacement */
    IAS_CORRELATION_FIT_TYPE fit_method, /*I: Correlation result fit
                                     method */
    const IAS_GRID_TYPE *grid, /* I: Grid structure, used for point
                                     selection and inverse mapping */
    float invalid_threshold,   /* I: Invalid threshold percentage */
    int band_number,           /* I: Band number (pan) */
    CORR_PT_INFO *fp_corr_pts, /* O: Focal plane correlation point info */
    int npts                   /* O: Number of focal plane corr points */
);

int calc_los_errors
(
    CORR_PT_INFO *fp_corr_pts, /* I/O: Focal plane correlation point info */
    int npts,                  /* I: Number of focal plane corr points */
    const IAS_LOS_MODEL *model, /* I: Precision model structure */
    int band_number            /* I: Band number */
);

int check_images_match
(
    const char *ref_img_name,  /* I: Name of the reference image */
    const char *terr_img_name, /* I: Name of the 1T image */
    const char *dem_img_name,  /* I: Name of the DEM image */
    int srch_band_number       /* I: Band number of search image */
); 

int map_coords_to_input_space
(
    CORR_PT_INFO *fp_corr_pts, /* I/O: Focal plane correlation points */
    const char *dem_name,      /* I: DEM file name */
    int npts,                  /* I: Number of focal plane corr points */
    const IAS_GRID_TYPE *grid, /* I: Grid structure for all bands */
    int band_number            /* I: Band number (pan) */
);

int output_correlation_info
(
    const char *correlation_file_name, /* I: Name of output file */
    const CORR_PT_INFO *fp_corr_pts, /* I: Correlation point info */
    int npts                   /* I: Number of points */
);

int perform_correlation
(
    CORR_PT_INFO *fp_corr_pts, /* I/O: Correlation point information */
    int npts,                  /* I: Total number of points */
    const char *ref_img,       /* I: Name of ref image */
    const char *srch_img,      /* I: Name of srch (1T) image */
    int corr_win_nl,           /* I: Line size of corr window */
    int corr_win_ns,           /* I: Sample size of corr window */
    float min_corr,            /* I: Minimum correlation strength */
    float max_disp,            /* I: Maximum correlation displacement */
    IAS_CORRELATION_FIT_TYPE fit_method, /* I: Correlation result fit
                                     method */
    int abs_corr_coeff,        /* I: Flag to use abs of corr coeffs */
    float invalid_threshold,   /* I: Invalid threshold percent */
    int srch_band_number       /* I: Search (1T) image band number */
);

CORR_PT_INFO *select_corr_pts
(
    const IAS_GRID_TYPE *grid, /* I: Grid structure */
    int pts_per_cell,          /* I: Num points per cell to correlate at */
    int band_number,           /* I: Band number (pan) */
    int *npts                  /* O: Total # of pts in image to correlate */
);

int set_up_grid
(
    const char *grid_name,     /* I: Precision grid filename */
    int band_number,           /* I: Band number (pan) */
    ALIGNMENT_PROCESSING_TYPE, /* I: Algorithm processing type: 0 = Focal
                                     Plane Alignment; 1 = TIRS Alignment */
    IAS_GRID_TYPE *grid        /* O: Whole grid read from file */
);

#endif
