#ifndef _CALCULATE_POST_FIT_RESIDUALS_H_
#define _CALCULATE_POST_FIT_RESIDUALS_H_

#include "stdlib.h"
#include "ias_model_io.h"
#include "focal_plane.h"     /* CORR_PT_INFO definition */
#include "filter_outliers.h"
#include "calculate_point_weights.h"

typedef struct
{
    double mean;    /* Mean value */
    double rms;     /* Root mean squared value */
    double stdev;   /* Standard deviation */
} STATS_TYPE;

/* Holds the post fit residual statistics information */
typedef struct
{
    int points;            /* Number of points used to generate statistics */
    STATS_TYPE delta_x;    /* Delta stats X (sample) */
    STATS_TYPE delta_y;    /* Delta stats Y (line) */
    STATS_TYPE residual_x; /* Residual stats X (sample) */
    STATS_TYPE residual_y; /* Residual stats Y (line) */
    
} POST_FIT_RESIDUAL_STATS_TYPE;

/* Structure parameters for fit calculation in tirs_alignment_legendre
   and estimate_tirs_ssm_angle applications */
typedef struct
{
    double *error_legendre_coeffs_x; /* I: IAS_LOS_LEGENDRE_TERMS error
                              Legendre coefficients in the sample direction */
    double *error_legendre_coeffs_y; /* I: IAS_LOS_LEGENDRE_TERMS error
                              Legendre coefficients in the line direction */
    double *alignment_corrections;   /* I: TIRS-to-OLI alignment
                              corrections for roll, pitch, and yaw */
    double ssm_angle_correction;     /* I: TIRS SSM rotation 
                                           correction angle */
    double pitch_angle_correction;   /* I: Pitch alignment angle 
                                           correction */
    double normalized_det;           /* I: Normalized detector location */
} PARAMETERS_FIT_CALCULATION;


int calculate_post_fit_residuals
(
    const double *original_legendre_coeffs_x, /* I: IAS_LOS_LEGENDRE_TERMS 
                              original Legendre coefficients in the line 
                              direction */
    const double *original_legendre_coeffs_y, /* I: IAS_LOS_LEGENDRE_TERMS 
                              original Legendre coefficients in the sample 
                              direction */
    int points,         /* I: Number of correlation points */
    int sca_num,        /* I: SCA number for calculating residuals */
    int sca_num_det,    /* I: Number of detectors in each SCA */
    CORR_PT_INFO *corr_pts_ptr, /* I/O: Correlation points to calculate post-
                              fit residuals on */
    POST_FIT_RESIDUAL_STATS_TYPE *residuals_ptr, /* O: Calculated residual
                              information */
    double db_save_threshold_x, /* I: Threshold to limit saving data to DB */
    double db_save_threshold_y, /* I: Threshold to limit saving data to DB */
    int *store_in_database_flag, /* O: Flag used to indicate whether results 
                              should be stored in the database */
     void (*calculate_fit) (const double, const double,
        const PARAMETERS_FIT_CALCULATION *,
        double *, double *), /* I: Generalized function pointer to call
                                   the requied function needed */
    PARAMETERS_FIT_CALCULATION *fit, /* I: Structure for fit calucaltion */
    int app_flag       /* I: Applicaton identifier flag 
                          1 : tirs_alignment_legendre
                          2 : estimate_tirs_ssm_angle */
);

#endif
