#ifndef _CREATE_REPORT_TIRS_ALIGNMNET_LEGENDRE_H_
#define _CREATE_REPORT_TIRS_ALIGNMNET_LEGENDRE_H_

#include "focal_plane.h"       /* CORR_PT_INFO definition */
#include "calculate_post_fit_residuals.h" /* POST_FIT_RESIDUAL_STATS_TYPE 
                                             definition */
#include "save_to_database.h"  /* Database save structure definitions */

int create_report_tirs_alignment_legendre
(
    const char *report_file_name, /* I: Report file name */
    const char *terr_image_name,  /* I: Name of input 1T image */
    const char *ref_image_name,   /* I: Name of reference image */
    const char *l0r_image_name,   /* I: Name of L0R image */
    int nscas,                    /* I: Number of SCAs */
    double sca_coef_x[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Existing X
                                        Legendre coefficients */
    double sca_coef_y[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS], /* I: Existing Y
                                        Legendre coefficients */
    double error_legendre_x[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS],
                                  /* I: Error X Legendre coefficients */
    double error_legendre_y[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS],
                                  /* I: Error Y Legendre coefficients */
    double updated_legendre_x[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS],
                                  /* I: Updated X coefficients */
    double updated_legendre_y[NUM_TIRS_SCAS][IAS_LOS_LEGENDRE_TERMS],
                                  /* I: Updated Y coefficients */
    const CORR_PT_INFO *corr_pts_ptr, /* I: Correlation points */
    int  points,                  /* I: Number of correlation points */
    const POST_FIT_RESIDUAL_STATS_TYPE *residuals_ptr, /* I: Calculated
                                        residual information */
    double confidence_level,      /* I: Confidence level used for outlier
                                        rejection */
    int fit_order,                /* I: Flag that indicates the polynomial
                                        order that was used in the solution */
    const char *work_order_id,    /* I: Work Order ID for report header */
    double mean_x_fit,            /* I: Mean best-fit x offset */
    double mean_y_fit,            /* I: Mean best-fit y offset */
    struct main_db_save_info* main_db_save  /* I: top-level data for DB */
);

int write_stats_report_file
(
    FILE *report_file,       /* I: Pointer to report file name */
    const char *report_file_name,  /* I: Report file name */
    int nscas,                     /* I: Number of SCAs */
    int fit_order,                 /* I: Flag that indicates the polynomial
                                         order that was used in the solution */
    int points,                   /* I: Number of correlation points */
    double confidence_level,      /* I: Confidence level used for
                                        outlier rejection */
    const POST_FIT_RESIDUAL_STATS_TYPE *residuals_ptr, /* I: Calulcated 
                                         residual information */
    const CORR_PT_INFO *corr_pts_ptr  /* I: Correlation points */
);

#endif
