#ifndef SAVE_ESTIMATED_SSM_TO_DATABASE_H
#define SAVE_ESTIMATED_SSM_TO_DATABASE_H

#include <limits.h>  /* PATH_MAX */

#include "calculate_post_fit_residuals.h" /* POST_FIT_RESIDUAL_STATS_TYPE
                                             definition */

/* Define a structure for the information to be collected and inserted into
   the TIRS_SSM_ESTIMATION table */
struct main_db_trend_info
{
    char wo_id[IAS_WORKORDER_ID_SIZE];  /* This one isn't in the database */
    char reference_image[PATH_MAX + 1];
    int number_of_scas;
    double ssm_epoch_year;
    double ssm_epoch_doy;
    double ssm_epoch_sod;
    double ssm_angle_correction;
    double net_ssm_angle;
    double pitch_angle_correction;
    const POST_FIT_RESIDUAL_STATS_TYPE *residual_ptr;
    double confidence_level;
} main_db_trend_info;

/* Define a structure for the information to be collected and inserted into
   table TIRS_SSM_ESTIMATION_SCA */
struct sca_db_trend_info
{
    int sca_number[NUM_TIRS_SCAS];
    int nbr_of_pnts_used[NUM_TIRS_SCAS];
    double pre_fit_alng_trk_mean[NUM_TIRS_SCAS];
    double pre_fit_alng_trk_stdev[NUM_TIRS_SCAS];
    double pre_fit_alng_trk_rmse[NUM_TIRS_SCAS];
    double pre_fit_acrss_trk_mean[NUM_TIRS_SCAS];
    double pre_fit_acrss_trk_stdev[NUM_TIRS_SCAS];
    double pre_fit_acrss_trk_rmse[NUM_TIRS_SCAS];
    double post_fit_alng_trk_mean[NUM_TIRS_SCAS];
    double post_fit_alng_trk_stdev[NUM_TIRS_SCAS];
    double post_fit_alng_trk_rmse[NUM_TIRS_SCAS];
    double post_fit_acrss_trk_mean[NUM_TIRS_SCAS];
    double post_fit_acrss_trk_stdev[NUM_TIRS_SCAS];
    double post_fit_acrss_trk_rmse[NUM_TIRS_SCAS];
} db_trend_info;


void prepare_estimated_ssm_for_database_trend
(
    const double *ssm_epoch,       /* I: Time epoch for estimated angles */
    double ssm_angle_correction,   /* I: Estimated SSM angle correction */
    double net_ssm_angle,          /* I: Net new estimated angle */
    double pitch_angle_correction, /* I: Estimated pitch alignment angle
                                         correction */
    const POST_FIT_RESIDUAL_STATS_TYPE *residual_stats, /* I: Calculated 
                                         residual information */
    double confidence_level,       /* I: Confidence level used for outlier
                                         rejection */
    const char *work_order_id,     /* I: Work order ID for report header */ 
    const char *ref_image_name,    /* I: Name of reference image */
    int number_sca_records,        /* I: The number of DB records */
    struct main_db_trend_info* main_db_trend, /* O: Populated main table data */
    struct sca_db_trend_info* sca_db_trend    /* O: Populated SCA table data */
);

int save_estimated_ssm_to_database
(
    struct main_db_trend_info* main_db_trend, /* I/O: Main table data */
    struct sca_db_trend_info* sca_db_trend,   /* I/O: SCA table data */
    int number_sca_records                    /* I: The number of DB records */
);

#endif
