#ifndef _GCPCORRELATE_H_
#define _GCPCORRELATE_H_

/*
 * Include file for GCPcorrelate task.
 */
#include <limits.h>           /* PATH_MAX definition */
#include "ias_l1g.h"
#include "ias_gcp.h"

/* fit method used in correlation */
typedef enum corr_fit_method
{
    FIT_ERROR=-1, 
    FIT_ELLIP_PARA=1, 
    FIT_ELLIP_GAUSS, 
    FIT_RECIP_PARA, 
    FIT_ROUND
} CorrFitMethod;

typedef struct gcp_corr_parms 
{
    char img_name[PATH_MAX];     /* Name of input 1G image */
    int srch_win_size[2];        /* Size of correlation search window */
    char gcp_data_filename[PATH_MAX]; /* Name of output GCP data file */
    char gcplib_filename[PATH_MAX]; /* Name of GCPLib file */
    int begin_date[2];           /* Begin date for GCP selection(mm/yyyy) */
    int end_date[2];             /* End date for GCP selection(mm/yyyy) */
    char season[IAS_GCP_NUM_SEASONS][IAS_GCP_SEASON_LEN];
                                 /* Seasons for GCP selection */
    char chip_source[IAS_GCP_NUM_CHIP_SOURCES][IAS_GCP_SOURCE_SIZE];
                                 /* Chip sources for GCP */
    char omf_filename[PATH_MAX]; /* OMF filename */
    char chip_type[IAS_GCP_TYPE_SIZE]; /* GCP type: control or validation */
    int band_number;             /* Band number used for correlation */
    char cpf_filename[PATH_MAX]; /* CPF filename */
    char gcp_dir[PATH_MAX];      /* Path to GCP LIB */
    int y_offset;                /* Line/Y offset entered by user */
    int x_offset;                /* Sample/X offset entered by user */
    int processing_pass;         /* Processing pass through the work order
                                    processing flow */
    char work_order_id[IAS_WORKORDER_ID_SIZE]; /* work order ID */
} GCP_CORR_PARMS;

/* 
 * Local functions
 */
int get_gcpcorrelate_parameters
(
    const char *parm_filename,  /* I: Parameter filename */
    GCP_CORR_PARMS *parm_data,  /* O: Parameters retrieved from parm file*/
    float *min_corr,            /* O: Minimum correlation strength */
    float *max_disp,            /* O: Maximum correlation displacement */
    float *fill,                /* O: DN fill value */
    float *threshold,           /* O: DN fill Percentage */
    CorrFitMethod *fit_method   /* O: Correlation result fit method */
);

int process_gcp
(
    IAS_GCP_RECORD *gcp_lib,    /* I: List of GCPs */
    int  numgcp,                /* I: Number of GCPs */
    const char *gcp_dir,        /* I: Root directory of GCP libraries */
    const char *img_name,       /* I: Name of 1g image */
    int  srch_win_size[2],      /* I: Correlation window size (lines,samps) */
    const char *gcp_data_filename,/* I: Name of output data file */
    int nsca,                   /* I: Number of SCAs */
    int abs_corr_coeff,         /* I: Flag for abs of corr coeffs in 
                                      ias_math_correlate_grey*/
    float min_corr,             /* I: Minimum correlation strength */
    float max_disp,             /* I: Maximum correlation displacement */
    float fill,                 /* I: Fill value to search for           */
    float threshold,            /* I: Percentage of valid pixels need for 
                                      correlation */
    int y_offset,               /* I: Line/Y user entered offset */
    int x_offset,               /* I: Sample/X user entered offset */
    CorrFitMethod fit_method,   /* I: Correlation result fit method */
    int band_number             /* I: Band number to run correlate on */
);

void get_search_line_samp
(
    double projy,               /* I: Projection Y coordinate of GCP */
    double projx,               /* I: Projection X coordinate of GCP */
    const IAS_L1G_BAND_METADATA *band_metadata, /* I: band metadata */
    double *pred_srch_line,     /* O: Predicted search line */
    double *pred_srch_samp      /* O: Predicted search sample */
);

#endif
