/******************************************************************************
NAME: get_search_line_samp

PURPOSE:
Find the line and sample that corresponds to the given projection y and x.  
Since the 1G image is positioned north up, finding the line (sample) 
is done by subtracting the upper left projection y(x) value from the 
GCP projection y(x) value and dividing the result by the line(sample) pixel 
size.

RETURN VALUE:
No return value

******************************************************************************/
#include "GCPcorrelate.h"

void get_search_line_samp
(
    double projy,       /* I: Projection Y coordinate of GCP */
    double projx,       /* I: Projection X coordinate of GCP */
    const IAS_L1G_BAND_METADATA *band_metadata, /* I: band metadata */
    double *pred_srch_line, /* O: Predicted search line */
    double *pred_srch_samp  /* O: Predicted search sample */
)
{
    /*
     * Calculate a 0-relative line and sample location 
     *  projection y increase as you go up;
     *  projection x increases as you go right
     *  so upper left corner is the max y and the min x
     */
    *pred_srch_line = (band_metadata->upper_left_y - projy) 
                      / band_metadata->projection_distance_y;
    *pred_srch_samp = (projx - band_metadata->upper_left_x) 
                      / band_metadata->projection_distance_x;
}
