#!/usr/bin/perl -w

use strict;

my $measurements_file = "measured.gcp";
my $measurements_file_orig = "measured.gcp.orig";
my $measurements_file_local = "measured.gcp.local";
my $omf_file = "testWO.omf";
my $omf_file_orig = "testWO.omf.orig";
my $omf_file_ref = "testWO.omf.ref";
my $omf_file_ref_local = "testWO.omf.ref.local";

# clean up old measured.gcp file
unlink ("$measurements_file");

# convert the OMF to the current test directory
convert_test_dir($omf_file_orig, $omf_file);
convert_test_dir($omf_file_ref, $omf_file_ref_local);

# convert the measurements file to the local test directory
convert_test_dir($measurements_file_orig, $measurements_file_local);

# run the correlator
system ("../gcpcorrelate testWO.odl");

# sort the measurements file
system ("sort $measurements_file -o $measurements_file");

# compare measurements files
my $rc = system ("diff --brief $measurements_file $measurements_file_local");
if ($rc != 0)
{
    print "measurements diff test failed\n";
    exit 1;
}
else
{
    print "measurements diff test passed\n";
    # compare omf files
    $rc = system ("diff --brief $omf_file $omf_file_ref_local");
    if ($rc != 0)
    {
        print "omf diff test failed\n";
        exit 1;
    }
    else
    {
        print "omf diff test passed\n";
    }
}

# run a second test with values from .odl file
$measurements_file = "measured2.gcp";
$measurements_file_orig = "measured2.gcp.orig";
$measurements_file_local = "measured2.gcp.local";
$omf_file = "testWO2.omf";
$omf_file_orig = "testWO2.omf.orig";
$omf_file_ref = "testWO2.omf.ref";
$omf_file_ref_local = "testWO2.omf.ref.local";

# clean up old measured.gcp file
unlink ("$measurements_file");

# convert the OMF to the current test directory
convert_test_dir($omf_file_orig, $omf_file);
convert_test_dir($omf_file_ref, $omf_file_ref_local);

# convert the measurements file to the local test directory
convert_test_dir($measurements_file_orig, $measurements_file_local);

# run the correlator
system ("../gcpcorrelate testWO2.odl");

# sort the measurements file
system ("sort $measurements_file -o $measurements_file");

# compare measurements files
$rc = system ("diff --brief $measurements_file $measurements_file_local");
if ($rc != 0)
{
    print "measurements diff test 2 failed\n";
    exit 1;
}
else
{
    print "measurements diff test 2 passed\n";
    # compare omf files
    $rc = system ("diff --brief $omf_file $omf_file_ref_local");
    if ($rc != 0)
    {
        print "omf diff test 2 failed\n";
        exit 1;
    }
    else
    {
        print "omf diff test 2 passed\n";
    }
}

# run a third test with using the GCP_TYPE of "BOTH"
$measurements_file = "measured3.gcp";
$measurements_file_orig = "measured3.gcp.orig";
$measurements_file_local = "measured3.gcp.local";
$omf_file = "testWO3.omf";
$omf_file_orig = "testWO3.omf.orig";
$omf_file_ref = "testWO3.omf.ref";
$omf_file_ref_local = "testWO3.omf.ref.local";

# clean up old measured.gcp file
unlink ("$measurements_file");

# convert the OMF to the current test directory
convert_test_dir($omf_file_orig, $omf_file);
convert_test_dir($omf_file_ref, $omf_file_ref_local);

# convert the measurements file to the local test directory
convert_test_dir($measurements_file_orig, $measurements_file_local);

# run the correlator
system ("../gcpcorrelate testWO3.odl");

# sort the measurements file
system ("sort $measurements_file -o $measurements_file");

# compare measurements files
$rc = system ("diff --brief $measurements_file $measurements_file_local");
if ($rc != 0)
{
    print "measurements diff test 3 failed\n";
    exit 1;
}
else
{
    print "measurements diff test 3 passed\n";
    # compare omf files
    $rc = system ("diff --brief $omf_file $omf_file_ref_local");
    if ($rc != 0)
    {
        print "omf diff test 3 failed\n";
        exit 1;
    }
    else
    {
        print "omf diff test 3 passed\n";
    }
}
# end main test script

sub convert_test_dir
{
    my $input_WO_OMF_file_name = shift;
    my $temp_WO_OMF_file_name = shift;

    my $data_dir = "$ENV{IAS_UNIT_TEST_DATA_DIR}";
    $data_dir =~ s/\/+$//; # trim trailing slashes, if any

    # open the WO OMF files
    open (INPUT_FILE, "<$input_WO_OMF_file_name") ||
      die ("Could not open $input_WO_OMF_file_name for reading\n");
    open (OUTPUT_FILE, ">$temp_WO_OMF_file_name") ||
      die ("Could not open $temp_WO_OMF_file_name for writing\n");

    # read a line at a time, parse for IAS_UNIT_TEST_DATA_DIR env variable
    # string
    my $current_line;
    while ($current_line = <INPUT_FILE>)
    {
      $current_line =~ s/\$IAS_UNIT_TEST_DATA_DIR\//$data_dir\//;
      print OUTPUT_FILE $current_line;
    }

    close INPUT_FILE;
    close OUTPUT_FILE;
}
