#ifndef GEODETIC_CHAR_H
#define GEODETIC_CHAR_H

#include "ias_geo.h"           /* Geometric library      */
#include "ias_gcp.h"
#include "ias_misc_gcp_residuals.h"

#define PROG_NAME "geodetic"

/* define a structure for the information to be collected and 
   inserted into the geodetic characterization table. */
typedef struct db_residual_statistics
{
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    int nbr_of_vld_pnts;
    double mean_lat_of_gcps;
    double mean_lon_of_gcps;
    double pst_fit_mean_alng_trk;
    double pst_fit_mean_acrss_trk;
    double pst_fit_std_dev_alng_trk;
    double pst_fit_std_dev_acrss_trk;
    double pst_fit_rmse_alng_trk;
    double pst_fit_rmse_acrss_trk;
    double pst_fit_corr_coeff;
    double pre_fit_mean_alng_trk;
    double pre_fit_mean_acrss_trk;
    double pre_fit_std_dev_alng_trk;
    double pre_fit_std_dev_acrss_trk;
    double pre_fit_rmse_alng_trk;
    double pre_fit_rmse_acrss_trk;
    double pre_fit_corr_coeff;
    int correction_type;
    char gcp_source[IAS_GCP_SOURCE_SIZE];
} DB_RESIDUAL_STATISTICS;

/* prototypes */
/**************/

int get_geod_char_parms
(
    const char *ias_parm_file, /* I: Name of the parameter file */
    int *store_in_database     /* O: flag for database storage:
                                     1 = yes, 0 = no */
);

int remove_outliers
(   
    const IAS_MISC_GCP_RESIDUAL *pre_gcp_res, /* I: ptr to pre-fit GCP
                                                    residual data */
    const IAS_MISC_GCP_RESIDUAL *post_gcp_res,/* I: ptr to post-fit GCP
                                                    residual data */

    int  num_pre_res,                /* I: number of pre-fit residual 
                                        structures */
    int  num_post_res,              /* I: number of post-fit residual 
                                          structures */
    int  *num_valid,                /* I: ptr to number valid GCP residuals */
        
    double **GCP_lat,               /* O: GCP residual latitude data */
    double **GCP_lon,               /* O: GCP residual longitude data */
    double **pre_across_res,        /* O: pre-fit across-track residual data */
    double **pre_along_res,         /* O: pre-fit along-track residual data */
    double **post_across_res,       /* O: post-fit across-track residual data */
    double **post_along_res,        /* O: post-fit along-track residual data */
    DB_RESIDUAL_STATISTICS *residual_stats/* O: Needed to set the gcp_source */
);

int output_resid_stats
(
    const GCP_RES_STATS *prefit_stats,  /* I: pre-fit GCP residual stats */
    const GCP_RES_STATS *postfit_stats, /* I: post-fit GCP residual stats */
    const char *gcp_source,             /* I: GCP source */
    int band_number                     /* I: The first pre-GCP band number */
);

int write_residual_statistics_report
(   
    FILE *stats_fptr,             /* I: Name of the GCP residual stats file */
    const GCP_RES_STATS *prefit_stats,  /* I: pre-fit GCP residual stats */
    const GCP_RES_STATS *postfit_stats, /* I: post-fit GCP residual stats */
    const char *gcp_source,             /* I: GCP source */
    int band_number                     /* I: The first pre-GCP band number */
);

int write_residual_statistics_to_db
(
    struct db_residual_statistics* ti  /* I: data to write to db */
);

int get_residuals
(
    const char *residuals_filename, /* I: Precision residual file name */
    int  iteration_number,          /* I: The iteration number to get */
    IAS_MISC_GCP_RESIDUAL **gcp_res,         /* O: GCP residual information */
    int *number_of_residuals        /* O: Number of residuals read from file */
);

/* Functions used to access parameters from the geodetic_char parameter file */
const char *get_sol_res_name(void);
const char *get_res_record_name(void);
const char *get_l0r_image_name(void);
const char *get_l1g_image_name(void);
const char *get_omf_file_name(void);
const char *get_work_order_id(void);
int get_wrs_path(void);
int get_wrs_row(void);
double get_roll_angle(void);
const char *get_capture_date(void);
const char *get_collection_type(void);
const char *get_spacecraft(void);
int get_precision_succeeded_flag(void);

#endif
