/*****************************************************************************
NAME:    output_resid_stats.c

PURPOSE: Statistics computed from GCP residuals are written to an output file.

RETURNS: SUCCESS or ERROR

******************************************************************************
                        Property of the U.S. Government
                            USGS EROS Data Center
*******************************************************************************/

#include "ias_logging.h"        /* Logging Library                          */
#include "ias_const.h"          /* ERROR/SUCCESS defines                    */
#include "geodetic_char.h"      /* prototypes for the three stats functions */


int output_resid_stats
(
    const GCP_RES_STATS *prefit_stats,  /* I: pre-fit GCP residual stats */
    const GCP_RES_STATS *postfit_stats, /* I: post-fit GCP residual stats */
    const char *gcp_source,             /* I: GCP source */
    int band_number                     /* I: The first pre-GCP band number */
)
{
    FILE *stats_fptr;           /* residual statistics file pointer       */
    int  status;                /* status of return from function         */


    /*----------------------------------------------------------------------
      Write to stats to the flat ASCII file.
      ----------------------------------------------------------------------*/
    stats_fptr = fopen(get_res_record_name(), "w");
    if (stats_fptr == NULL)
    {
        IAS_LOG_ERROR("Opening residual statistics output file: %s", 
            get_res_record_name());
        return ERROR;
    }

    /* write statistics to the ASCII file */
    status = write_residual_statistics_report(stats_fptr, prefit_stats,
        postfit_stats, gcp_source, band_number);
    if (status != SUCCESS)
    {
        IAS_LOG_ERROR("Writing the residual statistics output file");
        fclose(stats_fptr);
        return ERROR;
    }

    if (fclose(stats_fptr) == EOF)
    {
        IAS_LOG_ERROR("Closing the residual statistics output file");
        return ERROR;
    }

    return SUCCESS;
}
