#!/bin/csh -f
#
# Usage: ./retrieve_stats_from_db.csh [Input FILE]
#
# Where the Input FILE contains
#       Work Order ID
#       data path to expected results file (excluding $IAS_UNIT_TEST_DATA_DIR)
#       table name
#       column 1
#       column 2
#         ...
#       column N
#

# Ensure there is a database environment variable defined
if ( ! $?IAS_DB_L8_OLITIRS ) then
    echo "IAS_DB_L8_OLITIRS isn't set"
    exit 1
endif

# Ensure the test environment is set
if ( ! $?IAS_UNIT_TEST_DATA_DIR ) then
    echo "IAS_UNIT_TEST_DATA_DIR isn't set"
    exit 1
endif

set input_file = $1

# Grab the data from the file
set input_file_data = `cat $input_file`
# Get the Work Order ID
set woid = $input_file_data[1]
shift input_file_data
# Set the complete path to the expected results
set expected_results_file = $IAS_UNIT_TEST_DATA_DIR/$input_file_data[1]
shift input_file_data
# Get the table name
set table_name = $input_file_data[1]
shift input_file_data
# The input data variable now only contains column names


# Get the geometric common ID
set sql_script = "retrieve_woid.sql"
echo "set term off" > $sql_script
echo "set echo on" >> $sql_script
echo "set trimout on" >> $sql_script
echo "set trimspool on" >> $sql_script
echo "set heading off" >> $sql_script
echo "set feedback off" >> $sql_script
echo "set pause off" >> $sql_script
echo "set pagesize 0" >> $sql_script
echo "set linesize 500" >> $sql_script
echo "set space 0" >> $sql_script
echo "set colsep |" >> $sql_script
echo "set tab off" >> $sql_script
echo "set verify off" >> $sql_script
echo "spool ./woid.txt" >> $sql_script
echo "select work_order_id, geometric_wo_common_id " >> $sql_script
echo "from geometric_work_order_common " >> $sql_script
echo "where work_order_id='"$woid"';" >> $sql_script
echo "spool off" >> $sql_script
echo "exit" >> $sql_script

# Query the database
sqlplus $IAS_DB_L8_OLITIRS @$sql_script > & /dev/null
rm $sql_script

# Squeeze out the white space and select the lines beginning with the 
# work order ID
set common_id = `sed 's/  *//g' ./woid.txt | grep ^$woid | \
    awk -F'|' '{print $2}'`

# Create a script to query the database ... this is done here so that a
# separate script will not have to be maintained.  It will be used then
# removed at the end.
set sql_script = "retrieve_stats.sql"
echo "set term off" > $sql_script
echo "set echo on" >> $sql_script
echo "set trimout on" >> $sql_script
echo "set trimspool on" >> $sql_script
echo "set heading off" >> $sql_script
echo "set feedback off" >> $sql_script
echo "set pause off" >> $sql_script
echo "set pagesize 0" >> $sql_script
echo "set linesize 3000" >> $sql_script
echo "set space 0" >> $sql_script
echo "set colsep |" >> $sql_script
echo "set tab off" >> $sql_script
echo "set verify off" >> $sql_script
echo "spool ./db_results.txt" >> $sql_script
echo "select " >> $sql_script
# Insert the columns
set n = ${#input_file_data}
foreach column ( $input_file_data )
set i = 1
while ( $i <= $n )
    set column = $input_file_data[$i]
    if ( $i < $n ) then
        set column = "${column},"
    endif 
    echo $column >> $sql_script
    @ i++
end
echo "from " >> $sql_script
# Table
echo $table_name >> $sql_script
echo "where geometric_wo_common_id=$common_id;"  >> $sql_script
echo "spool off" >> $sql_script
echo "exit" >> $sql_script

# Query the database
sqlplus $IAS_DB_L8_OLITIRS @$sql_script > & /dev/null

# Squeeze out the white space and select the line with pipes
sed 's/  *//g' ./db_results.txt | grep '|' > ./db_results.tmp
sed 's/|/ /g' ./db_results.tmp | sort > ./db_results.txt

# Compare the results
set exit_status = 0
diff -q $expected_results_file ./db_results.txt
if ( $status != 0 ) then
    echo "diff $expected_results_file ./db_results.txt"
    echo "Database results differ from expected"
    set exit_status = 1
endif

rm ./db_results.txt ./db_results.tmp ./woid.txt $sql_script
exit $exit_status
