/*****************************************************************************
NAME:    update_omf.c

PURPOSE: Writes the statistics to the OMF

RETURNS:   SUCCESS or ERROR

*****************************************************************************/
#include "ias_const.h"
#include "ias_logging.h"
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "geometric_char.h"

int update_omf
(
    int number_valid_points,  /* I: number of valid points */
    double combined_rmse      /* I: the combined rmse value */
)
{
    int status;
    int write_count;

    /* Set up the parameter table */
    IAS_PARM_DECLARE_TABLE(parms, 2);

    IAS_PARM_GROUND_CONTROL_POINTS_VERIFY(parms, 0, NULL,
            &number_valid_points, sizeof(number_valid_points));
    IAS_PARM_SET_COUNT_WRITE(parms, GROUND_CONTROL_POINTS_VERIFY, 1);

    IAS_PARM_GEOMETRIC_RMSE_VERIFY(parms, 0, NULL,
            &combined_rmse, sizeof(combined_rmse));
    IAS_PARM_SET_COUNT_WRITE(parms, GEOMETRIC_RMSE_VERIFY, 1);

    /* Write the information */
    write_count = IAS_PARM_GET_TABLE_SIZE( parms );
    status = ias_parm_update( get_omf_filename(), parms, write_count );
    if ( status != SUCCESS )
    {
        IAS_LOG_ERROR("Writing parameters to %s", get_omf_filename());
        return ERROR;
    }

    return SUCCESS;
}  /* END update_omf */
