#ifndef _GET_RESAMPLE_PARAMETERS_H_
#define _GET_RESAMPLE_PARAMETERS_H_

#include "ias_const.h"   

typedef enum
{
   CC_RESAMPLING,
   MTF_RESAMPLING,
   NN_RESAMPLING,
   BI_RESAMPLING,
   NUMBER_RESAMPLING_TYPES
} RESAMPLE_TYPE;

typedef enum
{
    BYTE_OUTPUT,
    INT16_OUTPUT,
    UINT16_OUTPUT,
    INT32_OUTPUT,
    FLOAT_OUTPUT,
    NUMBER_OUTPUT_TYPES
} OUTPUT_DATA_TYPE;

/* The WINDOW_TYPE structure holds the parameters that define an image
   window.  Both the end line/sample and the number of lines/samples are
   included to allow the user to determine which method of defining the
   window is more convenient. */
typedef struct
{
    int start_line;
    int start_sample;
    int end_line;
    int end_sample;
    int num_lines;
    int num_samples;
} WINDOW_TYPE;

int read_resample_parameters
(
    const char *wo_parameter_filename   /* I: Work Order parameter
                                           filename that contains resample 
                                           parameters */
);

char *get_input_image_filename(void);

const int *get_band_list(void);

char *get_output_image_filename(void);

char *get_geom_grid_filename(void);

char *get_omf_filename(void);

int do_terrain_correction(void);

char *get_DEM_filename(void);

OUTPUT_DATA_TYPE get_output_data_type(void);

int get_max_processors_to_use(void); /* return maximum processor number to 
                                        use */
int get_output_data_size(void); /* returns bytes for current OUTPUT_DATA_TYPE */
int do_output_window(void);

const WINDOW_TYPE *get_output_window
(
    int band_index /* I: band index for the desired the output window */
);

void set_output_window
(
    int band_index, /* I: band index for the desired output window */
    int start_line,  /* I: starting line for the output window */
    int start_sample,/* I: starting sample for the output window */
    int num_lines,   /* I: number of lines in the output window */
    int num_samples  /* I: number of samples in the output window */
);

void set_scaled_output_window
(
    int band_index,     /* I: band index for the desired output window */
    float line_scaling,  /* I: scaling factor for the window line size */
    float sample_scaling /* I: scaling factor for the window sample size */
);

RESAMPLE_TYPE get_resampling_type(void);

float get_output_range_minimum(void);

float get_output_range_maximum(void);

float get_cubic_convolution_alpha(void);

float get_fill_pixel(void);

int get_processing_pass(void);

int get_doq_image_flag(void);

int get_satellite_number(void);
#endif 
