#ifndef _READ_INPUT_IMAGE_
#define _READ_INPUT_IMAGE_

#include "ias_types.h"     /* IAS_DATA_TYPE, IAS_ACCESS_MODE definitions */
#include "ias_l1g.h"       /* L1g I/O routines */

/*
**
** TYPE DEFINITIONS
**
*/

/* legal input data types */
typedef enum
{
   BYTE_IN,
   INT16_IN,
   UINT16_IN,
   INT32_IN,
   FLOAT_IN
} INPUT_DATA_TYPE;

/* This structure contains the state information for reading an
   input file. */
typedef struct
{
    L1GIO *input_file;          
    /* L1G input file id */

    L1G_BAND_IO *band_io;
    /* L1G band id */ 

    INPUT_DATA_TYPE in_dtype;
    /* type of data stored in image */

    int band_index;
    /* band_index being read */
    
    int samples_per_line;
    /* number of samples per line of input */

    void *buf_ptr;
    /* pointer to the buffer for storing the raw data read from the input
       file.  The storage is allocated when the file is opened to 
       prevent the allocation from taking place for each data set read. */
} IN_IMAGE_TYPE;

IN_IMAGE_TYPE *open_input_image
(
    char *input_filename,  /* I: input file name of image to open */
    int  band_index,       /* I: band index of image to open */
    int  *in_nl_ptr,       /* O: number of lines in image */
    int  *in_ns_ptr        /* O: number of samples in image */
);

int close_input_image
(
    IN_IMAGE_TYPE *in_image_ptr  /* I/O: pointer to image to close */
);

int read_input_lines
(
    IN_IMAGE_TYPE *in_image_ptr, /* I/O: input file state pointer */
    int   start_line,            /* I: current start line number */
    int   num_lines,             /* I: number of lines to read */
    float *buffer                /* O: data buffer */
);

#endif 
