#ifndef _WARP_H_
#define _WARP_H_

#include "ias_threadpool.h"          /* multiprocessing details */
#include "scanman.h"                 /* SCAN_MAN_TYPE definition */
#include "get_resample_parameters.h" /* RESAMPLE_TYPE definition */
#include "output_image_buffer.h"     /* OUTPUT_IMAGE_BUFFER_TYPE definition */


typedef struct
{
    struct ias_threadpool *threadpool;  /* I: threadpool to use */
    const IAS_GEOM_GRID_BAND_TYPE *grid_band_ptr; /*I:pointer to grid 
                                                      structure */
    int         band_index; /* I: current band index           */
    int         in_nl;      /* I: input space number of lines  */
    int         in_ns;      /* I: input space number of samples*/
    const SCAN_MAN_TYPE *scan_man_ptr; /* I: pointer to scan manager */
    int   resample_dir;     /* I: direction in which resampling should be
                                  performed (1=forward, -1 = reverse)*/
    int last_line_complete_index; /* I: last line index where all samples have
                                been completed (actually just an estimate due
                                to multiprocessing) */
    int returned_last_line_complete_index; /* O: last line completed by the 
                                                 last call to resample */
    int thread_error;       /* I/O : set to zero by warp and set
                               to thread number + 1 if an error occurs
                               in a thread.  If multiple threads 
                               encounter errors, the last thread to
                               encounter an error will be here */
    OUTPUT_IMAGE_BUFFER_TYPE *output_image_buffer_ptr;
                            /* I: pointer to output buffer structure */
    RESAMPLE_TYPE resample_type; /* type of resampling to apply */

} RESAMPLE_THREAD_PARAMS;

int warp
( 
    struct ias_threadpool *threadpool,  /* I: threadpool to use */
    const IAS_GEOM_GRID_TYPE *grid_ptr, /* I: pointer to grid */
    int band_index,                     /* I: current band  index    */
    RESAMPLE_TYPE resampling_type,      /* I: type of resampling */
    L1G_BAND_IO *output_l1g_band,       /* I: output I/O file pointer */
    int  lines_to_buffer,         /* I: number of input lines to buffer */
    int  procs_to_use,            /* I: number of processors to use */
    int  max_output_image_buffer, /* I: max memory in MB to use for buffering
                                        the output image */
    int  buffer_full_output_image /* I: flag to indicate entire output image
                                        should be kept in memory during 
                                        resampling */
);

#endif 

