#!/bin/csh -f

################################################################################
# NAME: test_l8_angles
#
# PURPOSE: Set up the environment and run the l8_angles program and check that
#          the results are correct.
#
################################################################################

# Set up the environment for the OLI tests.
set ERROR = 1
set SUCCESS = 0

set verify_dir = "$IAS_UNIT_TEST_DATA_DIR/ias_base/gps/l8_angles"
set log = "test_l8_angles.log"
set metafile = "LC81650342013170LGN00_ANG.verify"
set test_cases = ("rpc_sat" "rpc_solar" "rpc_both")
set parameters = ("${metafile} SATELLITE 7 -f 500 -b 3" \
                  "${metafile} SOLAR 3 -f 500 -b 10" \
                  "${metafile} BOTH 1 -f 500 -b 1" )
set sat_file = ("LC81650342013170LGN00_sensor_B03.img" \
                "LC81650342013170LGN00_sensor_B10.img" \
                "LC81650342013170LGN00_sensor_B01.img")

set solar_file = ("LC81650342013170LGN00_solar_B03.img" \
                 "LC81650342013170LGN00_solar_B10.img" \
                 "LC81650342013170LGN00_solar_B01.img")

set sat_vfile = ("LC81650342013170LGN00_sensor_B03_V2.img" \
                "LC81650342013170LGN00_sensor_B10.img" \
                "LC81650342013170LGN00_sensor_B01_V2.img")

set solar_vfile = ("LC81650342013170LGN00_solar_B03.img" \
                 "LC81650342013170LGN00_solar_B10_V2.img" \
                 "LC81650342013170LGN00_solar_B01_V2.img")

# Clean up the log
echo "" > $log

@ i = 1
@ j = 1
foreach test ($test_cases)

    # Run the simple view using the test odl file
    echo "Running test ${test}" | tee -a $log
    echo "../l8_angles $parameters[$j]"
    ../l8_angles $parameters[$j] >> $log
    if ( $status ) then
        echo "L8 angles test ${test} failed" | tee -a $log
        exit $ERROR
    endif

    # Verify the satellite image and header file
    if ( $i == "1" || $i == "0" ) then
        echo "    - diff -q $sat_file[$j] ${verify_dir}/${test}_$sat_vfile[$j]"\
            | tee -a $log
        diff -q $sat_file[$j] ${verify_dir}/${test}_$sat_vfile[$j]
        if ($status ) then
            echo "        - ERROR: Files differ"
            exit $ERROR
        endif
        echo "    - diff -q $sat_file[$j].hdr ${verify_dir}/" \
            "${test}_$sat_file[$j].hdr" | tee -a $log
        diff -q $sat_file[$j].hdr ${verify_dir}/${test}_$sat_file[$j].hdr
        if ($status ) then
            echo "        - ERROR: Files differ" | tee -a $log
            exit $ERROR
        endif

        rm $sat_file[$j]
        rm $sat_file[$j].hdr
    endif

    # Verify the solar image and header file
    if ( $i == "2" || $i == "0" ) then
        echo "    - diff -q $solar_file[$j] ${verify_dir}/${test}_" \
            "$solar_vfile[$j]" | tee -a $log
        diff -q $solar_file[$j] ${verify_dir}/${test}_$solar_vfile[$j]
        if ($status ) then
            echo "        - ERROR: Files differ"
            exit $ERROR
        endif
        echo "    - diff -q $solar_file[$j].hdr ${verify_dir}/" \
            "${test}_$solar_file[$j].hdr" | tee -a $log
        diff -q $solar_file[$j].hdr ${verify_dir}/${test}_$solar_file[$j].hdr
        if ($status ) then
            echo "        - ERROR: Files differ" | tee -a $log
            exit $ERROR
        endif

        rm $solar_file[$j]
        rm $solar_file[$j].hdr
    endif

    echo "Test ${test} completed Successfully" | tee -a $log
    echo "" | tee -a $log
    @ i = ($i + 1) % 3
    @ j = $j + 1
end

exit $SUCCESS
