/***************************************************************************
 NAME:                     update_omf

 PURPOSE:   Writes the generated Geometric Grid filename to the OMF
 
 RETURNS:   SUCCESS or ERROR

****************************************************************************/
#include <string.h>
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "ias_logging.h"
#include "ias_const.h"

#include "update_omf.h"

int update_omf
(
    char *omf_filename,        /* I: Name of OMF file */
    char *geom_grid_filename,  /* I: Name of the generated Geometric 
                                     Grid data file */
    int processing_pass,       /* I: Number of WO processing flow pass */
    int doq_image_flag         /* I: Process DEM or DOQ image */
)
{
    int write_count;              
    int write_status;

    /* Update the OMF based on whether a DOQ or a DEM is to be processed.  Use 
       full separate if blocks so macros are handled properly */
    if (doq_image_flag)
    {
        /* Set up the parameter table */
        IAS_PARM_DECLARE_TABLE(omf_param_out_table, 1);

        /* Don't use the processing pass for the DOQ */
        IAS_PARM_DOQ_GRID_FILENAME(omf_param_out_table, 
               geom_grid_filename, sizeof(geom_grid_filename), 0);
        IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, DOQ_GRID_FILENAME, 1);

        /* Write the information to the OMF */
        write_count = IAS_PARM_GET_TABLE_SIZE(omf_param_out_table);
        write_status = ias_parm_update(omf_filename, omf_param_out_table,
                                   write_count);
    }
    else
    {
        /* Set up the parameter table */
        IAS_PARM_DECLARE_TABLE(omf_param_out_table, 1);

        IAS_PARM_GEOM_GRID_FILENAME_FROM_PASS(omf_param_out_table, 
               IAS_PARM_REQUIRED, geom_grid_filename, 
               sizeof(geom_grid_filename), 0, processing_pass);                 

        IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, GEOM_GRID_FILENAME, 
                                 1);

        /* Write the information to the OMF */
        write_count = IAS_PARM_GET_TABLE_SIZE(omf_param_out_table);
        write_status = ias_parm_update(omf_filename, omf_param_out_table,
                                   write_count);
    }

    if (write_status != SUCCESS)
    {
        IAS_LOG_ERROR("Cannot write Geometric Grid filename to OMF file %s\n", 
                      omf_filename);
        return ERROR;
    }

    return SUCCESS;
}


