#ifndef BUFFER_OUTPUT_IMAGE_H
#define BUFFER_OUTPUT_IMAGE_H

#include "ias_l1g.h"
#include "ias_threadsync.h"
#include "ias_grid.h"
#include "track_tile.h"    /* TILE_TYPE */

/* forward reference to the OUTPUT_BUFFER structure so external code can handle
   pointers to it.  Note that the actual definition of the structure is never
   visible outside the buffer_output_image.c file. */
typedef struct output_buffer OUTPUT_BUFFER;

OUTPUT_BUFFER *open_output_image
(
    const char *filename    /* I: name of image file */
);

int open_output_band
(
    OUTPUT_BUFFER *img,     /* I: image to write */
    int band_index,         /* I: band index to start writing */
    int number_of_scas,     /* I: number of scas to include in the band */
    int lines,              /* I: number of lines in the band */
    int samples,            /* I: number of samples in the band */
    IAS_DATA_TYPE data_type /* I: data type for the output file */
);

int write_output_image_data
(
    OUTPUT_BUFFER *img,     /* I: pointer to image structure */
    const TILE_TYPE *tile,  /* I: pointer to tile location */
    IAS_THREAD_MUTEX_TYPE *hdf_io_mutex, /* I: HDF I/O mutex */
    void *tile_buf          /* I: pointer to the tile to write */
);

int close_output_band
(
    OUTPUT_BUFFER *img      /* I: pointer to image to close */
);

int close_output_image
(
    OUTPUT_BUFFER *img      /* I: pointer to image to close */
);

void reset_output_buffer
(
    OUTPUT_BUFFER *img,     /* I: pointer to image structure */
    int sca_index           /* I: sca_index to write */
);

int flush_output_buffer
(
    OUTPUT_BUFFER *img      /* I: pointer to image structure */
);

L1GIO* get_l1gio_ptr
(
    OUTPUT_BUFFER *img      /* I: pointer to image structure */
);

#endif
