/* IAS Library Includes */
#include "ias_logging.h"
#include "ias_grid_io.h"
#include "ias_model_io.h"
#include "ias_angle_gen.h"

/* Local Includes */
#include "calculate_angle_coeffs.h"

/******************************************************************************
NAME: calculate_coeff  

PURPOSE: Calculates the band angle coefficients on a background thread while
         the band resampling takes place. 

RETURN: SUCCESS / ERROR

******************************************************************************/
int calculate_angle_coeffs
(
    void *params,   /* I: pointer to input parameter structure */
    int thread_num  /* I: thread number for the thread running this routine */
)
{
    /* Cast the parameters struct and create local pointers for ease of use */
    COEFF_THREAD_PARAMS *param_ptr = (COEFF_THREAD_PARAMS *)params;
    const IAS_GRID_TYPE *grid_ptr = param_ptr->grid_ptr;
    const IAS_LOS_MODEL *model_ptr = param_ptr->model_ptr;
    IAS_ANGLE_GEN_METADATA *metadata = param_ptr->metadata;
    int band_index = param_ptr->band_index;
    int band_number;

    /* Get the current band number */
    band_number = ias_sat_attr_convert_band_index_to_number(band_index);
    if (band_number == ERROR)
    {
        IAS_LOG_ERROR("Converting band index %d to band number", band_index);
        param_ptr->thread_error += 1;
        return ERROR;
    }

    /* Get the band data needed for calculating the coefficients */
    if (ias_angle_gen_get_band_data(band_index, grid_ptr, model_ptr, metadata) 
        != SUCCESS)
    {
        IAS_LOG_ERROR("Getting the angle band data for band number %d",
            band_number);
        param_ptr->thread_error = 1;
        return ERROR;
    }
 
    /* Calculate the coefficients */
    if (ias_angle_gen_calculate_band_rpc(grid_ptr->gridbands[band_index], 
        band_index, metadata) != SUCCESS)
    {
        IAS_LOG_ERROR("Calculating the band coefficients for band number %d", 
            band_number);
        param_ptr->thread_error = 1;
        return ERROR;
    }

    return SUCCESS;
}
