#ifndef GET_INPUT_IMAGE_H
#define GET_INPUT_IMAGE_H

#include "ias_l0r.h"
#include "ias_l1r.h"
#include "ias_threadsync.h"
#include "track_tile.h"    /* TILE_TYPE definition */
#include "ias_satellite_attributes.h"

typedef struct input_image
{
    int band_number;    /* current band number */
    int scas;           /* count of SCAS in the open band */
    int nl;             /* number of lines */
    int ns;             /* number of samples */
    int is_l1r;         /* flag to indicate input is a L1R (1 = L1r, 0 = L0R) */
    L0RIO *l0r_file;    /* pointer to the L0R image if it is an L0R */
    L1RIO *l1r_file;    /* pointer to the L1R image if it is an L1R */
    L1R_BAND_IO *l1r_band; /* point to the L1R band that is open */
    IAS_THREAD_MUTEX_TYPE *io_lock; /* lock for serializing access to the file*/
    void *band_data[IAS_MAX_NSCAS];/* band data pointers */
    int read_whole_band;/* flag to indicate if entire band should be read */
    int buffer_message_issued;/* flag indicating if buffer message was output */
} INPUT_IMAGE;

INPUT_IMAGE *open_input_image
(
    const char *l1r_filename,   /* I: L1R filename to open */
    const char *l0r_filename    /* I: L0R filename to open if the L1R file name
                                      isn't provided. */
);

int open_input_band
(
    INPUT_IMAGE *image,     /* I: input image pointer */
    int band_number         /* I: band number to open */
);

void set_input_image_io_lock
(
    INPUT_IMAGE *image,             /* I: input image pointer */
    IAS_THREAD_MUTEX_TYPE *io_lock  /* I: pointer to the mutex to use for 
                                          serializing access to the file */
);

int read_input_image_data
(
    INPUT_IMAGE *image,         /* I: input image pointer */
    int sca_index,              /* I: SCA index to read */
    const TILE_TYPE *tile,      /* I: specification of the tile to read */
    float *tile_buffer          /* I/O: pointer to a buffer for the read data */
);

int close_input_band
(
    INPUT_IMAGE *image      /* I: input image pointer */
);

int close_input_image
(
    INPUT_IMAGE *image      /* I: input image pointer */
);

void setup_radiance_parameters
(
    int band_index /* I: current band */
);

float wrapped_apply_scaling_factors
(
    float input_value /* I: The value to apply scaling to */
);

int setup_qcal_min_max
(
    int band_number         /* I: band number to set up */
);

#endif
