/*****************************************************************************
NAME: get_output_image_buffer

PURPOSE: Helper routine to allocate a memory buffer for a chunk of the output
    image.

RETURNS:
    Pointer to the allocated buffer on success, NULL on an error

*****************************************************************************/
#include <stdlib.h>
#include "ias_types.h"
#include "get_resample_parameters.h"
#include "get_output_image_buffer.h"

void *get_output_image_buffer
(
    int nl,         /* I: number of lines in the buffer */
    int ns          /* I: number of samples in the buffer */
)
{
    IAS_DATA_TYPE output_data_type;

    output_data_type = get_output_data_type();

    if (output_data_type == IAS_I2)
    {
        short int *int16_ptr;
        int16_ptr = (short int *)malloc(sizeof(short int) * nl * ns);
        return int16_ptr;
    }
    else if (output_data_type == IAS_UI2)
    {
        unsigned short int *uint16_ptr;
        uint16_ptr = (unsigned short int *)malloc(sizeof(unsigned short int)
                                                 * nl * ns);
        return uint16_ptr;
    }
    else if (output_data_type == IAS_BYTE)
    {
        unsigned char *char_ptr;
        char_ptr = (unsigned char *)malloc(sizeof(unsigned char) * nl * ns);
        return char_ptr;
    }
    else if (output_data_type == IAS_R4)
    {
        float *float_ptr;
        float_ptr = (float *)malloc(sizeof(float) * nl * ns);
        return float_ptr;
    }
    else
    {
        int *int32_ptr;
        int32_ptr = (int *)malloc(sizeof(int) * nl * ns);
        return int32_ptr;
    }
}
