#ifndef _GET_RESAMPLE_PARAMETERS_H_
#define _GET_RESAMPLE_PARAMETERS_H_

#include "ias_types.h"  /* IAS_DATA_TYPE definition */
#include "ias_satellite_attributes.h" /* IAS_SATELLITE_ID definition */
#include "sca_overlap_io.h"

/*
**
** TYPE DEFINITIONS
**
*/

typedef enum
{
   CC_RESAMPLING,
   NN_RESAMPLING,
   NUMBER_RESAMPLING_TYPES
} RESAMPLE_TYPE;

typedef enum
{
   DEFAULT_BUFFER = -1,
   TILE_BUFFER = 0, 
   FULL_BAND_BUFFER = 1
} BUFFER_TYPE;

/*
** 
** FUNCTION PROTOTYPES
**
*/

int read_resample_parameters
(
    const char *parm_filename   /* I: Parameter filename that contains
                                      resample parameters */
);

int read_omf_parameters
(
    const char *omf_filename   /* I: OMF filename that contains order 
                                     parameters */
);

int process_parameters();

IAS_ACQUISITION_TYPE get_acquisition_type();
const int *get_band_index_list(void);
float get_output_range_minimum(void);
float get_output_range_maximum(void);
float get_cubic_convolution_alpha(void);
int get_create_ang_flag(void);
float get_fill_pixel(void);
char *get_1R_filename(void);
char *get_1G_filename(void);
char *get_grid_filename(void);
int do_terrain_correction(void);
int do_sca_combine(void);
int do_apply_cpf_rad_rescale(void);
char *get_DEM_filename(void);
IAS_DATA_TYPE get_output_data_type(void);
int get_output_data_size(void);
RESAMPLE_TYPE get_resampling_type(void);
BUFFER_TYPE get_buffer_type(void);
int get_input_image_buffer_threshold(void);
char *get_0R_filename(void);
char *get_CPF_filename(void);
char *get_model_filename(void);
int get_processing_pass(void);
int get_max_processors_to_use(void);
char *get_omf_filename(void);
IAS_SATELLITE_ID get_satellite_id(void);
SCA_OVERLAP_CHAR_TYPE get_sca_overlap_char_type(void);
char *get_sca_overlap_char_filename(void);

int get_wrs_path(void);
int get_wrs_row(void);

#endif /* _GET_RESAMPLE_PARAMETERS_H_ */
