#ifndef SCA_OVERLAP_IO_H
#define SCA_OVERLAP_IO_H

/* Define the type of SCA overlap characterization statistics that should be
   gathered.  The "limited" version collects just the essential information.
   It is the one that is used for processing data in LPGS. */
typedef enum
{
    SCA_OVERLAP_CHAR_NONE,
    SCA_OVERLAP_CHAR_LIMITED,
    SCA_OVERLAP_CHAR_FULL
} SCA_OVERLAP_CHAR_TYPE;

/* Forward reference to the sca_overlap_io structure */
typedef struct sca_overlap_io SCA_OVERLAP_IO;

/* This structure stores the full set of SCA overlap characterization
   information.  This level of information typically only collected when
   running in the IAS.  LPGS is usually configured to collect the limited
   set which is sufficient for characterizing the results. */
typedef struct sca_overlap_record
{
    int l1t_line;       /* L1G image line number */
    int l1t_sample;     /* L1G image sample number */
    int sca_zone;       /* Overlap zone number (same as left SCA number) */
    float l1r_value[2]; /* DN value from the left and right SCAs */
    float l1r_line[2];  /* Line number from the left and right SCAs */
    float l1r_sample[2];/* Sample number from the left and right SCAs */
} SCA_OVERLAP_RECORD;

/* This structure stores the limited set of SCA overlap characterization
   information which is typically gathered in LPGS. */
typedef struct limited_sca_overlap_record
{
    int sca_zone;       /* Overlap zone number (same as left SCA number) */
    float l1r_value[2]; /* DN value from the left and right SCAs */
    float l1r_line[2];  /* Line number from the left and right SCAs */
} LIMITED_SCA_OVERLAP_RECORD;

/* Define a union to allow refering to the correct type of pointer based on
   the type of SCA overlap characterization data being collected. */
typedef union sca_overlap_ptr
{
    SCA_OVERLAP_RECORD *full_ptr;
    LIMITED_SCA_OVERLAP_RECORD *limited_ptr;
} SCA_OVERLAP_PTR;

SCA_OVERLAP_IO *open_sca_overlap_file
(
    const char *filename,   /* I: File name to open */
    SCA_OVERLAP_CHAR_TYPE overlap_type /* I: Specifies the type of overlap data
                                             to write to the file */
);

int close_sca_overlap_file
(
    SCA_OVERLAP_IO *io      /* I: File to close */
);

int open_sca_overlap_band
(
    SCA_OVERLAP_IO *io,     /* I/O: Pointer to the previously opened file */
    int band_number         /* I: Band number to write */
);

int close_sca_overlap_band
(
    SCA_OVERLAP_IO *io      /* I/O: Pointer to the previously opened file */
);

int write_sca_overlap_records
(
    SCA_OVERLAP_IO *io,         /* I: File to write */
    const SCA_OVERLAP_PTR records_ptr, /* I: Set of records to write (can point
                                             to full or limited records) */
    int record_count            /* I: Count of records to write */
);

#endif
