#include <stdio.h>
#include <stdlib.h>

#include "ias_logging.h"
#include "ias_satellite_attributes.h"
#include "get_resample_parameters.h"
#include "update_omf.h"
#include "cgreen/cgreen.h"

int parameter_processing(char* ODL_filename)
{
    int status;

    /* Read the parameters from the parameter file and the omf file. */
    status = read_resample_parameters(ODL_filename);
    assert_equal(status, SUCCESS);

    /* Initialize the satellite attributes. */
    status = ias_sat_attr_initialize(get_satellite_id());
    assert_equal(status, SUCCESS);

    /* Do special processing on some parameters that were read. */
    status = process_parameters();
    assert_equal(status, SUCCESS);

    /* Write the L1G filename to the OMF */
    status = update_omf(get_omf_filename(), get_1G_filename(),
        "params_test_ANG.txt", get_sca_overlap_char_filename(),
        get_processing_pass());
    assert_equal(status, SUCCESS);

    /* test the radiance rescale flag, the default is one */
    assert_equal(do_apply_cpf_rad_rescale(), 0);

    return SUCCESS;
}

Ensure test1()
{
    char* ODL_filename = "TEST_PARAMS.odl";
    int result = parameter_processing(ODL_filename);
    assert_equal(result, SUCCESS);
}

int main(int argc, char **argv)
{
    TestSuite *suite = create_test_suite();
    add_test(suite, test1);
    if (argc > 1)
        return run_single_test(suite, argv[1], create_text_reporter());
    return run_test_suite(suite, create_text_reporter());
}

