/***************************************************************************
 NAME:                     update_omf

 PURPOSE:   Writes the generated L1G filename to the OMF
 
 RETURNS:   SUCCESS or ERROR

****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "ias_const.h"
#include "ias_logging.h"
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "get_resample_parameters.h"  /* read parameters routine */

int update_omf
(
    const char *omf_filename,       /* I: Name of OMF                       */
    char *l1g_image_filename,       /* I: Name of L1G image                 */
    char *ang_filename,             /* I: Angle coefficient filename        */
    char *sca_overlap_char_filename,/* I: SCA overlap char filename         */
    int processing_pass             /* I: Number of WO processing flow pass */
)
{
    int write_count;

    /* Set up the parameter table */
    IAS_PARM_DECLARE_TABLE(omf_param_out_table, 3);

    /* Add the output L1G filename */
    IAS_PARM_L1G_FILENAME_FROM_PASS(omf_param_out_table, IAS_PARM_REQUIRED,
        l1g_image_filename, sizeof(l1g_image_filename), 0,
        processing_pass);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, L1G_FILENAME, 1);

    /* Add the angle coefficient filename */
    IAS_PARM_ANGLE_COEF_FILENAME_FROM_PASS(omf_param_out_table, 
        IAS_PARM_OPTIONAL, ang_filename, sizeof(ang_filename), 1, 
        processing_pass);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, ANGLE_COEF_FILENAME, 1);  

    /* If the angle coefficient file wasn't created, pop it off the list */
    if (!get_create_ang_flag())
        IAS_PARM_POP_LAST_PARAMETER(omf_param_out_table);

    /* Add the SCA overlap characterization filename */
    IAS_PARM_SCA_OVERLAP_CHAR_FILENAME(omf_param_out_table, IAS_PARM_OPTIONAL,
        sca_overlap_char_filename, sizeof(sca_overlap_char_filename), 1);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, SCA_OVERLAP_CHAR_FILENAME, 1);

    /* If the SCA overlap characterization file wasn't created, pop it off the
       list */
    if (get_sca_overlap_char_type() == SCA_OVERLAP_CHAR_NONE)
        IAS_PARM_POP_LAST_PARAMETER(omf_param_out_table);

    write_count = IAS_PARM_GET_TABLE_COUNT(omf_param_out_table);

    if (ias_parm_update(omf_filename, omf_param_out_table, write_count) 
        != SUCCESS)
    {
        IAS_LOG_ERROR("Cannot write updates to OMF %s\n", omf_filename);
        return ERROR;
    }

    return SUCCESS;
}

