#ifndef SAVE_TO_DATABASE_H
#define SAVE_TO_DATABASE_H

#include <limits.h>     /* PATH_MAX */

#include "ias_const.h"  /* Constants */
#include "ias_satellite_attributes.h" /* Satellite attributes library */

#define MAX_RECORDS ((IAS_MAX_NBANDS * (IAS_MAX_NBANDS - 1) / 2)* IAS_MAX_NSCAS)
                        /* Band combo / SCA table */ 

/* Define a structure for the information to be collected and inserted into
   the IMAGE_CHARACTERIZATION/BAND_CHARACTERIZATION tables */
struct main_db_save_info
{
    char wo_id[IAS_WORKORDER_ID_SIZE]; /* Unlike the other fields here, 
                                              there isn't a DB column for wo_id
                                              in the tables */
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    char reference_image[PATH_MAX + 1];
    double t_distribution_threshold;
};

/* Define a structure for the information to be collected and inserted into
   the IMAGE_CHAR_BAND_SCA/BAND_CHAR_BAND_SCA tables */
struct band_sca_db_save_info
{
    char geometric_wo_common_id[IAS_CHAR_ID_SIZE];  
    int reference_band_id[MAX_RECORDS];
    int search_band_id[MAX_RECORDS];
    int sensor_chip_assembly_id[MAX_RECORDS];
    int nbr_of_pnts_corr[MAX_RECORDS];
    int nbr_of_pnts_successfully_corr[MAX_RECORDS];
    int nbr_of_vld_pnts[MAX_RECORDS];
    double rmse_line[MAX_RECORDS];
    double rmse_sample[MAX_RECORDS];
    double std_dev_line[MAX_RECORDS];
    double std_dev_sample[MAX_RECORDS];
    double min_line[MAX_RECORDS];
    double min_sample[MAX_RECORDS];
    double max_line[MAX_RECORDS];
    double max_sample[MAX_RECORDS];
    double med_line[MAX_RECORDS];
    double med_sample[MAX_RECORDS];
    double mean_line[MAX_RECORDS];
    double mean_sample[MAX_RECORDS];
};

int save_to_database
(
    struct main_db_save_info* main_ti, /* I/O: Main table data */
    struct band_sca_db_save_info* band_sca_ti, /* I/O: Band/SCA table data */
    const char *char_type,        /* I: "I2I" or "B2B" - tells routine if it's
                                        running image to image or band to band
                                        characterization */ 
    int number_records            /* I: The number of DB records */
);

#endif
