/******************************************************************************
NAME:           update_omf

PURPOSE:
Update the omf file with the output file name.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

NOTES:

ALGORITHM REFERENCES:
******************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <tdist.h>
#include <ias_parm.h>                      /* parameter library */
#include <ias_parm_standard_parameters.h>  /* parameter table standard fields */
int update_omf
(
    char *omf_file_name,
    char *residual_filename,
    char *input_gcp_source 
)
{

    char local_residual_filename[PATH_MAX];
    strncpy(local_residual_filename, residual_filename, PATH_MAX);

    if (strcmp(input_gcp_source, "B2B") == 0)
    {
        IAS_PARM_DECLARE_TABLE(omf_update_parms, 1);

        IAS_PARM_B2B_CHAR_RES_FILENAME(omf_update_parms,
             local_residual_filename, sizeof(local_residual_filename), 1);

        IAS_PARM_SET_COUNT_WRITE(omf_update_parms, B2B_CHAR_RES_FILENAME, 1);

        if (ias_parm_update(omf_file_name, omf_update_parms, 1) != SUCCESS)
        {
            IAS_LOG_ERROR("Updating omf file with residuals file name");
            return ERROR;
        }
    }
    else
    {
        IAS_PARM_DECLARE_TABLE(omf_update_parms, 1);

        IAS_PARM_ADD_STRING(omf_update_parms, I2I_CHAR_RES_FILENAME,
            "Output GCP residual file name", IAS_PARM_REQUIRED, 0, NULL,
            0, NULL, local_residual_filename,
            sizeof(local_residual_filename), 0);

        IAS_PARM_SET_COUNT_WRITE(omf_update_parms, I2I_CHAR_RES_FILENAME, 1);

        if (ias_parm_update(omf_file_name, omf_update_parms, 1) != SUCCESS)
        {
            IAS_LOG_ERROR("Updating omf file with residuals file name");
            return ERROR;
        }
    }

    return SUCCESS;
}
