/******************************************************************************
NAME:          calc_dem_bounds

PURPOSE:  Calculates minimum and maximum value within an image structure.
Used to find the maximum and minimum elevations within a DEM file.

RETURN VALUE:    Type = void

******************************************************************************/

#include "terrain_occlusion.h"

#include "ias_structures.h"

void calc_dem_bounds
(
    const IAS_IMAGE *dem,  /* I: DEM image data */
    int *elev_min,         /* O: Minimum elevation in DEM */
    int *elev_max          /* O: Maximum elevation in DEM */
)
{
    int ii;   /* Counters */
    unsigned int image_size = dem->nl * dem->ns; /* Total size of the image */
    int curr_value; 
    short *dem_data =  (short *)dem->data;

    *elev_min = dem_data[0];
    *elev_max = dem_data[0];


    for (ii = 1; ii < image_size; ii++)
    {
        curr_value = dem_data[ii];
 
        if (*elev_max < curr_value)
        {
            *elev_max = curr_value;
        }
        else if (*elev_min > curr_value)
        {
            *elev_min = curr_value;
        }
    }
}
