/*****************************************************************************
 * Name:    terrain_occlusion_test
 * 
 * Purpose: Unit tests for the terrain_occlusion application.  
 *
 * Notes:
 *****************************************************************************/

/* System Includes */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>

/* IAS Includes */
#include "../terrain_occlusion.h"
#include "ias_grid.h"
#include "ias_satellite_attributes.h"
#include "ias_logging.h"

/* Unit Test Includes */
#include "cgreen/cgreen.h"

Ensure test_get_parms(void);

int main(int argc, char *argv[])
{
    TestSuite *suite = create_test_suite();
    add_test(suite, test_get_parms);

    /* Run single test if provided as command line arg */
    if (argc == 2)
    {
        return run_single_test(suite, argv[1], create_text_reporter());
    }

    return run_test_suite(suite, create_text_reporter());
}

Ensure test_get_parms(void)
{
    char parm_file[PATH_MAX];
    char grid_file[PATH_MAX];
    char geom_grid_file[PATH_MAX];
    char occ_file[PATH_MAX];
    char dem_file[PATH_MAX];
    char work_order_id[PATH_MAX];
    char omf_file[PATH_MAX];
    int occ_band;
    int num_procs;
    int min_elev;
    int max_elev;
    int status;
    IAS_SATELLITE_ID sat_id;

    /**** Test 1: successful read */
    strcpy(parm_file, "TEST1.odl");

    status = get_parms(parm_file, grid_file, occ_file, geom_grid_file, 
        &occ_band, work_order_id, dem_file, omf_file, &num_procs, 
        &min_elev, &max_elev, &sat_id);
    
    if (status != SUCCESS)
    {
        assert_true_with_message(0, "Test 1: Error in get_parms");
        return;
    }

    assert_equal(strncmp(grid_file, "grid.file", PATH_MAX), 0);
    assert_equal(strncmp(dem_file, "dem.file", PATH_MAX), 0);
    assert_equal(strncmp(geom_grid_file, "geom_grid.file", PATH_MAX), 0);
    assert_equal(strncmp(work_order_id, "TEST1", PATH_MAX), 0);
    assert_equal(strncmp(omf_file, "TEST1.omf", PATH_MAX), 0);
    assert_equal(strncmp(occ_file, "occlusion_mask.h5", PATH_MAX), 0);
    assert_equal(num_procs, 4);
    assert_equal(occ_band, 6);
    assert_equal(min_elev, 200);
    assert_equal(max_elev, 500);
    assert_equal(sat_id, IAS_L8);

    /* Disable logging */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);

    /**** Test 2: Grid missing from OMF produces an error */
    strcpy(parm_file, "TEST2.odl");

    status = get_parms(parm_file, grid_file, occ_file, geom_grid_file, 
        &occ_band, work_order_id, dem_file, omf_file, &num_procs, 
        &min_elev, &max_elev, &sat_id);

    assert_equal(status, ERROR);    

    /**** Test 3: DEM missing from OMF produces an error */
    strcpy(parm_file, "TEST3.odl");

    status = get_parms(parm_file, grid_file, occ_file, geom_grid_file, 
        &occ_band, work_order_id, dem_file, omf_file, &num_procs, 
        &min_elev, &max_elev, &sat_id);

    assert_equal(status, ERROR);
   
    /**** Test 4: Geometric Grid missing from OMF produces an error */
    strcpy(parm_file, "TEST4.odl");

    status = get_parms(parm_file, grid_file, occ_file, geom_grid_file, 
        &occ_band, work_order_id, dem_file, omf_file, &num_procs, 
        &min_elev, &max_elev, &sat_id);

    assert_equal(status, ERROR);
   
    /* Enable logging */ 
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}
