#!/usr/bin/perl -w
use strict;

# Get the unit test directory env variable and escape the path separator
my $unit_test_dir = $ENV{IAS_UNIT_TEST_DATA_DIR};
my $unit_test_dir_esc = $unit_test_dir;
$unit_test_dir_esc =~ s/\//\\\//g;

# Build the sed command that replaces placehold with the unit test directory
my $cmd = "sed \"s/IAS_UNIT_TEST_DATA_DIR/$unit_test_dir_esc/g\" RUN.omf "
        . "> RUN_temp.omf";

# Create the temp OMF file
my $result = system($cmd);
if ($result != 0)
{
    print "ERROR: executing sed command for OMF\n";
    exit 1;
}

# Build and run the terrain_occlusion command
$cmd = "../terrain_occlusion RUN.odl";

$result = system($cmd);
if ($result != 0)
{
    print "ERROR: executing terrain_occlusion command\n";
    exit 1;
}

# Build the check command
$cmd = "h5diff $unit_test_dir/ias_base/gps/terrain_occlusion/output_data/"
     . "occlusion_mask.h5 occlusion_mask.h5 B01 B01";

$result = system($cmd);
if ($result != 0)
{
    print "ERROR: executing h5diff on results\n";
    exit 1;
}

# Check the ENVI header with a diff.
my $envi_header_file = "occlusion_mask.h5.hdr";

$cmd = "diff $unit_test_dir/ias_base/gps/terrain_occlusion/output_data/"
    . "$envi_header_file $envi_header_file";

$result = system($cmd);
if ($result != 0)
{
    print "diff of ENVI header file failed.\n";
    exit 1;
}

exit 0;
