/******************************************************************************
NAME:           update_omf

PURPOSE:
Update the omf file with the output file name.

RETURN VALUE:   Type = int
Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed

******************************************************************************/

#include <stdio.h>
#include <limits.h>
#include <string.h>

#include "terrain_occlusion.h"

#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"

int update_omf
(
    const char *omf_filename,           /* I: OMF filename */
    const char *occlusion_filename      /* I: Terrain occlusion filename */
)
{
    /* Initialize the OMF table */
    IAS_PARM_DECLARE_TABLE(omf_parms, 1);

    /* Add the occlusion filename parameter */
    IAS_PARM_OCCLUSION_FILENAME(omf_parms, (char *)occlusion_filename,
        sizeof(occlusion_filename));

    /* Set the number of parameters to write to the OMF */
    IAS_PARM_SET_COUNT_WRITE(omf_parms, OCCLUSION_FILENAME, 1);

    /* Update the OMF file */
    if (ias_parm_update(omf_filename, omf_parms, 1) != SUCCESS)
    {
        IAS_LOG_ERROR("Updating OMF with occlusion filename");
        return ERROR;
    }

    return SUCCESS;
}
