#include <string.h>
#include "ias_const.h"
#include "convert_geotiff_to_l1g.h"

/******************************************************************************
Name: is_l7_file

Purpose: Determines if the GeoTIFF file is from the L7 processing system
         based on the filename

Returns:
    TRUE
    FALSE
******************************************************************************/
int is_l7_file
(
    const char *filename        /* I: The GeoTIFF filename */
)
{
    const char *base_filename;      /* Pointer into the filename string */

    /* Find the last '/', or if there is none assume this is a filename
       only with no path component. If '/' found, advance one more char to
       the beginning of the filename. */
    base_filename = strrchr(filename, '/');
    if (base_filename)
        base_filename++;
    else
        base_filename = filename;

    /* The filename for a Landsat 7 scene is expected to begin with "L7" */
    if (strncasecmp("L7", base_filename, 2) == 0)
        return TRUE;

    return FALSE;
}

/******************************************************************************
Name: is_l7_ee_file

Purpose: Determines if the GeoTIFF file is from the L7 processing system
         as the files are named when downloaded from Earth Explorer (EE)
         based on the filename

Returns:
    TRUE
    FALSE
******************************************************************************/
int is_l7_ee_file
(
    const char *filename        /* I: The GeoTIFF filename */
)
{
    const char *base_filename;      /* Pointer into the filename string */

    /* Find the last '/', or if there is none assume this is a filename
       only with no path component. If '/' found, advance one more char to
       the beginning of the filename. */
    base_filename = strrchr(filename, '/');
    if (base_filename)
        base_filename++;
    else
        base_filename = filename;

    /* The filename for a Landsat 7 scene that was retrieved from Earth
       Explorer is expected to begin with "LE7" */
    if (strncasecmp("LE7", base_filename, 3) == 0)
        return TRUE;

    return FALSE;
}

/******************************************************************************
Name: is_l8_file

Purpose: Determines if the GeoTIFF file is from the L8 processing system
         based on the filename

Returns:
    TRUE
    FALSE
******************************************************************************/
int is_l8_file
(
    const char *filename        /* I: The GeoTIFF filename */
)
{
    const char *base_filename;      /* Pointer into the filename string */

    /* Find the last '/', or if there is none assume this is a filename
       only with no path component. If '/' found, advance one more char to
       the beginning of the filename. */
    base_filename = strrchr(filename, '/');
    if (base_filename)
        base_filename++;
    else
        base_filename = filename;

    /* The filename for a Landsat 8 scene is expected to begin with
       "LC8", "LO8", or "LT8" */
    if (strncasecmp("LC8", base_filename, 3) == 0)
        return TRUE;
    if (strncasecmp("LO8", base_filename, 3) == 0)
        return TRUE;
    if (strncasecmp("LT8", base_filename, 3) == 0)
        return TRUE;

    return FALSE;
}
