#ifndef CONVERT_GEOTIFF_TO_L1G_H
#define CONVERT_GEOTIFF_TO_L1G_H

#include "ias_const.h"
#include "ias_l1g.h"
#include "geotiff_io.h"

int check_metadata
(
    const IAS_L1G_FILE_METADATA *base_file_meta, /* I: Base file metadata */
    const IAS_L1G_BAND_METADATA *base_band_meta, /* I: Base band metadata */
    const IAS_L1G_FILE_METADATA *l1g_file_meta,  /* I: L1G file metadata */
    const IAS_L1G_BAND_METADATA *l1g_band_meta   /* I: L1G band metadata */
);

int convert_imagery
(
    const GEOTIFF_BAND_IO *gtiff_band,      /* I: GEOTIFF_BAND_IO structure */
    const char *l1g_filename,               /* I: The name of the output file */
    int sca_index,                          /* I: For L1G file format */
    L1G_BAND_IO *l1g_band                   /* O: L1G band to write to */
);

void convert_metadata
(
    const GEOTIFF_FILE_METADATA *gtiff_file_meta,
                                            /* I: GeoTIFF file-level metadata */
    const GEOTIFF_BAND_METADATA *gtiff_band_meta,
                                            /* I: GeoTIFF band-level metadata */
    IAS_L1G_FILE_METADATA *l1g_file_meta,   /* O: L1G file metadata */
    IAS_L1G_BAND_METADATA *l1g_band_meta    /* O: L1G band metadata */
);

int get_conversion_file_metadata
(
    const GEOTIFFIO *gtiff_file,        /* I: GEOTIFFIO structure */
    GEOTIFF_FILE_METADATA *metadata     /* O: Output metadata */
);

int is_l7_file
(
    const char *filename        /* I: The GeoTIFF filename */
);

int is_l7_ee_file
(
    const char *filename        /*: The GeoTIFF filename */
);

int is_l8_file
(
    const char *filename        /* I: The GeoTIFF filename */
);

int read_parameters
(
    int argc,                /* I: count of command line arguments */
    char *argv[],            /* I: command line arguments array */
    int max_files,           /* I: Max number of input GTIFF files */
    char *gtiff_file[],      /* O: GeoTIFF file name to convert */
    char **l1g_file,         /* O: Name of output L1G file to convert to */
    int *total_bands,        /* O: Total number of band file names read in */
    int *starting_band_number/* O: Starting band number in the list */
);

#endif
