/******************************************************************************
Name: convert_metadata

Purpose: Copies the metadata from the GeoTIFF structures into the L1G
         metadata structures

Returns:
    Nothing
******************************************************************************/
#include <stdlib.h>
#include <string.h>
#include "ias_const.h"
#include "ias_l1g.h"
#include "convert_geotiff_to_l1g.h"

void convert_metadata
(
    const GEOTIFF_FILE_METADATA *gtiff_file_meta,
                                            /* I: GeoTIFF file-level metadata */
    const GEOTIFF_BAND_METADATA *gtiff_band_meta,
                                            /* I: GeoTIFF band-level metadata */
    IAS_L1G_FILE_METADATA *l1g_file_meta,   /* O: L1G file metadata */
    IAS_L1G_BAND_METADATA *l1g_band_meta    /* O: L1G band metadata */
)
{
    int i;

    /* Initialize the L1G metadata structures */
    memset(l1g_file_meta, 0, sizeof(IAS_L1G_FILE_METADATA));
    memset(l1g_band_meta, 0, sizeof(IAS_L1G_BAND_METADATA));

    /* Copy the relevant GeoTIFF metadata into the L1G file-level metadata
       structure */
    l1g_file_meta->projection_code = gtiff_file_meta->projection_code;
    l1g_file_meta->zone_code = gtiff_file_meta->zone_code;
    strncpy(l1g_file_meta->datum, gtiff_file_meta->datum, IAS_DATUM_SIZE);
    l1g_file_meta->datum[IAS_DATUM_SIZE - 1] = '\0';
    l1g_file_meta->spheroid_code = gtiff_file_meta->spheroid_code;
    strncpy(l1g_file_meta->projection_units, gtiff_file_meta->projection_units,
            IAS_UNITS_SIZE);
    l1g_file_meta->projection_units[IAS_UNITS_SIZE - 1] = '\0';
    for (i = 0; i < IAS_PROJ_PARAM_SIZE; i++)
    {
        l1g_file_meta->projection_parameters[i]
            = gtiff_file_meta->projection_parameters[i];
    }
    l1g_file_meta->wrs_path = gtiff_file_meta->wrs_path;
    l1g_file_meta->wrs_row = gtiff_file_meta->wrs_row;
    strncpy(l1g_file_meta->spacecraft, gtiff_file_meta->spacecraft,
            IAS_L1G_SPACECRAFT_SIZE);
    l1g_file_meta->spacecraft[IAS_L1G_SPACECRAFT_SIZE - 1] = '\0';
    strncpy(l1g_file_meta->capture_direction,
            gtiff_file_meta->capture_direction, IAS_L1G_CAPTURE_DIRECTION_SIZE);
    l1g_file_meta->capture_direction[IAS_L1G_CAPTURE_DIRECTION_SIZE - 1] = '\0';
    strncpy(l1g_file_meta->capture_date, gtiff_file_meta->capture_date,
            IAS_L1G_CAPTURE_DATE_SIZE);
    l1g_file_meta->capture_date[IAS_L1G_CAPTURE_DATE_SIZE - 1] = '\0';
    l1g_file_meta->sun_angles_valid = 0;

    /* Copy the relevant GeoTIFF metadata into the L1G band-level metadata
       structure */
    l1g_band_meta->band_number = gtiff_band_meta->band_number;
    strncpy(l1g_band_meta->band_name, gtiff_band_meta->band_name,
            IAS_BAND_NAME_SIZE);
    l1g_band_meta->band_name[IAS_BAND_NAME_SIZE - 1] = '\0';
    l1g_band_meta->upper_left_y = gtiff_band_meta->upper_left_y;
    l1g_band_meta->upper_left_x = gtiff_band_meta->upper_left_x;
    l1g_band_meta->upper_right_y = gtiff_band_meta->upper_right_y;
    l1g_band_meta->upper_right_x = gtiff_band_meta->upper_right_x;
    l1g_band_meta->lower_left_y = gtiff_band_meta->lower_left_y;
    l1g_band_meta->lower_left_x = gtiff_band_meta->lower_left_x;
    l1g_band_meta->lower_right_y = gtiff_band_meta->lower_right_y;
    l1g_band_meta->lower_right_x = gtiff_band_meta->lower_right_x;
    l1g_band_meta->projection_distance_y
        = gtiff_band_meta->projection_distance_y;
    l1g_band_meta->projection_distance_x
        = gtiff_band_meta->projection_distance_x;
    l1g_band_meta->pixel_range_valid = 0;
    l1g_band_meta->radiance_valid = 0;
    l1g_band_meta->reflectance_valid = 0;
}
