/******************************************************************************
NAME: convert_l1g_to_ui16

PURPOSE:
Converts l1g hd5 files from 16 bit integer data to unsigned 16 bit data.

******************************************************************************/

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "ias_l1g.h"
#include "ias_types.h"
#include "ias_const.h"


int main(int argc, char *argv[])
{

    IAS_DATA_TYPE in_data_type;
    int i;
    int status;
    int in_sca_count;
    int in_line_count;
    int in_sample_count;
    int num_bands;
    int bands_processed = 0;
    IAS_DATA_TYPE out_data_type;
    L1GIO *input_image;
    L1GIO *output_image;
    L1G_BAND_IO *input_band;
    L1G_BAND_IO *output_band;
    char *input_filename;
    char *output_filename;
    IAS_L1G_BAND_METADATA bmd;
    IAS_L1G_FILE_METADATA fmd;

    if (argc < 3)
    {
        printf("Usage: convert_l1g_to_ui16 <input_file> <output_file>\n");
        exit(0);
    }
    
    input_filename = argv[1];
    output_filename = argv[2];

    input_image = ias_l1g_open_image(input_filename, IAS_READ);

    if (input_image == NULL)
    {
        printf("Can't open input file: %s\n", input_filename);
        exit(0);
    }

    num_bands = ias_l1g_get_band_count(input_image);


    output_image = ias_l1g_open_image(output_filename, IAS_WRITE);

    if (output_image == NULL)
    {
        printf("Can't open output file: %s\n", output_filename);
        exit(0);
    }

    printf("Number of bands: %d\n", num_bands);

    /* process one band at at time */
    i = 1;
    while (bands_processed < num_bands)
    {
        printf("Looking for band: %d\n", i);
        input_band = ias_l1g_open_band(input_image, i, &in_data_type,
                     &in_sca_count, &in_line_count, &in_sample_count);
        if (input_band == NULL)
        {
            i++;
            continue;
        }

        printf("Processing band: %d\n", i);
        short int *in_data = (short int *)malloc(in_sca_count * 
                          in_line_count * in_sample_count * sizeof(short int));

        status = ias_l1g_read_image(input_band, 0, 0, 0, in_line_count,
                     in_sample_count, in_data);

        /* change the data type to unsigned 16 bit */
        out_data_type = IAS_UI2;
        output_band = ias_l1g_open_band(output_image, i, &out_data_type,
                      &in_sca_count, &in_line_count, &in_sample_count);
        status = ias_l1g_write_image(output_band, 0, 0, 0, in_line_count,
                                     in_sample_count, in_data);

        status = ias_l1g_close_band(input_band);
        status = ias_l1g_close_band(output_band);
        bands_processed++;
    }

    printf("Processing metadata bands.\n");
    /* write band metadata. There may be more metadata than bands. */

    i = 1;
    while ( i < 12)
    {
        status = ias_l1g_get_band_metadata(input_image, i, &bmd);
        if (status == ERROR)
        {
            i++;
            continue;
        }
        printf("Processing metadata band: %d\n", i);
        bmd.maximum_pixel_value = 65535.0;
        status = ias_l1g_set_band_metadata(output_image, &bmd, 1);
        printf("status from ias_l1g_set_band_metadata: %d\n", status);
        i++;
    }

    status = ias_l1g_get_file_metadata(input_image, &fmd);

    if(status == SUCCESS)
    {
        ias_l1g_set_file_metadata(output_image, &fmd);
    }

    return(0);
}
