#!/usr/bin/perl -w
use strict;
use warnings;

use ias_const;

my $status;
my $system_call;
my $diff_count = 0;

# Get the unit test directory
my $data_dir = "$ENV{IAS_UNIT_TEST_DATA_DIR}";
$data_dir =~ s/\/+$//; # trim trailing slashes, if any

$data_dir = $data_dir . "/ias_base/gps/tools/dump_adp";

# Run the dump adp routine
$system_call = "../dump_adp " . $data_dir . "/ancillary_file.h5 test_adp_out";

$status = system($system_call);

# Diff the attitude data with the unit test directory
$status = system("diff test_adp_out.att.txt " . $data_dir . "/adp_out.att.txt");
if ($status == 0)
{
    print "There are no differences in the attitude data\n";
}
else
{
    print "There are differences in the attitude data\n";
    $diff_count++;
}

# Diff the ECEF data with the unit test directory
$status = system("diff test_adp_out.ecef.txt " . $data_dir . 
        "/adp_out.ecef.txt");
if ($status == 0)
{
    print "There are no differences in the ECEF data\n";
}
else
{
    print "There are differences in the ECEF data\n";
    $diff_count++;
}

# Diff the ECI data with the unit test directory
$status = system("diff test_adp_out.eci.txt " . $data_dir . 
        "/adp_out.eci.txt");
if ($status == 0)
{
    print "There are no differences in the ECI data\n";
}
else
{
    print "There are differences in the ECI data\n";
    $diff_count++;
}

if ($diff_count > 0)
{
    print "Differences were found\n";
    exit FAILURE;
}

print "Test completed successfully\n";

# Delete the files to clean up
system("rm test_adp_out.*");

exit SUCCESS;
