/******************************************************************************
NAME:           print_file_meta

PURPOSE:
Print the file metadata to a file.

Value    Description
-----    -----------
SUCCESS  Successful completion
ERROR    Operation failed 

******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "ias_l1g.h"
#include "ias_logging.h"
#include "dump_l1g_meta.h"

int print_file_meta
(
    const IAS_L1G_FILE_METADATA *fmd,   /* I: Pointer to the file metadata */
    FILE *ofile                         /* I/O: Output file pointer */
)
{
    int nn;

    if (fprintf(ofile, "File\n   Projection code: %d\n   Zone code: %d\n"
        "   Datum: %s\n   Spheroid: %d\n   Projection units: \"%s\"\n"
        "   Projection parameters\n", fmd->projection_code, fmd->zone_code, 
        fmd->datum, fmd->spheroid_code, fmd->projection_units) < 0)
    {
        IAS_LOG_ERROR("Unable to write file metadata to output file");
        return ERROR;
    }

    for (nn = 0; nn < IAS_PROJ_PARAM_SIZE; nn++)
    {
        if (fprintf(ofile, "      %e\n",fmd->projection_parameters[nn]) < 0)
        {
            IAS_LOG_ERROR("Unable to write file metadata to output file");
            return ERROR;
        }
    }
    if (fprintf(ofile, 
        "   Path/Row: %d/%d\n   Roll angle: %e\n   Spacecraft: \"%s\"\n"
        "   Collection type: \"%s\"\n   Direction: \"%s\"\n   Date: \"%s\"\n"
        "   Time: \"%s\"\n   Correction type: \"%s\"\n"
        "   Resampling type: \"%s\"\n   Software Version: \"%s\"\n"
        "   Ingest Software Version L0R: \"%s\"\n",
        fmd->wrs_path, fmd->wrs_row, fmd->roll_angle, fmd->spacecraft,
        fmd->collection_type, fmd->capture_direction, fmd->capture_date,
        fmd->capture_time, fmd->correction_type, fmd->resample_type,
        fmd->software_version, fmd->ingest_software_version) < 0)
    {
        IAS_LOG_ERROR("Unable to write file metadata to output file");
        return ERROR;
    }

    if (!fmd->sun_angles_valid)
    {
        if (fprintf(ofile, "   Sun Angle Valid: FALSE\n") < 0)
        {
            IAS_LOG_ERROR("Unable to write file metadata to output file");
            return ERROR;
        }
    }
    else  /* Sun angle data is valid, print it */
    {
        if (fprintf(ofile, "   Sun Angle Valid: TRUE\n   Sun Azimuth: %lf\n"
            "   Sun Elevation: %lf\n", fmd->sun_azimuth, fmd->sun_elevation)
            < 0)
        {
            IAS_LOG_ERROR("Unable to write file metadata to output file");
            return ERROR;
        }
    }
    
    return SUCCESS;
}
