#!/usr/bin/perl -w
use strict;
use warnings;

use ias_const;

sub diff_data($$$)
{
    my ($file1, $file2, $data_type) = @_;

    # Diff the files
    my $status = system("diff $file1 $file2");
    if ($status == 0)
    {
        print "There are no differences in the $data_type data\n";
        return 0;
    }
    else
    {
        print "There are differences in the $data_type data\n";
        return 1;
    }
}

my $status;
my $system_call;
my $diff_count = 0;

# Get the unit test directory
my $data_dir = "$ENV{IAS_UNIT_TEST_DATA_DIR}";
$data_dir =~ s/\/+$//; # trim trailing slashes, if any

$data_dir = $data_dir . "/ias_base/gps/tools/dump_los_model";

# Run the dump los model routine
$system_call = "../dump_los_model " . $data_dir . 
    "/systematic_model.h5 test_los_model_out";

$status = system($system_call);

# Diff the attitude data with the unit test directory
$diff_count += diff_data("test_los_model_out.att.txt",
    "$data_dir/los_model_out.att.txt", "attitude");

# Diff the ephemris data with the unit test directory
$diff_count += diff_data("test_los_model_out.eph.txt",
    "$data_dir/los_model_out.eph.txt", "ephemeris");

# Diff the jitter data with the unit test directory
$diff_count += diff_data("test_los_model_out.jitter.txt",
    "$data_dir/los_model_out.jitter.txt", "jitter");

# Diff the ssm data with the unit test directory
$diff_count += diff_data("test_los_model_out.tirs_ssm.txt",
    "$data_dir/los_model_out.tirs_ssm.txt", "tirs ssm");

# Diff the ssm data with the unit test directory
$diff_count += diff_data("test_los_model_out.tirs_frames.txt",
    "$data_dir/los_model_out.tirs_frames.txt", "tirs frame");

# Diff the oli frame data with the unit test directory
$diff_count += diff_data("test_los_model_out.oli_frames.txt",
    "$data_dir/los_model_out.oli_frames.txt", "oli frame");

if ($diff_count > 0)
{
    print "Differences were found\n";
    exit FAILURE;
}

print "Test completed successfully\n";

# Delete the files to clean up
system("rm test_los_model_out.*");

exit SUCCESS;
