
#ifndef EXTRACT_L1G_AREA_H
#define EXTRACT_L1G_AREA_H

/* IAS Includes */
#include "ias_l1g.h"
#include "ias_gcp.h"
#include "ias_geo.h"

/*****************************************************************************
 The following are the defines used by generate chips
*****************************************************************************/

/* We are only supporting 1 SCA so use a define for it */
#define SUPPORTED_SCAS 1

/* Create a type to hold information about the input L1G file */
typedef struct extract_area_l1g_data
{
    L1GIO *io_ptr; /* Pointer to the L1G object */
    IAS_L1G_FILE_METADATA metadata; /* Holds the metadata information for the
                                       L1G data */
    L1G_BAND_IO *band_io_ptr;            /* Pointer to the requested band */
    IAS_L1G_BAND_METADATA band_metadata; /* Holds the metadata for the
                                            specified band */
    IAS_DATA_TYPE data_type;     /* The data type of the band information */
    int number_of_scas;          /* The number of SCAs in the band */
    int number_of_image_lines;   /* The number of lines in the band */
    int number_of_image_samples; /* The number of samples in the band */
} EXTRACT_AREA_L1G_DATA;

/* User specified input parameters */
typedef struct extract_area_parameters
{
    /* COMMON Parameters */
    char l1g_filename[PATH_MAX];    /* Filename of the input L1G */
    char output_filename[PATH_MAX]; /* Filename of the GCPLib file */
    int band_number;                /* Band to use for generating the GCPs */
    int center_line_sample[2];    /* Starting line and sample to extract */
    int lines_samples[2];           /* How many lines and samples to extract */
} EXTRACT_AREA_PARAMETERS;

/*****************************************************************************
 The following are the routines used by extract L1G area
*****************************************************************************/

int read_parameters
(
    const char *param_filename,
    EXTRACT_AREA_PARAMETERS *parameters
);

int open_l1g_data
(
    const EXTRACT_AREA_PARAMETERS *parameters,
    EXTRACT_AREA_L1G_DATA *input_l1g_data,
    EXTRACT_AREA_L1G_DATA *output_l1g_data
);

int close_l1g_data
(
    const EXTRACT_AREA_L1G_DATA *input_l1g_data,
    const EXTRACT_AREA_L1G_DATA *output_l1g_data
);

#endif /* EXTRACT_L1G_AREA_H */

