#!/bin/csh
# 
# This script will run the quality_band_extraction application on the chosen
# quality band file, dump selected mask to an ENVI file, and then compare these
# values to the benchmark results.

# Set up variables for this test
set app = "quality_band_extraction"
set quality_band_filename = "${IAS_UNIT_TEST_DATA_DIR}/ias_base/gps/tools/quality_band_extraction/quality_band.h5"
set output_filename = "output.img"
set bit_mask = "0x0020"
set bit_value = "0x0020"

# Ensure the require environment is set
if (! -x ../${app}) then
    echo "Permission denied: ../${app}"
    exit 1;
endif

# Run ${app} on the quality band extraction
echo "Running: ../${app} ${quality_band_filename} ${output_filename} ${bit_mask} ${bit_value}"
../${app} ${quality_band_filename} ${output_filename} ${bit_mask} ${bit_value} >& /dev/null
if ($status != 0) then
    echo "ERROR running ${app}"
    exit 1
endif


# Compare the results against the benchmark results in
# ${IAS_UNIT_TEST_DATA_DIR}/ias_base/gps/tools/quality_band_extraction
echo "Comparing current results with benchmark results"
set dir = ${IAS_UNIT_TEST_DATA_DIR}/ias_base/gps/tools/${app}
diff -q ${dir}/output.img ./output.img
if ($status != 0) then
    echo "ERROR mask file differences found"
    exit 1
endif

diff -q ${dir}/output.img.hdr ./output.img.hdr
if ($status != 0) then
    echo "ERROR ENVI header file differences found"
    exit 1
endif

echo "SUCCESS: newly generated files match benchmark files for test"

# Remove the output files
rm -rf output.img output.img.hdr output_summary.txt

exit 0
