#!/usr/bin/perl -w

# test script for the ias_assess_x2x.pl utility

use strict; 
use ias_processing_system;  # define ias_error_msg and ias_validate_environment

# Define list of environment variables that we should check up-front to bail
# out sooner if our environment isn't setup as required
my @envVarsList = qw(
        IAS_DB_L8_OLITIRS
        ORACLE_SID
        );
my $envVarsListRef = \@envVarsList;

# make sure DB tests are enabled
if (!defined($ENV{ENABLE_DB_TESTS}))
{
    print "ias_assess_x2x.pl testing not performed. Requires database.\n";
    exit 0;
}

# Validate the required environment variables.
if (ias_validate_environment($envVarsListRef) > 0)
{
    print "$ias_error_msg\n";
    exit 1;
}

my $db_dump_file_b2b = 'b2b_output.txt';
my $db_dump_file_verify_b2b = 'b2b_output.txt.verify';
my $db_dump_file_i2i = 'i2i_output.txt';
my $db_dump_file_verify_i2i = 'i2i_output.txt.verify';

# delete any old database records
my $rc = system ('./delete_schema.sh');
if ($rc != 0)
{
    print "Delete schema failed: ./delete_schema.sh\n";
    exit 1;
}

print "DB cleanup passed\n";

# load database records
$rc = system ('./load_test_schema.sh');
if ($rc != 0)
{
    print "Load schema failed: ./load_test_schema.sh\n";
    exit 1;
}

print "Loading schema passed\n";

# test b2b version
$rc = system ('../../ias_assess_x2x.pl -vb2b -a 01-jan-2048,01-jan-2049 ' .
    '> b2b_output.txt');
    
if ($rc != 0)
{
    print 'Application failed: ../../ias_assess_x2x.pl -vb2b -a ',
          "01-jan-2048,01-jan-2049 > b2b_output.txt\n";
    exit 1;
}

# test i2i version
$rc = system ('../../ias_assess_x2x.pl -vi2i -a 01-jan-2048,01-jan-2049 ' .
    '> i2i_output.txt');
    
if ($rc != 0)
{
    print 'Application failed: ../../ias_assess_x2x.pl -vi2i -a ', 
          "01-jan-2048,01-jan-2049 > i2i_output.txt\n";
    exit 1;
}

print "Running utility passed\n";

# delete the database records
$rc = system ('./delete_schema.sh');
if ($rc != 0)
{
    print "Delete schema failed: ./delete_schema.sh\n";
    exit 1;
}

print "Database cleanup passed\n";

# diff the output records
my $diff_cmd = "sed '/Assessing band/,\$!'d $db_dump_file_b2b | "
             . "diff -q - $db_dump_file_verify_b2b";
$rc = system ($diff_cmd);
if ($rc != 0)
{
    print "Diff failed: $diff_cmd\n";
    exit 1;
}

$diff_cmd = "sed '/Assessing image/,\$!'d $db_dump_file_i2i | "
          . "diff -q - $db_dump_file_verify_i2i";
$rc = system ($diff_cmd);
if ($rc != 0)
{
    print "Diff failed: $diff_cmd\n";
    exit 1;
}

print "Output diff testing passed\n";

exit 0;
