package pcs_db;

############################################################################
#
# This is derived from the ALIAS file xxx_db.pm.
#
############################################################################

use strict;
use DBI;
 
use ias_processing_system;
use ias_const;
use ias_wo_const;           # Assign work order constants

use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
use Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(
                pcs_db_UpdatePwsStatus
                pcs_db_UpdatePwsState
                PWS_STATUS_RUNNING
                PWS_STATUS_STOPPED
                PWS_STATE_UP
                PWS_STATE_DOWN
            );

# constants for the status of each processing node
use constant PWS_STATUS_RUNNING   => "RUNNING";
use constant PWS_STATUS_STOPPED   => "STOPPED";

# constants for operator set state of a processing node
use constant PWS_STATE_UP   => "UP";
use constant PWS_STATE_DOWN => "DOWN";

############################################################################
# Name: pcs_db_UpdateNodeStatus
#
# Description: Updates the processing node status
#
# Parameters:
#   database handle
#   the new processing node status
#   hostname to udpate
#   reference for returning error message
#
# Return:
#   SUCCESS or ERROR
############################################################################
sub pcs_db_UpdatePwsStatus($$$$)
{
    my ($dbh, $status, $host, $err_ref) = @_;

    my $sql = "UPDATE processing_nodes "
            . "   SET status = '$status', "
            . "       status_date = sysdate "
            . " WHERE hostname = '$host'";

    # Execute the update statement
    my $rows_updated = $dbh->do($sql);

    # Check for errors
    if (not defined $rows_updated)
    {
        $err_ref = "Updating node status failed: $DBI::errstr";
        return ERROR;
    }

    # Check that the node was updated
    if ($rows_updated < 1)
    {
        $$err_ref = "No rows updated for $host";
        return ERROR;
    }

    if (!$dbh->commit())
    {
        $$err_ref = "Commiting node status update failed: $DBI::errstr";
        return ERROR;
    }

    return SUCCESS;
}

############################################################################
# Name: pcs_db_UpdateNodeState
#
# Description: Updates the processing node state
#
# Parameters:
#   database handle
#   the new processing node state
#   hostname to udpate
#   reference for returning error message
#
# Return:
#   SUCCESS or ERROR
############################################################################
sub pcs_db_UpdatePwsState($$$$)
{
    my ($dbh, $status, $host, $err_ref) = @_;

    my $sql = "UPDATE processing_nodes "
            . "   SET state = '$status' "
            . " WHERE hostname = '$host'";

    # Execute the update statement
    my $rows_updated = $dbh->do($sql);

    # Check for errors
    if (not defined $rows_updated)
    {
        $err_ref = "Updating node state failed: $DBI::errstr";
        return ERROR;
    }

    # Check that the node was updated
    if ($rows_updated < 1)
    {
        $$err_ref = "No rows updated for $host";
        return ERROR;
    }

    if (!$dbh->commit())
    {
        $$err_ref = "Commiting node state update failed: $DBI::errstr";
        return ERROR;
    }

    return SUCCESS;
}

1;
