#!/bin/sh

# This script loads the specified schema with default values for the tables
# which require them.  It also generates a log file in the current directory.
# The sqlldr generated "*.log" files are placed into the "logs" directory.
# The sqlldr generated "*.bad" files are placed into the "bad" directory.

PWD=`pwd`
LOG="$PWD/load_test_schema.log"
DB="$IAS_DB_COM"

# Initialize the log file.
DATE=`date`
echo "Created $DATE" 2>&1 > $LOG

# Create the log and bad file directories.
mkdir -p bad logs 2>&1 >> $LOG

# Process the tables.
echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading Processing Instance---------------------------" 2>&1 >> $LOG
NAME="dummy_instance"
sqlldr $DB control=$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
echo "sqlldr " $DB " control="$NAME.ldr log=logs/"$NAME".log bad=bad/"$NAME".bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PROCESSING_INSTANCE table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading MODULEStest ----------------------------------" 2>&1 >> $LOG
NAME="MODULEStest"
sqlldr $DB control=$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
echo "sqlldr " $DB " control="$NAME.ldr log=logs/"$NAME".log bad=bad/"$NAME".bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load MODULES table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading SUB_MODULEStest ------------------------------" 2>&1 >> $LOG
NAME="SUB_MODULEStest"
sqlldr $DB control=$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load SUB_MODULES table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading PARM_EDITStest -------------------------------" 2>&1 >> $LOG
NAME="PARM_EDITStest"
sqlldr $DB control=$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PARM_EDITS table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading PARAMETERStest -------------------------------" 2>&1 >> $LOG
NAME="PARAMETERStest"
sqlldr $DB control=$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PARAMETERS table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading DEF_PARMStest --------------------------------" 2>&1 >> $LOG
NAME="DEF_PARMStest"
sqlldr $DB control=$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load DEF_PARMS table failed."
    exit 1
fi

echo -n "."
echo "" 2>&1 >> $LOG
echo "--- Loading PARM_LISTtest --------------------------------" 2>&1 >> $LOG
NAME="PARM_LISTtest"
sqlldr $DB control=$NAME.ldr log=logs/$NAME.log bad=bad/$NAME.bad 2>&1 >> $LOG
if [ ! $? == 0 ]; then
    echo "Load PARM_LIST table failed."
    exit 1
fi

echo "."
echo "" 2>&1 >> $LOG
DATE=`date`
echo "Completed - $0 - $DATE" 2>&1 >> $LOG

