#ifndef CREATE_SATURATION_MASK_H
#define CREATE_SATURATION_MASK_H

#include "ias_pixel_mask.h"

/* Define a forward reference to the saturation structure */
typedef struct SATURATION_MASK SATURATION_MASK;

int create_l1r_saturation_mask
(
    SATURATION_MASK *sat_mask,    /* I/O: Saturated pixel tracking structure */
    const IAS_PIXEL_MASK_IO *pixel_mask_file, /* I: Pixel mask image */
    const IAS_LOS_MODEL *model,               /* I: LOS Model */
    const IAS_PROJECTION *l1g_projection,     /* I: L1G Projection */
    IAS_CORNERS *corners,              /* I: L1G Image Corners */
    const IAS_L1G_BAND_METADATA *band_metadata, /* I: band metadata structure */
    double min_elevation,              /* I: Minimum elevation in image */
    double max_elevation,              /* I: Maximum elevation in image */
    const IAS_IMAGE *dem,                    /* I: Elevation data */
    int output_saturation_mask_flag,   /* I: Flag to output saturation mask */
    const int is_band_present[IAS_MAX_NBANDS],/* I: Band present in L1G flags*/
    int band_has_saturation[IAS_MAX_NBANDS] /* O: Band saturation flags */
);

const unsigned char *get_l1r_saturation_mask
(
    const SATURATION_MASK *mask,    /* I: Saturated pixel tracking structure */
    int line                        /* I: Line in L1G buffer wanted */
);

SATURATION_MASK *initialize_saturation_mask
(
    int line_count,     /* I: Number of lines in the image */
    int sample_count    /* I: Number of samples in the image */
);

void identify_saturated_l1g_pixels
(
    SATURATION_MASK *mask,      /* I/O: Saturated pixel tracking structure */
    const unsigned short *image_values,/* I: DN values from the input image */
    int start_line,             /* I: Starting line in the image */
    int line_count,             /* I: Lines in image */
    int sample_count,           /* I: Samples in image */
    int band_number,            /* I: Band number being checked */
    int band_index              /* I: Band index being checked */
);

int want_l1g_saturation_for_band
(
    const SATURATION_MASK *mask,    /* I: Saturated pixel tracking structure */
    int band_index                  /* I: Band index to check */
);

const unsigned char *get_l1g_saturation_mask
(
    const SATURATION_MASK *mask,    /* I: Saturated pixel tracking structure */
    int line                        /* I: Line in L1G buffer wanted */
);

int read_and_check_l1g_band_saturation
(
    SATURATION_MASK *mask,   /* I/O: Saturated pixel tracking structure */
    L1GIO *l1g_file,         /* I: L1G image file containing the band to read */
    int band_number,         /* I: Band number to read */
    int band_index           /* I: Band index of the band number */
);

void update_bands_with_l1g_saturation
(
    const SATURATION_MASK *mask,    /* I: Saturated pixel tracking structure */
    int band_has_saturation[IAS_MAX_NBANDS] /* I/O: Band saturation flags */
);

void cleanup_saturation_mask
(
    SATURATION_MASK *mask       /* I: Saturated pixel tracking structure */
);

#endif
