/*==============================================================================
NAME: Names functions

PURPOSE:
    This file contains functions that return names of the algorithms and
    classifications that are user friendly.
==============================================================================*/

/* System Includes */

/* IAS Includes */
#include "ias_satellite_attributes.h"
#include "ias_logging.h"

/* Local Includes */
#include "assess_cloud_cover.h"


/*------------------------------------------------------------------------------
NAME: get_algorithm_name

PURPOSE:
    Given the enumeration representing a cloud cover algorithm, return that
    algorithm's name to the caller.  These names are the names of the algorithms
    that appear in the CPF.

RETURNS:
    String representation of the algorithm name
------------------------------------------------------------------------------*/
const char * get_algorithm_name
(
    int algorithm /* I: Cloud cover algorithm of interest */
)
{
    static char error[NAME_STRLEN] = "UnknownAlgorithm";
    static char names[NUM_ALGORITHMS][NAME_STRLEN] =
        {"ACCA", "ATACCA", "Cirrus", "See5", "Cfmask"};

    if ((algorithm >= 0) && (algorithm < NUM_ALGORITHMS))
        return names[algorithm];
    IAS_LOG_WARNING("Algorithm enumeration %d is out of range (0-%d)",
        algorithm, (NUM_ALGORITHMS-1));
    return error;
}
