/*******************************************************************************
Name: test_map_azimuth_angle

Purpose: Test the calculate_map_azimuth_angle routine.

*******************************************************************************/

/* System Includes */
#include <string.h>
#include <math.h>
#include "gctp.h"
#include "ias_geo.h"
#include "ias_logging.h"
#include "ias_geo.h"
#include "ias_math.h"
#include "calculate_map_azimuth_angle.h"
#include "cgreen/cgreen.h"


/*******************************************************************************
NAME: test_map_azimuth_angle

PURPOSE: Test driver for calculate_map_azimuth_angle.
*******************************************************************************/
Ensure test_map_azimuth_angle()
{
    IAS_L1G_FILE_METADATA fmd;
    IAS_L1G_BAND_METADATA bmd;
    double azimuth_angle_radians;
    int status;

    memset(&fmd, 0, sizeof(fmd));
    memset(&bmd, 0, sizeof(bmd));

    /* Test a UTM projection, which should return an angle of zero, leaving
       the projection parameters set to zero from the previous memset */
    fmd.projection_code = UTM;
    fmd.zone_code = 34;
    fmd.spheroid_code = WGS84_SPHEROID;
    strcpy(fmd.projection_units, "METERS");

    /* Set the band metadata corners */
    bmd.upper_left_y = 910800.0;
    bmd.upper_left_x = 494100.0;
    bmd.upper_right_y = 910800.0;
    bmd.upper_right_x = 718500.0;
    bmd.lower_left_y = 692400.0;
    bmd.lower_left_x = 494100.0;
    bmd.lower_right_y = 692400.0;
    bmd.lower_right_x = 718500.0;

    /* Calculate the map azimuth angle.  The results were confirmed by
       examining the reference scene used to set up the inputs. */
    status = calculate_map_azimuth_angle(&fmd, &bmd, &azimuth_angle_radians);
    assert_equal(status, SUCCESS);
    assert_double_equal(azimuth_angle_radians, -2.121749429e-03);

    /* Test a Polar Stereographic projection */
    memset(&fmd, 0, sizeof(fmd));
    memset(&bmd, 0, sizeof(bmd));
    fmd.projection_code = PS;
    fmd.zone_code = 0;
    fmd.spheroid_code = WGS84_SPHEROID;
    strcpy(fmd.projection_units, "METERS");
    /* Define the non-zero projection parameters */
    fmd.projection_parameters[0] = 6378137.0;
    fmd.projection_parameters[1] = 6356752.314245;
    fmd.projection_parameters[5] = -7.1E7;

    /* Set the band metadata corners */
    bmd.upper_left_y = -775200.0;
    bmd.upper_left_x = -555900.0;
    bmd.upper_right_y = -775200.0;
    bmd.upper_right_x = -285900.0;
    bmd.lower_left_y = -1044300.0;
    bmd.lower_left_x = -555900.0;
    bmd.lower_right_y = -1044300.0;
    bmd.lower_right_x = -285900.0;

    /* Calculate the map azimuth angle.  The results were confirmed by
       examining the reference scene used to set up the inputs. */
    status = calculate_map_azimuth_angle(&fmd, &bmd, &azimuth_angle_radians);
    assert_equal(status, SUCCESS);
    assert_double_equal(azimuth_angle_radians, -2.708265155e+00);
}

int main (int argc, char * argv[])
{
    TestSuite * suite  = create_test_suite();
    int         status;

    add_test(suite, test_map_azimuth_angle);

    if (argc > 1)
        status = run_single_test(suite, argv[1], create_text_reporter());
    else
        status = run_test_suite(suite, create_text_reporter());

    return status;
}
