#!/bin/csh
################################################################################
# Name: test_apply_sun_angle_correction
#
# Purpose: Tests the main functionality of apply_sun_angle_correction
#
################################################################################
set FAILURE=1
set SUCCESS=0
set work_order_id="I10000"
set log = "test_apply_sun_angle_correction.log"
set omf_file = "${work_order_id}.omf"
set parameter_file = "${work_order_id}.odl"
set data_dir = "$IAS_UNIT_TEST_DATA_DIR/ias_base/rps/apply_sun_angle_correction"
setenv IAS_VERSION_OVERRIDE "Y"

set tests = ( \
    "Scene_center_correction" \
    "Scene_center_reversal" \
    "Per_Pixel_correction" \
    "Per_Pixel_reversal")

set template_omf_files = ( \
    "./templates/template_${omf_file}" \
    "./templates/template_rev_${omf_file}" \
    "./templates/template_per_${omf_file}" \
    "./templates/template_per_rev_${omf_file}")

set template_parameter_files = ( \
    "./templates/template_${parameter_file}" \
    "./templates/template_rev_${parameter_file}" \
    "./templates/template_per_${parameter_file}" \
    "./templates/template_per_rev_${parameter_file}")

set output_files = ( \
    "l1t_sc_float.h5" \
    "l1t_sc_float_rev.h5" \
    "l1t_pp_uint.h5" \
    "l1t_pp_uint_rev.h5")

set verification_files = ( \
    "${data_dir}/l1t_sc_float.h5" \
    "${data_dir}/l1t_sc_float_rev.h5" \
    "${data_dir}/l1t_pp_uint.h5" \
    "${data_dir}/l1t_pp_uint_rev.h5")

# Clean up the log file
echo "" > $log
set i = 0

# Run each test and verify the output
foreach test ( $tests )
    @ i++

    echo "Running test {$test}" | tee -a $log
    # Copy the parameter file to current directory
    cp $template_parameter_files[$i] $parameter_file

    # Replace text in the template omf file
    sed -e "s|IAS_UNIT_TEST_DATA_DIR|$data_dir|" $template_omf_files[$i] > \
        $omf_file

    # Run apply_sun_angle_correction
    echo "    ../apply_sun_angle_correction $parameter_file"\
        | tee -a $log
    ../apply_sun_angle_correction $parameter_file >> $log
    if ( $status ) then
        echo "Failed: ../apply_sun_angle_correction $parameter_file" \
            | tee -a $log
        exit $FAILURE
    endif

    echo "    - h5diff -q -n 1 $output_files[$i] $verification_files[$i]" \
        | tee -a $log
    h5diff -q -n 1 $output_files[$i] $verification_files[$i]
    if ( $status ) then
        echo "Failed: h5diff -q -n 1 $output_files[$i] $verification_files[$i]" \
             | tee -a $log
        exit $FAILURE
    endif

    # Clean up
    rm $output_files[$i]
    rm $omf_file
    rm $parameter_file
end

