/***************************************************************************
 NAME:                     update_omf

 PURPOSE:   Writes the generated SUN_ANGLE_CORRECTED_L1G filename to the OMF
 
 RETURNS:   SUCCESS or ERROR

****************************************************************************/
/* Standard Library Includes */
#include <string.h>

/* IAS Library Includes */
#include "ias_const.h"
#include "ias_logging.h"
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"

/* Local Includes */
#include "apply_sun_angle_correction.h"

int update_omf
(
    SUN_ANGLE_CORRECTION_PARAMETERS *parameters /* I: Sun angle parameters */
)
{
    int write_count; /* OMF parameter count */

    /* Set up the parameter table */
    IAS_PARM_DECLARE_TABLE(omf_param_out_table, 1);

    IAS_PARM_SUN_ANGLE_CORRECTED_L1G_FILENAME(omf_param_out_table, 
        IAS_PARM_REQUIRED, parameters->l1g_output_filename, 
        sizeof(parameters->l1g_output_filename), 0);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table, 
        SUN_ANGLE_CORRECTED_L1G_FILENAME, 1);
   
    /* Get the write count for the table */
    write_count = IAS_PARM_GET_TABLE_SIZE(omf_param_out_table);
 
    /* Write the information to the OMF */
    if (ias_parm_update(parameters->omf_filename, omf_param_out_table, 
        write_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Cannot write updates to OMF %s\n",
            parameters->omf_filename);
        return ERROR;
    }

    return SUCCESS;
}

