#ifndef CONVERT_STRAY_LIGHT_TO_LAT_LONG_H
#define CONVERT_STRAY_LIGHT_TO_LAT_LONG_H

#include "ias_geo.h"
#include "ias_math.h"

#define COMPUTE_VECTOR_LENGTH(V) (sqrt(V[0] * V[0] + V[1] * V[1] + V[2] * V[2]))

typedef struct model_cache
{
    int line;
    double image_time;      /* time for the image line */
    IAS_VECTOR satpos;      /* Satellite position for the line */
    IAS_VECTOR satvel;      /* Satellite velocity for the line */
    double satpos_arr[3];   /* Satellite position array for line */
    double orb2ecf[3][3];   /* Orbit to ECEF transformation */
    double attpert[3][3];   /* Attitude perturbation matrix */
    double los2sc[3][3];    /* oli2acs * attpert * orb2ecf matrix */
    double ellipsoid[3];
    double inv_ellipsoid[3];
    double roll;
    double pitch;
    double yaw;
    double P[3];
    double MagP;
    const IAS_SENSOR_BAND_MODEL *band;
    const IAS_LOS_MODEL *model;
} MODEL_CACHE;

int prepare_cache_for_line
(
    int line,                           /* I: Input line number */
    int band_index,                     /* I: Input band index */
    int sca_index,                      /* I: SCA index */
    const IAS_LOS_MODEL *model,         /* I: LOS model information */
    const double major_axis,            /* I: Semi-major axis */
    const double minor_axis,            /* I: Semi-minor axis */
    MODEL_CACHE *cache                  /* O: Output matrix */
);

int convert_stray_light_to_lat_long_cached
(
    MODEL_CACHE *cache,
    const IAS_VECTOR *stray_light_vector,/* I: stray light vector in sensor
                                               coordinate system */
    double *target_latd,                /* O: Target latitude */
    double *target_long                 /* O: Target longitude */
);

#endif
