/* COTS Library Includes */
#include "gctp.h"

/* IAS Library Includes */
#include "ias_geo.h"
#include "create_projection_transformation.h"

/* Local Defines */
#define FROM_GEO 0
#define TO_GEO   1

/****************************************************************************
Name: create_projection_transformation

Purpose: Creates a projection transformation to convert coordinates using the
         input projection.

Returns: A pointer to the created transformation which is NULL if an error
         occurs.

****************************************************************************/
static IAS_GEO_PROJ_TRANSFORMATION *create_projection_transformation
(
    const IAS_PROJECTION *input_projection, /* I: Input projection */
    int to_geo_flag /* I: Flag to indicate create geographic to projection
                          transformation */
)
{
    IAS_PROJECTION geo;
    double proj_parms[IAS_PROJ_PARAM_SIZE];
    int index;

    /* Create the source geographic projection */
    for (index = 0; index < IAS_PROJ_PARAM_SIZE; index++)
        proj_parms[index] = 0.0;

    ias_geo_set_projection(GEO, -1, DEGREE, input_projection->spheroid,
        proj_parms, &geo);

    /* Create the transformation. If the to geo flag has been set it will
       return the geographic to projection transformation otherwise it will
       return the projection to geographic transformation */
    if (to_geo_flag)
    {
        return ias_geo_create_proj_transformation(input_projection, &geo);
    }
    return ias_geo_create_proj_transformation(&geo, input_projection);
}

/****************************************************************************
Name: create_geographic_to_target_transformation

Purpose: Creates a projection transformation to convert geographic coordinates
         to the target projection.

Returns: A pointer to the created transformation which is NULL if an error
         occurs.

****************************************************************************/
IAS_GEO_PROJ_TRANSFORMATION *create_geographic_to_target_transformation
(
    const IAS_PROJECTION *target_projection /* I: Target projection */
)
{
    return create_projection_transformation(target_projection, FROM_GEO);
}

/****************************************************************************
Name: create_source_to_geographic_transformation

Purpose: Creates a geographic projection transformation to convert the source
         projection coordinates to geographic coordinates

Returns: A pointer to the created transformation which is NULL if an error
         occurs.

****************************************************************************/
IAS_GEO_PROJ_TRANSFORMATION *create_source_to_geographic_transformation
(
    const IAS_PROJECTION *source_projection /* I: Source projection */
)
{
    return create_projection_transformation(source_projection, TO_GEO);
}
