#ifndef CREATE_TIRS_GHOST_IMAGE_H
#define CREATE_TIRS_GHOST_IMAGE_H

/* Standard Library Includes */
#include <limits.h>

/* IAS Library Includes */
#include "ias_l0r.h"
#include "ias_geo.h"
#include "get_l1g.h"

#define TIRS_STRAY_LIGHT_DIRECTORY "tirs_stray_light"

/* Define a structure for holding a requested band, sca, detector and frame
   for reporting the sampled locations */
typedef struct sampling_location_structure
{
    int band_index;
    int sca_index;
    int detector_index;
    int frame_index;
} SAMPLING_LOCATION;

/* Create a type to hold all the possible input parameters */
typedef struct ghost_image_parameters
{
    char stray_light_correction_filename[PATH_MAX];
    char stray_light_vector_filename[PATH_MAX];
    char radiance_coefficient_filename[PATH_MAX];
    char water_mask_filename[PATH_MAX];
    char l1g_filename[PATH_MAX];
    char model_filename[PATH_MAX];
    char l0r_filename[PATH_MAX];
    char omf_filename[PATH_MAX];
    char landsat_scene_id[IAS_L0R_SCENE_ID_LENGTH + 1];
    char source_image_sensor[20];
    char source_image_filename[PATH_MAX];
    int max_processors;
    int apply_radiance_coefficients;
    int blur_kernel_size;
    int sample_location_requested_flag;
    int use_land_water_radiance_average_flag;
    SAMPLING_LOCATION sampling_location;
    int output_files_to_envi_flag;
    double semi_major_axis;
    double semi_minor_axis;
    int spheroid;
    int process_band[IAS_MAX_NBANDS];
    int number_bounding_box_frame_sections;
} GHOST_IMAGE_PARAMETERS;

int read_parameters
(
    const char *parameter_filename,         /* I: Parameter file name */
    GHOST_IMAGE_PARAMETERS *parameters      /* O: Processing parameters */
);

int update_omf
(
    const char *omf_filename,       /* I: Name of OMF */
    char *stray_light_filename      /* I: Name of stray light image */
);

int initialize_directory
(
    const char *directory      /* I: Directory to create/check */
);

#endif /* CREATE_TIRS_GHOST_IMAGE_H */

