/*****************************************************************************
Name: find_image_corners

Purpose: Finds the corners of the input imagery

Returns: SUCCESS / ERROR

*****************************************************************************/
/* Standard Library Includes */
#include <stdlib.h>

/* IAS Library Includes */
#include "ias_logging.h"
#include "ias_const.h"

/* Local Includes */
#include "find_image_corners.h"

int find_image_corners
(
    const float *image,  /* I: Imagery used to find corners */
    int lines,           /* I: Number of lines in imagery */
    int samples,         /* I: Number of samples in imagery */
    int *corner_lines,   /* O: Line array of 4 corners */
    int *corner_samples  /* O: Sample array of 4 corners */
)
{
    int line;   /* Line loop variable */
    int sample; /* Sample loop variable */
    int found;  /* Flag indicating the corner was found */

    /* Find the lower left corner */
    found = 0;
    for (sample = 0; sample < samples && !found; sample++)
    {
        for (line = lines - 1; line >= 0; line--)
        {
            if (image[line * samples + sample] != 0.0)
            {
                corner_lines[0] = line;
                corner_samples[0] = sample;
                found = 1;
                break;
            }
        }
    }
    if (!found)
    {
        IAS_LOG_ERROR("Unable to find the lower left corner");
        return ERROR;
    }

    /* Find the upper left corner */
    found = 0;
    for (line = 0; line < lines && !found; line++)
    {
        int line_index = line * samples;
        for (sample = 0; sample < samples; sample++)
        {
            if (image[line_index + sample] != 0.0)
            {
                corner_lines[1] = line;
                corner_samples[1] = sample;
                found = 1;
                break;
            }
        }
    }
    if (!found)
    {
        IAS_LOG_ERROR("Unable to find the upper left corner");
        return ERROR;
    }

    /* Find the upper right corner */
    found = 0;
    for (sample = samples - 1; sample >= 0 && !found; sample--)
    {
        for (line = 0; line < lines; line++)
        {
            if (image[line * samples + sample] != 0.0)
            {
                corner_lines[2] = line;
                corner_samples[2] = sample;
                found = 1;
                break;
            }
        }
    }
    if (!found)
    {
        IAS_LOG_ERROR("Unable to find the upper right corner");
        return ERROR;
    }

    /* Find the lower right corner */
    found = 0;
    for (line = lines - 1; line >= 0 && !found; line--)
    {
        int line_index = line * samples;
        for (sample = samples - 1; sample >= 0; sample--)
        {
            if (image[line_index + sample] != 0.0)
            {
                corner_lines[3] = line;
                corner_samples[3] = sample;
                found = 1;
                break;
            }
        }
    }
    if (!found)
    {
        IAS_LOG_ERROR("Unable to find the lower right corner");
        return ERROR;
    }

    return SUCCESS;
}
