#ifndef GRID_H
#define GRID_H

#include "ias_structures.h" /* IAS_COEFFICIENTS definition */
#include "ias_geo.h"        /* IAS_GEO_PROJ_TRANSFORMATION definition */

/* Define a simple grid structure */
typedef struct grid
{
    IAS_COEFFICIENTS *coeffs;   /* Coefficients for converting from lat/long to
                                   the map projection.  Contains rows * columns
                                   entries. */
    int rows;           /* Rows in the grid */
    int columns;        /* Columns in the grid */
    double *in_y;       /* Input coordinates in the line direction with
                           in_y_size elements */
    double *in_x;       /* Input coordinates in the sample direction with
                           in_x_size elements */
    int in_y_size;      /* Number of elements in in_y */
    int in_x_size;      /* Number of elements in in_x */
    double *out_y;      /* Output coordinates in grid (in_y_size * in_x_size) */
    double *out_x;      /* Output coordinates in grid (in_y_size * in_x_size) */
    double ul_y;        /* Upper left corner y coordinate */
    double ul_x;        /* Upper left corner x coordinate */
    double cell_size;   /* Size of cell in x/y directions */
} GRID;

int create_grid
(
    IAS_GEO_PROJ_TRANSFORMATION *proj_trans, /* I: Target projection */
    double in_ul_x,           /* I: Upper left x coordinate */
    double in_ul_y,           /* I: Upper left y coordinate */
    double in_lr_x,           /* I: Lower right x coordinate */
    double in_lr_y,           /* I: Lower right y coordinate */
    double x_pixel_size,      /* I: X pixel size of the target image */
    double y_pixel_size,      /* I: Y pixel size of the target image */
    GRID *grid,               /* O: Grid to create */
    int *valid_grid_created_flag /* O: Indicates a valid grid was created
                                       (1 = valid, 0 = invalid).  This can be
                                       set to invalid if the input bounding box
                                       crosses 180 degrees */
);

void free_grid
(
    GRID *grid /* I: Grid to free */
);

#endif
