/* Standard C Includes */
#include <sys/stat.h>
#include <errno.h>
#include <string.h>

/* IAS Includes */
#include "ias_const.h"
#include "ias_logging.h"
#include "create_tirs_ghost_image.h"

/*****************************************************************************
Name: initialize_directory

Purpose: To initialize a directory or to ensure that it already exists

Returns: Type = int
    Value      Description
    ---------  --------------------------
    SUCCESS    Successful completion
    ERROR      Operation failed

*****************************************************************************/
int initialize_directory
(
    const char *directory      /* I: Directory to create/check */
)
{
    struct stat directory_stat; /* Holds stat's info for the directory */
    int status;                 /* Status of stat call */

    /* Verify that the output directory exists, if it doesn't then create it */
    status = stat(directory, &directory_stat);
    if (status == 0)
    {
        if (!S_ISDIR(directory_stat.st_mode))
        {
            /* Does exist but is not a directory */
            IAS_LOG_ERROR("%s already exists and is not a directory",
                directory);
            return ERROR;
        }
    }
    else
    {
        if (errno == ENOENT)
        {
            /* Directory does not exist so create it */
            status = mkdir(directory, 0777);
            if (status != 0)
            {
                IAS_LOG_ERROR("Creating the directory %s", directory);
                return ERROR;
            }
        }
        else
        {
            const char *error_msg = strerror(errno);

            /* Error besides does not exist error was thrown */
            IAS_LOG_ERROR("Error while running stat for %s. %s", directory,
                error_msg);
            return ERROR;
        }
    }

    return SUCCESS;
}
