#ifndef READ_STRAY_LIGHT_VECTORS_H
#define READ_STRAY_LIGHT_VECTORS_H

#include "ias_math.h"       /* IAS_VECTOR definition */
#include "local_defines.h"

/* Structure to hold a single stray light vector */
typedef struct stray_light_record
{
    IAS_VECTOR stray_light_vector; /* LOS vector of the stray light component */
    double weight;      /* Weight to assign this vector sample */
} STRAY_LIGHT_RECORD;

typedef struct stray_light_vectors
{
    STRAY_LIGHT_RECORD *records;    /* Bulk set of records */
    STRAY_LIGHT_RECORD *indexed[NUMBER_OF_TIRS_BANDS][NUMBER_OF_TIRS_SCAS]
        [NUMBER_OF_TIRS_DETECTORS]; /* Indexed by band/sca/detector */
    int count[NUMBER_OF_TIRS_BANDS][NUMBER_OF_TIRS_SCAS]
        [NUMBER_OF_TIRS_DETECTORS]; /* count of records for each detector */
} STRAY_LIGHT_VECTORS;

int read_stray_light_vectors
(
    const char *filename,            /* I: Stray light vector filename */
    STRAY_LIGHT_VECTORS *stray_light /* O: Stray light vectors */
);

void free_stray_light_vectors
(
    STRAY_LIGHT_VECTORS *stray_light /* I: Stray light vectors */

);

#endif
