#ifndef SAMPLE_STRAY_LIGHT_H
#define SAMPLE_STRAY_LIGHT_H

#include "create_tirs_ghost_image.h"

typedef struct sample_params
{
    const IAS_LOS_MODEL *model; /* I: Line-of-sight model */
    const GRID *grid;           /* I: Grid to map lat/long to map proj */
    int valid_grid_flag;        /* I: Flag indicating the grid provided is
                                      valid */
    L1G_INFO *l1g_info;         /* I: L1G image */
    int start_frame;            /* I: Starting frame number */
    int end_frame;              /* I: Ending frame number */
    int l1r_frames;             /* I: Count of number of frames */
    int band_index;             /* I: Band index */
    int band_number;            /* I: Band number */
    int sca_index;              /* I: SCA index */
    int detector_count;         /* I: Detector count per SCA */
    int sample_location_requested_flag; /* I: An output file for a sample 
                                              location was requested */
    SAMPLING_LOCATION *sampling_location; /* I: Requested sampling location */
    int apply_radiance_coefficients; /* I: Flag to apply the 'a' and 'b'
                                           coefficients */
    const int *corner_lines;    /* I: line numbers of the 4 image corners */
    const int *corner_samples;  /* I: sample numbers of the 4 image corners */
    const STRAY_LIGHT_VECTORS *stray_light_vectors;/* I: Stray light vectors */
    const RADIANCE_COEFFICIENTS *rad_coeffs; /* I: radiance coefficients */
    float *ghost;               /* O: ghost image */
    IAS_THREAD_MUTEX_TYPE frame_mutex; /* I: Thread mutex for next frame */
    int next_frame; /* I/O: Next frame in image */
    int use_land_water_radiance_average_flag; /* I: Use average radiance instead
                                                    of sampled radiance */
    IAS_BYTE_TYPE *water_mask; /* I: Water mask */
    int mask_samples;
    int mask_line_offset; /* I: Line offset from the water mask to the L1G */
    int mask_samp_offset; /* I: Samp offset from the water mask to the L1G */
    double semi_major_axis;
    double semi_minor_axis;
    int outside_grid_flag; /* O: Flag to indicate points were outside the 
                                 grid */
} SAMPLE_PARAMS;

int sample_stray_light
(
    void *params,   /* I: Sample parameters struct */
    int thread_num  /* I: Thread number */
);

int find_bounding_box_using_model
(
    const IAS_LOS_MODEL *model, /* I: LOS Model */
    const STRAY_LIGHT_VECTORS *stray_light_vectors, /* I: Stray light vectors */
    int band_index,         /* I: Band index */
    int sca_index,          /* I: SCA index */
    int frame_count,        /* I: Number of frames in imagery */
    double major_axis,      /* I: Semi-major axis */
    double minor_axis,      /* I: Semi-minor axis */
    int frame_sections,     /* I: Number of frame sections to sample */
    double *out_min_lat,    /* O: Minimum latitude in degrees */
    double *out_max_lat,    /* O: Maximum latitude in degrees */
    double *out_min_lng,    /* O: Minimum longitude in degrees */
    double *out_max_lng     /* O: Maximum longitude in degrees */
);

#endif
