/***************************************************************************
Name:                     update_omf

Purpose:   Writes the generated L1G filename to the OMF

Returns:   SUCCESS or ERROR

****************************************************************************/
/* Standard Library Includes */
#include <string.h>

/* IAS Library Includes */
#include "ias_const.h"
#include "ias_logging.h"
#include "ias_parm.h"
#include "ias_parm_standard_parameters.h"
#include "create_tirs_ghost_image.h"

int update_omf
(
    const char *omf_filename,       /* I: Name of OMF */
    char *stray_light_filename      /* I: Name of stray light image */
)
{
    /* Set up the parameter table */
    IAS_PARM_DECLARE_TABLE(omf_param_out_table, 1);

    IAS_PARM_STRAY_LIGHT_CORRECTION_FILENAME(omf_param_out_table,
        IAS_PARM_REQUIRED, stray_light_filename,
        strlen(stray_light_filename) + 1, 1);
    IAS_PARM_SET_COUNT_WRITE(omf_param_out_table,
        STRAY_LIGHT_CORRECTION_FILENAME, 1);

    /* Write the information to the OMF */
    if (ias_parm_update(omf_filename, omf_param_out_table, 1) != SUCCESS)
    {
        IAS_LOG_ERROR("Cannot write updates to OMF %s\n", omf_filename);
        return ERROR;
    }

    return SUCCESS;
}

