/*----------------------------------------------------------------------------
NAME:    generic_parameter_removal

PURPOSE: Remove the per-detector input parameter from the input data buffer

RETURNS: none
-----------------------------------------------------------------------------*/
#include "rps_local.h"

void generic_parameter_removal
(
    float *data_buffer,      /* I/O: On input data at some processing, on
                                   output data with the parameter removed */
    int number_detectors,    /* I: Number of detectors */
    int number_lines,        /* I: Number of lines */
    const double *parameter  /* I: Per-detector parameter to remove from the
                                   input buffer */
)
{
    int det_index;       /* detector loop index */
    int line_index;      /* Line loop index */

    /* Loop through the detectors.  An outer detector loop is used here
       since the same thresholds and remapping coefficients are used for
       all the detector samples. */
    for (det_index = 0; det_index < number_detectors; det_index++)
    {
        float *data_buffer_ptr = &data_buffer[det_index];
        float parameter_value = (float)parameter[det_index];

        /* Loop through the lines */
        for (line_index = 0; line_index < number_lines; line_index++)
        {
            /* Update the image data with bias removal applied */
            data_buffer_ptr[0] -= parameter_value;

            /* Move the pointer to the next line */
            data_buffer_ptr += number_detectors;
        }  
    } 
} 
