/******************************************************************************
 NAME:    residual_striping_correction

 PURPOSE: The algorithm described herein implements a cosmetic approach for 
          residual striping removal in radiometrically corrected image data 
          assuming a standard relative gain correction has already been 
          applied. Data obtained from the striping characterization algorithm 
          will be used to drive the Residual Striping Correction algorithm.
 
 RETURNS: Nothing

******************************************************************************/
#include "rps_local.h"


void residual_striping_correction
(
    float *l1r_image_buffer,           /* I/O: Image data for the current
                                              band/SCA */
    double *striping_correction_matrix,/* I: Scene striping correction matrix 
                                            for the current band/SCA */
    int num_detectors,                 /* I: Number of detectors per SCA */
    int num_frames                     /* I: Number of frames in the data */
)
{
    long pixel;              /* Loop counter for the pixels */
    long num_pixels;         /* Local variable for total pixels in image */ 

    /* Calculate number of pixels */
    num_pixels = num_frames * num_detectors;

    /* Loop through the pixel across frames and detectors */
    for (pixel = 0; pixel < num_pixels; pixel++)
        l1r_image_buffer[pixel] -= striping_correction_matrix[pixel]; 
}  
