/*----------------------------------------------------------------------------
NAME:    temperature_sensitivity_correction

PURPOSE: Calculate the temperature sensitivity corrections as needed.

RETURNS: SUCCESS or ERROR
-----------------------------------------------------------------------------*/

void temperature_sensitivity_correction
(
    int num_detectors,              /* I: Number of detectors in the SCA */
    double mean_focal_temp,         /* I: Mean focal plane temperature */
    const double *temp_sens_coeff,  /* I: Temperature sensitivity 
                                          coefficients, its size is 
                                          num_detectors */
    float ref_temp,                 /* I: Reference temperature */
    double *temp_correction_factor  /* O: Temperature correction factor  */
)
{
    int det;

    /* Loop through each detector of the input data */
    for (det = 0; det < num_detectors; det++)
    {
        /* Calculate detector level temperature correction factor */
        temp_correction_factor[det] = 
            (1 + temp_sens_coeff[det] * mean_focal_temp) / 
            (1 + temp_sens_coeff[det] * ref_temp);

    }  /* END for det loop */
}  /* END temperature_sensitivity_correction */

