#ifndef RPS_ALGORITHM_H
#define RPS_ALGORITHM_H

/* Bias determination bias source selection.  This is here since it is used
   by two algorithms. */
typedef enum bias_source
{
    PRE_ACQUISITION_SHUTTER = 0,
    POST_ACQUISITION_SHUTTER,
    MEAN_ACQUISITION_SHUTTER,
    CPF_BIAS,
    A1_C1_ESTIMATION
} BIAS_SOURCE;

typedef enum background_response_selection
{
    PRE_ACQUISITION_DEEP_SPACE = 1,
    POST_ACQUISITION_DEEP_SPACE,
    MEAN_ACQUISITION_DEEP_SPACE,
    CPF_DARK_AND_BACKGROUND_RESPONSE
} BACKGROUND_RESPONSE_SELECTION;

/* ---------------------------------------------------------------------- */
/* ----------------------- General API Prototypes ----------------------- */
/* ------------- These are the interface to library routines ------------ */
int api_dump_imagery
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int dump_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int dump_postprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int api_dropped_frame_characterization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int dropped_frame_characterization_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int api_convert_to_float
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int convert_to_float_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int api_tirs_histogram_statistics_characterization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int api_oli_histogram_statistics_characterization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int histogram_statistics_characterization_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int histogram_statistics_characterization_postprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int store_histogram_statistics_per_sca_to_db
(
    void *message; /* I: Pointer to IAS_RPS_SCENE_SUMMARY_STATISTICS
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

int store_histogram_summary_stats_in_database
(
    DB_SCENE_SUMMARY_STATISTICS **statistics,/* I: Stats array ptr */
    const int num_scas                       /* I: Total SCAs */
);

int api_saturated_pixel_characterization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int saturated_pixel_characterization_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int api_inoperable_detector_identification
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int inoperable_detector_identification_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int api_tirs_dark_response_determination
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int tirs_dark_response_determination_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int tirs_dark_response_determination_postprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int api_impulse_noise_characterization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int impulse_noise_characterization_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int api_tirs_stray_light_correction
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int tirs_stray_light_correction_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int tirs_stray_light_correction_postprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ---------------------------------------------------------------------- */
/* ---------------- Algorithm Structures and Prototypes ----------------- */
/* -------------- These are the ones with local algorithms -------------- */

/* ---------- SCA Discontinuity Correction ---------- */
int sca_discontinuity_correction
(
    float *data_buffer,         /* I/O: Input and output L1R data buffer */
    int num_detectors,          /* I: Number of detectors in the SCA */
    int num_lines,              /* I: Number of lines in the data */
    IAS_PIXEL_MASK *pixel_mask, /* I: Contains pixel artifacts */
    double correction_factor    /* I: Normalized corection factor */
);

int api_sca_discontinuity_correction
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int sca_discontinuity_correction_preprocess
(
    BLOB *blob                 /* I: Miscellaneous parameters */
);

int sca_discontinuity_correction_postprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ---------- Inoperable Detectors Fill ------------- */
int inoperable_detectors_fill
(
    float *l1r_buffer,                  /* I/O:  On input--original pixel
                                           values
                                           On output--adjusted pixel
                                           values */
    int number_detectors,               /* I: Number of detectors in the
                                           current band/SCA */
    int number_lines,                   /* I: Number of lines in the current
                                           SCA */
    int *det_offsets,                   /* I: Normalized CPF detector offsets
                                           for the current band/SCA */
    IAS_PIXEL_MASK *pmask               /* I: Pixel mask for the current
                                           band/SCA */
);

int api_inoperable_detectors_fill
(
    BLOB *blob,                         /* I: Miscellaneous processing
                                           parameters */
    int  band_index,                    /* I: Current band */
    int  sca_index,                     /* I: Current SCA */
    int  algo_index                     /* I: Current algorithm */
);

int inoperable_detectors_fill_preprocess
(
    BLOB *blob                          /* I: Miscellaneous processing
                                           parameters */
);


/* ---------- Saturated Pixel Replacement ---------- */
int api_saturated_pixel_replacement
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int saturated_pixel_replacement
(
    float *data_buffer,         /* I/O: Input and output L1R data buffer */
    int num_detectors,          /* I: Number of detectors in the SCA */
    int num_lines,              /* I: Number of lines in the data */
    IAS_PIXEL_MASK *pixel_mask, /* I: Contains pixel artifacts */
    float high_replace,         /* I: High replacement value */
    float low_replace,          /* I: Low replacement value */
    int digital_high_flag,      /* I: Digitally high pixals are replaced flag*/
    int digital_low_flag,       /* I: Digitally low pixals are replaced flag */
    int analog_high_flag,       /* I: Analog high pixals are replaced flag */
    int analog_low_flag         /* I: Analog high pixals are replaced flag */
);

int saturated_pixel_replacement_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ---------- Detector Response Characterization Lamp ---------- */

/* The enumeration defined here matches the 'Stim Lamp Bulb Pair
   Selection' bits (bits 0 and 1) in the 'stl_flags' field in the L0R OLI
   telemetry_group_4 information.  The bit values are as follows.  The left
   bit is bit 1, the right is bit 0.
   
   00  --  'pristine' pair
   01  --  'backup'   pair
   10  --  'working'  pair
   11  --  no         pair */
typedef enum lamp_pair_type
{
    LAMP_PRISTINE_PAIR=0,            /* STIM PRISTINE LAMP PAIR */
    LAMP_REFERENCE_PAIR=1,           /* STIM REFERENCE LAMP PAIR */
    LAMP_WORKING_PAIR=2,             /* STIM WORKING LAMP PAIR */
    LAMP_NONE_PAIR=3                 /* STIM LAMP NONE PAIR */
} LAMP_PAIR_TYPE;

typedef enum report_file_type
{
    REPORT_FILE_ERROR=-1,
    REPORT_FILE_DETECTOR=1,         /* Detector level report file */
    REPORT_FILE_SCA,                /* SCA level report file */
    REPORT_FILE_BAND,               /* Band level report file */
    REPORT_FILE_RESPONSE,           /* Lamp response report file */
    REPORT_FILE_TELEMETRY           /* Lamp telemetry report file */
} REPORT_FILE_TYPE;

typedef struct db_char_lamp_response_detector_results
{
    struct ias_db_connection *dbase;  /* Database connection structure */
    char rad_common_id[IAS_CHAR_ID_SIZE];   /* Radiometric common id */ 
    int  band;                        /* 1-based band number */
    int  sca;                         /* 1-based SCA number */
    int  num_detectors;               /* Number of detectors per SCA */
    int  *detector;                   /* List of 1-based detector number */
    float *db_mean;                   /* Detector level mean */
    float *db_stdev;                  /* Detector level standard deviation */ 
    float *db_skewness;               /* Detector level skewness */   
    float *db_kurtosis;               /* Detector level kurtosis */   
    float *db_corrected;              /* Detector level corrected mean */   
    char *processing_level;           /* RPS data level */  
} DB_CHAR_LAMP_RESPONSE_DETECTOR_RESULTS;

/* Detector level statistics for stim lamp data */
typedef struct db_char_lamp_response_one_sca_results
{
    struct ias_db_connection *dbase;    /* Database connection structure */ 
    char rad_common_id[IAS_CHAR_ID_SIZE];   /* Radiometric common id */ 
    int  band;                          /* 1-based band number */
    int sca;                            /* 1-based SCA number */
    float db_mean;                      /* Detector level mean */
    float db_stdev;                     /* Detector level standard deviation */
    float db_corrected;                 /* Corrected mean value */
    char *processing_level;             /* RPS data level */
} DB_CHAR_LAMP_RESPONSE_ONE_SCA_RESULTS;

/* SCA level statistics for stim lamp data */
typedef struct db_char_lamp_response_sca_results
{
    struct ias_db_connection *dbase;     /* Database connection structure */
    char rad_common_id[IAS_CHAR_ID_SIZE];   /* Radiometric common id */ 
    int  band;                           /* 1-based band number */
    int  num_scas;                       /* Total numbers of SCA */
    int *sca;                            /* List of 1-based SCA numbers */
    float *db_mean;                      /* SCA level mean */ 
    float *db_stdev;                     /* SCA level standard deviation */   
    float *db_corrected;                 /* Corrected mean value */  
    char *processing_level;              /* RPS data level */    
} DB_CHAR_LAMP_RESPONSE_SCA_RESULTS;

/* Band level statistics for stim lamp data */
typedef struct db_char_lamp_response_band_results
{
    struct ias_db_connection *dbase;     /* Database connection structure */
    char rad_common_id[IAS_CHAR_ID_SIZE];   /* Radiometric common id */ 
    int num_bands;                       /* Total numbers of bands */
    int *band;                           /* List of 1-based band numbers */
    float *db_mean;                      /* Band level mean */ 
    float *db_stdev;                     /* Band level standard deviation */   
    float *db_corrected;                 /* Corrected mean value */     
    char *processing_level;              /* RPS data level */      
} DB_CHAR_LAMP_RESPONSE_BAND_RESULTS;

/* Stim lamp response data */
typedef struct db_char_lamp_response_results
{
    struct ias_db_connection *dbase;     /* Database connection structure */
    char rad_common_id[IAS_CHAR_ID_SIZE];   /* Radiometric common id */ 
    int  lamp_pair_id;                   /* Lamp pair id */
    float lamp_on_time;                  /* Lamp turn on time */
    float interval_start_time;           /* Processing interval start time */
    float interval_stop_time;            /* Processing interval stop time */
    int interval_start_line;             /* Processing interval start line */  
    int interval_stop_line;              /* Processing interval stop line */   
    float lamp_warmup_time;              /* Lamp warm up time */   
    int lamp_warmup_start_line;          /* Lamp warm up start line */   
    int lamp_warmup_stop_line;           /* Lamp warm up stop line */     
} DB_CHAR_LAMP_RESPONSE_RESULTS;

/* Stim lamp telemetry data */
typedef struct db_char_lamp_telemetry_results
{
    struct ias_db_connection *dbase;     /* Database connection structure */
    char rad_common_id[IAS_CHAR_ID_SIZE];   /* Radiometric common id */ 
    float lamp_current_a_mean;           /* Group A lamp current mean value */
    float lamp_current_a_stdev;          /* Group A lamp current standard 
                                            deviation */
    float lamp_voltage_a_mean;           /* Group A lamp voltage mean value */ 
    float lamp_voltage_a_stdev;          /* Group A lamp voltage standard 
                                            deviation */ 
    float photodiode_micro_amp_a_mean;   /* Group A photodiode current mean 
                                            value */    
    float photodiode_micro_amp_a_stdev;  /* Group A photodiode current standard
                                            deviation */    
    float lamp_housing_temp_a_mean;      /* Group A lamp housing temeperature 
                                            mean value */ 
    float lamp_housing_temp_a_stdev;     /* Group A lamp housing temperature 
                                            standard deviation */ 
    float monitor_diode_temp_a_mean;     /* Group A monitor diode temeperature 
                                            mean value */    
    float monitor_diode_temp_a_stdev;    /* Group A monitor diode temperature 
                                            standard deviation */ 
    float lamp_current_b_mean;           /* Group B lamp current mean value */
    float lamp_current_b_stdev;          /* Group B lamp current standard 
                                            deviation */
    float lamp_voltage_b_mean;           /* Group B lamp voltage mean value */ 
    float lamp_voltage_b_stdev;          /* Group B lamp voltage standard 
                                            deviation */ 
    float photodiode_micro_amp_b_mean;   /* Group B photodiode current mean 
                                            value */    
    float photodiode_micro_amp_b_stdev;  /* Group B photodiode current standard
                                            deviation */    
    float lamp_housing_temp_b_mean;      /* Group B lamp housing temeperature 
                                            mean value */ 
    float lamp_housing_temp_b_stdev;     /* Group B lamp housing temperature 
                                            standard deviation */ 
    float monitor_diode_temp_b_mean;     /* Group B monitor diode temeperature 
                                            mean value */    
    float monitor_diode_temp_b_stdev;    /* Group B monitor diode temperature 
                                            standard deviation */ 
    float fp_temp_7_mean;                /* Focal plane temperature channel 7 
                                            mean */
    float fp_temp_7_stdev;               /* Focal plane temperature channel 7 
                                            stdev */    
    float fp_temp_14_mean;               /* Focal plane temperature channel 14 
                                            mean */    
    float fp_temp_14_stdev;              /* Focal plane temperature channel 14 
                                            stdev */    
} DB_CHAR_LAMP_TELEMETRY_RESULTS;

int char_lamp_detector_response
(
    int band_number,             /* I: Band number, 1-based */
    int sca_number,              /* I: SCA number, 1-based */
    int num_detectors,           /* I: Number of detectors in the SCA */
    int num_lines,               /* I: Number of lines in the data */
    int lamp_pair_id,            /* I: Lamp pair ID */
    float lamp_on_time,          /* I: Lamp power on time */
    float post_warmup_start_time,/* I: Start time for post warmup period */
    float post_warmup_stop_time, /* I: Stop time for post warmup period */
    int post_warmup_start_frame, /* I: Start frame number for post warmup 
                                       period */ 
    int post_warmup_stop_frame,  /* I: Stop frame number for post warmup 
                                       period */ 
    IAS_PIXEL_MASK *pixel_mask,  /* I: Contains inop detector and other
                                       ignore pixel locations */
    IAS_RPS_HISTOGRAM_INTERMEDIATE_RESULTS *statistics_results,
                                 /* I: Statistics results from the Histogram
                                       Statistics calculation */  
    IAS_REPORT *report_info,     /* I: General information for the test
                                       report.  If no report is desired pass
                                       NULL. */
    DB_CHAR_LAMP_RESPONSE_DETECTOR_RESULTS *db_detector_results,
                                 /* I/O: Pointer to results of the 
                                       lamp response detector results */
    DB_CHAR_LAMP_RESPONSE_ONE_SCA_RESULTS *db_one_sca_results
                                 /* O: Pointer to results of the 
                                       lamp response one SCA results */
);

int api_char_lamp_detector_response
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int char_lamp_detector_response_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int char_lamp_detector_response_postprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

DB_CHAR_LAMP_RESPONSE_DETECTOR_RESULTS 
      *rps_db_allocate_lamp_detector_results
(
    int number_of_detectors /* I: Number of array elements to allocate */
);

int rps_store_lamp_detector_in_database
(
    void *message /* I: Pointer to DB_CHAR_LAMP_RESPONSE_DETECTOR_RESULTS
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

void rps_db_free_lamp_detector_results
(
    DB_CHAR_LAMP_RESPONSE_DETECTOR_RESULTS *db_detector_results 
                                               /* I: structure to free */
);

DB_CHAR_LAMP_RESPONSE_SCA_RESULTS 
                 *rps_db_allocate_lamp_sca_results
(
    int number_of_scas /* I: Number of array elements to allocate */
);

int rps_store_lamp_sca_in_database
(
    DB_CHAR_LAMP_RESPONSE_SCA_RESULTS *db_sca_results 
                  /* I: Pointer to DB_CHAR_LAMP_RESPONSE_SCA_RESULTS
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

void rps_db_free_lamp_sca_results
(
    DB_CHAR_LAMP_RESPONSE_SCA_RESULTS *db_sca_results 
                                               /* I: structure to free */
);

DB_CHAR_LAMP_RESPONSE_BAND_RESULTS *rps_db_allocate_lamp_band_results
(
    int number_of_bands /* I: Number of array elements to allocate */
);

int rps_store_lamp_band_in_database
(
    DB_CHAR_LAMP_RESPONSE_BAND_RESULTS *db_band_results
                  /* I: Pointer to DB_CHAR_LAMP_RESPONSE_BAND_RESULTS
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

void rps_db_free_lamp_band_results
(
    DB_CHAR_LAMP_RESPONSE_BAND_RESULTS *db_band_results 
                                               /* I: structure to free */
);

int rps_store_lamp_response_in_database
(
    DB_CHAR_LAMP_RESPONSE_RESULTS *db_response_results
                  /* I: Pointer to DB_CHAR_LAMP_RESPONSE_RESULTS
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

int rps_store_lamp_telemetry_in_database
(
    DB_CHAR_LAMP_TELEMETRY_RESULTS *db_telemetry_results
                  /* I: Pointer to DB_CHAR_LAMP_TELEMETRY_RESULTS
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

int rps_output_lamp_sca_results
(
    int band_number,             /* I: 1-based band number */
    DB_CHAR_LAMP_RESPONSE_SCA_RESULTS *db_sca_results,
                                 /* I: Pointer to lamp SCA results */
    IAS_REPORT *report_info,     /* I: General information for the test
                                       report.  If no report is desired pass
                                       NULL. */
    int lamp_pair_id,            /* I: Lamp pair id */
    float lamp_on_time,          /* I: Lamp power on time */
    float post_warmup_start_time,/* I: Start time for post warmup period */
    float post_warmup_stop_time, /* I: Stop time for post warmup period */
    int post_warmup_start_frame, /* I: Start frame number for post warmup 
                                       period */ 
    int post_warmup_stop_frame   /* I: Stop frame number for post warmup 
                                       period */ 
);

int rps_output_lamp_band_results
(
    DB_CHAR_LAMP_RESPONSE_BAND_RESULTS *db_band_results,
                                 /* I: Pointer to lamp band results */
    IAS_REPORT *report_info,     /* I: General information for the test
                                        report.  If no report is desired pass
                                        NULL. */
    int lamp_pair_id,            /* I: Lamp pair id */
    float lamp_on_time,          /* I: Lamp power on time */
    float post_warmup_start_time,/* I: Start time for post warmup period */
    float post_warmup_stop_time, /* I: Stop time for post warmup period */
    int post_warmup_start_frame, /* I: Start frame number for post warmup 
                                       period */ 
    int post_warmup_stop_frame   /* I: Stop frame number for post warmup 
                                       period */ 
);

int rps_output_lamp_response_results
(
    DB_CHAR_LAMP_RESPONSE_RESULTS *db_response_results,
                                /* I: Pointer to lamp response results */
    IAS_REPORT *report_info     /* I: General information for the test
                                       report.  If no report is desired pass
                                       NULL. */
);

int rps_output_lamp_telemetry_results
(
    DB_CHAR_LAMP_TELEMETRY_RESULTS *db_telemetry_results,
                                /* I: Pointer to lamp telemetry results */
    IAS_REPORT *report_info,    /* I: General information for the test
                                       report.  If no report is desired pass
                                       NULL. */
    int lamp_pair_id,            /* I: Lamp pair id */
    float lamp_on_time,          /* I: Lamp power on time */
    float post_warmup_start_time,/* I: Start time for post warmup period */
    float post_warmup_stop_time, /* I: Stop time for post warmup period */
    int post_warmup_start_frame, /* I: Start frame number for post warmup 
                                       period */ 
    int post_warmup_stop_frame   /* I: Stop frame number for post warmup 
                                       period */ 
);


/* ---------- Temperature Senditivity Correction ---------- */
void temperature_sensitivity_correction
(
    int num_detectors,              /* I: Number of detectors in the SCA */
    double mean_focal_temp,         /* I: Mean focal plane temperature */
    const double *temp_sens_coeff,  /* I: Temperature sensitivity 
                                           coefficients, its size is 
                                           num_detectors */
    float ref_temp,                 /* I: Reference temperature */
    double *temp_correction_factor  /* O: Temperature correction factor  */
);

int api_temperature_sensitivity_correction
(
    BLOB *blob,   /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int temperature_sensitivity_correction_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);


/* ---------- Gain Application ---------- */
void gain_application
(
    float *l1r_data,             /* I/O: One SCA of l1r data to apply gain */
    int band,                    /* I: Band number, 1-based */
    int sca,                     /* I: SCA number, 1-based */
    int num_frames,              /* I: Number of frames in the data */
    int num_detectors,           /* I: Number of detectors in the SCA */
    double absolute_gain,        /* I: SCA level absolute gain from CPF */
    double *relative_gain,       /* I: detector level relative gain from CPF */
    const double *temp_sens_coeffs,/* I: detector level temperature sensitivity
                                         coefficients */
    int perform_abs_gain,        /* I: Flag for the absolute gain correction */
    int perform_relative_gain,   /* I: Flag for the relative gain correction */
    int perform_temp_sens        /* I: Flag for the temperature sensitivity 
                                       correction */
);

int api_gain_application
(
    BLOB *blob,   /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int gain_application_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);


/* ---------- OLI Bias Removal ---------- */
int oli_bias_removal
(
    float *l1r_image_buffer,         /* I/O: Image data for the current
                                        band/SCA */
    const double *cpf_bias_buffer_1, /* I: CPF bias data buffer #1 (pass in
                                        NULL if per-frame bias is used).  For
                                        PAN band, "odd" state detector
                                        biases.  For MS bands, detector
                                        biases */
    const double *cpf_bias_buffer_2, /* I: CPF bias data buffer #2 (pass in
                                        NULL if per-frame bias is used).  For
                                        PAN band, "even" state detector
                                        biases.  For MS bands, pass in NULL*/
    const double *per_line_bias_buffer,
                                     /* I: Per-line bias data for the current
                                        band/SCA (pass in NULL if CPF current
                                        launch bias is used) */
    BIAS_SOURCE bias_source,         /* I: Source of bias correction to
                                        apply */
    int perframe_bias_flag,          /* Flag to indicate the selected bias type
                                        0 = PER_DETECTOR_BIAS, 
                                        1 = PER_FRAME_BIAS */
    int pan_flag,                    /* I: Flag indicating whether PAN band
                                        is being processed (0=no, 1=yes) */
    int number_detectors,            /* I: # of detectors per SCA in the
                                        current band */
    int number_lines,                /* I: # of lines of image data in the
                                        current band/SCA */
    double *temp_correction_factors
                                     /* I: Temperature sensitivity
                                       correction factors for the current
                                       band/SCA (pass in NULL if no
                                       temperature correction is to be
                                       performed--default case */
);

int api_oli_bias_removal
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int oli_bias_removal_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);


/* ---------- OLI/TIRS response linearization prototypes ---------- */

/* "Wrapper" functions for each sensor.  Allows these to be called in the
   proper sequence within the overall radiometric processing flow.  They
   just test for the correct sensor and call the "main" API routine if
   found */
int api_oli_3q_response_linearization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int api_tirs_3q_response_linearization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int response_linearization_3q_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ---------- OLI/TIRS alternate response linearization prototypes ---------- */

/* "Wrapper" functions for each sensor.  Allows these to be called in the
   proper sequence within the overall radiometric processing flow.  They
   just test for the correct sensor and call the "main" API routine if
   found */
int api_oli_lookup_response_linearization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int api_tirs_lookup_response_linearization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int lookup_response_linearization_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ---------- TIRS secondary linearization ---------- */
int api_tirs_secondary_linearization
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int tirs_secondary_linearization_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ------ Generic parameter removal prototype ------- */
void generic_parameter_removal
(
    float *data_buffer,      /* I/O: On input data at some processing, on
                                   output data with the parameter removed */
    int number_detectors,    /* I: Number of detectors */
    int number_lines,        /* I: Number of lines */
    const double *parameter  /* I: Per-detector parameter to remove from the
                                   input buffer */
);

/* ---------- TIRS bias removal prototypes ---------- */
int api_tirs_bias_removal
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int tirs_bias_removal_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ------ TIRS gain offsets removal prototypes ------ */
int api_tirs_gain_offset_removal
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int tirs_gain_offset_removal_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/* ---------------------- Reflectance Conversion ---------------------- */
int reflectance_conversion
(
    float *l1r_data,             /* I/O: One SCA of l1r data to apply gain */
    int num_detectors,           /* I: Number of detectors in the SCA */
    int num_frames,              /* I: Number of frames in the data */
    double earth_sun_distance,   /* I: earth sun distance in astronomy unit
                                       from NOVAS libray calculation */
    double rad_to_reflect_conv_coeff,       
                                 /* I: band level radiance to reflectance
                                       conversion coefficient */
    double *reflect_to_rad_conv_coeff /* O: band level reflectance to radiance
                                           conversion coefficient */   
);

int api_reflectance_conversion
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int reflectance_conversion_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);


/*  ----------------- Bias Determination ----------------- */
typedef enum bias_spectral_type
{
    NON_PAN = 0,
    PAN_ODD,
    PAN_EVEN
} BIAS_SPECTRAL_TYPE;

/* Bias determination model parameter source */
typedef enum per_frame_bias_flag
{
    PER_DETECTOR_BIAS = 0,
    PER_FRAME_BIAS
} PER_FRAME_BIAS_FLAG;

int oli_bias_determination
(
    uint16_t *l0r_vrp_data,     /* I: One SCA of VRP data in DN */
    int band_number,            /* I: Band number, 1-based */
    int sca_number,             /* I: SCA number, 1-based */
    int num_detectors,          /* I: Number of detectors in the SCA */
    int num_lines,              /* I: Number of lines in the data */
    int vrp_detectors,          /* I: Number of detectors in the VRP band */
    int vrp_lines,              /* I: Number of lines in the VRP band */
    int perframe_bias_flag,     /* Flag to indicate the selected bias type, 
                                   0 = PER_DETECTOR_BIAS, 1 = PER_FRAME_BIAS */
    int a1_c1_estimate_flag,    /* Flag to indicate the detector level bais are
                                   from a1/C1 estimation option, YES/NO = 1/0 */
    BIAS_SPECTRAL_TYPE bias_spectral_type,    
        /* Flag to indicate the spectral type for bias application, NON_PAN = 0,
           PAN_ODD = 1, PAN_EVEN = 2 */
    double *bias_from_file,     /* I: Per detector bias from BPF/CPF */
    const double *a1_parameter, /* I: Per detector a1_parameter from BPF */
    const double *c1_parameter, /* I: Per detector c1_parameter from BPF */
    const double a0_parameter,  /* I: a0_parameter in model calculation */
    IAS_PIXEL_MASK *pixel_mask, /* I: Contains inop detector and other
                                      ignore pixel locations */
    IAS_REPORT *report_info,    /* I: General information for the test report. 
                                      If no report is desired pass NULL. */
    double *perframe_bias       /* O: Pointer to the results of bias
                                      value per detector, per frame */
);

int api_oli_bias_determination
(
    BLOB *blob,         /* I: Miscellaneous parameters */
    int   band_index,   /* I: */
    int   sca_index,    /* I: */
    int   algo_index    /* I: Algorithm index */
);

int oli_bias_determination_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

/*  ----------------- Striping Characterization ----------------- */
typedef struct db_overall_striping_metric_results
{
    struct ias_db_connection *dbase;
    char rad_common_id[IAS_CHAR_ID_SIZE];
    int number_bands;
    int *band_numbers;    /* List of bands */
    double *osm_radiance; /* Overall striping metric in radiance, one per
                             band */
    double *osm_dn;       /* Overall striping metric in DN, one per band */
} DB_OVERALL_STRIPING_METRIC_RESULTS;

int striping_characterization
(
    float *image_buffer,        /* I: One SCA of image data */
    int band_number,            /* I: */
    int sca_number,             /* I: */
    int number_detectors,       /* I: */
    int number_lines,           /* I: */
    int *detector_offsets,      /* I: Integer detector offsets with most
                                      negative offset shifted to zero */
    int offset_range,           /* I: */
    IAS_PIXEL_MASK *pixel_mask, /* I: */
    double striping_metric_cutoff, /* I: The CPF cutoff value */
    int dump_matrix_flag,       /* I: If flag is true (non-zero) the striping
                                      correction matrix will be dumped to a
                                      file.  If the flag is false (0) data
                                      will not be dumped. */
    const IAS_REPORT *report_info,/* I: General information for the report.
                                        If no report is desired a NULL pointer
                                        will be passed. */
    double *overall_striping_metric,  /* O: Measure of the amount of striping
                                            found in the image */
    double *striping_correction_matrix/* O: Correction matrix sized the same
                                            as the image buffer */
);

int api_striping_characterization
(
    BLOB *blob,         /* I: Various input parameters */
    int band_index,     /* I: */
    int sca_index,      /* I: */
    int algorithm_index /* I: Algorithm index */
);

int striping_characterization_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int striping_characterization_postprocess
(
    BLOB *blob          /* I: Miscellaneous parameters */
);

int calculate_overall_striping_metric
(
    double *dsm,          /* I: Detector striping metric, number_detectors
                                in length */
    int number_detectors, /* I: Number of detectors */
    double absolute_gain, /* I: CPF absolute gain value */
    double *osm_radiance, /* O: Overall striping metric in radiance */
    double *osm_dn        /* O: Overall striping metric in DN */
);

int generate_overall_striping_metric_report
(
    const IAS_REPORT *report_info, /* I: General information for the report */
    DB_OVERALL_STRIPING_METRIC_RESULTS *results /* I: Pointer to the results */
);

int db_store_overall_striping_metric_in_database
(
    DB_OVERALL_STRIPING_METRIC_RESULTS *db_results /* I: Pointer to the
                                                         results */
);

DB_OVERALL_STRIPING_METRIC_RESULTS *db_allocate_overall_striping_metric_results
(   
    int number_of_bands /* I: Number of bands to allocate */
);

void db_free_overall_striping_metric_results
(
    DB_OVERALL_STRIPING_METRIC_RESULTS *db_results /* I: Structure to free */
);


/*  ----------------- Residual Striping Correction ----------------- */
void residual_striping_correction
(
    float *l1r_image_buffer,           /* I/O: Image data for the current
                                              band/SCA */
    double *striping_correction_matrix,/* I: Scene striping correction matrix 
                                            for the current band/SCA */
    int num_detectors,                 /* I: Number of detectors per SCA */
    int num_frames                     /* I: Number of frames in the data */
);

int api_residual_striping_correction
(
    BLOB *blob,         /* I: Various input parameters */
    int band_index,     /* I: */
    int sca_index,      /* I: */
    int algorithm_index /* I: Algorithm index */
);

int residual_striping_correction_preprocess
(
    BLOB *blob          /* I: Miscellaneous parameters
                           O: Updated bias_correction_applied flag */
);

#endif
