#include <stdlib.h>
#include <string.h>
#include <limits.h>
#include "cgreen.h"
#include "ias_const.h"
#include "ias_l0r_constants.h"
#include "ias_l0r_structures.h"
#include "ias_logging.h"
#include "ias_pixel_mask.h"
#include "ias_radiometry.h"
#include "ias_satellite_attributes.h"
#include "../rps_local.h"
#include "../rps_blob.h"

static char *test_data_path = NULL;
static char l0r_data_dir[] = "ias_base/rps/driver/dropped_frame_char";
static char l0r_basename[] = "LO80390360362003148EDC00";
static char cpf_data_dir[] = "ias_lib/cpf";
static char cpf_basename[] = "L8CPF20090101_20090331.01";
static char bpf_data_dir[] = "ias_lib/bpf";
static char bpf_basename_oli[] = "test_LO8BPF20140310103310_20140310103345.06";
static char rlut_data_dir[] = "ias_lib/rlut";
static char rlut_basename[] = "test_linearization_rlut.h5";
static BLOB *blob = NULL;


Ensure band_attributes_test(void)
{
    #include "band_attributes_test.h"
    int band_index;
    int status;

    ias_log_initialize("band_attributes_test");

    /* Allocate BLOB data block */
    blob = allocate_blob();
    if (blob == NULL)
    {
        assert_true_with_message(FALSE, "Error allocating BLOB base data "
            "block");
        return;
    }

    /* Initialize the BLOB */
    blob->max_number_scas = 14;
    blob->total_bands = 30;
    blob->generate_report = 0;
    blob->store_in_database = 0;

    sprintf(blob->l0r_file_name, "%s/%s/%s", test_data_path, l0r_data_dir,
        l0r_basename);
    sprintf(blob->l1r_file_name, "%s", "L1R_output_file");
    sprintf(blob->cpf_filename, "%s/%s/%s", test_data_path, cpf_data_dir,
        cpf_basename);
    sprintf(blob->bpf_filename_oli, "%s/%s/%s", test_data_path, bpf_data_dir,
        bpf_basename_oli);
    strcpy(blob->bpf_filename_tirs, "");
    sprintf(blob->rlut_filename, "%s/%s/%s", test_data_path, rlut_data_dir,
        rlut_basename);

    status = finish_blob_initialization();
    assert_equal_with_message(status, SUCCESS, "Error completing test blob "
        "initialization");
    if (status != SUCCESS)
    {
        free_the_blob();
        return;
    }
    blob->list_of_bands[0] = 1;
    blob->number_of_bands = 1;

    /* Initialize the L0R image data */
    ias_log_set_output_level( IAS_LOG_LEVEL_DISABLE );
    status = initialize_io_routines(blob);
    ias_log_set_output_level( IAS_LOG_LEVEL_INFO );
    if ( status != SUCCESS )
    {
        assert_equal_with_message( status, SUCCESS, "Error initializing "
            "the I/O routines");
        free_the_blob();
        return;
    }

    for ( band_index = 0; band_index < 30; band_index++ )
    {
        RPS_BAND_ATTRIBUTES *band_atts = blob->band_information[band_index];
        RPS_BAND_ATTRIBUTES exp_atts = expected_results[band_index];
        assert_equal( band_atts->band_present, exp_atts.band_present );
        assert_equal( band_atts->process_band, exp_atts.process_band );
        assert_equal( band_atts->one_sca_present, exp_atts.one_sca_present ); 
        assert_equal( band_atts->is_normal_band, exp_atts.is_normal_band );
        assert_equal( band_atts->sca_number, exp_atts.sca_number );
        assert_equal( band_atts->band_number, exp_atts.band_number );
        assert_equal( band_atts->vrp_band_number, exp_atts.vrp_band_number ); 
        assert_equal( band_atts->vrp_band_index, exp_atts.vrp_band_index ); 
        assert_equal( band_atts->blind_band_number,
            exp_atts.blind_band_number );
        assert_equal( band_atts->blind_band_index, exp_atts.blind_band_index );
        assert_equal( band_atts->process_blind_band_flag,
            exp_atts.process_blind_band_flag );
        assert_equal( band_atts->number_lines, exp_atts.number_lines ); 
        assert_equal( band_atts->number_detectors, exp_atts.number_detectors );
        assert_equal( band_atts->number_scas, exp_atts.number_scas );
        assert_equal( band_atts->sensor_id, exp_atts.sensor_id ); 
        assert_equal( band_atts->band_classification,
            exp_atts.band_classification );
        assert_equal( band_atts->spectral_type, exp_atts.spectral_type );
    }

    /* Cleanup */
    cleanup_io_routines(blob);
    free_the_blob();
}  /* END band_attributes_test */


int main(int argc, char *argv[])
{
    int status;

    /* Look for the test data path */
    test_data_path = getenv("IAS_UNIT_TEST_DATA_DIR");
    if (test_data_path == NULL)
    {
        printf("Cannot locate IAS test data directory\n");
        return -1;
    }

    /* Initialize the satellite attributes */
    status = ias_sat_attr_initialize(IAS_L8);
    if (status != SUCCESS)
    {
        printf("Initializing Satellite Attributes Library\n");
        return -1;
    }

    /* Build the "test suite" */
    TestSuite *suite = create_test_suite();
    add_test(suite, band_attributes_test);

    /* Run the test */
    if (argc > 1)
        return run_single_test(suite, argv[1], create_text_reporter());
    return run_test_suite(suite, create_text_reporter());
}   /* END main */
