#!/bin/csh -f

# Ensure there is a database environment variable defined
if ( ! $?IAS_DB_L8_OLITIRS ) then
    exit 1
endif

# Create a script to query the database ... this is done here so that a
# separate script will not have to be maintained.  It will be used then
# removed at the end.
set sql_script = "retrieve_sca_overlap_stats.sql"
echo "set term off" > $sql_script
echo "set echo on" >> $sql_script
echo "set trimout on" >> $sql_script
echo "set trimspool on" >> $sql_script
echo "set heading off" >> $sql_script
echo "set feedback off" >> $sql_script
echo "set pause off" >> $sql_script
echo "set pagesize 0" >> $sql_script
echo "set linesize 500" >> $sql_script
echo "set space 0" >> $sql_script
echo "set colsep |" >> $sql_script
echo "set tab off" >> $sql_script
echo "set verify off" >> $sql_script
echo "spool ./so8899.txt" >> $sql_script
echo "select radiometric_wo_common_id, band_id, " >> $sql_script
echo "sensor_chip_assembly_id, overlap_ratio_mean, " >> $sql_script
echo "overlap_ratio_stdev, overlap_segment_percent, " >> $sql_script
echo "invalid_sca_correlation_flag from overlap_statistics_sca " >> $sql_script
echo "where radiometric_wo_common_id=8899;" >> $sql_script
echo "spool off" >> $sql_script
echo "exit" >> $sql_script

# Query the database
sqlplus $IAS_DB_L8_OLITIRS @$sql_script > & /dev/null

# Squeeze out the whitespace and eliminate extraneous lines
sed 's/  *//g' ./so8899.txt | grep  ^8899 > ./so8899.tmp
sed 's/|/ /g' ./so8899.tmp > ./so8899.txt

# Remove the script and temporary file
rm -f $sql_script ./so8899.tmp

exit 0

