#!/bin/csh -f
#
#  NAME -    compare_image_results.csh
#
#  PURPOSE - Compare the flat files in the list with files created by the 
#            Cal/Val prototype code.  These expected results files are in the
#            the unit test directory.  If there are no differences, the
#            output file is removed.  On differences or errors the output
#            file is not removed.

if ( ${?IAS_UNIT_TEST_DATA_DIR} ) then
    set test_dir = "$IAS_UNIT_TEST_DATA_DIR/ias_base/rps/l1r_sca_stitching"
else
    exit 1
endif

set report = "./difference_report"
set return_status = 0

set file_names = "out_stitch_B1_half_overlap.img out_stitch_B1_left_overlap.img out_stitch_B1_no_overlap.img out_stitch_B1_right_overlap.img out_stitch_B2_half_overlap.img out_stitch_B2_left_overlap.img out_stitch_B2_no_overlap.img out_stitch_B2_right_overlap.img out_stitch_B3_half_overlap.img out_stitch_B3_left_overlap.img out_stitch_B3_no_overlap.img out_stitch_B3_right_overlap.img"

if ( -e $report ) then
    rm $report
endif

foreach file_name ( $file_names )
    diff -q $test_dir/$file_name ./$file_name >> $report
    if ( $status ) then
        set return_status = 1
    else
        rm ./$file_name
    endif
end

if ( $return_status == 1 ) then
    echo "ERROR - there is a difference in expected results" >> $report
else
    rm $report
endif

exit 0
