#!/bin/csh -f
#
#  NAME -    compare_results.csh
#
#  PURPOSE - Extract the raw data from HDF and subset it.  Compare the flat
#            files with files created by the Cal/Val prototype code.  These
#            expected results files are in the the unit test directory.  If
#            there are no differences, the output file is removed.  On
#            differences or errors the output file is not removed.
#
#  USAGE:    compare_results.csh stitch_method - no, left, right, half
#                                file_name - file to subset and check
#                                band_number - 1, 2, 3
#                                subset_samples - number of samples to 
#                                                 extract from file
#                                subset_lines - number of lines to extract
#                                               from the file
#---------------------------------------------------------------------------

if ( ! ${?IAS_UNIT_TEST_DATA_DIR} ) then
    exit 1
endif

set subset  = "$1_subset"

# Pad the band number if it doesn't have 2 digits
set band = $3
if ( $band < 10 ) then
    set band = 0$band
endif

# Get the raw data and subset it
$COTS/hdf5/bin/h5dump --binary=LE -o $subset --dataset="B$band" \
    -s "0,0,0" -c "1,$5,$4" $2 >& /dev/null

if ( $status ) then
    echo "Error running the h5dump routine on " $2
    exit 1
endif

# The expected results files were created as B1, B2, B3
set test_data_dir = "$IAS_UNIT_TEST_DATA_DIR/ias_base/rps/l1r_sca_stitching"
set basename = "out_stitch_B$3"
set expected_results = "$test_data_dir/${basename}_$1_overlap.img"

diff -q $subset $expected_results
if ( $status ) then
    exit 1
else
    rm $subset
    exit 0
endif
