/*-------------------------------------------------------------------------
  NAME:    l1r_sca_stitching_read_parameters_test

  PURPOSE: Test reading the input parameters routine
-------------------------------------------------------------------------*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>

#include "ias_satellite_attributes.h"
#include "ias_const.h"
#include "cgreen.h"
#include "../l1r_sca_stitching.h"


Ensure test_read_stitch_parameters()
{
    /* Input parameter file name */
    const char stitch_params_basename[] = "test_stitch_params_read_test.odl";

    char *test_data_path = NULL;

    /* Just names -- no serious data */
    const char test_l1r_basename[] = "out_testim";
    const char test_cpf_basename[] = "L8CPF_20090101_20090331.01";

    /* "Absolute" filenames (includes path) */
    char test_l1r_filename[PATH_MAX];
    char test_cpf_filename[PATH_MAX];
    char stitch_params_filename[PATH_MAX];

    SCA_STITCH_PARAMS stitch_params;

    int status;
    int band_index;
    int test_band_list[] = {1, 2, 5, 7, 10, 11};
    int test_num_bands_to_process = 6;

    STITCH_METHOD_TYPE test_stitch_method    = SCA_STITCH_LEFT_OVERLAP;

    /* Get the location of the test data directory */
    test_data_path = getenv("IAS_UNIT_TEST_DATA_DIR");
    if ( test_data_path == NULL )
    {
        assert_true_with_message( 0,
            " Could not get environment variable IAS_UNIT_TEST_DATA_DIR");
        return;
    }

    /* Clear out the parameter data structure */
    memset( &stitch_params, 0, sizeof(SCA_STITCH_PARAMS));

    /* Read the parameter file */
    sprintf( stitch_params_filename, "%s/ias_base/rps/l1r_sca_stitching/%s",
        test_data_path, stitch_params_basename );
    status = read_stitch_parameters( stitch_params_filename, &stitch_params );
    if ( status != SUCCESS )
    {
        assert_true_with_message( 0, "Cannot read parameters in file %s",
            stitch_params_filename );
        return;
    }

    /* Do a sanity check on the read parameters */
    sprintf( test_l1r_filename,
            "%s/ias_base/rps/l1r_sca_stitching/%s", test_data_path,
            test_l1r_basename );
    sprintf( test_cpf_filename, "%s/ias_lib/cpf/%s", test_data_path,
            test_cpf_basename );

    assert_string_equal((const char *)stitch_params.l1r_filename,
                        test_l1r_filename );
    assert_string_equal((const char *)stitch_params.cpf_filename,
                        test_cpf_filename );

    if ( strcmp( stitch_params.l1r_filename, test_l1r_filename )
        || strcmp( stitch_params.cpf_filename, test_cpf_filename ))
    {
        return;
    }

    assert_equal( stitch_params.num_bands_to_process,
                 test_num_bands_to_process );
    if ( stitch_params.num_bands_to_process != test_num_bands_to_process )
    {
        return;
    }

    for ( band_index = 0; band_index < stitch_params.num_bands_to_process;
         band_index++ )
    {
        assert_equal( stitch_params.band_number_list[band_index],
                     test_band_list[band_index] );
    }

    assert_equal( stitch_params.stitch_method, test_stitch_method );
}  /* END test_read_stitch_parameters */


int main( int argc, char *argv[] )
{
    TestSuite *suite = create_test_suite();

    add_test( suite, test_read_stitch_parameters );

    if ( argc > 1 )
    {
        return run_single_test( suite, argv[1], create_text_reporter());
    }
    return run_test_suite( suite, create_text_reporter());
}
