#!/bin/csh -f

##############################################################################
# NAME:      get_script_parameters.csh
#
# PURPOSE:   Queries the 'def_parms' database table to get the list
#            of parameters, their occurrence, and their values
#            for the specified script in the specified procedure.
#
# RETURNS:   Integer status of 0 or 1 (command line error)
#
# NOTES:     Use single or double quotes around the procedure name string to
#            include the space(s) within
##############################################################################

# Check the command line to ensure we have two parameters -- the
# procedure name and the name of the script.  If we don't, print a
# usage message and exit as if it's an error.
if ( ${#argv} != 2 ) then
    echo
    echo "USAGE:   $0 <procedure_name> <script_name>"

    echo "EXAMPLE: $0 "'"L1G Lunar Product" L8RPS'
    exit 1
endif

# Define and run the query
sqlplus -s ${IAS_DB_L8_OLITIRS} << END
    set head off
    set pagesize 50000
    set linesize 132
    set colsep ' '
    set space 0
    column parm_name  format a40
    column parm_value format a45
    select parm_name, cast(parm_occurrence as varchar(5)), parm_value
    from def_parms
    where module_id='$1' and sub_module_id='$2';
    exit
END

exit 0
