#!/bin/csh -f

##############################################################################
# NAME:        get_scripts.csh
#
# PURPOSE:     Queries the 'sub_modules' database table for the list of
#              processing scripts associated with the specified procedure
#              name.
#
# RETURNS:     Integer status of 0 or 1 (command line error)
#
# NOTES:       Use single or double quotes around the procedure name string,
#              in order to capture any spaces within the string
##############################################################################

# Check the command line to ensure we have one parameter -- the procedure
# name.  If we don't, print a usage message and exit as if it's an error.
if ( ${#argv} != 1 ) then
    echo
    echo "    USAGE:    $0 <procedure_name>"
    echo "    EXAMPLE:  $0 "'"L1G Lunar Product"'
    echo
    exit 1
endif

# Define and run the query
sqlplus -s ${IAS_DB_L8_OLITIRS} << END
    set head off
    set pagesize 50000
    select seq_nbr, sub_module_id from sub_modules
    where module_id='$1'
    order by seq_nbr;
    exit
END

exit 0
