#!/usr/bin/perl -w
use strict;

use DBI;

die "Usage: process_control_list.pl <control_file> <dbstr>\n" if ($#ARGV != 1);

my $control_file = $ARGV[0];
die "$control_file does not exist\n" if ( ! -e $control_file );

print "Loading $control_file\n";

# Load the validation list
my @validation_gcps;
open(FH, "< $control_file") or die "ERROR: opening $control_file\n";
while (<FH>)
{
    my $line = $_;
    chomp($line);
    
    my @parts = split(/\s+/, $line);
    push(@validation_gcps, $parts[0]) if ($parts[17] eq "VAL");
}
close(FH);

printf("Validation GCPs found: %d\n", scalar @validation_gcps);

# Update database
my ($username, $password) = split(/\//, $ARGV[1]);
my $sid = $ENV{"ORACLE_SID"};

my $dbh = DBI->connect("DBI:Oracle:$sid", $username, $password,
    {AutoCommit => 0, PrintError => 0, RaiseError => 0});
die "ERROR: could not connect to database $DBI::errstr\n" if (!$dbh);

my $sql = "UPDATE ground_control_points "
        . "   SET type = 'VALIDATION' "
        . " WHERE ground_control_points_id = ?";

my $sth = $dbh->prepare($sql);

$dbh->begin_work;

my $rows = 0;
foreach my $id (@validation_gcps)
{
    $sth->bind_param( 1, $id );
    if ($sth->execute() == 1)
    {
        $rows += 1;
    }
    else
    {
        print "Missing id: $id\n";
    }
}

if ($rows != scalar @validation_gcps)
{
    printf("WARN: expected %d updates, saw %d updates\n", 
        scalar @validation_gcps, $rows);
}
$sth->finish();

$dbh->commit();
$dbh->disconnect();

