#!/usr/bin/perl

##############################################################################
#
#    UNIT NAME: subsetter_data_available.pl
#
#    PURPOSE: Simulate completion of a subsetter request by setting
#      the status and L0RP location in the subsetter_request table.
#      This script assumes you have the SUBSETTER_REQUEST table set up in your
#      $IAS_DB_COM schema or a synonym to the table & permissions to update it.
#
##############################################################################
use warnings;
use strict;

my $num_args = @ARGV;
if ( $num_args < 2 )
{
   die "Usage: $0 WO_ID L0RP_PATH\n";
}
my $wo_id = $ARGV[0];
my $l0rp_path = $ARGV[1];

# Verify the environment variables for connection to the db
unless (defined($ENV{ORACLE_SID}) || defined($ENV{TWO_TASK})) 
{
    die "ERROR: Oracle instance (ORACLE_SID or TWO_TASK) is not set";
}
unless (defined($ENV{IAS_DB_COM})) 
{
    die "ERROR: IAS_DB_COM is not set";
}

#  Update the SUBSETTER_REQUEST table 
my $script_output = `sqlplus -L -S $ENV{IAS_DB_COM} 2>&1 <<END
  WHENEVER SQLERROR EXIT FAILURE;
  update subsetter_request
  set l0rp_location = '$l0rp_path', 
  status = 'L0Rp-READY'
  where work_order_id = '$wo_id' and status = 'REQ-NEW';
END
`;
if ($? != 0) 
{
    die "ERROR updating SUBSETTER_REQUEST table:\n$script_output\n";
}

# Show stdout, which includes the # of rows updated.
print "$script_output\n";

exit 0;
