package flow_utilities;

use strict;
use warnings;
use File::Basename;         # Fileparse routine
use Logger;                 # Provides logging for module
use ias_const;              # Defines SUCCESS and ERROR
use ias_wo_const;           # Defines SKIP and PENDING script flags
use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
use Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(
                skip_work_order_scripts
            );

#############################################################################
# Name: skip_work_order_scripts
#
# Description: Given a work order ID and list of scripts, update the work
#              order to skip the scripts.
#
# Parameters:
#   Database handle
#   Work order ID
#   Reference to an array of script names
#
# Returns:
#   SUCCESS/ERROR
#############################################################################
sub skip_work_order_scripts
{
    my $dbh = shift;
    my $work_order_id = shift;
    my $script_names_ref = shift;

    my $logger = get_default_log();

    # Build an string of '?' for binding the script names
    my @bind_array = ('?') x scalar(@$script_names_ref);
    my $bind_string = join(',', @bind_array);

    # Create the SQL statement
    my $sql = "UPDATE wo_scripts SET state = '" . DB_WO_SCRIPT_SKIP
        . "' WHERE work_order_id = ?"
        . " AND script_id IN ($bind_string) AND state = '"
        . DB_WO_SCRIPT_PENDING . "'";

    my $sth = $dbh->prepare($sql);
    if (!$sth)
    {
        $logger->fatal_msg("Unable to prepare query: $sql");
        $logger->fatal_msg("DBI error: $DBI::errstr");
        return ERROR;
    }

    # Execute the statement
    if (!$sth->execute(($work_order_id, @$script_names_ref)))
    {
        $logger->fatal_msg("Unable to execute update query: $DBI::errstr");
        $sth->finish();
        return ERROR;
    }

    # Get the row updated count
    my $rows_updated = $sth->rows;

    # Issue a warning if the number of updated rows does not match
    # This is incase the user manually skips the script
    if ($rows_updated != scalar @$script_names_ref)
    {
        $logger->warn_msg("Expected $rows_updated rows to be updated but " .
            "only " . scalar(@$script_names_ref) . " rows were updated");
    }
    $sth->finish();

    return SUCCESS;
}
