#!/bin/csh -ef
#  -e flag will cause the script to exit if any command fails
#  -f flag will keep current environment (skip re-sourcing the cshrc)
# 
# Compile and install the IAS libraries (ias_lib), base applications (ias_base),
# and IAS-specific applications (ias).  Also create a cshrc file for use by
# the operational account.

# Must supply iasdev, iasit, iasst, or iasops
if (($#argv != 1) || ($1 !~ ias{dev,it,st,ops} )) then
  echo "Usage: $0 iasdev|iasit|iasst|iasops"
  exit 1
endif
set iasuser=$1
# get the dev/it/st/ops indication
set install_env = `echo $iasuser | cut -c 4-`

# Build ias_lib
cd ias_lib
./autogen.sh
./configure
./build
cd ..

# Build ias_base
cd ias_base
./autogen.sh
./configure
make -j4 install
cd ..

# Build ias
cd ias
./autogen.sh
./configure
make install
cd ..

# Precompile the individual python libraries and applications
python3 -m compileall $IASBASE_PYLIB
python3 -m compileall $IAS_BIN

# Create the version.txt file
#  This assumes the directory we are sitting in is named with the CM tag
#  (i.e., that the code was checked out using the tag).
basename $cwd >& $IASBUILD/version.txt

# Create the setup file
./create_setup_file.csh ias $install_env

exit 0
