#include <stdlib.h>
#include <stdio.h>
#include "xxx_const.h"    /* BandNumber definition */
#include "oli_grid.h"
#include "ias_grid_io.h"
#include "ias_satellite_attributes.h"
#include "wedge_tirs_grid.h"

void test_ols2ils
(
    oli_GRID_TYPE *grid
)
{
    /* This routine implements a quick test to allow checking that the grid
       conversion is reasonably correct */

    int band_index = 1;
    int sca_index;

    for (sca_index = 0; sca_index < grid->nscas; sca_index++)
    {
        oli_GRID_BAND_TYPE *gridband = &grid->gridbands[sca_index][band_index];
        double oline;
        double osamp;
        double iline;
        double isamp;
        int status;

        oline = gridband->lines / 2.0;
        osamp = gridband->samps / 2.0;

        status = oli_all_ols2ils(gridband, oline, osamp, &iline, &isamp, 1);
        if (status != ERROR)
        {
            printf("sca %d: %f %f %f %f\n", sca_index, oline, osamp, iline,
                   isamp);
        }
    }

}

/****************************************************************************/
int main(int argc, char *argv[])
{
    char *input_filename;
    const char *output_filename;
    BandNumber bands[20];
    int nbands = 0;
    oli_GRID_TYPE old_grid;
    IAS_GRID_TYPE grid;
    int calval_version;

    if ((argc != 3) && (argc != 4))
    {
        printf("Error: wrong number of parameters, expected:\n"
               "   convert_tirs_grid [-2] input_grid output_grid\n"
               "   where -2 is optional for calval band layout #2\n");
        return EXIT_FAILURE;
    }
    if ((argc == 4) && (strcmp(argv[1], "-2") == 0))
    {
        input_filename = argv[2];
        output_filename = argv[3];
        calval_version = 2;
    }
    else
    {
        input_filename = argv[1];
        output_filename = argv[2];
        calval_version = 1;
    }
    printf("Converting grid in %s to new grid in %s\n", input_filename,
           output_filename);

    ias_sat_attr_initialize(IAS_L8);

    /* read the old grid file */
    if (oli_get_grid(input_filename, bands, &nbands, &old_grid) != SUCCESS)
    {
        printf("Error reading grid from %s\n", input_filename);
        return EXIT_FAILURE;
    }

#if 0
    /* generate test data for the grid tests */
    test_ols2ils(&old_grid);
#endif

    if (!wedge_tirs_grid(&old_grid, &grid, calval_version))
    {
        printf("Error converting old grid to the new grid\n");
        return EXIT_FAILURE;
    }

    /* write the new grid to a file */
    if (ias_grid_write(output_filename, &grid) != SUCCESS)
    {
        printf("Error writing grid file: %s\n", output_filename);
        return EXIT_FAILURE;
    }

    /* free both grids */
    ias_grid_free(&grid);
    nbands = 0;
    oli_free_grid(bands, &nbands, &old_grid);

    return EXIT_SUCCESS;
}
