
#ifndef IASDATABASELOGIN_H
#define IASDATABASELOGIN_H

/*!
    \file IASDatabaseLogin.h
    \brief Provides an extension of IASDatabaseLoginBase.

    See IASDatabaseLogin.
*/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>
#include <QtSql>

/* Local Includes */
#include "ui_IASDatabaseLoginBase.h"

/*!
    \brief This provides the Qt database driver to use.
*/
#define DB_DRIVER "QOCI"

/*!
    \brief This class provides an extension of IASDatabaseLoginBase.

    IASDatabaseLoginBase provides the base GUI component for IASDatabaseLogin.

    The sole purpose of the IASDatabaseLogin class is to connect to the
    database.  The user will be prompted for database access information
    if the information is not supplied by the environment.
*/
class IASDatabaseLogin : public QDialog, public Ui::IASDatabaseLoginBase
{
    Q_OBJECT

    public:

        IASDatabaseLogin(QWidget* parent = 0,
                      QString environmentVariable = QString::null,
                      Qt::WindowFlags fl = 0);

        void exec();

        void setDatabase(QSqlDatabase newDatabase); // Sets dbase object

    protected slots:

         void tryConnect(); // Attempt to connect to the database

    private:

        /*!
            \brief The object used to establish the database connection.
        */
        QSqlDatabase theDatabase;

        /*!
            \brief Used to determine if the environment was used to
                   pre-populate the text edit objects.
        */
        bool myPrePopulated;

        /*!
            \brief Used to determine if we have already connected to
                   the database.
        */
        bool myConnected;
};

#endif /* IASDATABASELOGIN_H */

