
#ifndef IASKEYVALUECOMBOBOX_H
#define IASKEYVALUECOMBOBOX_H

/*!
    \file IASKeyValueComboBox.h
    \brief Provides a (key, value) extension of QComboBox.

    See IASKeyValueComboBox.
*/


/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */

/*!
    \brief This class provides a (key, value) extension of QComboBox.

    The purpose of this class is to provide a combo box class which
    provides a presented key to the user and an internal value which
    the software uses.
*/
class IASKeyValueComboBox : public QComboBox
{
    Q_OBJECT

    public:

        IASKeyValueComboBox(QWidget * parent = 0);

        void addKeyValue(QString & key,
                         QString & value);
        QString currentValue();

    signals:

        /*!
            This signal is emitted when an item is selected.
        */
        void activatedSignal(const QString & value);

    protected:

    private:

        /*!
            \brief The map object to poulate and use.
        */
        QMap<QString,QString> m_dataMap;

    private slots:

        void activatedSlot(const QString & key);
};

#endif /* IASKEYVALUECOMBOBOX_H */

