
#ifndef IASLISTVIEW_H
#define IASLISTVIEW_H

/*!
    \file IASListView.h
    \brief Provides an extension of QTreeWidget.

    See IASListView.
*/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */

/*!
    \brief This is be used to describe the data in the columns of a listview.

        Id        - WO ID - Sort on the number

        DateYMD   - Date string in YYYY-MM-DD format.
                    Convert to QDate.

        DateMDY   - Date string in MM-DD-YYYY format.
                    Convert to QDate.

        DateDMMMY - Date string in DD-MMM-YYYY format ie. 01-MAR-2002.
                    Convert to QDate.

        DateYYJJJ - Date string in Julian format ie. 02-238

        DateTIME  - Date/Time string in YYYY-MM-DD/HH:MM:SS format.
                    Convert to QDateTime.

        Time      - Time string in HH:MM:SS format.
                    Convert to QTime.

        Number    - Number string.  Convert to integer

        Float     - Float string

        Alpha     - Alphanumeric string
*/
typedef enum {
    Id,
    DateYMD,
    DateMDY,
    DateDMMMY,
    DateYYJJJ,
    DateTime,
    Time,
    Number,
    Float,
    Alpha
} columnDataTypes;

/*!
    \brief This is a doubly-linked list of enumerated data type.
*/
typedef QList<columnDataTypes> columnDataTypesList;


/*!
    \brief Structure used to create columns in a list view.
*/
typedef struct lvFields
{
    QString colName;
    QString fieldName;
    QString tableName;
    columnDataTypes colType;
    int colWidth;
} lvFields;

/*!
    \brief This class provides an extension of QTreeWidget.

    The purpose of this class is to provide a listview class which
    provides the ability to copy and paste cell information from the
    listview.
*/
class IASListView : public QTreeWidget
{
    Q_OBJECT

    public:

        IASListView(QWidget *parent = 0);

        QMenu *getPopupMenu();

    protected slots:

        void showPopupMenu(const QPoint& pos);

        void copyCell();
        void copyRow();
        void copyColumn();

    private:

        /*!
            \brief The QMenu object to populate and use.
        */
        QMenu *m_popMenu;
};

#endif /* IASLISTVIEW_H */

