
#ifndef IASLISTVIEWITEM_H
#define IASLISTVIEWITEM_H

/*!
    \file IASListViewItem.h
    \brief Provides an extension of QTreeWidgetItem.

    See IASListViewItem.
*/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "IASListView.h"

/*!
    \brief This class provides an extension of QTreeWidgetItem.

    The purpose of this class is to provide a listview that can sort
    based on the type of data in the column.
*/
class IASListViewItem : public QTreeWidgetItem
{
    public:

        IASListViewItem();
        IASListViewItem(columnDataTypesList &list);
        IASListViewItem(QTreeWidget *parent);
        IASListViewItem(QTreeWidget *parent,
                        columnDataTypesList &list);

        bool operator<(const QTreeWidgetItem &item) const;

        // Gets the tag associated with this listviewitem
        QString getTag();

        // Sets the tag associated with this listviewitem
        void setTag(QString);

    private:

        /*!
            \brief Used to maintain a list of the column types presented
            in the listview.
        */
        columnDataTypesList m_listColumnType;

        /*!
            \brief The tag associated with this listviewitem.

            The purpose of the tag is to allow the listviewItem to contain
            more information or to associate it with a group of other items.
        */
        QString m_Tag;
};

#endif /* IASLISTVIEWITEM_H */

