
#ifndef IASPARAMETERITEM_H
#define IASPARAMETERITEM_H

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */

/* ===========================================================================
  IASParameterItem

  This class defines the items that are held by the IASParameterModel.

  This implementation follows the Model/View architecture defined in the
  Qt 4+ documentation.  See the Qt 4+ documentation for more details.
=========================================================================== */
class IASParameterItem
{
    public:

        /* Define types for the item. */
        enum ItemType
        {
            Text,
            TextSelection,
            Integer,
            IntegerRange,
            Float,
            FloatRange
        };

        IASParameterItem();

        void setData(QVariant& data);
        QVariant data();

        void setType(IASParameterItem::ItemType type);
        IASParameterItem::ItemType type();

        /* Set the minimum and maximum values to the same value if you want
           an unlimited range.  This is the case by default. */
        void setMinimum(QVariant& data);
        QVariant minimum();

        void setMaximum(QVariant& data);
        QVariant maximum();

        void setDecimals(QVariant& decimals);
        QVariant decimals();

        void setAlignment(Qt::Alignment alignment);
        Qt::Alignment alignment();

        void setEditable(bool editable);
        bool editable();

        void setOptions(QStringList& options);
        QStringList options();

    private:

        IASParameterItem::ItemType m_type; /* The type of item. */

        QVariant m_value; /* The current value of the item. */

        QVariant m_minValue; /* The minimum value allowed. */
        QVariant m_maxValue; /* The maximum value allowed. */
        QVariant m_decimals; /* The precision for floating point values. */

        QStringList m_options; /* The possible options for this value. */

        Qt::Alignment m_alignment; /* The alignment for the displayed text. */
        bool m_editable; /* Defines if this item can be modified. */
};

/* Define row types to be utilized by the model. */
typedef QList<IASParameterItem*> IASParameterItemRow;
typedef QList<IASParameterItemRow*> IASParameterItemRows;

#endif /* IASPARAMETERITEM_H */

