
#ifndef IASPARAMETERMODEL_H
#define IASPARAMETERMODEL_H

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "IASParameterItem.h"

/* ===========================================================================
  IASParameterModel

  This class defines the model applied to a QTableView for modifying parameter
  values.  The class interacts with the QTableView object to provide access
  and modification of the underlying data.

  This implementation follows the Model/View architecture defined in the
  Qt 4+ documentation.  See the Qt 4+ documentation for more details.
=========================================================================== */
class IASParameterModel : public QAbstractTableModel
{
    Q_OBJECT

    public:

        IASParameterModel(QObject* parent = 0);

        Qt::ItemFlags flags(const QModelIndex& index) const;
        QVariant headerData(int section,
                            Qt::Orientation orientation,
                            int role = Qt::DisplayRole) const;
        int rowCount(const QModelIndex& parent = QModelIndex()) const;

        void setColumnCount(int columns);
        int columnCount(const QModelIndex& parent = QModelIndex()) const;

        bool setData(const QModelIndex& index,
                     const QVariant& value,
                     int role = Qt::EditRole);
        QVariant data(const QModelIndex& index,
                      int role = Qt::DisplayRole) const;

        void setModelData(IASParameterItemRows& data);
        IASParameterItemRows& modelData();

        void insertRow(const QModelIndex& index,
                       IASParameterItemRow* row);
        void appendRow(IASParameterItemRow* row);
        IASParameterItemRow* takeRow(const QModelIndex& index);
        void deleteRow(int row);

        bool setItemData(const int row,
                         const int column,
                         const QVariant& value);

        void deleteData();

        IASParameterItem* getItem(int row,
                               int column);

        void setModified(bool state);
        bool modified();

        void setHorizontalHeaderLabels(QStringList& labels);

    signals:

        void itemDataChanged(const QModelIndex&);

    private:

        int m_rows; /* The number of rows in the model. */
        int m_columns; /* The number of columns in the model. */

        IASParameterItem *m_dummyIASParameterItem; /* An empty item for errors */
        IASParameterItemRows m_data; /* The data held by the model. */

        QStringList m_horizontalHeaderLabels; /* The labels for the headers. */

        bool m_modified;
};

#endif /* IASPARAMETERMODEL_H */

