/******************************************************************************
               Image Assessment System (IAS) Software
 ******************************************************************************
 *
 * Name:   IASSchemaConfig.h
 *
 * PURPOSE:
 * This is the definition of the IASSchemaConfig class which is used to
 * get the schema name from database and return satellite and sensor values.
 *
 *****************************************************************************/

#ifndef IASSCHEMACONFIG_H
#define IASSCHEMACONFIG_H

// System Includes

// QT Includes
#include <QtCore>

// Local Includes

class IASSchemaConfig
{
    public:

        static IASSchemaConfig * instance();

        QString schemaNameFromL0rProductId(QString productId);
        QString schemaNameFromOrderId(QString orderId);
        QString schemaNameFromKey(QString key);
        QString schemaNameFromWOId(QString woId);
        QString schemaName(QString sat,
                           QString sen);

        QString commonSchemaName();

        QStringList allSchemas();
        QStringList allKeys();

        QString satSenFromWOId(QString woId);

        QDate epochDateFromSchemaName(QString schemaName);

    private:
        Q_DISABLE_COPY(IASSchemaConfig);

        IASSchemaConfig();
        bool initialize();

        static IASSchemaConfig * myInstance;
        QMap<QString,QString> mySchemaMap;
        QMap<QString,QDate> myEpochBySchemaMap;
        QString myCommonSchema;
};

#endif /* IASSCHEMACONFIG_H */

