
#ifndef IASSqlQuery_H
#define IASSqlQuery_H

/*!
    \file IASSqlQuery.h
    \brief Provides an extension of QSqlQuery.

    See IASSqlQuery.
*/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>
#include <QtSql>
   
/* Local Includes */

/*!
    \brief This class provides an extension of QSqlQuery.

    This class extends QSqlQuery by re-implementing the "exec" function
    to check the return status of the QSqlQuery's exec function and
    display an error dialog if an error occurred.  This way, the error
    display does not have to be done everywhere "exec" is used.
*/
class IASSqlQuery : public QSqlQuery
{
    public:

        IASSqlQuery(const QString& query = QString::null,
                    QSqlDatabase db = QSqlDatabase());

        bool exec(const QString &query,
                  QString fileName,
                  int lineNum);

        QVariant value(const QString &columnName) const;

        QStringList toStringList() const;

        // Bring the value(int) function from QSqlQuery into scope
        using QSqlQuery::value;
};

#endif /* IASSqlQuery_H */

