
#ifndef IASUTILITIES_H
#define IASUTILITIES_H

/*!
    \file IASUtilities.h
    \brief Provides utility functions that are used throughout the IAS GUIs.

    See IASUtilities.
*/

/* System Includes */

/* Qt Includes */
#include <QtCore>

/* Local Includes */
#include "IASListView.h"
#include "IASQtConst.h"

/*!
    \brief A macro to determine the number of elements an array can hold.
*/
#define ARRAY_SIZE(x)      (sizeof(x)/sizeof(x[0]))

/*!
    \brief The number of seconds in a day.
*/
#define SEC_IN_DAY 86400

typedef QMap<QString,QString> KeyValueMap;
typedef KeyValueMap::iterator KeyValueMapItr;

/*!
    \brief Provides utility functions that are used throughout the IAS GUIs.

    This class groups several independent functions into a namespace which
    can be used throughout the GUI code.  Functions which convert date
    representations are provided as well as several database related
    functions.
*/
class IASUtilities
{
    public:
        /* Date/Time utilities */
        static QDateTime getDateTime(const QString str);
        static QDate getDate(const QString str,
                             columnDataTypes columnType);
        static QTime getTime(const QString str);
        static int getMonth(const QString month);
        static QString changeSecsToDate(int secs,
                                        QDate epochDate);

        /* Database utilities */
        static bool dbValidWoId(const QString& woId);
        static bool resetWOPending(const QString &woID,
                                   QString &errorMessage,
                                   const bool &displayMessage);

        /* Key = Value utilities */
        static KeyValueMap readKeyValueFile(const QString& filename,
                                            QStringList& list);

        /* Process utilities */
        static QString unEnvCmd(const QString& cmd);

        /* Sort utilities */
        static bool numericLessThan(const QString &first,
                                    const QString &second);

        static QString getStateValue(const QString& stateText);
        static QString getStateText(const QString& stateValue);
        static QStringList getListOfStateText();

        /* GUI utilities */
        static void addPlugins(QMenuBar *menuBar,
                               QSignalMapper *mapper,
                               QString filename);
        static void loadPluginFile(QMenuBar *menuBar,
                                   QSignalMapper *mapper,
                                   QString filename);
        static void insertPlugin(QStringList menuPath,
                                 QString cmd,
                                 QSignalMapper *mapper,
                                 QObject* parent);
    private:
        static bool resetWOPending(const QString &woID,
                                   QString &errorMessage,
                                   const bool &displayMessage,
                                   bool &errorShown);
};

#endif /* IASUTILITIES_H */

