/******************************************************************************
 *
 * Name: IASConfigureInstances
 *
 * PURPOSE: Used to enable/disable the processing instances.
 *
 *****************************************************************************/
// Qt Includes
#include <QtCore>
#include <QtGui>
#include <QtSql>

// Local Includes
#include "IASConfigureInstances.h"
#include "IASUtilities.h"
#include "IASSqlQuery.h"

IASConfigureInstances::IASConfigureInstances(
    QWidget* parent,    // I: The address to this widget's parent
    Qt::WindowFlags fl) // I: Used by QT
: QDialog(parent, fl)
{
    QString strSqlSelect = "Select instance_name, enabled "
        "from processing_instances";
    QStringList list;
    IASSqlQuery query;

    // Initialize the dropdown list
    list.append("Yes");
    list.append("No");
    list.append("No New Requests");

    // Set up the user interface.
    setupUi(this);

    // Initialize the instance counter
    instance_count = 0;

    // Get the current configuration information
    if (query.exec(strSqlSelect, __FILE__, __LINE__))
    {
        while (query.next())
        {
            QString instance = query.value(0).toString();
            QString enabled = query.value(1).toString();
            QHBoxLayout *layout = new QHBoxLayout();
            QLabel *label = new QLabel();
            QLabel *instanceName = new QLabel();
            QComboBox *cboEnabled = new QComboBox();

            // Add the list of options and check if the current is
            // set to 'N' (No) or 'R' (No New Requests) otherwise no update
            // is neccessary
            cboEnabled->addItems(list);
            if (enabled == "N")
            {
                cboEnabled->setCurrentIndex(1);
            }
            else if (enabled == "R")
            {
                cboEnabled->setCurrentIndex(2);
            }

            // Set the label text
            label->setText(instance + " Enabled:");
            instanceName->setText(instance);

            // Don't show the instance name
            instanceName->setHidden(true);

            // Add the label combo box to a horizontal layout
            layout->addWidget(label);
            layout->addWidget(instanceName);
            layout->addWidget(cboEnabled);

            // Add the new layout to the window
            layoutMain->addLayout(layout, instance_count++, 1);
        }
    }

    // Connect all of the signal slots.
    connect(pbCancel, SIGNAL(clicked()), this, SLOT(close()));
    connect(pbOK, SIGNAL(clicked()), this, SLOT(updateDbase()));
}

void IASConfigureInstances::updateDbase()
{
    // Update all fields regardless if they have changed since there are
    // few fields to update
    for (int i = 0; i < instance_count; i++)
    {
        IASSqlQuery query;
        QLayout *layout = layoutMain->itemAt(i)->layout();
        QLabel *instance = (QLabel*)(layout->itemAt(1)->widget());
        QComboBox *cbo = (QComboBox*)(layout->itemAt(2)->widget());
        QString enabledFlag;

        if (cbo->currentText().compare("Yes") == 0)
        {
            enabledFlag = "Y";
        }
        else if (cbo->currentText().compare("No") == 0)
        {
            enabledFlag = "N";
        }
        else if (cbo->currentText().compare("No New Requests") == 0)
        {
            enabledFlag = "R";
        }
        else
        {
            // The GUI should prevent this, but just in case issue an error
            // and continue
            QMessageBox::critical(0, "Instance Error", "The instance state (" +
                cbo->currentText() + ") is invalid.", QMessageBox::Ok, 0);
            continue;
        }

        query.exec("UPDATE PROCESSING_INSTANCES set ENABLED = '" +
            enabledFlag + "' WHERE INSTANCE_NAME = '" +
            instance->text() + "'", __FILE__, __LINE__);
    }

    close();
}

