
/*!
    \file IASErrorDialog.cpp
    \brief Provides the implementation for IASErrorDialog.

    See IASErrorDialog.
*/

/* System Includes */
#include <iostream>

/* Qt Includes */
#include <QtCore>
#include <QtGui>
#include <QtSql>

/* Local Includes */
#include "IASErrorDialog.h"
#include "IASDatabaseErrorDialog.h"

/*!
    This constructor allows the user to create a IASErrorDialog object.

    \param parent Input: The parent widget from which to create the
                         IASErrorDialog object.

    \param errorText Input: A short description of the error.

    \param fl Input: Qt uses this for internal purposes.
*/
IASErrorDialog::IASErrorDialog(QWidget* parent,
                         const QString errorText,
                         Qt::WindowFlags fl)
: QDialog(parent, fl)
{
    // Set up the user interface.
    setupUi(this);

    setWindowTitle(tr("Standard Error")); 

    lblErrorInfo->setText(errorText);

    frameDetails->hide();

    // Connect all the signals and slots.
    connect(pbOK, SIGNAL(clicked(bool)), this, SLOT(accept()));
}

/*!
    This function displays a standard error message.

    \param parent Input: The parent widget from which to create the
                         IASErrorDialog object.

    \param errorText Input: A short description of the error.

    \param fl Input: Qt uses this for internal purposes.
*/
void IASErrorDialog::standardError(QWidget* parent,
                                const QString errorText,
                                Qt::WindowFlags fl)
{
    IASErrorDialog *error;
    error=new IASErrorDialog(parent, errorText, fl);
    error->exec();
    delete error;
}

/*!
    This method displays a standard database error message. It will
    display additional information relating to the database.

    \param parent Input: The parent widget from which to create the
                         IASErrorDialog object.

    \param errorText Input: A short description of the error.

    \param fileName Input: The name of the invoking file.
                           (Use __FILE__)

    \param lineNum Input: The line number from the invoking file.
                          (Use __LINE__)

    \param rsDetails Input: The pointer to the QSqlQuery that returned
                            the error.

    \param fl Input: Qt uses this for internal purposes.
*/
void IASErrorDialog::databaseError(QWidget* parent,
                                const QString errorText,
                                const QString fileName,
                                const int lineNum,
                                QSqlQuery *rsDetails,
                                Qt::WindowFlags fl) 
{
    IASDatabaseErrorDialog *error;
    error=new IASDatabaseErrorDialog(parent,errorText,fileName,lineNum,
                                  rsDetails,fl);
    error->exec();
    delete error;
}

void IASErrorDialog::addDetailLine(QString line)
{
    mlTextEdit->appendPlainText(line);
}

