
/*!
    \file IASKeyValueComboBox.cpp
    \brief Provides the implementation for IASKeyValueComboBox.

    See IASKeyValueComboBox.
*/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "IASKeyValueComboBox.h"

/*!
    This constructor allows the user to create a IASKeyValueComboBox object.

    \param parent Input: The parent widget from which to create the
                         IASKeyValueComboBox object.

    \param name Input: The name Qt should use for this widget.
*/
IASKeyValueComboBox::IASKeyValueComboBox(QWidget *parent)
: QComboBox(parent)
{
    // Connect the activated signal from the base class to our slot,
    // so that we can emit our own signal with the right output.
    connect(this, SIGNAL(activated(const QString&)),
            this, SLOT(activatedSlot(const QString&)));
}

/*!
    This method adds a (key, value) pair to this object.

    \param key Input: The key for the value.  It is displayed by the interface.

    \param value Input: The value to return based on the selected key.
*/
void IASKeyValueComboBox::addKeyValue(QString & key,
                                   QString & value)
{
    m_dataMap.insert(key, value);

    insertItem(count(), key);
}

/*!
    This method returns the value for the currently selected item.
*/
QString IASKeyValueComboBox::currentValue()
{
    QString key = currentText();
    QString value = m_dataMap[key];

    return value;
}

/*!
    This slot emits activatedSignal with the value of the currently
    selected item.
*/
void IASKeyValueComboBox::activatedSlot(const QString & key)
{
    QString value = m_dataMap[key];

    emit(activatedSignal(value));
}

