
/*!
    \file IASListView.cpp
    \brief Provides the implementation for IASListView.

    See IASListView.
*/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "IASListView.h"

/*!
    This constructor allows the user to create a IASListView object.

    \param parent Input: The parent widget from which to create the
                         IASListView object.
*/
IASListView::IASListView(QWidget *parent)
: QTreeWidget(parent)
{
    // All listviews should have bolded headings and focus will be 
    // across the row.
    //------------------------------------------------------------
    QFont bold = font();
    bold.setWeight(QFont::Bold);
    header()->setFont(bold);
    setAllColumnsShowFocus(TRUE);

    // Allow for the context menu to be selected.
    setContextMenuPolicy(Qt::CustomContextMenu);

    // Create the popup menu and add the menu items
    //---------------------------------------------
    m_popMenu = new QMenu(this);
    m_popMenu->addAction("Copy Cell to Clipboard", this, SLOT(copyCell()));
    m_popMenu->addAction("Copy Row to Clipboard", this, SLOT(copyRow()));
    m_popMenu->addAction("Copy Column to Clipboard", this, SLOT(copyColumn()));

    // Display a popup menu when the user presses the right button
    // to allow copying of text to the mouse and clipboard
    //------------------------------------------------------------
    connect(this, SIGNAL(customContextMenuRequested(const QPoint&)),
                  SLOT(showPopupMenu(const QPoint&)));
}

void IASListView::showPopupMenu(const QPoint& pos)
{
    m_popMenu->exec(mapToGlobal(pos));
}

void IASListView::copyCell()
{
    QTreeWidgetItem *lvi = NULL;
    QString lvText("");

    // Grab the currently selected item.
    lvi = currentItem();
    if(lvi == NULL)
    {
        return;
    }

    // Grab the text for it.
    lvText = lvi->text(currentColumn());

    // Insert the text into the clipboard and mouse
    QClipboard* cb = QApplication::clipboard();
    cb->clear();
    cb->setText(lvText);
}

void IASListView::copyRow()
{
    QTreeWidgetItem *lvi = NULL;
    QString lvText("");

    // Grab the currently selected item.
    lvi = currentItem();
    if(lvi == NULL)
    {
        return;
    }

    // Grab the text for it.
    for(int i = 0; i < columnCount(); i++)
    {
        if(i != 0)
        {
            lvText += "\t";
        }
        lvText += lvi->text(i);
    }

    // Insert the text into the clipboard and mouse
    QClipboard* cb = QApplication::clipboard();
    cb->clear();
    cb->setText(lvText);
}

void IASListView::copyColumn()
{
    QString lvText("");

    // Grab the text for it.
    int column = currentColumn();
    QTreeWidgetItemIterator itr(this);
    while(*itr)
    {
        lvText += (*itr)->text(column) + " \n";
        ++itr;
    }

    // Insert the text into the clipboard and mouse
    QClipboard* cb = QApplication::clipboard();
    cb->clear();
    cb->setText(lvText);
}

/*!
    Returns a pointer to the popup menu.
*/
QMenu *IASListView::getPopupMenu()
{
    return (m_popMenu);
}

