
/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "IASParameterItem.h"

/* ===========================================================================
  IASParameterItem

  The constructor for the item object.
=========================================================================== */
IASParameterItem::IASParameterItem()
{
    // Set default values for the item.

    m_type = IASParameterItem::Text;

    m_editable = false;
    m_alignment = (Qt::AlignVCenter | Qt::AlignLeft);

    /* Set the minimum and maximum values to the same value so by default
       we have an unlimited range. */
    m_minValue = 0;
    m_maxValue = 0;
    m_decimals = 6;

    m_options.clear();
}

/* ===========================================================================
  setData

  Sets the data value for the item.
=========================================================================== */
void IASParameterItem::setData(QVariant& data)
{
    m_value = data;
}

/* ===========================================================================
  data

  Returns the data value for the item.
=========================================================================== */
QVariant IASParameterItem::data()
{
    return m_value;
}

/* ===========================================================================
  setType

  Sets the type of the item.
=========================================================================== */
void IASParameterItem::setType(IASParameterItem::ItemType type)
{
    m_type = type;
}

/* ===========================================================================
  type

  Returns the type of the item.
=========================================================================== */
IASParameterItem::ItemType IASParameterItem::type()
{
    return m_type;
}

/* ===========================================================================
  setMinimum

  Sets the minimum value for the item.

  Set the minimum and maximum values to the same value if you want an
  unlimited range.  This is the case by default.
=========================================================================== */
void IASParameterItem::setMinimum(QVariant& data)
{
    m_minValue = data;
}

/* ===========================================================================
  minimum

  Returns the minimum value for the item.
=========================================================================== */
QVariant IASParameterItem::minimum()
{
    return m_minValue;
}

/* ===========================================================================
  setMaximum

  Sets the maximum value for the item.

  Set the minimum and maximum values to the same value if you want an
  unlimited range.  This is the case by default.
=========================================================================== */
void IASParameterItem::setMaximum(QVariant& data)
{
    m_maxValue = data;
}

/* ===========================================================================
  maximum

  Returns the maximum value for the item.
=========================================================================== */
QVariant IASParameterItem::maximum()
{
    return m_maxValue;
}

/* ===========================================================================
  setDecimals

  Sets the precision for floating point values.  Used by display and editor
  objects.
=========================================================================== */
void IASParameterItem::setDecimals(QVariant& decimals)
{
    m_decimals = decimals;
}

/* ===========================================================================
  decimals

  Returns the precision for floating point values.  Used by display and editor
  objects.
=========================================================================== */
QVariant IASParameterItem::decimals()
{
    return m_decimals;
}

/* ===========================================================================
  setAlignment

  Sets the alignment of the text to be displayed.
=========================================================================== */
void IASParameterItem::setAlignment(Qt::Alignment alignment)
{
    m_alignment = alignment;
}

/* ===========================================================================
  alignment

  Returns the alignment of the text to be displayed.
=========================================================================== */
Qt::Alignment IASParameterItem::alignment()
{
    return m_alignment;
}

/* ===========================================================================
  setEditable

  Sets the object to be editable or not.
=========================================================================== */
void IASParameterItem::setEditable(bool editable)
{
    m_editable = editable;
}

/* ===========================================================================
  editable

  Returns true or false depending on if the item is editable or not.
=========================================================================== */
bool IASParameterItem::editable()
{
    return m_editable;
}

/* ===========================================================================
  setOptions

  Sets the defined possible values for the item.  To be used by the
  QComboBox editor.
=========================================================================== */
void IASParameterItem::setOptions(QStringList& options)
{
    m_options = options;
}

/* ===========================================================================
  options

  Returns a list of the possible values for this item. To be used by the
  QComboBox editor.
=========================================================================== */
QStringList IASParameterItem::options()
{
    return m_options;
}

