/***************************************************************************
This is a quick hack to convert the epoch 4 L0R files to the
epoch 5 L0R format.
***************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <limits.h>
#include <dlfcn.h>          /* for dlopen and related routines */
#include "ias_types.h"
#include "ias_const.h"
#include "ias_logging.h"
#include "ias_old_l0r_constants.h"
#include "ias_old_l0r_structures.h"
#include "ias_l0r.h"
#include "ias_satellite_attributes.h"

/*****************************************************************************/
/* function pointers for the old L0R IO library */
void *lib_handle;

OLD_L0RIO *(*old_l0r_open_from_filename)(const char *,
    const IAS_OLD_L0R_BAND_COMPRESSION);
int (*old_l0r_close)(OLD_L0RIO *);
int (*old_l0r_get_ancillary_tirs_ssm_records_count)(OLD_L0RIO *, int *);

int (*old_l0r_open_band)(OLD_L0RIO *, const int, const IAS_ACCESS_MODE);
int (*old_l0r_close_band)(OLD_L0RIO *, const int);
int (*old_l0r_get_band_records_count)(OLD_L0RIO *, const int, unsigned int *);
int (*old_l0r_get_band_offset_records_count)(
    OLD_L0RIO *l0r,            /* I: structure for the file used in I/O */
    const int band_number, /* I: band number */
    unsigned int *size     /* O: number of records for the offset
                                 dataset for this band */
);

int (*old_l0r_get_band_lines)(OLD_L0RIO *, const int, const uint32_t,
        const int, const int, uint16_t *);
int (*old_l0r_get_top_detector_offsets)(OLD_L0RIO *, const int, uint16_t *,
        const int);
int (*old_l0r_get_bottom_detector_offsets)(OLD_L0RIO *, const int, uint16_t *,
        const int);
int (*old_l0r_open_metadata)(OLD_L0RIO *, const IAS_ACCESS_MODE);
int (*old_l0r_close_metadata)(OLD_L0RIO *);
int (*old_l0r_get_interval_metadata)(OLD_L0RIO *,
    IAS_OLD_L0R_INTERVAL_METADATA *);
int (*old_l0r_get_scene_metadata)(OLD_L0RIO *, const int, const int,
    IAS_OLD_L0R_SCENE_METADATA *);
int (*old_l0r_get_scene_metadata_records_count)(
    OLD_L0RIO *l0r,        /* I: structure used with the l0r data */
    unsigned int *size /* O: number of records in the scene dataset */
);
int (*old_l0r_get_file_metadata)(
     OLD_L0RIO *l0r, /* I: structure used with the l0r data to be read from */
     IAS_OLD_L0R_FILE_METADATA *mta_info_file /* O: File Metadata */
);
int (*old_l0r_get_file_metadata_records_count)(
    OLD_L0RIO *l0r,        /* I: structure used with the l0r data */
    unsigned int *size /* O: number of records in the file dataset */
);
int (*old_l0r_get_oli_image_header)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data  */
    IAS_OLD_L0R_OLI_IMAGE_HEADER *image_header /* O: Data read */
);

int (*old_l0r_is_oli_image_header_present)(
    OLD_L0RIO *l0r,        /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in the image header dataset*/
);
int (*old_l0r_open_header)( 
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    const IAS_ACCESS_MODE file_access_mode /* I: Mode to open file in */
);

int (*old_l0r_close_header)(
    OLD_L0RIO *l0r /* I:structure used with the L0R data */
);
int (*old_l0r_get_oli_frame_headers)(
    OLD_L0RIO *l0r,                    /* I: structure used with the L0R data */
    const int start_record,        /* I: First record to read */
    const int num_records_to_read, /* I: Number to read */
    IAS_OLD_L0R_OLI_FRAME_HEADER *frame_header /* O: Data read */
);

int (*old_l0r_get_tirs_frame_headers)(
    OLD_L0RIO *l0r,                    /* I: structure used with the L0R data */
    const int start_record,        /* I: First record to read */
    const int num_records_to_read, /* I: Number to read */
    IAS_OLD_L0R_TIRS_FRAME_HEADER *frame_header /* O: Data read */
);

int (*old_l0r_get_oli_frame_headers_records_count)(
    OLD_L0RIO *l0r,        /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in the OLI frame header dataset*/
);

int (*old_l0r_get_tirs_frame_headers_records_count)(
    OLD_L0RIO *l0r,        /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in  the TIRS frame header
                             dataset*/
);
int (*old_l0r_open_ancillary)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    const IAS_ACCESS_MODE file_access_mode /* I: Mode to open file in */
);

int (*old_l0r_close_ancillary)(
    OLD_L0RIO *l0r /* I: structure used with the L0R data */
);
int (*old_l0r_get_ancillary_oli_telemetry)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    const int index, /* I: the index to begin the read at */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_OLI_TELEMETRY *telemetry /* O: buffer to hold data read */
);
int (*old_l0r_get_ancillary_oli_telemetry_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_tirs_telemetry)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    const int index, /* I: the index to begin the read at */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_TIRS_TELEMETRY *telemetry /* O: buffer to hold data read */
);
int (*old_l0r_get_ancillary_tirs_telemetry_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_imu)(
    OLD_L0RIO *l0r,      /* I: structure used with the L0R data  */
    const int index, /* I: index to begin read at */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_IMU *imu /* O: buffer for the read data */
);

int (*old_l0r_get_ancillary_imu_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_attitude)( 
    OLD_L0RIO *l0r, /* I: structure used with the L0R data   */
    const int index, /* I: index to being the read at */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_ATTITUDE *attitude /* O: buffer for read data */
);
int (*old_l0r_get_ancillary_attitude_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_attitude_filter_states)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data   */
    const int index, /* I: index to being the read at */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_ATTITUDE_FILTER_STATES *attitude /* O: buffer for read data */
);
int (*old_l0r_get_ancillary_attitude_filter_states_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_ephemeris)(  
    OLD_L0RIO *l0r, /* I: structure used with the L0R data  */
    const int index, /* I: index to begin read at  */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_EPHEMERIS *ephemeris /* O: buffer for read data */
);
int (*old_l0r_get_ancillary_ephemeris_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_gps_position)( 
    OLD_L0RIO *l0r, /* I: structure used with the L0R data   */
    const int index, /* I: index to begin read at */
    const int count, /* I: the number of items to read */
    IAS_OLD_L0R_GPS_POSITION *gps_position /* O: buffer for the read data */
);
int (*old_l0r_get_ancillary_gps_range)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data   */
    const int index, /* I: index to begin read at */
    const int count, /* I: the number of items to read */
    IAS_OLD_L0R_GPS_RANGE *gps_range /* O: buffer for the read data */
);
int (*old_l0r_get_ancillary_gps_position_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_gps_range_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_star_tracker_centroid)( 
    OLD_L0RIO *l0r,/* I: structure used with the L0R data */
    const int index, /* I: index to begin read at */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_STAR_TRACKER_CENTROID *centroid /* O: buffer for read data */
);
int (*old_l0r_get_ancillary_star_tracker_quaternion)(
    OLD_L0RIO *l0r,/* I: structure used with the L0R data */
    const int index, /* I: index to begin read at */
    const int count, /* I: number of items to read */
    IAS_OLD_L0R_STAR_TRACKER_QUATERNION *quaternion/* O: buffer for read data */
);
int (*old_l0r_get_ancillary_star_tracker_centroid_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_star_tracker_quaternion_records_count)(
    OLD_L0RIO *l0r, /* I: structure used with the L0R data */
    unsigned int *size /* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_gyro_temperature)
(
    OLD_L0RIO *l0r, /* I: pointer to structure used in I/O */
    const int index, /* I: index to begin read at */
    const int count,/* I: number of items to read */
    IAS_OLD_L0R_GYRO_TEMPERATURE *buffer/* O: buffer for read data */
);
int (*old_l0r_get_ancillary_gyro_temperature_records_count)
(
    OLD_L0RIO *l0r, /* I: pointer to structure used in I/O */
    unsigned int *size/* O: number of records in this dataset */
);
int (*old_l0r_get_ancillary_oli_tirs_temperature)
(
    OLD_L0RIO *l0r, /* I: pointer to structure used in I/O */
    const int index,/* I: index to begin read at */
    const int count,/* I: number of items to read */
    IAS_OLD_L0R_OLI_TIRS_TEMPERATURE *buffer/* O: buffer for read data */
);
int (*old_l0r_get_ancillary_oli_tirs_temperature_records_count)
(
    OLD_L0RIO *l0r, /* I: pointer to structure used in I/O */
    unsigned int *size/* O: number of records in this dataset */
);
int (*old_sat_attr_initialize)
(
    int satellite_id        /* I: Satellite ID */
);

/*****************************************************************************/
/* global variables */

/*****************************************************************************/
int setup_function_pointers()
{
    char *error;

#define GETFUNC(name) \
    old_l0r_##name = dlsym(lib_handle, "ias_l0r_"#name); \
    error = dlerror(); \
    if (error) \
    { \
        printf("Error loading function %s\n", #name); \
        return ERROR; \
    }

    /* open the dynamic library */
    lib_handle = dlopen("liboldl0r.so.1.0.1", RTLD_NOW);//RTLD_LAZY);
    if (!lib_handle)
    {
        IAS_LOG_ERROR("Opening the old L0R library: %s", dlerror());
        return ERROR;
    }

    /* get each of the function names needed */
    GETFUNC(open_from_filename);
    GETFUNC(close);
    GETFUNC(get_ancillary_tirs_ssm_records_count);
    GETFUNC(open_band);
    GETFUNC(close_band);
    GETFUNC(get_band_records_count);
    GETFUNC(get_band_offset_records_count);
    GETFUNC(get_band_lines);
    GETFUNC(get_top_detector_offsets);
    GETFUNC(get_bottom_detector_offsets);
    GETFUNC(open_metadata);
    GETFUNC(close_metadata);
    GETFUNC(get_interval_metadata);
    GETFUNC(get_scene_metadata);
    GETFUNC(get_scene_metadata_records_count);
    GETFUNC(get_file_metadata);
    GETFUNC(get_file_metadata_records_count);
    GETFUNC(get_oli_image_header);
    GETFUNC(is_oli_image_header_present);
    GETFUNC(open_header);
    GETFUNC(close_header);
    GETFUNC(get_oli_frame_headers);
    GETFUNC(get_tirs_frame_headers);
    GETFUNC(get_oli_frame_headers_records_count);
    GETFUNC(get_tirs_frame_headers_records_count);
    GETFUNC(open_ancillary);
    GETFUNC(close_ancillary);
    GETFUNC(get_ancillary_oli_telemetry);
    GETFUNC(get_ancillary_oli_telemetry_records_count);
    GETFUNC(get_ancillary_tirs_telemetry);
    GETFUNC(get_ancillary_tirs_telemetry_records_count);
    GETFUNC(get_ancillary_imu);
    GETFUNC(get_ancillary_imu_records_count);
    GETFUNC(get_ancillary_attitude);
    GETFUNC(get_ancillary_attitude_records_count);
    GETFUNC(get_ancillary_attitude_filter_states);
    GETFUNC(get_ancillary_attitude_filter_states_records_count);
    GETFUNC(get_ancillary_ephemeris);
    GETFUNC(get_ancillary_ephemeris_records_count);
    GETFUNC(get_ancillary_gps_position);
    GETFUNC(get_ancillary_gps_position_records_count);
    GETFUNC(get_ancillary_gps_range);
    GETFUNC(get_ancillary_gps_range_records_count);
    GETFUNC(get_ancillary_star_tracker_centroid);
    GETFUNC(get_ancillary_star_tracker_centroid_records_count);
    GETFUNC(get_ancillary_star_tracker_quaternion);
    GETFUNC(get_ancillary_star_tracker_quaternion_records_count);
    GETFUNC(get_ancillary_gyro_temperature);
    GETFUNC(get_ancillary_gyro_temperature_records_count);
    GETFUNC(get_ancillary_oli_tirs_temperature);
    GETFUNC(get_ancillary_oli_tirs_temperature_records_count);
    old_sat_attr_initialize = dlsym(lib_handle, "ias_sat_attr_initialize");
    error = dlerror();
    if (error)
    {
        printf("Error loading function %s\n", "ias_sat_attr_initialize");
        return ERROR;
    }

    return SUCCESS;
}

/*****************************************************************************/
int copy_vrp
(
    OLD_L0RIO *old_l0r_file, 
    L0RIO *new_l0r_file, 
    int band_number, 
    int vrp_band_number
)
{
    const IAS_BAND_ATTRIBUTES *band_attr;
    int detector_count;
    int sca_count;
    unsigned int line_count;
    int status;
    unsigned short int *imagery;

    IAS_LOG_INFO("Converting VRP for band %d (VRP band %d)", band_number,
                 vrp_band_number);

    /* get attributes for the vrp band */
    band_attr = ias_sat_attr_get_band_attributes(vrp_band_number);
    if (!band_attr)
    {
        IAS_LOG_ERROR("Failed to get band attributes for band %d",
                      band_number);
        return ERROR;
    }
    detector_count = band_attr->detectors_per_sca;
    sca_count = band_attr->scas;

    /* open the input band */
    status = old_l0r_open_band(old_l0r_file, vrp_band_number, IAS_READ);
    if (status != SUCCESS)
    {
        IAS_LOG_ERROR("Error opening band number %d", vrp_band_number);
        return ERROR;
    }

    /* get the size of the old image */
    status = old_l0r_get_band_records_count(old_l0r_file,
                vrp_band_number, &line_count);
    if (status != SUCCESS || line_count < 1)
    {
        IAS_LOG_ERROR("Invalid line count %d for input band number %d",
                      line_count, vrp_band_number);
        old_l0r_close_band(old_l0r_file, vrp_band_number);
        return ERROR;
    }

    /* allocate memory for the entire band - brutal on memory use, but
       not important in this hack */
    imagery = malloc(sizeof(*imagery) * line_count * sca_count 
                    * detector_count);
    if (!imagery)
    {
        IAS_LOG_ERROR("Allocating imagery buffer");
        return ERROR;
    }

    /* read the imagery */
    if (old_l0r_get_band_lines(old_l0r_file, vrp_band_number, 0,
            line_count, sca_count * detector_count, imagery) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading source image for input band number %d", 
                      vrp_band_number);
        old_l0r_close_band(old_l0r_file, vrp_band_number);
        free(imagery);
        return ERROR;
    }

    old_l0r_close_band(old_l0r_file, vrp_band_number);

    /* open the band for writing */
    if (ias_l0r_open_band(new_l0r_file, vrp_band_number, IAS_WRITE) != SUCCESS)
    {
        IAS_LOG_ERROR("Opening target image for band number %d", 
                      vrp_band_number);
        free(imagery);
        return ERROR;
    }

    /* write the imagery to the new file */
    if (ias_l0r_set_band_lines(new_l0r_file, vrp_band_number, 0, line_count,
            imagery) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing target image for band number %d", 
                      vrp_band_number);
        ias_l0r_close_band(new_l0r_file, vrp_band_number);
        free(imagery);
        return ERROR;
    }

    free(imagery);
    imagery = NULL;

    if (ias_l0r_close_band(new_l0r_file, vrp_band_number) != SUCCESS)
    {
        IAS_LOG_ERROR("Closing target image for band number %d", 
                      vrp_band_number);
        return ERROR;
    }

    return SUCCESS;
}

/*****************************************************************************/
int convert_imagery
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    int band_index;
    unsigned int line_count;
    int band_count;
    int status;

    band_count = IAS_MAX_NBANDS + 7 ;

    for (band_index = 0; band_index < band_count; band_index++)
    {
        int out_band_number = band_index + 1;
        int in_band_number = band_index + 1;
        int detector_count;
        int sca_count;
        const IAS_BAND_ATTRIBUTES *band_attr;
        unsigned short int *imagery;
        unsigned short int *offsets;
        unsigned int offset_count;

        IAS_LOG_INFO("Converting imagery for output band number %d", 
                     out_band_number);

        /* get the sca and detector counts for the band */
        band_attr = ias_sat_attr_get_band_attributes(out_band_number);
        if (!band_attr)
        {
            IAS_LOG_ERROR("Failed to get band attributes for output band %d",
                          out_band_number);
            return ERROR;
        }
        detector_count = band_attr->detectors_per_sca;
        sca_count = band_attr->scas;

        /* open the input band */
        status = old_l0r_open_band(old_l0r_file, in_band_number, IAS_READ);
        if (status != SUCCESS)
        {
            IAS_LOG_ERROR("Error opening band number %d", in_band_number);
            return ERROR;
        }

        /* get the size of the old image */
        status = old_l0r_get_band_records_count(old_l0r_file,
                    in_band_number, &line_count);
        if (status != SUCCESS)
        {
            IAS_LOG_ERROR("Error reading line count in band number %d",
                in_band_number);
            old_l0r_close_band(old_l0r_file, in_band_number);
            return ERROR;
        }
        if (line_count < 1)
        {
            IAS_LOG_WARNING("No lines in band number %d, must not be present "
                "- skipping it", in_band_number);
            old_l0r_close_band(old_l0r_file, in_band_number);
            continue;
        }

        /* allocate memory for the entire band - brutal on memory use, but
           not important in this hack */
        imagery = malloc(sizeof(*imagery) * line_count * sca_count 
                        * detector_count);
        if (!imagery)
        {
            IAS_LOG_ERROR("Allocating imagery buffer");
            return ERROR;
        }

        /* read the imagery */
        if (old_l0r_get_band_lines(old_l0r_file, in_band_number, 0,
                line_count, sca_count * detector_count, imagery) != SUCCESS)
        {
            IAS_LOG_ERROR("Reading source image for input band number %d", 
                          in_band_number);
            free(imagery);
            return ERROR;
        }

        /* open the band for writing */
        if (ias_l0r_open_band(new_l0r_file, out_band_number, IAS_WRITE)
                != SUCCESS)
        {
            IAS_LOG_ERROR("Opening target image for band number %d", 
                          out_band_number);
            free(imagery);
            return ERROR;
        }

        /* write the imagery to the new file */
        if (ias_l0r_set_band_lines(new_l0r_file, out_band_number, 0, line_count,
                imagery) != SUCCESS)
        {
            IAS_LOG_ERROR("Writing target image for band number %d", 
                          out_band_number);
            ias_l0r_close_band(new_l0r_file, out_band_number);
            free(imagery);
            return ERROR;
        }

        free(imagery);
        imagery = NULL;

        /* now convert the detector offsets, first allocate space */
        offsets = malloc(sizeof(*offsets) * detector_count * sca_count);
        if (!offsets)
        {
            IAS_LOG_ERROR("Allocating offset memory");
            ias_l0r_close_band(new_l0r_file, out_band_number);
            return ERROR;
        }

        /* get the count of offsets for the band */
        if (old_l0r_get_band_offset_records_count(old_l0r_file,
                in_band_number, &offset_count) != SUCCESS)
        {
            IAS_LOG_ERROR("Reading detector offsets count");
            free(offsets);
            ias_l0r_close_band(new_l0r_file, out_band_number);
            return ERROR;
        }

        if (offset_count > 0)
        {
            /* read the top offsets */
            if (old_l0r_get_top_detector_offsets(old_l0r_file,
                    in_band_number, offsets, detector_count * sca_count)
                    != SUCCESS)
            {
                IAS_LOG_ERROR("Reading detector offsets");
                free(offsets);
                ias_l0r_close_band(new_l0r_file, out_band_number);
                return ERROR;
            }

            /* write the offsets as the top offsets in the file */
            if (ias_l0r_set_top_detector_offsets(new_l0r_file, out_band_number, 
                    offsets) != SUCCESS)
            {
                IAS_LOG_ERROR("Writing detector offsets");
                free(offsets);
                ias_l0r_close_band(new_l0r_file, out_band_number);
                return ERROR;
            }

            /* skip reading the tirs bottom offsets since there don't appear to
               be any in the old files.  It will just write the top offsets
               which are always zero for our test data anyway */
            if (offset_count > 1)
            {
                /* now the bottom offsets */
                if (old_l0r_get_bottom_detector_offsets(old_l0r_file,
                        in_band_number, offsets, detector_count * sca_count)
                        != SUCCESS)
                {
                    IAS_LOG_WARNING(
                        "Couldn't read bottom detector offsets - just "
                        "copying top offsets since they're likely zero anyway");
                }
            }

            /* write the offsets as the top offsets in the file */
            if (ias_l0r_set_bottom_detector_offsets(new_l0r_file, 
                    out_band_number, offsets) != SUCCESS)
            {
                IAS_LOG_ERROR("Writing detector offsets");
                free(offsets);
                ias_l0r_close_band(new_l0r_file, out_band_number);
                return ERROR;
            }
        }

        free(offsets);
        offsets = NULL;

        /* copy the VRPS if there are any */
        if (band_attr->vrp_band_number >= 1)
        {
            if (copy_vrp(old_l0r_file, new_l0r_file, in_band_number, 
                         band_attr->vrp_band_number) != SUCCESS)
            {
                IAS_LOG_ERROR("Copying VRPs for band number %d (vrp band "
                    "number %d)", out_band_number, band_attr->vrp_band_number);
                ias_l0r_close_band(new_l0r_file, out_band_number);
                return ERROR;
            }
        }

        /* close the target band */
        if (ias_l0r_close_band(new_l0r_file, out_band_number) != SUCCESS)
        {
            IAS_LOG_ERROR("Closing target image for band number %d", 
                          out_band_number);
            return ERROR;
        }

        old_l0r_close_band(old_l0r_file, in_band_number);
    }

    return SUCCESS;
}

#define COPY_CORNERS(cd, cs) \
    cd.upleft.lat = cs.upleft.lat; \
    cd.upleft.lng = cs.upleft.lng;  \
    cd.upright.lat = cs.upright.lat; \
    cd.upright.lng = cs.upright.lng; \
    cd.loleft.lat = cs.loleft.lat; \
    cd.loleft.lng = cs.loleft.lng; \
    cd.loright.lat = cs.loright.lat; \
    cd.loright.lng = cs.loright.lng;

/*****************************************************************************/
int convert_interval_metadata
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_INTERVAL_METADATA omd;
    IAS_L0R_INTERVAL_METADATA nmd;
    int i;
    int acq_year;
    int anc_year;

    if (old_l0r_get_interval_metadata(old_l0r_file, &omd) != SUCCESS)
    {
        IAS_LOG_WARNING("Reading old interval metadata - assuming a partial "
            "set of source data so skipping");
        return SUCCESS;
    }

    memset(&nmd, 0, sizeof(nmd));
    memcpy(nmd.ancillary_start_time, omd.ancillary_start_time,
           sizeof(nmd.ancillary_start_time));
    nmd.ancillary_start_time[IAS_L0R_DATE_LENGTH] = '\0';
    memcpy(nmd.ancillary_stop_time, omd.ancillary_stop_time,
           sizeof(nmd.ancillary_stop_time));
    nmd.ancillary_stop_time[IAS_L0R_DATE_LENGTH] = '\0';
    nmd.attitude_points = omd.attitude_points;
    nmd.attitude_points_missing = omd.attitude_points_missing;
    nmd.attitude_points_rejected = omd.attitude_points_rejected;
    memcpy(nmd.collection_type, omd.collection_type,
           sizeof(nmd.collection_type));
    /* Replace spaces with underscores for Epoch 3*/
    for (i=0; i < IAS_L0R_COLLECTION_TYPE_LENGTH-1; i++)
        if(nmd.collection_type[i] == ' ')
            nmd.collection_type[i] = '_';
    nmd.collection_type[IAS_L0R_COLLECTION_TYPE_LENGTH] = '\0';

    COPY_CORNERS(nmd.corners_oli, omd.corners_oli);
    COPY_CORNERS(nmd.corners_tirs, omd.corners_tirs);

    memcpy(nmd.cpf_name, omd.cpf_name, sizeof(nmd.cpf_name));
    nmd.cpf_name[IAS_L0R_CPF_NAME_LENGTH] = '\0';
    nmd.crc_errors_oli = omd.crc_errors_oli;
    nmd.crc_errors_tirs = omd.crc_errors_tirs;
    memcpy(nmd.data_type, omd.data_type, sizeof(nmd.data_type));
    nmd.data_type[IAS_L0R_DATA_TYPE_LENGTH] = '\0';
    memcpy(nmd.date_acquired, omd.date_acquired,
        sizeof(nmd.date_acquired));
    nmd.date_acquired[IAS_L0R_DATE_LENGTH] = '\0';
    nmd.ephemeris_points = omd.ephemeris_points;
    nmd.ephemeris_points_missing = omd.ephemeris_points_missing;
    nmd.ephemeris_points_rejected = omd.ephemeris_points_rejected;
    memcpy(nmd.hostname, omd.hostname, sizeof(nmd.hostname));
    nmd.hostname[IAS_L0R_HOSTNAME_LENGTH] = '\0';
    nmd.image_quality_oli = omd.image_quality_oli;
    nmd.image_quality_tirs = omd.image_quality_tirs;
    nmd.interval_frames_oli = omd.interval_frames_oli;
    nmd.interval_frames_tirs = omd.interval_frames_tirs;
    nmd.interval_number = omd.interval_number;
    nmd.interval_version = omd.interval_version;
    memcpy(nmd.is_version, omd.is_version, sizeof(nmd.is_version));
    nmd.is_version[IAS_SOFTWARE_VERSION_SIZE - 1] = '\0';
    memcpy(nmd.landsat_cal_interval_id, omd.landsat_cal_interval_id,
        sizeof(nmd.landsat_cal_interval_id));
    nmd.landsat_cal_interval_id[IAS_L0R_INTERVAL_ID_LENGTH] = '\0';
    memcpy(nmd.landsat_interval_id, omd.landsat_interval_id,
        sizeof(nmd.landsat_interval_id));
    nmd.landsat_interval_id[IAS_L0R_INTERVAL_ID_LENGTH] = '\0';
    nmd.frames_filled_oli = omd.frames_filled_oli;
    nmd.frames_filled_tirs = omd.frames_filled_tirs;
    memcpy(nmd.nadir_offnadir, omd.nadir_offnadir, sizeof(nmd.nadir_offnadir));
    nmd.nadir_offnadir[IAS_L0R_NADIR_LENGTH] = '\0';
    memcpy(nmd.quality_algorithm, omd.quality_algorithm,
           sizeof(nmd.quality_algorithm));
    nmd.quality_algorithm[IAS_L0R_ALGORITHM_NAME_LENGTH] = '\0';
    nmd.roll_angle = omd.roll_angle;
    nmd.satellite = omd.satellite;
    memcpy(nmd.sensor_id, omd.sensor_id, sizeof(nmd.sensor_id));
    nmd.sensor_id[IAS_L0R_SENSOR_ID_LENGTH] = '\0';
    memcpy(nmd.spacecraft_id, omd.spacecraft_id, sizeof(nmd.spacecraft_id));
    nmd.spacecraft_id[IAS_L0R_SPACECRAFT_ID_LENGTH] = '\0';
    memcpy(nmd.start_time_oli, omd.start_time_oli, sizeof(nmd.start_time_oli));
    nmd.start_time_oli[IAS_L0R_DATE_LENGTH] = '\0';
    memcpy(nmd.start_time_tirs, omd.start_time_tirs,
        sizeof(nmd.start_time_tirs));
    nmd.start_time_tirs[IAS_L0R_DATE_LENGTH] = '\0';
    memcpy(nmd.station_id, omd.station_id, sizeof(nmd.station_id));
    nmd.station_id[IAS_L0R_STATION_ID_LENGTH] = '\0';
    memcpy(nmd.stop_time_oli, omd.stop_time_oli, sizeof(nmd.stop_time_oli));
    nmd.stop_time_oli[IAS_L0R_DATE_LENGTH] = '\0';
    memcpy(nmd.stop_time_tirs, omd.stop_time_tirs,
        sizeof(nmd.stop_time_tirs));
    nmd.stop_time_tirs[IAS_L0R_DATE_LENGTH] = '\0';
    nmd.time_code_errors_oli = omd.time_code_errors_oli;
    nmd.time_code_errors_tirs = omd.time_code_errors_tirs;
    nmd.detector_map_id_tirs = omd.detector_map_id_tirs;
    nmd.wrs_ending_row = omd.wrs_ending_row;
    nmd.wrs_scenes = omd.wrs_scenes;
    nmd.wrs_scenes_full = omd.wrs_scenes_full;
    nmd.wrs_scenes_partial = omd.wrs_scenes_partial;
    nmd.wrs_starting_path = omd.wrs_starting_path;
    nmd.wrs_starting_row = omd.wrs_starting_row;
    nmd.wrs_type = omd.wrs_type;

    if (strlen(nmd.collection_type) == 0)
    {
        /* assume earth if the data didn't have a collection type */
        IAS_LOG_WARNING("No collection type found - defaulting to "
            "EARTH_IMAGING");
        strcpy(nmd.collection_type, "EARTH_IMAGING");
    }

    /* if the date_acquired appears to be garbage, fix it up from the ancillary
       start time.  "garbage" is defined as a completely unrealistic year or
       a year that is different than the ancillary start time year (since some
       of the cal/val L0Rs mistakenly had the processing date in the date
       acquired) */
    acq_year = atoi(nmd.date_acquired);
    anc_year = atoi(nmd.ancillary_start_time);
    if (acq_year <= 1990 || acq_year >= 2050 
        || (anc_year != 0 && acq_year != anc_year))
    {
        /* copy the ancillary start time */
        strcpy(nmd.date_acquired, nmd.ancillary_start_time);
    }


    if (ias_l0r_set_interval_metadata(new_l0r_file, &nmd) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new interval metadata");
        return ERROR;
    }

    return SUCCESS;
}

/*****************************************************************************/
int convert_scene_metadata
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_SCENE_METADATA omd;
    IAS_L0R_SCENE_METADATA nmd;
    unsigned int scene_count;
    int status;
    int scene;

    status = old_l0r_get_scene_metadata_records_count(old_l0r_file,
        &scene_count);
    if (status != SUCCESS)
    {
        IAS_LOG_ERROR("Error reading scene metadata record count");
        return ERROR;
    }

    for (scene = 0; scene < scene_count; scene++)
    {
        if (old_l0r_get_scene_metadata(old_l0r_file, scene, 1, &omd) != SUCCESS)
        {
            IAS_LOG_ERROR("Reading old scene metadata");
            return ERROR;
        }

        memset(&nmd, 0, sizeof(nmd));

        nmd.attitude_points = omd.attitude_points;
        nmd.attitude_points_missing = omd.attitude_points_missing;
        nmd.attitude_points_rejected = omd.attitude_points_rejected;

        nmd.sensor_present_oli = omd.sensor_present_oli;
        nmd.sensor_present_tirs = omd.sensor_present_tirs;

        COPY_CORNERS(nmd.corners_oli, omd.corners_oli);
        COPY_CORNERS(nmd.corners_tirs, omd.corners_tirs);

        nmd.crc_errors = omd.crc_errors;
        memcpy(nmd.date_acquired, omd.date_acquired, sizeof(nmd.date_acquired));
        nmd.date_acquired[IAS_L0R_TIME_LENGTH] = '\0';
        memcpy(nmd.day_night, omd.day_night, sizeof(nmd.day_night));
        nmd.day_night[IAS_L0R_DAY_NIGHT_LENGTH] = '\0';
        nmd.ephemeris_points = omd.ephemeris_points;
        nmd.ephemeris_points_missing = omd.ephemeris_points_missing;
        nmd.ephemeris_points_rejected = omd.ephemeris_points_rejected;
        memcpy(nmd.full_partial_scene, omd.full_partial_scene,
            sizeof(nmd.full_partial_scene));
        nmd.full_partial_scene[IAS_L0R_SCENE_FULL_PARTIAL_LENGTH] = '\0';
        nmd.scene_center_shift = omd.scene_center_shift;
        memcpy(nmd.hostname, omd.hostname, sizeof(nmd.hostname));
        nmd.hostname[IAS_L0R_HOSTNAME_LENGTH] = '\0';
        nmd.image_quality_oli = omd.image_quality_oli;
        nmd.image_quality_tirs = omd.image_quality_tirs;
        /* some scene have junk for a scene id.  If it is too long, it will
           just get truncated */
        memcpy(nmd.landsat_scene_id, omd.landsat_scene_id,
                sizeof(nmd.landsat_scene_id));
        nmd.landsat_scene_id[sizeof(nmd.landsat_scene_id)-1] = '\0';
        nmd.missing_frames = omd.missing_frames;
        memcpy(nmd.nadir_offnadir, omd.nadir_offnadir, 
            sizeof(nmd.nadir_offnadir));
        nmd.nadir_offnadir[IAS_L0R_NADIR_LENGTH] ='\0';
        nmd.roll_angle = omd.roll_angle;
        nmd.scene_center = omd.scene_center;
        nmd.scene_start_frame_oli = omd.scene_start_frame_oli;
        nmd.scene_stop_frame_oli = omd.scene_stop_frame_oli;
        nmd.scene_start_frame_tirs = omd.scene_start_frame_tirs;
        nmd.scene_stop_frame_tirs = omd.scene_stop_frame_tirs;
        memcpy(nmd.start_time, omd.start_time, sizeof(nmd.start_time));
        nmd.start_time[IAS_L0R_TIME_LENGTH] = '\0';
        memcpy(nmd.stop_time, omd.stop_time, sizeof(nmd.stop_time));
        nmd.stop_time[IAS_L0R_TIME_LENGTH] = '\0';
        memcpy(nmd.subsetter_version_l0rp, omd.subsetter_version_l0rp,
            sizeof(nmd.subsetter_version_l0rp));
        nmd.subsetter_version_l0rp[IAS_SOFTWARE_VERSION_SIZE - 1] = '\0';
        nmd.sun_azimuth = omd.sun_azimuth;
        nmd.sun_elevation = omd.sun_elevation;
        nmd.target_wrs_path = omd.target_wrs_path;
        nmd.target_wrs_row = omd.target_wrs_row;
        nmd.time_code_errors = omd.time_code_errors;
        nmd.wrs_path = omd.wrs_path;
        nmd.wrs_row = omd.wrs_row;
        nmd.wrs_scene_number = omd.wrs_scene_number;

        if (ias_l0r_set_scene_metadata(new_l0r_file, scene, 1, &nmd) != SUCCESS)
        {
            IAS_LOG_ERROR("Writing new scene metadata");
            return ERROR;
        }
    }

    return SUCCESS;
}

/*****************************************************************************/
int convert_file_metadata
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_FILE_METADATA omd;
    IAS_L0R_FILE_METADATA nmd;
    unsigned int record_count;
    int status;
    int i;

    status = old_l0r_get_file_metadata_records_count(old_l0r_file,
        &record_count);
    if (status != SUCCESS)
    {
        /* should only be a single file metadata record */
        IAS_LOG_ERROR("Invalid file metadata count read: %d", record_count);
        return ERROR;
    }
    if (record_count != 1)
    {
        /* assume the file just doesn't have one and pretend it worked */
        IAS_LOG_WARNING("No file metadata found - skipping it");
        return SUCCESS;
    }

    status = old_l0r_get_file_metadata(old_l0r_file, &omd);
    if (status != SUCCESS)
    {
        IAS_LOG_ERROR("Error reading old file metadata");
        return ERROR;
    }

    memset(&nmd, 0, sizeof(nmd));

    memcpy(nmd.ancillary_file.name, omd.ancillary_file.name,
           sizeof(nmd.ancillary_file.name));
    nmd.ancillary_file.name[IAS_L0R_FILE_NAME_LENGTH] = '\0';

    memcpy(nmd.checksum_file.name, omd.checksum_file.name,
           sizeof(nmd.checksum_file.name));
    nmd.checksum_file.name[IAS_L0R_FILE_NAME_LENGTH] = '\0';

    for (i = 0; i < IAS_L0R_MAX_BAND_FILES; i++)
    {
        memcpy(nmd.band_files[i].name, omd.band_files[i].name,
               sizeof(nmd.band_files[i].name));
        nmd.band_files[i].name[IAS_L0R_FILE_NAME_LENGTH] = '\0';
    }
    nmd.interval_files = omd.interval_files;

    memcpy(nmd.metadata_file.name, omd.metadata_file.name,
           sizeof(nmd.metadata_file.name));
    nmd.metadata_file.name[IAS_L0R_FILE_NAME_LENGTH] = '\0';

    if (ias_l0r_set_file_metadata(new_l0r_file, &nmd) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new file metadata");
        return ERROR;
    }

    return SUCCESS;
}

/*****************************************************************************/
int convert_image_header
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_OLI_IMAGE_HEADER oih;
    IAS_L0R_OLI_IMAGE_HEADER nih;
    unsigned int size;

    if (old_l0r_is_oli_image_header_present(old_l0r_file, &size) != SUCCESS)
    {
        IAS_LOG_ERROR("Determining if OLI image header is present");
        return ERROR;
    }
    if (size == 0)
    {
        /* no image header, so just return */
        return SUCCESS;
    }

    if (old_l0r_get_oli_image_header(old_l0r_file, &oih) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old frame header");
        return ERROR;
    }

    memset(&nih, 0, sizeof(nih));

    nih.length_of_image = oih.length_of_image;
    nih.image_content_definition = oih.image_content_definition;
    /* copy integration times across, (same units now) */
    nih.ms_integration_time = oih.ms_integration_time;
    nih.pan_integration_time = oih.pan_integration_time;
    nih.ms_data_word = oih.ms_data_word;
    nih.pan_data_word = oih.pan_data_word;
    nih.extended_integration_flag = oih.extended_integration_flag;
    nih.blind_band_record_rate = oih.blind_band_record_rate;
    nih.test_pattern_setting = oih.test_pattern_setting;
    nih.current_detector_select_table = oih.current_detector_select_table;
    nih.detector_select_table_id_number = oih.detector_select_table_id_number; 
    nih.image_data_truncation_setting = oih.image_data_truncation_setting;

    /* set the values in the Frame Header associated with the image header */
    nih.frame_header.frame_number = oih.frame_header.frame_number;
    nih.frame_header.l0r_time.days_from_J2000 =
          oih.frame_header.l0r_time.days_from_J2000;
    nih.frame_header.l0r_time.seconds_of_day =
        oih.frame_header.l0r_time.seconds_of_day;
    nih.frame_header.day = oih.frame_header.day;
    nih.frame_header.milliseconds = oih.frame_header.milliseconds;
    nih.frame_header.microseconds = oih.frame_header.microseconds;
    nih.frame_header.blind_data_included_in_frame 
            = oih.frame_header.blind_data_included_in_frame;
    nih.frame_header.time_error = oih.frame_header.time_error;
    nih.frame_header.frame_status = oih.frame_header.frame_status;

    if (ias_l0r_set_oli_image_header(new_l0r_file, &nih) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new frame header");
        return ERROR;
    }

    return SUCCESS;
}

/*****************************************************************************/
int convert_frame_headers
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_OLI_FRAME_HEADER *ofh_array;
    IAS_L0R_OLI_FRAME_HEADER *nfh_array;
    unsigned int frame_header_count;
    int index;

    /* get the count of the frame headers */
    if (old_l0r_get_oli_frame_headers_records_count(old_l0r_file,
        &frame_header_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old frame header count");
        return ERROR;
    }

    if (frame_header_count < 1)
    {
        /* no OLI frame headers to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the frame headers */
    ofh_array = malloc(sizeof(*ofh_array) * frame_header_count);
    nfh_array = malloc(sizeof(*nfh_array) * frame_header_count);
    if (!ofh_array || !nfh_array)
    {
        IAS_LOG_ERROR("Allocating memory for the frame headers");
        free(ofh_array);
        free(nfh_array);
        return ERROR;
    }

    /* read the old frame headers */
    if (old_l0r_get_oli_frame_headers(old_l0r_file, 0, frame_header_count,
            ofh_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old frame headers");
        free(ofh_array);
        free(nfh_array);
        return ERROR;
    }

    /* copy all the frame headers */
    for (index = 0; index < frame_header_count; index++)
    {
        IAS_OLD_L0R_OLI_FRAME_HEADER *ofh = &ofh_array[index];
        IAS_L0R_OLI_FRAME_HEADER *nfh = &nfh_array[index];
        
        memset(nfh, 0, sizeof(*nfh));

        nfh->frame_number = ofh->frame_number;
        nfh->l0r_time.days_from_J2000 = ofh->l0r_time.days_from_J2000;
        nfh->l0r_time.seconds_of_day = ofh->l0r_time.seconds_of_day;
        nfh->day = ofh->day;
        nfh->milliseconds = ofh->milliseconds;
        nfh->microseconds = ofh->microseconds;
        nfh->blind_data_included_in_frame 
                = ofh->blind_data_included_in_frame;
        nfh->time_error = ofh->time_error;
        nfh->frame_status = ofh->frame_status;
        /* fix up the frame status values that are zero */
        if (nfh->frame_status == 0)
            nfh->frame_status =  (IAS_L0R_VERIFIED | IAS_L0R_CRC_STATUS);
    }

    if (ias_l0r_set_oli_frame_headers(new_l0r_file, 0, frame_header_count,
            nfh_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new frame headers");
        free(ofh_array);
        free(nfh_array);
        return ERROR;
    }

    free(ofh_array);
    free(nfh_array);

    return SUCCESS;
}

/*****************************************************************************/
/* routine to detect if the input file is a TIRS file by looking for the SSM
   info */
int is_tirs_file
(
    OLD_L0RIO *old_l0r_file
)
{
    int count;
    int status;

    status = old_l0r_get_ancillary_tirs_ssm_records_count(old_l0r_file, &count);
    if ((status == SUCCESS) && (count > 0))
        return 1;
    else
        return 0;
}

/*****************************************************************************/
int convert_tirs_frame_headers
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_TIRS_FRAME_HEADER *ofh_array;
    IAS_L0R_TIRS_FRAME_HEADER *nfh_array;
    unsigned int frame_header_count;
    int index;

    /* get the count of the frame headers */
    if (old_l0r_get_tirs_frame_headers_records_count(old_l0r_file,
        &frame_header_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old tirs frame header count");
        return ERROR;
    }
    if (frame_header_count < 1)
    {
        /* no TIRS frame headers to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the frame headers */
    ofh_array = malloc(sizeof(*ofh_array) * frame_header_count);
    nfh_array = malloc(sizeof(*nfh_array) * frame_header_count);
    if (!ofh_array || !nfh_array)
    {
        IAS_LOG_ERROR("Allocating memory for the frame headers");
        free(ofh_array);
        free(nfh_array);
        return ERROR;
    }

    /* read the old frame headers */
    if (old_l0r_get_tirs_frame_headers(old_l0r_file, 0, frame_header_count,
            ofh_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old tirs frame headers");
        free(ofh_array);
        free(nfh_array);
        return ERROR;
    }

    /* copy all the frame headers */
    for (index = 0; index < frame_header_count; index++)
    {
        IAS_OLD_L0R_TIRS_FRAME_HEADER *ofh = &ofh_array[index];
        IAS_L0R_TIRS_FRAME_HEADER *nfh = &nfh_array[index];
        
        memset(nfh, 0, sizeof(*nfh));

        nfh->l0r_time.days_from_J2000 = ofh->l0r_time.days_from_J2000;
        nfh->l0r_time.seconds_of_day = ofh->l0r_time.seconds_of_day;
        nfh->day = ofh->day;
        nfh->milliseconds = ofh->milliseconds;
        nfh->microseconds = ofh->microseconds;
        nfh->frame_number = ofh->frame_number;
        nfh->sync_byte = ofh->sync_byte;
        nfh->data_set_type = ofh->data_set_type;
        nfh->integration_duration = ofh->integration_duration;

        /* ROIC Crc status flags were separated and renamed for
           epoch 4 */
        nfh->roic_crc_status_blind = ofh->roic_crc_status_blind;
        nfh->roic_crc_status_10_8 = ofh->roic_crc_status_10_8;
        nfh->roic_crc_status_12 = ofh->roic_crc_status_12;
        nfh->frame_status = ofh->frame_status;
        /* fix up the frame status values that are zero */
        if (nfh->frame_status == 0)
            nfh->frame_status =  (IAS_L0R_VERIFIED | IAS_L0R_CRC_STATUS);

        nfh->total_frames_requested = ofh->total_frames_requested;

        /* Copy the other parts of the frame header as whole structures.
         * If the structures change in the future this must be UPDATED */
        memcpy(&(nfh->row_offset), &(ofh->row_offset), sizeof(nfh->row_offset));
        memcpy(&(nfh->d_header), &(ofh->d_header), sizeof(nfh->d_header));
        memcpy(&(nfh->fpe_words), &(ofh->fpe_words), sizeof(nfh->fpe_words));
    }

    if (ias_l0r_set_tirs_frame_headers(new_l0r_file, 0, frame_header_count,
            nfh_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new TIRS frame headers");
        free(ofh_array);
        free(nfh_array);
        return ERROR;
    }

    free(ofh_array);
    free(nfh_array);

    return SUCCESS;
}

/*****************************************************************************/

#define COPY_L0R_TIME(old, new) \
    (new).l0r_time.days_from_J2000 = (old).l0r_time.days_from_J2000; \
    (new).l0r_time.seconds_of_day = (old).l0r_time.seconds_of_day; \
    (new).days_orig = (old).days_orig; \
    (new).milliseconds_orig = (old).milliseconds_orig; \
    (new).microseconds_orig = (old).microseconds_orig

/*****************************************************************************/
int convert_oli_telemetry
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_OLI_TELEMETRY *ot_array;
    IAS_L0R_OLI_TELEMETRY *nt_array;
    unsigned int record_count;
    int index;

    /* get the count of the old oli telemetery records */
    if (old_l0r_get_ancillary_oli_telemetry_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old oli telemetry record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no OLI telemetry to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the oli telemetry ancillary records */
    ot_array = malloc(sizeof(*ot_array) * record_count);
    nt_array = malloc(sizeof(*nt_array) * record_count);
    if (!ot_array || !nt_array)
    {
        IAS_LOG_ERROR("Allocating memory for the oli telemetry records");
        free(ot_array);
        free(nt_array);
        return ERROR;
    }

    /* read the old oli telemetry */
    if (old_l0r_get_ancillary_oli_telemetry(old_l0r_file, 0, record_count,
            ot_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old oli telemetry records");
        free(ot_array);
        free(nt_array);
        return ERROR;
    }

#define COPY_BLOCK(num,name) \
    nt->oli_telemetry_header_##num.name = ot->oli_telemetry_header_##num.name

    /* copy all the oli telemetry ancillary */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_OLI_TELEMETRY *ot = &ot_array[index];
        IAS_L0R_OLI_TELEMETRY *nt = &nt_array[index];
        int i;
        
        memset(nt, 0, sizeof(*nt));

        /* copy the times in each block */
        COPY_L0R_TIME(ot->oli_telemetry_header_3, nt->oli_telemetry_header_3);
        COPY_L0R_TIME(ot->oli_telemetry_header_4, nt->oli_telemetry_header_4);
        COPY_L0R_TIME(ot->oli_telemetry_header_5, nt->oli_telemetry_header_5);

        /* copy block 3 */
        COPY_BLOCK(3,sync_word);
        COPY_BLOCK(3,id);
        COPY_BLOCK(3,stim_lamp_output_current_amps);
        COPY_BLOCK(3,stim_lamp_bulb_a_volts);
        COPY_BLOCK(3,stim_lamp_bulb_b_volts);

        /* Name changes for epoch 4, adding celsius to thermistors */
        nt->oli_telemetry_header_3.stim_lamp_thermistor1_celsius = 
            ot->oli_telemetry_header_3.stim_lamp_thermistor1_celsius;
        nt->oli_telemetry_header_3.stim_lamp_thermistor2_celsius = 
            ot->oli_telemetry_header_3.stim_lamp_thermistor2_celsius;
        /* Name changes for epoch 4, adding micro amps to photodiodes */
        nt->oli_telemetry_header_3.stim_lamp_photodiode1_micro_amps = 
            ot->oli_telemetry_header_3.stim_lamp_photodiode1_micro_amps;
        nt->oli_telemetry_header_3.stim_lamp_photodiode2_micro_amps = 
            ot->oli_telemetry_header_3.stim_lamp_photodiode2_micro_amps;

        for (i = 0; i < IAS_L0R_OLI_TELEMETRY_FOCUS_MOTORS; i++)
        {
            COPY_BLOCK(3,focus_motor_lvdt[i]);
        }
        COPY_BLOCK(3,pos_z_minus_y_temp_celsius);
        for (i = 0; i < IAS_L0R_OLI_TELEMETRY_BENCH_TEMPS; i++)
        {
            COPY_BLOCK(3,bench_temps_celsius[i]);
        }
        COPY_BLOCK(3,fpm_7_temp_celsius);
        COPY_BLOCK(3,calibration_assembly_a_temp_celsius);
        COPY_BLOCK(3,pos_z_pos_y_temp_celsius);
        COPY_BLOCK(3,tertiary_mirror_temp_celsius);
        COPY_BLOCK(3,fp_chassis_temp_celsius);
        COPY_BLOCK(3,pos_y_temp_celsius);
        COPY_BLOCK(3,fp_evap_temp_celsius);
        COPY_BLOCK(3,fp_window_temp_celsius);
        COPY_BLOCK(3,minus_z_pos_y_temp_celsius);
        COPY_BLOCK(3,minus_z_minus_y_temp_celsius);
        COPY_BLOCK(3,minus_y_temp_celsius);
        COPY_BLOCK(3,fpm_14_temp_celsius);
        COPY_BLOCK(3,lvps_temp_celsius);
        COPY_BLOCK(3,warning_flag);

        /* copy block 4 */
        COPY_BLOCK(4,sync_word);
        COPY_BLOCK(4,id);
        COPY_BLOCK(4,mech_command_reject_count);
        COPY_BLOCK(4,mech_command_accept_count);
        COPY_BLOCK(4,shutter_active);
        COPY_BLOCK(4,last_command_opcode);
        COPY_BLOCK(4,diffuser_active);
        COPY_BLOCK(4,shutter_commanded_moves);
        COPY_BLOCK(4,focus_motor_flags);
        COPY_BLOCK(4,diffuser_commanded_moves);
        COPY_BLOCK(4,focus_motor_pulse_time_step_sec);
        COPY_BLOCK(4,focus_motor_pulse_length_sec);
        COPY_BLOCK(4,focus_motor_pulses);
        COPY_BLOCK(4,focus_mechanism_lvdt_relay_status);
        COPY_BLOCK(4,focus_mechanism_motor_relay_status);
        COPY_BLOCK(4,shutter_motor_pulse_length_sec);
        COPY_BLOCK(4,shutter_status_flags);
        COPY_BLOCK(4,diffuser_status_flags);
        COPY_BLOCK(4,shutter_motor_pulse_time_sec);
        COPY_BLOCK(4,diffuser_motor_pulse_time_sec);
        COPY_BLOCK(4,diffuser_motor_pulse_length_sec);
        COPY_BLOCK(4,shutter_move_count);
        COPY_BLOCK(4,shutter_resolver_position);
        COPY_BLOCK(4,diffuser_move_count);
        COPY_BLOCK(4,diffuser_resolver_position);
        COPY_BLOCK(4,diffuser_flags);
        COPY_BLOCK(4,stl_command_rejected_count);
        COPY_BLOCK(4,stl_command_accepted_count);
        COPY_BLOCK(4,stl_power_flags);
        COPY_BLOCK(4,stl_last_accepted_command);
        COPY_BLOCK(4,stl_flags);
        COPY_BLOCK(4,warning_flag);

        /* copy block 5 */
        COPY_BLOCK(5,sync_word);
        COPY_BLOCK(5,id);
        COPY_BLOCK(5,fpe_command_reject_count);
        COPY_BLOCK(5,fpe_command_accept_count);
        COPY_BLOCK(5,safe_mode_consecutive_requests);
        COPY_BLOCK(5,last_command_opcode);
        COPY_BLOCK(5,single_bit_edac_errors_detected);
        COPY_BLOCK(5,consecutive_unacknowledged_requests);
        COPY_BLOCK(5,fpe_message_errors_detected);
        COPY_BLOCK(5,multi_bit_edac_errors_detected);
        COPY_BLOCK(5,messages_forwarded_to_fpe);
        COPY_BLOCK(5,command_sequence_count);
        COPY_BLOCK(5,messages_reject_invalid_mode);
        COPY_BLOCK(5,fpe_telemetry_valid);
        COPY_BLOCK(5,dlvps_relay_pos_28vdc_voltage);
        COPY_BLOCK(5,dlvps_pos_5v_voltage);
        COPY_BLOCK(5,dlvps_pos_15v_voltage);
        COPY_BLOCK(5,dlvps_neg_15v_voltage);
        COPY_BLOCK(5,dlvps_pos_3_3v_voltage);
        COPY_BLOCK(5,alvps_hv_bias_pos_85v_voltage);
        COPY_BLOCK(5,alvps_pos_12v_voltage);
        COPY_BLOCK(5,alvps_pos_7_5v_voltage);
        COPY_BLOCK(5,alvps_neg_2_5v_voltage);
        COPY_BLOCK(5,alvps_pos_12v_current_amps);
        COPY_BLOCK(5,alvps_pos_7_5v_current_amps);
        COPY_BLOCK(5,alvps_pos_2_5v_current_amps);
        COPY_BLOCK(5,lvps_temperature_sensor_celsius);
        COPY_BLOCK(5,ctlr_temperature_sensor_celsius);
        COPY_BLOCK(5,ana_0_temperature_sensor_celsius);
        COPY_BLOCK(5,ana_1_temperature_sensor_celsius);
        COPY_BLOCK(5,ana_0_ch_0_vpa_bias_voltage);
        COPY_BLOCK(5,ana_0_ch_1_vpa_bias_voltage);
        COPY_BLOCK(5,ana_0_ch_2_vpa_bias_voltage);
        COPY_BLOCK(5,ana_0_ch_3_vpa_bias_voltage);
        COPY_BLOCK(5,ana_0_ch_4_vpa_bias_voltage);
        COPY_BLOCK(5,ana_0_ch_5_vpa_bias_voltage);
        COPY_BLOCK(5,ana_0_ch_6_vpa_bias_voltage);
        COPY_BLOCK(5,ana_0_ch_7_vpa_bias_voltage);
        COPY_BLOCK(5,warning_flag);
    }

#undef COPY_BLOCK

    if (ias_l0r_set_ancillary_oli_telemetry(new_l0r_file, 0, record_count,
            nt_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing OLI Telemetry");
        free(ot_array);
        free(nt_array);
        return ERROR;
    }

    free(ot_array);
    free(nt_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_tirs_telemetry
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_TIRS_TELEMETRY *ot_array;
    IAS_L0R_TIRS_TELEMETRY *nt_array;
    unsigned int record_count;
    int index;

    /* get the count of the tirs telemetry records */
    if (old_l0r_get_ancillary_tirs_telemetry_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old tirs telemetry record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no TIRS telemetry to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the tirs telemetry */
    ot_array = malloc(sizeof(*ot_array) * record_count);
    nt_array = malloc(sizeof(*nt_array) * record_count);
    if (!ot_array || !nt_array)
    {
        IAS_LOG_ERROR("Allocating memory for the tirs telemetry records");
        free(ot_array);
        free(nt_array);
        return ERROR;
    }

    /* read the old tirs telemetry */
    if (old_l0r_get_ancillary_tirs_telemetry(old_l0r_file, 0, record_count,
            ot_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old tirs telemetry records");
        free(ot_array);
        free(nt_array);
        return ERROR;
    }

    /* copy all the tirs telemetry records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_TIRS_TELEMETRY *ot = &ot_array[index];
        IAS_L0R_TIRS_TELEMETRY *nt = &nt_array[index];
        int i;
        int j;
        
        memset(nt, 0, sizeof(*nt));

        /* Before very few of the tirs telemetry parameters were copied
           and the rest were left as 0. This is changed to copy 
           everything in epoch 4. */
        nt->l0r_time.days_from_J2000 = ot->l0r_time.days_from_J2000;
        nt->l0r_time.seconds_of_day = ot->l0r_time.seconds_of_day;
        nt->warning_flag = ot->warning_flag;

        /* TIRS Telemetry Command parameters */
        nt->command.unaccepted_command_count =
            ot->command.unaccepted_command_count;
        nt->command.accepted_command_count =
            ot->command.accepted_command_count;
        nt->command.pulse_per_second_count = 
            ot->command.pulse_per_second_count;
        nt->command.tod_command_counter =
            ot->command.tod_command_counter;
        nt->command.day = ot->command.day;
        nt->command.millisecond = ot->command.millisecond;
        nt->command.mc_encoder_flags = ot->command.mc_encoder_flags;

        nt->command.science_data_frame_capture_count = 
            ot->command.science_data_frame_capture_count;
        nt->command.science_acquisition_frame_rate = 
            ot->command.science_acquisition_frame_rate;
        nt->command.active_timing_table_pattern =
            ot->command.active_timing_table_pattern;
        nt->command.mode_register = ot->command.mode_register;

        for (i = 0; i < 
            IAS_OLD_L0R_TIRS_TELEMETRY_NUM_TIMING_TABLES;
            i++)
        {
            nt->command.timing_table_pattern_id[i] = 
                ot->command.timing_table_pattern_id[i];
        }

        nt->command.ssm_position_sel = ot->command.ssm_position_sel;
        nt->command.ssm_mech_mode =  ot->command.ssm_mech_mode;

        for (i = 0; i < 
            IAS_OLD_L0R_TIRS_TELEMETRY_SSM_ENCODER_POSITION_SAMPLE_COUNT;
            i++)
        {
            nt->command.ssm_encoder_position_sample[i] = 
                ot->command.ssm_encoder_position_sample[i];
        }

        /* TIRS Temperature Telemetry parameters */
        nt->temperature.bbcal_op7_a_celsius =  
            ot->temperature.bbcal_op7_a_celsius;

        nt->temperature.bbcal_op7_b_celsius =
            ot->temperature.bbcal_op7_b_celsius;

        nt->temperature.bbcal_supp_1_celsius =
            ot->temperature.bbcal_supp_1_celsius;

        for (i = 0; i < 
            IAS_OLD_L0R_TIRS_TELEMETRY_NUM_BLACK_BODY_TEMPS;
            i++)
        {
            nt->temperature.blackbody_calibrator_celsius[i] =
                ot->temperature.blackbody_calibrator_celsius[i];
        }

        nt->temperature.cold_stage_heat_strap_cf_if_celsius =
            ot->temperature.cold_stage_heat_strap_cf_if_celsius;

        nt->temperature.cryo_diode_t3_measured_celsius =
            ot->temperature.cryo_diode_t3_measured_celsius;

        nt->temperature.cryo_diode_t4_measured_celsius =
            ot->temperature.cryo_diode_t4_measured_celsius;

        nt->temperature.cryo_shroud_outer_at_tunnel_celsius =
            ot->temperature.cryo_shroud_outer_at_tunnel_celsius;

        nt->temperature.cryo_shroud_outer_flange_celsius =
            ot->temperature.cryo_shroud_outer_flange_celsius;

        nt->temperature.fixed_baff_nadir_aft_hot_corner_celsius =
            ot->temperature.fixed_baff_nadir_aft_hot_corner_celsius;

        nt->temperature.fixed_baff_nadir_aft_space_corner_celsius =
            ot->temperature.fixed_baff_nadir_aft_space_corner_celsius;

        nt->temperature.fixed_baff_nadir_fwd_hot_corner_celsius =
            ot->temperature.fixed_baff_nadir_fwd_hot_corner_celsius;

        nt->temperature.fixed_baff_nadir_fwd_space_corner_celsius =
            ot->temperature.fixed_baff_nadir_fwd_space_corner_celsius;

        nt->temperature.fp_a_asic_celsius =
            ot->temperature.fp_a_asic_celsius;

        nt->temperature.fp_b_asic_celsius =
            ot->temperature.fp_b_asic_celsius;
        
        nt->temperature.fpe1_fpe_a_asic_celsius =
            ot->temperature.fpe1_fpe_a_asic_celsius;

        nt->temperature.fpe2_fpe_b_asic_celsius =
            ot->temperature.fpe2_fpe_b_asic_celsius;

        nt->temperature.fp_f2_fine_sensor_1_celsius =
            ot->temperature.fp_f2_fine_sensor_1_celsius;

        nt->temperature.fp_f4_fine_sensor_3_celsius =
            ot->temperature.fp_f4_fine_sensor_3_celsius;

        nt->temperature.fp_f6_fine_sensor_1_celsius =
            ot->temperature.fp_f6_fine_sensor_1_celsius;

        nt->temperature.fp_f7_fine_sensor_2_celsius =
            ot->temperature.fp_f7_fine_sensor_2_celsius;

        nt->temperature.fp_op6_a_celsius =
            ot->temperature.fp_op6_a_celsius;

        nt->temperature.fp_op6_b_celsius =
            ot->temperature.fp_op6_b_celsius;

        nt->temperature.optical_deck_celsius =
            ot->temperature.optical_deck_celsius;

        nt->temperature.spare_4_thermistor_celsius =
            ot->temperature.spare_4_thermistor_celsius;

        nt->temperature.spare_5_thermistor_celsius =
            ot->temperature.spare_5_thermistor_celsius;

        nt->temperature.ssm_bearing_aft_celsius =
            ot->temperature.ssm_bearing_aft_celsius;

        nt->temperature.ssm_bearing_fwd_celsius =
            ot->temperature.ssm_bearing_fwd_celsius;

        nt->temperature.ssm_bearing_housing_d4_aft_hot_side_celsius =
            ot->temperature.ssm_bearing_housing_d4_aft_hot_side_celsius;

        nt->temperature.ssm_bearing_housing_d5_fwd_hot_side_celsius =
            ot->temperature.ssm_bearing_housing_d5_fwd_hot_side_celsius;

        nt->temperature.ssm_bearing_housing_d6_aft_space_side_celsius =
            ot->temperature.ssm_bearing_housing_d6_aft_space_side_celsius;

        nt->temperature.ssm_bearing_housing_d7_fwd_space_side_celsius =
            ot->temperature.ssm_bearing_housing_d7_fwd_space_side_celsius;

        nt->temperature.ssm_bh_op5_a_celsius =
            ot->temperature.ssm_bh_op5_a_celsius;

        nt->temperature.ssm_bh_op5_b_celsius =
            ot->temperature.ssm_bh_op5_b_celsius;

        nt->temperature.ssm_encoder_remote_elec_celsius =
            ot->temperature.ssm_encoder_remote_elec_celsius;

        nt->temperature.ssm_enc_read_head_sensor_1_celsius =
            ot->temperature.ssm_enc_read_head_sensor_1_celsius;

        nt->temperature.ssm_motor_housing_celsius =
            ot->temperature.ssm_motor_housing_celsius;

        nt->temperature.structure_foot_a_neg_z_celsius =
            ot->temperature.structure_foot_a_neg_z_celsius;

        nt->temperature.structure_foot_c_pos_z_celsius =
            ot->temperature.structure_foot_c_pos_z_celsius;

        nt->temperature.structure_nadir_aperture_celsius =
            ot->temperature.structure_nadir_aperture_celsius;

        nt->temperature.tcb_board_celsius =
            ot->temperature.tcb_board_celsius;

        nt->temperature.telescope_aft_barrel_neg_z_celsius =
            ot->temperature.telescope_aft_barrel_neg_z_celsius;

        nt->temperature.telescope_aft_barrel_pos_z_celsius =
            ot->temperature.telescope_aft_barrel_pos_z_celsius;

        nt->temperature.telescope_aft_op3_a_celsius =
            ot->temperature.telescope_aft_op3_a_celsius;

        nt->temperature.telescope_aft_op3_b_celsius =
            ot->temperature.telescope_aft_op3_b_celsius;

        nt->temperature.telescope_fwd_barrel_neg_z_celsius =
            ot->temperature.telescope_fwd_barrel_neg_z_celsius;

        nt->temperature.telescope_fwd_barrel_pos_z_celsius =
            ot->temperature.telescope_fwd_barrel_pos_z_celsius;

        nt->temperature.telescope_fwd_op4_a_celsius =
            ot->temperature.telescope_fwd_op4_a_celsius;

        nt->temperature.telescope_fwd_op4_b_celsius =
            ot->temperature.telescope_fwd_op4_b_celsius;

        nt->temperature.telescope_stage_op2_a_celsius =
            ot->temperature.telescope_stage_op2_a_celsius;

        nt->temperature.telescope_stage_op2_b_celsius =
            ot->temperature.telescope_stage_op2_b_celsius;

        /* TIRS Circuit Telemetry parameters */
        for (i = 0; i < 
            IAS_L0R_TIRS_TELEMETRY_NUM_CIRCUIT_BOARDS;
            i++)
        {
            nt->circuit.focal_plane_boards[i].mon_pos_12v_volts =
                ot->circuit.focal_plane_boards[i].mon_pos_12v_volts;

            for (j = 0; j < IAS_L0R_TIRS_TELEMETRY_NUM_VPD_CURRENTS;
                j++)
            {
                nt->circuit.focal_plane_boards[i].a_vpd_current_1_amps[j] =
                    ot->circuit.focal_plane_boards[i].a_vpd_current_1_amps[j];
            }

            nt->circuit.focal_plane_boards[i].
                detector_substrate_conn_for_sca_a_roic_volts = 
            ot->circuit.focal_plane_boards[i].
                detector_substrate_conn_for_sca_a_roic_volts;

            nt->circuit.focal_plane_boards[i].
                detector_substrate_conn_for_sca_b_roic_volts =
            ot->circuit.focal_plane_boards[i].
                detector_substrate_conn_for_sca_b_roic_volts;

            nt->circuit.focal_plane_boards[i].
                detector_substrate_conn_for_sca_c_roic_volts =
            ot->circuit.focal_plane_boards[i].
                detector_substrate_conn_for_sca_c_roic_volts;

            nt->circuit.focal_plane_boards[i].
                digi_supply_mon_pos_5_5_for_sca_c_roic_volts =
            ot->circuit.focal_plane_boards[i].
                digi_supply_mon_pos_5_5_for_sca_c_roic_volts;

            nt->circuit.focal_plane_boards[i].
                supply_mon_pos_5_5_for_sca_a_roic_volts =
            ot->circuit.focal_plane_boards[i].
                supply_mon_pos_5_5_for_sca_a_roic_volts;

            nt->circuit.focal_plane_boards[i].
                supply_mon_pos_5_5_for_sca_b_roic_volts =
            ot->circuit.focal_plane_boards[i].
                supply_mon_pos_5_5_for_sca_b_roic_volts;

            nt->circuit.focal_plane_boards[i].
                supply_mon_pos_5_5_for_sca_c_roic_volts =
            ot->circuit.focal_plane_boards[i].
                supply_mon_pos_5_5_for_sca_c_roic_volts;

            nt->circuit.focal_plane_boards[i].
                output_ref_level_mon_5_5_for_sca_c_roic_volts =
            ot->circuit.focal_plane_boards[i].
                output_ref_level_mon_5_5_for_sca_c_roic_volts;

            nt->circuit.focal_plane_boards[i].
                supply_10v_for_sca_a_current_mon_amps =
            ot->circuit.focal_plane_boards[i].
                supply_10v_for_sca_a_current_mon_amps; 

            nt->circuit.focal_plane_boards[i].
                supply_10v_for_sca_b_current_mon_amps =
            ot->circuit.focal_plane_boards[i].
                supply_10v_for_sca_b_current_mon_amps;

            nt->circuit.focal_plane_boards[i].
                supply_10v_for_sca_c_current_mon_amps =
            ot->circuit.focal_plane_boards[i].
                supply_10v_for_sca_c_current_mon_amps; 

            nt->circuit.focal_plane_boards[i].
                output_driver_pos_5_5_for_sca_c_roic_volts =
            ot->circuit.focal_plane_boards[i].
                output_driver_pos_5_5_for_sca_c_roic_volts;

            nt->circuit.focal_plane_boards[i].
                output_ref_level_1_6_for_sca_c_roic_volts =
            ot->circuit.focal_plane_boards[i].
                output_ref_level_1_6_for_sca_c_roic_volts;

            nt->circuit.focal_plane_boards[i].
                channel_ref_suppy_1_6_for_sca_c_roic_volts =
            ot->circuit.focal_plane_boards[i].
                channel_ref_suppy_1_6_for_sca_c_roic_volts;

            nt->circuit.focal_plane_boards[i].vpe_sca_a_video_ref =
            ot->circuit.focal_plane_boards[i].vpe_sca_a_video_ref;

            nt->circuit.focal_plane_boards[i].vpe_sca_b_video_ref =
            ot->circuit.focal_plane_boards[i].vpe_sca_b_video_ref;

            nt->circuit.focal_plane_boards[i].vpe_sca_c_video_ref =
            ot->circuit.focal_plane_boards[i].vpe_sca_c_video_ref;
        }
        nt->circuit.cosine_motor_drive_for_mce_current_amps =
            ot->circuit.cosine_motor_drive_for_mce_current_amps;

        nt->circuit.sine_motor_drive_for_mce_current_amps =
            ot->circuit.sine_motor_drive_for_mce_current_amps;

        nt->circuit.hsib_3_3_current_mon_amps =
            ot->circuit.hsib_3_3_current_mon_amps;

        nt->circuit.cosine_dac_telemetry_for_mce_volts =
            ot->circuit.cosine_dac_telemetry_for_mce_volts;

        nt->circuit.sine_dac_telemetry_for_mce_volts =
            ot->circuit.sine_dac_telemetry_for_mce_volts;

        nt->circuit.elec_enabled_flags =
            ot->circuit.elec_enabled_flags;
    }

    
    if (ias_l0r_set_ancillary_tirs_telemetry(new_l0r_file, 0, record_count,
            nt_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new TIRS telemetry records");
        free(ot_array);
        free(nt_array);
        return ERROR;
    }

    free(ot_array);
    free(nt_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_attitude
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_ATTITUDE *old_array;
    IAS_L0R_ATTITUDE *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_attitude_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old attitude record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the attitude records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_attitude(old_l0r_file, 0, record_count,
            old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old attitude records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_ATTITUDE *old = &old_array[index];
        IAS_L0R_ATTITUDE *new = &new_array[index];
        
        memset(new, 0, sizeof(*new));

        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->time_tag_sec_orig = old->time_tag_sec_orig;
        new->inertial_to_body = old->inertial_to_body;
        new->warning_flag = old->warning_flag;
    }

    if (ias_l0r_set_ancillary_attitude(new_l0r_file, 0, record_count, new_array)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new attitude records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_attitude_filter_states
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_ATTITUDE_FILTER_STATES *old_array;
    IAS_L0R_ATTITUDE_FILTER_STATES *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_attitude_filter_states_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old attitude filter states record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the attitude filter states "
            "records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_attitude_filter_states(old_l0r_file, 0,
            record_count, old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old attitude filter states records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_ATTITUDE_FILTER_STATES *old = &old_array[index];
        IAS_L0R_ATTITUDE_FILTER_STATES *new = &new_array[index];
        
        memset(new, 0, sizeof(*new));


        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->time_tag_sec_orig = old->time_tag_sec_orig;
        /* Name change in epoch 4 */
        new->time_tag_subseconds_orig = old->time_tag_subseconds_orig;
        new->gyro_combined_bias_rad_sec = old->gyro_combined_bias_rad_sec;
        new->gyro_scale_factor = old->gyro_scale_factor;
        new->gyro_x_misalignment_along_y_rad =
            old->gyro_x_misalignment_along_y_rad;
        new->gyro_x_misalignment_along_z_rad =
            old->gyro_x_misalignment_along_z_rad;
        new->gyro_y_misalignment_along_x_rad =
            old->gyro_y_misalignment_along_x_rad;
        new->gyro_y_misalignment_along_z_rad =
            old->gyro_y_misalignment_along_z_rad;
        new->gyro_z_misalignment_along_x_rad =
            old->gyro_z_misalignment_along_x_rad;
        new->gyro_z_misalignment_along_y_rad =
            old->gyro_z_misalignment_along_y_rad;
        new->kalman_filter_error_rad = old->kalman_filter_error_rad;
        new->covariance_diagonal = old->covariance_diagonal;
        new->warning_flag = old->warning_flag;
    }

    if (ias_l0r_set_ancillary_attitude_filter_states(new_l0r_file, 0,
        record_count, new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new attitude filter states records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_ephemeris
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_EPHEMERIS *old_array;
    IAS_L0R_EPHEMERIS *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_ephemeris_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old ephemeris record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the ephemeris records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_ephemeris(old_l0r_file, 0, record_count,
            old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old ephemeris records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_EPHEMERIS *old = &old_array[index];
        IAS_L0R_EPHEMERIS *new = &new_array[index];
        
        memset(new, 0, sizeof(*new));

        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->time_tag_sec_orig = old->time_tag_sec_orig;

        new->ecef_position_meters = old->ecef_position_meters;
        new->ecef_velocity_meters_per_sec = old->ecef_velocity_meters_per_sec;
        new->orbit_determination_position_error_meters
            = old->orbit_determination_position_error_meters;
        new->orbit_determination_velocity_error_meters_per_sec
            = old->orbit_determination_velocity_error_meters_per_sec;

        new->warning_flag = old->warning_flag;
    }

    if (ias_l0r_set_ancillary_ephemeris(new_l0r_file, 0, record_count,
        new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new ephemeris records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_gps_position
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_GPS_POSITION *old_array;
    IAS_L0R_GPS_POSITION *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_gps_position_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old gps position record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the gps position records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_gps_position(old_l0r_file, 0, record_count,
            old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old gps position records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_GPS_POSITION *old = &old_array[index];
        IAS_L0R_GPS_POSITION *new = &new_array[index];
        int i;
        
        memset(new, 0, sizeof(*new));

        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->month = old->month;
        new->day = old->day;
        new->year = old->year;
        new->hours = old->hours;
        new->minutes = old->minutes;
        new->seconds = old->seconds;
        new->nanoseconds = old->nanoseconds;
        new->point_arc_secs = old->point_arc_secs;
        new->height_uncorrected_meters = old->height_uncorrected_meters;
        new->height_corrected_meters = old->height_corrected_meters;
        new->velocity_meters_per_sec = old->velocity_meters_per_sec;
        new->heading_degrees = old->heading_degrees;
        new->current_dop = old->current_dop;
        new->dop_type = old->dop_type;
        new->num_visible_satellites = old->num_visible_satellites;
        new->num_satellites_tracked = old->num_satellites_tracked;
        new->receiver_status_flags = old->receiver_status_flags;
        new->ecef_position_meters = old->ecef_position_meters;
        new->ecef_velocity_meters_per_sec = old->ecef_velocity_meters_per_sec;
        new->function = old->function;
        new->sub_function = old->sub_function;
        for (i = 0; i < IAS_GPS_NUM_SATELLITES; i++)
        {
            new->tracked_satellites[i].id = old->tracked_satellites[i].id;
            new->tracked_satellites[i].track_mode
                = old->tracked_satellites[i].track_mode;
            new->tracked_satellites[i].signal_strength
                = old->tracked_satellites[i].signal_strength;
            new->tracked_satellites[i].channel_status_flags
                = old->tracked_satellites[i].channel_status_flags;
        }
        new->warning_flag = old->warning_flag;
    }

    if (ias_l0r_set_ancillary_gps_position(new_l0r_file, 0, record_count,
        new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new gps position records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_gps_range
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_GPS_RANGE *old_array;
    IAS_L0R_GPS_RANGE *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_gps_range_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old gps range record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the gps range records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_gps_range(old_l0r_file, 0, record_count,
            old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old gps range records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_GPS_RANGE *old = &old_array[index];
        IAS_L0R_GPS_RANGE *new = &new_array[index];
        int i;
        
        memset(new, 0, sizeof(*new));

        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->seconds = old->seconds;
        new->nanoseconds = old->nanoseconds;
        new->function = old->function;
        new->sub_function = old->sub_function;
        for (i = 0; i < IAS_GPS_NUM_SATELLITES; i++)
        {
            new->tracked_satellites[i].id = old->tracked_satellites[i].id;
            new->tracked_satellites[i].tracking_mode
                = old->tracked_satellites[i].tracking_mode;
            new->tracked_satellites[i].gps_time_seconds
                = old->tracked_satellites[i].gps_time_seconds;
            new->tracked_satellites[i].gps_time_nanoseconds
                = old->tracked_satellites[i].gps_time_nanoseconds;
            new->tracked_satellites[i].raw_code_phase
                = old->tracked_satellites[i].raw_code_phase;
            new->tracked_satellites[i].integrated_carrier_phase_deg
                = old->tracked_satellites[i].integrated_carrier_phase_deg;
            new->tracked_satellites[i].code_discriminator_output
                = old->tracked_satellites[i].code_discriminator_output;
        }
        new->warning_flag = old->warning_flag;
    }

    if (ias_l0r_set_ancillary_gps_range(new_l0r_file, 0, record_count,
        new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new gps range records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_imu
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_IMU *old_array;
    IAS_L0R_IMU *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_imu_records_count(old_l0r_file, &record_count)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old IMU record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the IMU records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_imu(old_l0r_file, 0, record_count,
            old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old IMU records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_IMU *old = &old_array[index];
        IAS_L0R_IMU *new = &new_array[index];
        memset(new, 0, sizeof(*new));

        int gyro_index;

        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->time_tag_sec_orig = old->time_tag_sec_orig;
        /* Name change in epoch 4 */
        new->time_tag_subseconds_orig = old->time_tag_subseconds_orig;
        new->warning_flag = old->warning_flag;

        for (gyro_index = 0; gyro_index < IAS_L0R_NUM_SAMPLES_PER_IMU_RECORD;
            gyro_index++)
        {
            int angle_index;
            IAS_L0R_IMU_SAMPLE *new_samp
                = &new->gyro_samples[gyro_index];

            new_samp->sync_event_time_tag
                = old->gyro_samples[gyro_index].sync_event_time_tag;
            new_samp->time_tag
                = old->gyro_samples[gyro_index].time_tag;

            new_samp->saturation_and_scaling
                = old->gyro_samples[gyro_index].saturation_and_scaling;
            new_samp->angular_rate_valid
                = old->gyro_samples[gyro_index].angular_rate_valid;

            for (angle_index = 0; angle_index < IAS_L0R_NUM_GYROS;
                 angle_index++)
            {
                new_samp->integrated_angle_count[angle_index]
                    = old->gyro_samples[gyro_index]
                        .integrated_angle_count[angle_index];
            }
        }
    }

    if (ias_l0r_set_ancillary_imu(new_l0r_file, 0, record_count, new_array)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new IMU records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_star_tracker_centroid
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_STAR_TRACKER_CENTROID *old_array;
    IAS_L0R_STAR_TRACKER_CENTROID *new_array;
    unsigned int record_count;
    int index;
    int i;

    /* get the count of the records */
    if (old_l0r_get_ancillary_star_tracker_centroid_records_count(old_l0r_file,
        &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old star tracker centroid record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the star tracker centroid "
                "records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_star_tracker_centroid(old_l0r_file, 0,
            record_count, old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old star tracker centroid records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_STAR_TRACKER_CENTROID *old = &old_array[index];
        IAS_L0R_STAR_TRACKER_CENTROID *new = &new_array[index];
        
        memset(new, 0, sizeof(*new));

        new->quaternion_index = old->quaternion_index;

        for (i = 0 ; i < IAS_STAR_TRACKER_NUM_STARS; i++)
        {
            new->stars[i].valid =  old->stars[i].valid;
            new->stars[i].id =  old->stars[i].id;
            new->stars[i].background_bias =  old->stars[i].background_bias;
            new->stars[i].intensity_mi =  old->stars[i].intensity_mi;
            new->stars[i].position_arcsec.x =  old->stars[i].position_arcsec.x;
            new->stars[i].position_arcsec.y =  old->stars[i].position_arcsec.y;
        }
        new->effective_focal_length =  old->effective_focal_length;
        new->warning_flag =  old->warning_flag;
    }

    if (ias_l0r_set_ancillary_star_tracker_centroid(new_l0r_file, 0,
        record_count, new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new star tracker centroid records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_star_tracker_quaternion
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_STAR_TRACKER_QUATERNION *old_array;
    IAS_L0R_STAR_TRACKER_QUATERNION *new_array;
    unsigned int record_count;
    int index;
    int i;

    /* get the count of the records */
    if (old_l0r_get_ancillary_star_tracker_quaternion_records_count(
        old_l0r_file, &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old star tracker quaternion record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the star tracker quaternion "
                "records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_star_tracker_quaternion(old_l0r_file, 0,
            record_count, old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old star tracker quaternion records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_STAR_TRACKER_QUATERNION *old = &old_array[index];
        IAS_L0R_STAR_TRACKER_QUATERNION *new = &new_array[index];
        
        memset(new, 0, sizeof(*new));

        new->quaternion_index = old->quaternion_index;
        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->udl_time_sec_orig = old->udl_time_sec_orig;
        new->udl_time_subsec_orig = old->udl_time_subsec_orig;
        new->sta_time_tag = old->sta_time_tag;
        new->status_flags_1 = old->status_flags_1;
        new->status_flags_2 = old->status_flags_2;
        new->last_processed_command = old->last_processed_command;
        for(i=0; i < IAS_L0R_STAR_TRACKER_NUM_VIRTUAL_STATES; i++)
        {
            new->virtual_tracker_states[i] = old->virtual_tracker_states[i];
        }
        new->command_flags = old->command_flags;
        new->time_message_value = old->time_message_value;
        new->camera_id = old->camera_id;
        new->sw_version = old->sw_version;
        new->quaternion_seconds = old->quaternion_seconds;
        new->quaternion_element_1 = old->quaternion_element_1;
        new->quaternion_element_2 = old->quaternion_element_2;
        new->quaternion_element_3 = old->quaternion_element_3;
        new->quaternion_element_4 = old->quaternion_element_4;
        new->loss_function_value = old->loss_function_value;
        new->atm_frame_count = old->atm_frame_count;
        new->total_sa_writes = old->total_sa_writes;
        new->total_sa_reads = old->total_sa_reads;
        new->sa_15_writes = old->sa_15_writes;
        new->sa_15_reads = old->sa_15_reads;
        new->sa_26_writes = old->sa_26_writes;
        new->sa_29_reads = old->sa_29_reads;
        new->status_flags_3 = old->status_flags_3;
        new->adm_separation_tolerance_arc_secs =
            old->adm_separation_tolerance_arc_secs;
        new->adm_position_tolerance_arc_secs =
            old->adm_position_tolerance_arc_secs;
        new->adm_mag_tolerance = old->adm_mag_tolerance;
        new->hot_pixel_count = old->hot_pixel_count;
        new->hot_pixel_threshold = old->hot_pixel_threshold;
        new->track_mode_pixel_threshold = old->track_mode_pixel_threshold;
        new->acquisition_mode_pixel_threshold =
            old->acquisition_mode_pixel_threshold;
        new->tec_setpoint = old->tec_setpoint;
        new->boresight.x = old->boresight.x;
        new->boresight.y = old->boresight.y;
        new->ccd_temperature_celsius = old->ccd_temperature_celsius;
        new->lens_cell_temperature_celsius = old->lens_cell_temperature_celsius;
        new->warning_flag = old->warning_flag; 
    }

    if (ias_l0r_set_ancillary_star_tracker_quaternion(new_l0r_file, 0,
        record_count, new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new star tracker quaternion records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_gyro_temperatures
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_GYRO_TEMPERATURE *old_array;
    IAS_L0R_GYRO_TEMPERATURE *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_gyro_temperature_records_count(
        old_l0r_file, &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old gyro temperature record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the gyro temperature records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_gyro_temperature(old_l0r_file, 0,
            record_count, old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old gyro temperature records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

#define COPY_TEMP(name) \
    new->temperatures_celsius[name] = old->temperatures_celsius[OLD_##name]

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_GYRO_TEMPERATURE *old = &old_array[index];
        IAS_L0R_GYRO_TEMPERATURE *new = &new_array[index];
        
        memset(new, 0, sizeof(*new));

        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->warning_flag = old->warning_flag;

        /* just in case the indices change, copy them directly instead of
           using a loop */
        COPY_TEMP(GYRO_A_FILTERED_RESONATOR);
        COPY_TEMP(GYRO_A_FILTERED_DERIVATIVE_OF_RESONATOR);
        COPY_TEMP(GYRO_A_FILTERED_ELECTRONICS);
        COPY_TEMP(GYRO_A_FILTERED_DERIVATIVE_OF_ELECTRONICS);
        COPY_TEMP(GYRO_A_FILTERED_DIODE);
        COPY_TEMP(GYRO_A_FILTERED_DERIVATIVE_OF_DIODE);
        COPY_TEMP(GYRO_A_FILTERED_CASE);
        COPY_TEMP(GYRO_A_FILTERED_DERIVATIVE_OF_CASE);
        COPY_TEMP(GYRO_B_FILTERED_RESONATOR);
        COPY_TEMP(GYRO_B_FILTERED_DERIVATIVE_OF_RESONATOR);
        COPY_TEMP(GYRO_B_FILTERED_ELECTRONICS);
        COPY_TEMP(GYRO_B_FILTERED_DERIVATIVE_OF_ELECTRONICS);
        COPY_TEMP(GYRO_B_FILTERED_DIODE);
        COPY_TEMP(GYRO_B_FILTERED_DERIVATIVE_OF_DIODE);
        COPY_TEMP(GYRO_B_FILTERED_CASE);
        COPY_TEMP(GYRO_B_FILTERED_DERIVATIVE_OF_CASE);
        COPY_TEMP(GYRO_C_FILTERED_RESONATOR);
        COPY_TEMP(GYRO_C_FILTERED_DERIVATIVE_OF_RESONATOR);
        COPY_TEMP(GYRO_C_FILTERED_ELECTRONICS);
        COPY_TEMP(GYRO_C_FILTERED_DERIVATIVE_OF_ELECTRONICS);
        COPY_TEMP(GYRO_C_FILTERED_DIODE);
        COPY_TEMP(GYRO_C_FILTERED_DERIVATIVE_OF_DIODE);
        COPY_TEMP(GYRO_C_FILTERED_CASE);
        COPY_TEMP(GYRO_C_FILTERED_DERIVATIVE_OF_CASE);
        COPY_TEMP(GYRO_D_FILTERED_RESONATOR);
        COPY_TEMP(GYRO_D_FILTERED_DERIVATIVE_OF_RESONATOR);
        COPY_TEMP(GYRO_D_FILTERED_ELECTRONICS);
        COPY_TEMP(GYRO_D_FILTERED_DERIVATIVE_OF_ELECTRONICS);
        COPY_TEMP(GYRO_D_FILTERED_DIODE);
        COPY_TEMP(GYRO_D_FILTERED_DERIVATIVE_OF_DIODE);
        COPY_TEMP(GYRO_D_FILTERED_CASE);
        COPY_TEMP(GYRO_D_FILTERED_DERIVATIVE_OF_CASE);
    }

#undef COPY_TEMP

    if (ias_l0r_set_ancillary_temperatures_gyro(new_l0r_file, 0,
        record_count, new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new gyro temperature records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_ancillary_oli_tirs_temperatures
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{
    IAS_OLD_L0R_OLI_TIRS_TEMPERATURE *old_array;
    IAS_L0R_OLI_TIRS_TEMPERATURE *new_array;
    unsigned int record_count;
    int index;

    /* get the count of the records */
    if (old_l0r_get_ancillary_oli_tirs_temperature_records_count(
        old_l0r_file, &record_count) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old OLI/TIRS temperature record count");
        return ERROR;
    }
    if (record_count < 1)
    {
        /* no records to convert, so return */
        return SUCCESS;
    }

    /* allocate memory for the records */
    old_array = malloc(sizeof(*old_array) * record_count);
    new_array = malloc(sizeof(*new_array) * record_count);
    if (!old_array || !new_array)
    {
        IAS_LOG_ERROR("Allocating memory for the OLI/TIRS temperature records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    /* read the old records */
    if (old_l0r_get_ancillary_oli_tirs_temperature(old_l0r_file, 0,
            record_count, old_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Reading old OLI/TIRS temperature records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

#define COPY_TEMP(name) \
    new->temperatures_celsius[name] = old->temperatures_celsius[OLD_##name]

    /* copy all the records */
    for (index = 0; index < record_count; index++)
    {
        IAS_OLD_L0R_OLI_TIRS_TEMPERATURE *old = &old_array[index];
        IAS_L0R_OLI_TIRS_TEMPERATURE *new = &new_array[index];
        
        memset(new, 0, sizeof(*new));

        new->l0r_time.days_from_J2000 = old->l0r_time.days_from_J2000;
        new->l0r_time.seconds_of_day = old->l0r_time.seconds_of_day;
        new->warning_flag = old->warning_flag;

        /* just in case the indices change, copy them directly instead of
           using a loop */
        COPY_TEMP(OLI_PRIMARY_MIRROR_FLEXURE);
        COPY_TEMP(OLI_TELESCOPE_POSITIVE_Z_NEGATIVE_Y_STRUT_TUBE);
        COPY_TEMP(OLI_FPE_HEAT_PIPE_EVAPORATIOR);
        COPY_TEMP(OLI_BASEPLATE_POSITIVE_Z);
        COPY_TEMP(OLI_BASEPLATE_NEGATIVE_Z);
        COPY_TEMP(OLI_PRIMARY_MIRROR_BENCH_AT_FLEX);
        COPY_TEMP(OLI_SECONDARY_MIRROR_CENTER);
        COPY_TEMP(OLI_SECONDARY_MIRROR_EDGE);
        COPY_TEMP(OLI_SECONDARY_MIRROR_FLEXURE);
        COPY_TEMP(OLI_SECONDARY_MIRROR_BENCH_AT_FLEX);
        COPY_TEMP(OLI_TERTIARY_MIRROR_CENTER);
        COPY_TEMP(OLI_TERTIARY_MIRROR_EDGE);
        COPY_TEMP(OLI_TERTIARY_MIRROR_FLEXURE);
        COPY_TEMP(OLI_TERTIARY_MIRROR_BENCH_AT_FLEX);
        COPY_TEMP(OLI_QUAT_MIRROR_CENTER);
        COPY_TEMP(OLI_QUAT_MIRROR_EDGE);
        COPY_TEMP(OLI_FPA_1_RADIATOR);
        COPY_TEMP(OLI_QUAT_MIRROR_FLEXURE);
        COPY_TEMP(OLI_FPA_2_HEAT_PIPE_EVAPORATOR);
        COPY_TEMP(OLI_FPA_3_HEAT_PIPE_CONDENSOR);
        COPY_TEMP(OLI_FPA_4_MOLY_BP_PRIMARY);
        COPY_TEMP(OLI_FPA_5_MOLY_BP_REDUNDANT);
        COPY_TEMP(OLI_FPA_6_SINK);
        COPY_TEMP(OLI_FPA_7_COLD_CABLE_RADIATOR);
        COPY_TEMP(OLI_FPA_8_MLI_NEGATIVE_Y_BENCH_TEDLAR);
        COPY_TEMP(OLI_FPA_9_FOOT_AT_SPACECRAFT_INTERFACE);
        COPY_TEMP(OLI_FPA_10_CONDENSOR);
        COPY_TEMP(TIRS_TB1_CH49_BANK4_01);
        COPY_TEMP(TIRS_TB1_CH50_BANK4_02);
        COPY_TEMP(OLI_FPE_RADIATOR);
        COPY_TEMP(TIRS_TB1_CH51_BANK4_03);
        COPY_TEMP(OLI_FPE_HEAT_PTPT_CONDENSOR);
        COPY_TEMP(TIRS_TB1_CH52_BANK4_04);
        COPY_TEMP(OLI_FPE_CHASSIS_PRIMARY);
        COPY_TEMP(OLI_BASEPLATE_POSITIVE_Y);
        COPY_TEMP(OLI_FPE_CHASSIS_REDUNDANT);
        COPY_TEMP(OLI_ISE_CHASSIS_PRIMARY);
        COPY_TEMP(OLI_ISE_CHASSIS_REDUNDANT);
        COPY_TEMP(OLI_ISE_RADIATOR);
        COPY_TEMP(OLI_QUAT_MIRROR_BENCH_AT_FLEX);
        COPY_TEMP(OLI_BENCH_POSITIVE_Y_1);
        COPY_TEMP(OLI_BENCH_POSITIVE_Y_2);
        COPY_TEMP(OLI_BENCH_POSITIVE_Y_3);
        COPY_TEMP(OLI_BENCH_NEGATIVE_Y_1);
        COPY_TEMP(OLI_BENCH_NEGATIVE_Y_2);
        COPY_TEMP(OLI_BENCH_NEGATIVE_X);
        COPY_TEMP(OLI_BENCH_POSITIVE_X_1);
        COPY_TEMP(OLI_BENCH_POSITIVE_X_2);
        COPY_TEMP(OLI_CAL_ASSEMBLY_DIFFUSER_COVER);
        COPY_TEMP(OLI_NEGATIVE_X_FOCUS_MECHANISM);
        COPY_TEMP(OLI_STIMULATION_LAMP_1_DIODE_BOARD);
        COPY_TEMP(OLI_TB1_CH72_BANK5_8);
        COPY_TEMP(OLI_TB1_CH73_BANK5_9);
        COPY_TEMP(OLI_TB1_CH74_BANK5_10);
        COPY_TEMP(OLI_STIMULATION_LAMP_2_DIODE_BOARD);
        COPY_TEMP(OLI_BENCH_NEGATIVE_X_PANEL);
        COPY_TEMP(OLI_DIFFUSER_WHEEL_MOTOR);
        COPY_TEMP(OLI_SHUTTER_WHEEL_MOTOR);
        COPY_TEMP(TIRS_TB1_CH87_BANK6_7);
        COPY_TEMP(TIRS_TB1_CH88_BANK6_8);
        COPY_TEMP(TIRS_TB1_CH89_BANK6_9);
        COPY_TEMP(OLI_BASEPLATE_NEGATIVE_Y);
        COPY_TEMP(TIRS_TB1_CH90_BANK6_10);
        COPY_TEMP(OLI_PRIMARY_MIRROR_CENTER);
        COPY_TEMP(TIRS_TB1_CH91_BANK6_11);
        COPY_TEMP(OLI_PRIMARY_MIRROR_EDGE);
        COPY_TEMP(TIRS_TB1_CH92_BANK6_12);
    }

#undef COPY_TEMP

    if (ias_l0r_set_ancillary_temperatures_oli_tirs(new_l0r_file, 0,
        record_count, new_array) != SUCCESS)
    {
        IAS_LOG_ERROR("Writing new OLI/TIRS temperature records");
        free(old_array);
        free(new_array);
        return ERROR;
    }

    free(old_array);
    free(new_array);

    return SUCCESS;
}

/*****************************************************************************/
int convert_spacecraft_ancillary
(
    OLD_L0RIO *old_l0r_file,
    L0RIO *new_l0r_file
)
{

    /* convert attitude */
    if (convert_ancillary_attitude(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting attitude");
        return ERROR;
    }

    /* convert attitude filter states */
    if (convert_ancillary_attitude_filter_states(old_l0r_file, new_l0r_file)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Converting attitude filter states");
        return ERROR;
    }

    /* convert ephemeris */
    if (convert_ancillary_ephemeris(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting ephemeris");
        return ERROR;
    }

    /* convert gps position */
    if (convert_ancillary_gps_position(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting gps position");
        return ERROR;
    }

    /* convert gps range */
    if (convert_ancillary_gps_range(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting gps range");
        return ERROR;
    }

    /* convert IMU */
    if (convert_ancillary_imu(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting IMU ancillary");
        return ERROR;
    }

    /* convert star tracker centroid */
    if (convert_ancillary_star_tracker_centroid(old_l0r_file, new_l0r_file)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Converting star tracker centroid");
        return ERROR;
    }

    /* convert star tracker quaternion */
    if (convert_ancillary_star_tracker_quaternion(old_l0r_file, new_l0r_file)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Converting star tracker quaternion");
        return ERROR;
    }

    /* convert ACS temperatures */
    if (convert_ancillary_gyro_temperatures(old_l0r_file, new_l0r_file)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Converting gyro temperatures");
        return ERROR;
    }

    /* convert OLI/TIRS temperatures */
    if (convert_ancillary_oli_tirs_temperatures(old_l0r_file, new_l0r_file)
        != SUCCESS)
    {
        IAS_LOG_ERROR("Converting OLI/TIRS temperatures");
        return ERROR;
    }

    return SUCCESS;
}

/*****************************************************************************/
int main(int argc, char *argv[])
{
    const char *input_filename;
    const char *output_filename;
    OLD_L0RIO *old_l0r_file;
    L0RIO *new_l0r_file;
    int tirs_file_flag;
    int first_arg = 1;

    /* initialize the logging library */
    if (ias_log_initialize("convert_l0r") != SUCCESS)
    {
        IAS_LOG_ERROR("Error initializing logging library");
        return EXIT_FAILURE;
    }

    if (ias_sat_attr_initialize(IAS_L8) != SUCCESS)
    {
        IAS_LOG_ERROR("Initializing the satellite attributes library");
        return EXIT_FAILURE;
    }

    /* if incorrect number of arguments, generate a usage message */
    if (argc != 3)
    {
        printf("Usage: convert_l0r input_file output_file\n");
        return EXIT_FAILURE;
    }

    input_filename = argv[first_arg];
    output_filename = argv[first_arg+1];

    IAS_LOG_INFO("Converting %s and saving in %s", 
                 input_filename, output_filename);

    /* setup the function pointers for the old library */
    if (setup_function_pointers() != SUCCESS)
    {
        printf("Error loading the old L0R IO library\n");
        exit(-1);
    }

    if (old_sat_attr_initialize(IAS_L8) != SUCCESS)
    {
        printf("Error initializing loaded satellite attributes library\n");
        exit(-1);
    }

    /* open the input file */
    old_l0r_file = old_l0r_open_from_filename(input_filename,
            IAS_OLD_L0R_COMPRESSION_DEFAULT);
    if (!old_l0r_file)
    {
        IAS_LOG_ERROR("Could not open input L0R: %s", 
                      input_filename);
        return EXIT_FAILURE;
    }

    /* open the output file */
    new_l0r_file = ias_l0r_open_from_filename(output_filename, 
                                              IAS_L0R_COMPRESSION_OFF);
    if (!new_l0r_file)
    {
        IAS_LOG_ERROR("Could not open output L0R: %s", output_filename);
        return EXIT_FAILURE;
    }

    if (old_l0r_open_metadata(old_l0r_file, IAS_READ) != SUCCESS)
    {
        IAS_LOG_ERROR("Opening old metadata file");
        return ERROR;
    }

    if (ias_l0r_open_metadata(new_l0r_file, IAS_WRITE) != SUCCESS)
    {
        IAS_LOG_ERROR("Opening new metadata file");
        return ERROR;
    }

    /* convert the interval metadata */
    if (convert_interval_metadata(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Interval metadata conversion failed");
        ias_l0r_close_metadata(new_l0r_file);
        ias_l0r_close(new_l0r_file);
        old_l0r_close(old_l0r_file);
        return EXIT_FAILURE;
    }

    /* convert the scene metadata */
    if (convert_scene_metadata(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Scene metadata conversion failed");
        ias_l0r_close_metadata(new_l0r_file);
        ias_l0r_close(new_l0r_file);
        old_l0r_close(old_l0r_file);
        return EXIT_FAILURE;
    }

    /* convert the file metadata */
    if (convert_file_metadata(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("File metadata conversion failed");
        ias_l0r_close_metadata(new_l0r_file);
        ias_l0r_close(new_l0r_file);
        old_l0r_close(old_l0r_file);
        return EXIT_FAILURE;
    }
    if (old_l0r_close_metadata(old_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Closing old metadata file");
        return ERROR;
    }
    if (ias_l0r_close_metadata(new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Closing new metadata file");
        return ERROR;
    }

    if (old_l0r_open_ancillary(old_l0r_file, IAS_READ) != SUCCESS)
    {
        IAS_LOG_ERROR("Opening old ancillary file");
        return EXIT_FAILURE;
    }

    tirs_file_flag = is_tirs_file(old_l0r_file);
    if (tirs_file_flag)
        IAS_LOG_INFO("Input file is a TIRS file");

    if (ias_l0r_open_ancillary(new_l0r_file, IAS_WRITE) != SUCCESS)
    {
        IAS_LOG_ERROR("Opening new header file");
        return EXIT_FAILURE;
    }

    if (old_l0r_open_header(old_l0r_file, IAS_READ) != SUCCESS)
    {
        IAS_LOG_ERROR("Opening old header file");
        return ERROR;
    }

    if (ias_l0r_open_header(new_l0r_file, IAS_WRITE) != SUCCESS)
    {
        IAS_LOG_ERROR("Opening new header file");
        return ERROR;
    }

    /* convert the image header */
    if (convert_image_header(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Frame header conversion failed");
        ias_l0r_close(new_l0r_file);
        old_l0r_close(old_l0r_file);
        return EXIT_FAILURE;
    }

    /* convert the OLI frame headers */
    if (convert_frame_headers(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Frame header conversion failed");
        ias_l0r_close(new_l0r_file);
        old_l0r_close(old_l0r_file);
        return EXIT_FAILURE;
    }

    /* convert the TIRS frame headers */
    if (convert_tirs_frame_headers(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("TIRS frame header conversion failed");
        ias_l0r_close(new_l0r_file);
        old_l0r_close(old_l0r_file);
        return EXIT_FAILURE;
    }

    if (old_l0r_close_header(old_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Closing old header file");
        return EXIT_FAILURE;
    }

    if (ias_l0r_close_header(new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Closing new header file");
        return EXIT_FAILURE;
    }

    if (convert_oli_telemetry(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting OLI telemetry");
        return EXIT_FAILURE;
    }

    if (convert_tirs_telemetry(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting TIRS telemetry");
        return EXIT_FAILURE;
    }

    if (convert_spacecraft_ancillary(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Converting spacecraft ancillary");
        return EXIT_FAILURE;
    }

    if (old_l0r_close_ancillary(old_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Closing old ancillary file");
        return EXIT_FAILURE;
    }

    if (ias_l0r_close_ancillary(new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Closing new header file");
        return EXIT_FAILURE;
    }

#if 1
    /* convert the imagery */
    if (convert_imagery(old_l0r_file, new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Imagery conversion failed");
        ias_l0r_close(new_l0r_file);
        old_l0r_close(old_l0r_file);
        return EXIT_FAILURE;
    }
#endif

    /* close the output file */
    if (ias_l0r_close(new_l0r_file) != SUCCESS)
    {
        IAS_LOG_ERROR("Failed to close the L0R output file");
        return EXIT_FAILURE;
    }

    /* close the input file */
    old_l0r_close(old_l0r_file);

    dlclose(lib_handle);

    return EXIT_SUCCESS;
}
