/*-----------------------------------------------------------------------------

NAME: ias_l0r_mta_private.h

PURPOSE: Interval functions for reading and writing metadata contained in the 
    L0R data.

ALGORITHM REFERENCES: NONE

NOTES:

-----------------------------------------------------------------------------*/
#ifndef __IAS_L0R_MTA_PRIVATE_H__
#define __IAS_L0R_MTA_PRIVATE_H__

/* project included headers */
#include "ias_l0r.h"
#include "ias_l0r_hdf.h"

/******************************************************************************
 private routine prototypes
*******************************************************************************/
int ias_l0r_mta_establish_file
(
    HDFIO *hdfio_ptr, /* I: Pointer to structure used in I/O */
    int create_if_absent /* I: Create the file if it does not exist */
);

int ias_l0r_mta_read
(
    HDFIO *hdfio_ptr, /* I: Pointer to structure used in I/O */
    const int index, /* I: First record to read */
    const int count, /* I: Number of records to read */
    const char *table_name, /* I: Table name to read from */
    const size_t size, /* I: Size of the structure which stores the data */
    const size_t *offset, /* I: List of the offsets for each member */
    const size_t *size_list, /* I: List of the sizes of each member */
    void *buffer /* I: Data Buffer */
);

int ias_l0r_mta_table_records_count
(
    HDFIO *hdfio_ptr, /* I: Pointer to structure used in I/O */
    const char *table, /* I: Table name to read from */
    int *size          /* O: Number of records in the table */
);

int ias_l0r_mta_write
(
    L0RIO *l0r, /* structure for the file used in I/O */
    const int index, /* I: First record to write */
    const int count, /* I: Number of records to write */
    const char *table_name, /* I: Table name to write to */
    const size_t size, /* I: Size of the structure which stores the data */
    const size_t *offset, /* I: List of the offsets for each member */
    const size_t *size_list, /* I: List of the sizes of each member */
    const void *buffer /* I: Data Buffer */
);

#endif
