#include <limits.h>
#include <string.h>
#include <stdio.h>
#include <sys/stat.h>
#include <time.h>

#include "ias_logging.h"
#include "ias_l0r.h"
#include "ias_satellite_attributes.h"
#include "cgreen/cgreen.h"

static void test_l0r_open_close(void)
{

    int status;
    L0RIO *l0r_data;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
   
    /* test the alternate open function */
    l0r_data = ias_l0r_open_from_filename("./test",
        IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    /*close access to the L0R data again*/
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);

}

static void test_l0r_remove_test_files(void)
{
    int i = 0;
    struct stat file_info;
    char complete_filename[PATH_MAX];
    const IAS_SATELLITE_ATTRIBUTES *landsat8_attributes;

    assert_true(ias_sat_attr_initialize(IAS_L8) == SUCCESS);
    landsat8_attributes = ias_sat_attr_get_attributes();
    assert_true_with_message(landsat8_attributes != NULL,
        "Landsat Attributes is NULL");

    /* check for band files and remove those that exist */
    for (i = 0; i <= landsat8_attributes->total_bands; i++)
    {
        sprintf(complete_filename, "test_B%d.h5", i);
        /* If the files exist delete them */
        if (stat(complete_filename, &file_info) == 0)
        {
            assert_true(remove(complete_filename) == 0);
        }
    }

    /* Remove the Ancillary file if it exists */
    strncpy(complete_filename, "test_ANC.h5", PATH_MAX);
    if (stat(complete_filename, &file_info) == 0)
    {
        assert_true(remove(complete_filename) == 0);
    }
     
    /* Remove the metadata file if it exists */
    strncpy(complete_filename, "test_MTA.h5", PATH_MAX);
    if (stat(complete_filename, &file_info) == 0)
    {
        assert_true(remove(complete_filename) == 0);
    }
}

int main(int argc, char **argv)
{
    int status = 0;

    status = ias_log_initialize("L0R IO Test");
    if (status == ERROR)
    {
        IAS_LOG_ERROR("Error encountered when initializing the ias logging "
            "library");
        return ERROR;
    }
    if (ias_sat_attr_initialize(IAS_L8) != SUCCESS)
    {
        IAS_LOG_ERROR("Error initializing attributes");
        return ERROR;
    }
    ias_log_set_output_level(IAS_LOG_LEVEL_ERROR);

    TestSuite *suite = create_test_suite();
    add_test(suite, test_l0r_open_close);
    add_test(suite, test_l0r_remove_test_files);
    return run_test_suite(suite, create_text_reporter());
}
