#include <limits.h>
#include <string.h>
#include <stdio.h>
#include <sys/stat.h>
#include <time.h>

#include "ias_l0r.h"
#include "ias_logging.h"
#include "ias_satellite_attributes.h"
#include "cgreen/cgreen.h"

int generate_signed_32_int(void)
{
    int temp_int = 0;
    temp_int = rand()%INT32_MAX;
    if(rand()%2 == 1)
    {
        temp_int = temp_int * -1;
    }
    return temp_int;
}
int generate_signed_16_int(void)
{
    int temp_int = 0;
    temp_int = rand()%INT16_MAX;
    if(rand()%2 == 1)
    {
        temp_int = temp_int * -1;
    }
    return temp_int;
}
float generate_float(void)
{
    int i = 0;
    int exp = 0;
    int pos_neg_exp = 0;
    float temp_float = 0;

    temp_float = rand()%UINT16_MAX;
    temp_float += rand()%UINT8_MAX/(UINT8_MAX-(rand()%UINT8_MAX));
    exp = rand()%30;
    pos_neg_exp = rand() % 2;
    for(i = 0; i < exp; i++)
    {
        if(pos_neg_exp == 1)
        {
            temp_float = temp_float * 10;
        }
        else
        {
            temp_float = temp_float * .1;
        }
    }
    if(rand()%2 == 1)
    {
        temp_float = temp_float * -1;
    }
    return temp_float;
}
double generate_double(void)
{
    int i = 0;
    int exp = 0;
    int pos_neg_exp = 0;
    double temp_double = 0;

    temp_double = rand()%UINT32_MAX;
    temp_double += rand()%UINT8_MAX/(UINT8_MAX-(rand()%UINT8_MAX));
    exp = rand()%300;
    pos_neg_exp = rand() % 2;
    for(i = 0; i < exp; i++)
    {
        if(pos_neg_exp == 1)
        {
            temp_double = temp_double * 10;
        }
        else
        {
            temp_double = temp_double * .1;
        }
    }
    if(rand()%2 == 1)
    {
        temp_double = temp_double * -1;
    }
    return temp_double;
}

/**
*print_attitude outputs the contents of the attitude structure to stdout
*
*void print_attitude(const IAS_L0R_ATTITUDE *attitude) outputs the contents of
*the IAS_L0R_ATTITUDE structure to stdout
*/
void print_attitude(const IAS_L0R_ATTITUDE *attitude)
{
    printf("Printing attitude data\n");
    printf("%i\n",attitude->l0r_time.days_from_J2000);
    printf("%G\n",attitude->l0r_time.seconds_of_day);
    printf("%G\n", attitude->inertial_to_body.vector.x);
    printf("%G\n", attitude->inertial_to_body.vector.y);
    printf("%G\n", attitude->inertial_to_body.vector.z);
    printf("%G\n", attitude->inertial_to_body.scalar);
    printf("####################################\n");
}

void print_attitude_filter_states
    (const IAS_L0R_ATTITUDE_FILTER_STATES *attitude)
{
    printf("Printing attitude filter data\n");
    printf("%i\n",attitude->l0r_time.days_from_J2000);
    printf("%G\n",attitude->l0r_time.seconds_of_day);
    printf("%G\n", attitude->gyro_combined_bias_rad_sec.x);
    printf("%G\n", attitude->gyro_combined_bias_rad_sec.y);
    printf("%G\n", attitude->gyro_combined_bias_rad_sec.z);
    printf("%G\n", attitude->gyro_x_misalignment_along_y_rad);
    printf("%G\n", attitude->gyro_x_misalignment_along_z_rad);
    printf("%G\n", attitude->gyro_y_misalignment_along_x_rad);
    printf("%G\n", attitude->gyro_y_misalignment_along_z_rad);
    printf("%G\n", attitude->gyro_z_misalignment_along_x_rad);
    printf("%G\n", attitude->gyro_z_misalignment_along_y_rad);
    printf("%G\n", attitude->gyro_scale_factor.x);
    printf("%G\n", attitude->gyro_scale_factor.y);
    printf("%G\n", attitude->gyro_scale_factor.z);
    printf("%G\n", attitude->kalman_filter_error_rad.x);
    printf("%G\n", attitude->kalman_filter_error_rad.y);
    printf("%G\n", attitude->kalman_filter_error_rad.z);
    printf("%G\n", attitude->covariance_diagonal.x);
    printf("%G\n", attitude->covariance_diagonal.y);
    printf("%G\n", attitude->covariance_diagonal.z);
    printf("####################################\n");
}

void print_gps_range(const IAS_L0R_GPS_RANGE *gps_range)
{
    int i =0;

    printf("Printing GPS Range data\n");
    printf("L0R days from J2000 %i\n",gps_range->l0r_time.days_from_J2000);
    printf("L0R seconds of day %G\n",gps_range->l0r_time.seconds_of_day);
    printf("seconds - %i\n",gps_range->seconds);
    printf("nanoseconds - %i\n",gps_range->nanoseconds);
    printf("function - %i\n",gps_range->function);
    printf("sub_function - %i\n",gps_range->sub_function);
    for (i = 0; i <IAS_GPS_NUM_SATELLITES; i++)
    {
        printf("Sat # %d\n",i+1);
        printf("%d\n",gps_range->tracked_satellites[i].id);
        printf("%d\n",gps_range->tracked_satellites[i].tracking_mode);
        printf("%d\n",gps_range->tracked_satellites[i].
            gps_time_seconds);
        printf("%d\n",gps_range->tracked_satellites[i].
            gps_time_nanoseconds);
        printf("%G\n",gps_range->tracked_satellites[i].
                                integrated_carrier_phase_deg);
        printf("%G\n",gps_range->tracked_satellites[i].
                                code_discriminator_output);
    }
    printf("fill flag - %d",gps_range->warning_flag);
}

void print_star_tracker_centroid(const IAS_L0R_STAR_TRACKER_CENTROID *centroid)
{
    int i = 0;
 
    printf("Printing star tracker centroid data\n");
    printf ("%u\n",centroid->quaternion_index);
 
    for (i = 0; i< IAS_STAR_TRACKER_NUM_STARS; i++)
    {
        printf("%d\n",centroid->stars[i].valid);
        printf("%d\n",centroid->stars[i].id);
        printf("%d\n",centroid->stars[i].background_bias);
        printf("%G\n",centroid->stars[i].intensity_mi);
        printf("%G\n",centroid->stars[i].position_arcsec.x);
        printf("%G\n",centroid->stars[i].position_arcsec.y);
    }
    printf("%d\n",centroid->warning_flag);
    printf("####################################\n");
}


/**
*test_attitude_creation tests populating the attitude structure and i/o
*
*test_attitude_creation() populates the IAS_L0R_ATTITUDE
*structures with random data, writes the data to
*file, reads the data from file, and then compares the data to verify
*the values created are the same after writing and reading from file
*/
static void test_attitude_creation(void)
{
    int status;
    int different_elements_count;
    L0RIO *l0r_data = NULL;
    IAS_L0R_ATTITUDE attitude;
    IAS_L0R_ATTITUDE attitude_from_file;


    memset(&attitude, 0, sizeof(IAS_L0R_ATTITUDE));
    memset(&attitude_from_file, 0, sizeof(IAS_L0R_ATTITUDE));

    srand(time(NULL));
 
    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    ias_l0r_open_ancillary(l0r_data, IAS_WRITE);

    /* No files should exist for the data yet */
    if(ias_l0r_present("./test") == TRUE)
    {
        assert_true(system("rm ./test*.h5") == 0);
    }

    /* Seed the data with random values */
    attitude.l0r_time.days_from_J2000 = generate_signed_32_int();
    attitude.l0r_time.seconds_of_day = generate_double();
    attitude.time_tag_sec_orig = generate_double();
    attitude.inertial_to_body.vector.x = generate_double();
    attitude.inertial_to_body.vector.y = generate_double();
    attitude.inertial_to_body.vector.z = generate_double();
    attitude.inertial_to_body.scalar = generate_double();
    attitude.warning_flag = rand()%UINT8_MAX;
 
    status = ias_l0r_set_ancillary_attitude(l0r_data, 0, 1, &attitude);
    assert_true(status == SUCCESS);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_attitude(l0r_data,
        0, 1, &attitude_from_file);
    assert_true(status == SUCCESS);

    /* Verify that the values read from file match the values written */

    status = ias_l0r_compare_ancillary_attitude(&attitude,
     &attitude_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    if (different_elements_count != 0)
    {
        assert_true(1 == 0);
        print_attitude(&attitude);
        print_attitude(&attitude_from_file);
    }

   /* We should have an ANC file created at this point */
   assert_true(ias_l0r_present("./test") == TRUE);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

/**
*test_attitude_filter_states_creation tests populating
 the attitude structure and i/o

test_attitude_filter_states_creation() populates the
 IAS_L0R_ATTITUDE_FILTER_STATES
structure with random data, writes the data to
file, reads the data from file, and then compares the data to verify
the values created are the same after writing and reading from file
*/
static void test_attitude_filter_states_creation(void)
{
    int status;
    int different_elements_count;
    L0RIO *l0r_data = NULL;
    IAS_L0R_ATTITUDE_FILTER_STATES attitude_filter;
    IAS_L0R_ATTITUDE_FILTER_STATES attitude_filter_from_file;

    memset(&attitude_filter, 0, sizeof(IAS_L0R_ATTITUDE_FILTER_STATES));
    memset(&attitude_filter_from_file, 0,
        sizeof(IAS_L0R_ATTITUDE_FILTER_STATES));

    srand(time(NULL));

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    ias_l0r_open_ancillary(l0r_data, IAS_WRITE);

    /*  Populate the structure with random data */
    attitude_filter.l0r_time.days_from_J2000 = generate_signed_32_int();
    attitude_filter.l0r_time.seconds_of_day = generate_double();
    attitude_filter.time_tag_sec_orig = generate_signed_32_int();
    attitude_filter.time_tag_subseconds_orig = generate_signed_32_int();
    attitude_filter.gyro_combined_bias_rad_sec.x = generate_double();
    attitude_filter.gyro_combined_bias_rad_sec.y = generate_double();
    attitude_filter.gyro_combined_bias_rad_sec.z = generate_double();
    attitude_filter.gyro_scale_factor.x = generate_double();
    attitude_filter.gyro_scale_factor.y = generate_double();
    attitude_filter.gyro_scale_factor.z = generate_double();
    attitude_filter.gyro_x_misalignment_along_y_rad = generate_float();
    attitude_filter.gyro_x_misalignment_along_z_rad = generate_float();
    attitude_filter.gyro_y_misalignment_along_x_rad = generate_float();
    attitude_filter.gyro_y_misalignment_along_z_rad = generate_float();
    attitude_filter.gyro_z_misalignment_along_x_rad = generate_float();
    attitude_filter.gyro_z_misalignment_along_y_rad = generate_float();
    attitude_filter.kalman_filter_error_rad.x = generate_double();
    attitude_filter.kalman_filter_error_rad.y = generate_double();
    attitude_filter.kalman_filter_error_rad.z = generate_double();
    attitude_filter.covariance_diagonal.x = generate_double();
    attitude_filter.covariance_diagonal.y = generate_double();
    attitude_filter.covariance_diagonal.z = generate_double();
    attitude_filter.warning_flag = rand()%UINT8_MAX;

    status = ias_l0r_set_ancillary_attitude_filter_states(l0r_data,
         0, 1, &attitude_filter);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_attitude_filter_states(l0r_data,
         0, 1, &attitude_filter_from_file);
    assert_true(status == SUCCESS);

    status = ias_l0r_compare_ancillary_attitude_filter_states(&attitude_filter,
     &attitude_filter_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    if (different_elements_count != 0)
    {
        assert_true(1 == 0);
        print_attitude_filter_states(&attitude_filter);
        print_attitude_filter_states(&attitude_filter_from_file);
    }

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

/**
*test_copy_functionality tests copying from one Ancillary file to another.
 Add one dataset from both the Spacecraft and Telemetry groups to the source */
static void test_copy_functionality(void)
{
    char complete_filename[PATH_MAX];
    int status;
    int different_elements_count;
    L0RIO *l0r_data_1 = NULL;
    L0RIO *l0r_data_2 = NULL;
    IAS_L0R_ATTITUDE attitude;
    IAS_L0R_ATTITUDE attitude_from_file;
    IAS_L0R_TIRS_TELEMETRY telemetry_data;
    IAS_L0R_TIRS_TELEMETRY telemetry_data_from_file;

    struct stat file_info;

    strncpy(complete_filename, "test_ANC.h5", PATH_MAX);
    if (stat(complete_filename, &file_info) == 0)
    {
        assert_true(remove(complete_filename) == 0);
    }

    strncpy(complete_filename, "copy_test_ANC.h5", PATH_MAX);
    if (stat(complete_filename, &file_info) == 0)
    {
        assert_true(remove(complete_filename) == 0);
    }

    srand(time(NULL));

    memset(&telemetry_data, 0, sizeof(IAS_L0R_TIRS_TELEMETRY));
    memset(&telemetry_data_from_file, 0, sizeof(IAS_L0R_TIRS_TELEMETRY));
    memset(&attitude, 0, sizeof(IAS_L0R_ATTITUDE));
    memset(&attitude_from_file, 0, sizeof(IAS_L0R_ATTITUDE));

    srand(time(NULL));
 
    /* open access to L0R data */
    l0r_data_1 = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data_1 != NULL);
    l0r_data_2 = ias_l0r_open("copy_test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data_2 != NULL);

    ias_l0r_open_ancillary(l0r_data_1, IAS_WRITE);
    ias_l0r_open_ancillary(l0r_data_2, IAS_WRITE);

    /* Seed the data with random values */
    attitude.l0r_time.days_from_J2000 = generate_signed_32_int();
    attitude.l0r_time.seconds_of_day = generate_double();
    attitude.time_tag_sec_orig = generate_double();
    attitude.inertial_to_body.vector.x = generate_double();
    attitude.inertial_to_body.vector.y = generate_double();
    attitude.inertial_to_body.vector.z = generate_double();
    attitude.inertial_to_body.scalar = generate_double();
    attitude.warning_flag = rand()%UINT8_MAX;

    /* Set just a few TIRS Telemetry fields*/
    telemetry_data.l0r_time.
        days_from_J2000 = generate_signed_32_int();
    telemetry_data.l0r_time.
        seconds_of_day = generate_double();
    telemetry_data.command.unaccepted_command_count = rand() % UINT8_MAX;
    telemetry_data.command.accepted_command_count = rand() % UINT8_MAX;
    telemetry_data.command.pulse_per_second_count = rand() % UINT8_MAX;
    telemetry_data.command.tod_command_counter = rand() % UINT8_MAX;
    telemetry_data.command.day = generate_signed_16_int();
 
    status = ias_l0r_set_ancillary_attitude(l0r_data_1, 0, 1, &attitude);
    assert_true(status == SUCCESS);

    status = ias_l0r_set_ancillary_tirs_telemetry(l0r_data_1, 0, 1,
        &telemetry_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_set_tirs_telemetry failed");

    /* run the copy operation */
    status = ias_l0r_copy_ancillary(l0r_data_1, l0r_data_2);

    /* read from the copied file */
    status = ias_l0r_get_ancillary_attitude(l0r_data_2,
        0, 1, &attitude_from_file);
    assert_true(status == SUCCESS);
    status = ias_l0r_get_ancillary_tirs_telemetry(l0r_data_2,
         0, 1, &telemetry_data_from_file);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_get_ancillary_tirs_telemetry failed");

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_attitude(&attitude,
     &attitude_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    if (different_elements_count != 0)
    {
        assert_true(1 == 0);
        print_attitude(&attitude);
        print_attitude(&attitude_from_file);
    }
    status = ias_l0r_compare_ancillary_tirs_telemetry(&telemetry_data,
        &telemetry_data_from_file, &different_elements_count);
    assert_true_with_message(status == SUCCESS,
       "ias_l0r_compare_ancillary_tirs_telemetry failed");
    assert_true_with_message(different_elements_count == 0,
        "different_elements_count is %d", different_elements_count);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data_1);
    assert_true(status == SUCCESS);
    status = ias_l0r_close(l0r_data_2);
    assert_true(status == SUCCESS);
}

/**
*test_ephemeris_creation tests populating the ephemeris structure and i/o
*
*test_ephemeris_creation() populates the IAS_L0R_EPHEMERIS
*structure with random data, writes the data to
*file, reads the data from file, and then compares the data to verify
*the values created are the same after writing and reading from file
*/
static void test_ephemeris_creation(void)
{
    int status;
    int different_elements_count;
    L0RIO *l0r_data = NULL;
    IAS_L0R_EPHEMERIS ephemeris;
    IAS_L0R_EPHEMERIS ephemeris_from_file;

    memset(&ephemeris, 0, sizeof(IAS_L0R_EPHEMERIS));
    memset(&ephemeris_from_file, 0, sizeof(IAS_L0R_EPHEMERIS));

    srand(time(NULL));

    /*  Populate structure with random data */
    ephemeris.l0r_time.days_from_J2000 = generate_signed_32_int();
    ephemeris.l0r_time.seconds_of_day = generate_double();
    ephemeris.time_tag_sec_orig = generate_double();
    ephemeris.ecef_position_meters.x = generate_double();
    ephemeris.ecef_position_meters.y = generate_double();
    ephemeris.ecef_position_meters.z = generate_double();
    ephemeris.ecef_velocity_meters_per_sec.x = generate_double();
    ephemeris.ecef_velocity_meters_per_sec.y = generate_double();
    ephemeris.ecef_velocity_meters_per_sec.z = generate_double();
    ephemeris.orbit_determination_position_error_meters.x = generate_double();
    ephemeris.orbit_determination_position_error_meters.y = generate_double();
    ephemeris.orbit_determination_position_error_meters.z = generate_double();
    ephemeris.orbit_determination_velocity_error_meters_per_sec.x
        = generate_double();
    ephemeris.orbit_determination_velocity_error_meters_per_sec.y
        = generate_double();
    ephemeris.orbit_determination_velocity_error_meters_per_sec.z
        = generate_double();
    ephemeris.warning_flag = rand()%UINT8_MAX;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    ias_l0r_open_ancillary(l0r_data, IAS_WRITE);

    status = ias_l0r_set_ancillary_ephemeris(l0r_data, 0, 1, &ephemeris);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_ephemeris(l0r_data,
         0, 1, &ephemeris_from_file);
    assert_true(status == SUCCESS);

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_ephemeris(&ephemeris,
     &ephemeris_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    if (different_elements_count != 0)
    {
        assert_true(1 == 0);
    }

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

/**
*test_gps_creation tests the creation of L0R gps ancillary data
*
*
*/
static void test_gps_creation(void)
{
    int i = 0;
    int status = ERROR;
    int different_elements_count = 0;

    L0RIO *l0r_data = NULL;
    IAS_L0R_GPS_POSITION gps_position;
    IAS_L0R_GPS_POSITION gps_position_from_file;

    memset(&gps_position, 0, sizeof(IAS_L0R_GPS_POSITION));
    memset(&gps_position_from_file, 0, sizeof(IAS_L0R_GPS_POSITION));

    srand(time(NULL));

    /* Fill the structure with random data */
    gps_position.l0r_time.days_from_J2000 = generate_signed_32_int();
    gps_position.l0r_time.seconds_of_day = generate_double();
    gps_position.month = rand()%UINT8_MAX;
    gps_position.day = rand()%UINT8_MAX;
    gps_position.year = rand()%UINT16_MAX;
    gps_position.hours = rand()%UINT8_MAX;
    gps_position.minutes = rand()%UINT8_MAX;
    gps_position.seconds = rand()%UINT8_MAX;
    gps_position.nanoseconds = rand()%UINT32_MAX;
    gps_position.function = rand()%UINT8_MAX;
    gps_position.sub_function = rand()%UINT8_MAX;
    gps_position.point_arc_secs.lat = generate_double();
    gps_position.point_arc_secs.lng = generate_double();
    gps_position.height_uncorrected_meters = generate_double();
    gps_position.height_corrected_meters = generate_double();
    gps_position.velocity_meters_per_sec = generate_double();
    gps_position.heading_degrees = generate_double();
    gps_position.current_dop = generate_float();
    gps_position.dop_type = rand()%UINT8_MAX;
    gps_position.num_visible_satellites = rand()%UINT8_MAX;
    gps_position.num_satellites_tracked = rand()%UINT8_MAX;
    for (i = 0; i<IAS_GPS_NUM_SATELLITES; i++)
    {
             gps_position.tracked_satellites[i].id = rand()%UINT8_MAX;
             gps_position.tracked_satellites[i].track_mode = rand()%UINT8_MAX;
             gps_position.tracked_satellites[i].signal_strength =
                 rand()%UINT8_MAX;
             gps_position.tracked_satellites[i].channel_status_flags =
                 rand()%UINT8_MAX;
    }
    gps_position.receiver_status_flags = rand()%UINT8_MAX;
    gps_position.ecef_position_meters.x = generate_double();
    gps_position.ecef_position_meters.y = generate_double();
    gps_position.ecef_position_meters.z = generate_double();
    gps_position.ecef_velocity_meters_per_sec.x = generate_double();
    gps_position.ecef_velocity_meters_per_sec.y = generate_double();
    gps_position.ecef_velocity_meters_per_sec.z = generate_double();
    gps_position.warning_flag = rand()%UINT8_MAX;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);
    
    status = ias_l0r_open_ancillary(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);

    status = ias_l0r_set_ancillary_gps_position(l0r_data, 0, 1, &gps_position);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_gps_position(l0r_data, 0, 1,
        &gps_position_from_file);
    assert_true(status == SUCCESS);

    status = ias_l0r_close_ancillary(l0r_data);
    assert_true(status == SUCCESS);

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_gps_position(&gps_position,
        &gps_position_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    assert_true(different_elements_count == 0);

    assert_true(status == SUCCESS);
    assert_true(different_elements_count == 0);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

/**
*test_gps_range_creation tests the creation of L0R gps ancillary data
*/
static void test_gps_range_creation(void)
{
    int i = 0;
    int status = ERROR;
    int different_elements_count = 0;

    L0RIO *l0r_data = NULL;
    IAS_L0R_GPS_RANGE gps_range;
    IAS_L0R_GPS_RANGE gps_range_from_file;

    srand(time(NULL));

    memset(&gps_range, 0, sizeof(IAS_L0R_GPS_RANGE));
    memset(&gps_range_from_file, 0, sizeof(IAS_L0R_GPS_RANGE));

    gps_range.l0r_time.days_from_J2000 = generate_signed_32_int();
    gps_range.l0r_time.seconds_of_day = generate_double();
    gps_range.seconds = generate_signed_32_int();
    gps_range.nanoseconds = generate_signed_32_int();
    gps_range.function = rand()%UINT8_MAX;
    gps_range.sub_function = rand()%UINT8_MAX;
    for (i = 0; i <IAS_GPS_NUM_SATELLITES; i++)
    {
        gps_range.tracked_satellites[i].id = rand()%UINT8_MAX;
        gps_range.tracked_satellites[i].tracking_mode = rand()%UINT8_MAX;
        gps_range.tracked_satellites[i].gps_time_seconds
            = generate_signed_32_int();
        gps_range.tracked_satellites[i].gps_time_nanoseconds
            = generate_signed_32_int();
        gps_range.tracked_satellites[i].raw_code_phase = rand()%UINT32_MAX;
        gps_range.tracked_satellites[i].
            integrated_carrier_phase_cycles = rand()%UINT32_MAX;
        gps_range.tracked_satellites[i].
            integrated_carrier_phase_deg = generate_double();
        gps_range.tracked_satellites[i].
            code_discriminator_output = generate_double();
    }
    gps_range.warning_flag = rand()%UINT8_MAX;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_ancillary(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);

    status = ias_l0r_set_ancillary_gps_range(l0r_data, 0, 1,
        &gps_range);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_gps_range(l0r_data, 0, 1,
        &gps_range_from_file);
    assert_true(status == SUCCESS);

    status = ias_l0r_close_ancillary(l0r_data);
    assert_true(status == SUCCESS);

    /* Verify that the values read from file match the values written */

    status = ias_l0r_compare_ancillary_gps_range(&gps_range,
        &gps_range_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    assert_true(different_elements_count == 0);
    if(different_elements_count != 0)
    {
    print_gps_range(&gps_range);
    print_gps_range(&gps_range_from_file);
    }

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

static void test_imu_creation(void)
{
    int i = 0;
    int j = 0;
    int status = 0;
    int different_elements_count;
    L0RIO *l0r_data = NULL;
    IAS_L0R_IMU imu_data;
    IAS_L0R_IMU imu_data_from_file;

    srand(time(NULL));

    memset(&imu_data, 0, sizeof(IAS_L0R_IMU));
    memset(&imu_data_from_file, 0, sizeof(IAS_L0R_IMU));

    imu_data.l0r_time.days_from_J2000 = generate_signed_32_int();
    imu_data.l0r_time.seconds_of_day = generate_double();
    imu_data.time_tag_sec_orig = generate_signed_32_int();
    imu_data.time_tag_subseconds_orig = generate_signed_32_int();
    for (i = 0; i < IAS_L0R_NUM_SAMPLES_PER_IMU_RECORD; i++)
    {
        imu_data.gyro_samples[i].sync_event_time_tag = generate_signed_16_int();
        imu_data.gyro_samples[i].time_tag = rand()%UINT16_MAX;
        imu_data.gyro_samples[i].saturation_and_scaling = rand()%UINT8_MAX;
        imu_data.gyro_samples[i].angular_rate_valid = rand()%UINT8_MAX;
        for (j = 0; j <  IAS_L0R_NUM_GYROS; j++)
        {
            imu_data.gyro_samples[i].integrated_angle_count[j] =
                rand()%UINT16_MAX;
        }
    }
    imu_data.warning_flag = rand()%UINT8_MAX;

    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_ancillary(l0r_data, IAS_WRITE);
    assert_true_with_message(status == SUCCESS,
             "ias_l0r_open_ancillary failed");

    status = ias_l0r_set_ancillary_imu(l0r_data, 0, 1, &imu_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_set_ancillary_imu failed");

    status = ias_l0r_get_ancillary_imu(l0r_data, 0, 1, &imu_data_from_file);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_get_ancillary_imu failed");

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_imu(&imu_data,
        &imu_data_from_file, &different_elements_count);
    assert_true_with_message(status == SUCCESS,
       "ias_l0r_compare_ancillary_imu failed");
    assert_true_with_message(different_elements_count == 0,
        "different_elements_count is %d", different_elements_count);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_close failed");
}

static void test_imu_latency_creation(void)
{
    int status = 0;
    int different_elements_count;
    L0RIO *l0r_data = NULL;
    IAS_L0R_IMU_LATENCY imu_latency_data;
    IAS_L0R_IMU_LATENCY imu_latency_data_from_file;

    srand(time(NULL));

    memset(&imu_latency_data, 0, sizeof(IAS_L0R_IMU_LATENCY));
    memset(&imu_latency_data_from_file, 0, sizeof(IAS_L0R_IMU_LATENCY));

    imu_latency_data.l0r_time.days_from_J2000 = generate_signed_32_int();
    imu_latency_data.l0r_time.seconds_of_day = generate_double();
    imu_latency_data.fine_ad_solution_time = generate_double();
    imu_latency_data.measured_imu_latency = generate_float();
    imu_latency_data.warning_flag = rand()%UINT8_MAX;

    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_ancillary(l0r_data, IAS_WRITE);
    assert_true_with_message(status == SUCCESS,
             "ias_l0r_open_ancillary failed");

    status = ias_l0r_set_ancillary_imu_latency(l0r_data, 0, 1,
         &imu_latency_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_set_ancillary_imu_latency failed");

    status = ias_l0r_get_ancillary_imu_latency(l0r_data, 0, 1,
        &imu_latency_data_from_file);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_get_ancillary_imu_latency failed");

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_imu_latency(&imu_latency_data,
        &imu_latency_data_from_file, &different_elements_count);
    assert_true_with_message(status == SUCCESS,
       "ias_l0r_compare_ancillary_imu_latency failed");
    assert_true_with_message(different_elements_count == 0,
        "different_elements_count is %d", different_elements_count);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_close failed");
}


static void test_oli_telemetry_creation(void)
{
    /*  Test reading and writing to/from the buffer this number of records.
     This is done only with OLI telemetry because it unique in that it
     is written to multiple tables which complicates things... */
    const int TELEM_REPEAT_COUNT = 55;

    int status = 0;
    int i = 0;
    int repeat = 0;
    int different_elements_count;
    L0RIO *l0r_data = NULL;
    IAS_L0R_OLI_TELEMETRY telemetry_data[TELEM_REPEAT_COUNT];
    IAS_L0R_OLI_TELEMETRY telemetry_data_from_file[TELEM_REPEAT_COUNT];

    srand(time(NULL));

    memset(&telemetry_data, 0,
        sizeof(IAS_L0R_OLI_TELEMETRY)*TELEM_REPEAT_COUNT);
    memset(&telemetry_data_from_file, 0,
        sizeof(IAS_L0R_OLI_TELEMETRY)*TELEM_REPEAT_COUNT);

    for (repeat = 0; repeat < TELEM_REPEAT_COUNT; repeat++)
    {

        telemetry_data[repeat].oli_telemetry_header_3.
              l0r_time.days_from_J2000 = generate_signed_32_int();
        telemetry_data[repeat].oli_telemetry_header_3.
              l0r_time.seconds_of_day = generate_double();
        telemetry_data[repeat].oli_telemetry_header_3.
              days_orig = generate_signed_16_int();
        telemetry_data[repeat].oli_telemetry_header_3.
              milliseconds_orig = generate_signed_32_int();
        telemetry_data[repeat].oli_telemetry_header_3.
              microseconds_orig = generate_signed_16_int();
        telemetry_data[repeat].oli_telemetry_header_3.
              sync_word = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_3.
              id = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_3.
              stim_lamp_output_current_amps = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              stim_lamp_bulb_a_volts = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              stim_lamp_bulb_b_volts = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              stim_lamp_thermistor1_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              stim_lamp_thermistor2_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              stim_lamp_photodiode1_micro_amps = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              stim_lamp_photodiode2_micro_amps = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              focus_motor_lvdt[0] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              focus_motor_lvdt[1] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              focus_motor_lvdt[2] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              pos_z_minus_y_temp_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              bench_temps_celsius[0] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              bench_temps_celsius[1] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              bench_temps_celsius[2] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              bench_temps_celsius[3] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              bench_temps_celsius[4] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              bench_temps_celsius[5] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              bench_temps_celsius[6] = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              fpm_7_temp_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              calibration_assembly_a_temp_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              pos_z_pos_y_temp_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              tertiary_mirror_temp_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              fp_chassis_temp_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              pos_y_temp_celsius = generate_float();
        telemetry_data[repeat].oli_telemetry_header_3.
              fp_evap_temp_celsius =
              generate_float(); /* Focal Plane Assembly HP Evap Temperature */
        telemetry_data[repeat].oli_telemetry_header_3.
              fp_window_temp_celsius =
              generate_float(); /* Focal Plane Assembly Window Temperature */
        telemetry_data[repeat].oli_telemetry_header_3.
              minus_z_pos_y_temp_celsius =
              generate_float(); /* Minus Z/Minus Y Fitting Temperature */
        telemetry_data[repeat].oli_telemetry_header_3.
              minus_z_minus_y_temp_celsius =
              generate_float(); /* Minus Z/Minus Y Fitting Temperature */
        telemetry_data[repeat].oli_telemetry_header_3.
              minus_y_temp_celsius =
              generate_float(); /* Minus Y Fitting Temperature (baseplate) */
        telemetry_data[repeat].oli_telemetry_header_3.
              fpm_14_temp_celsius = generate_float();
               /* Focal Plane Module 14 Interface Temperature */
        telemetry_data[repeat].oli_telemetry_header_3.
              lvps_temp_celsius = generate_float();
        for(i = 0; i < IAS_L0R_OLI_TELEMETRY_GROUP_3_RESERVED; i++)
        {
           telemetry_data[repeat].oli_telemetry_header_3.
              reserved[i] = rand()%UINT8_MAX;
        }
        for(i = 0; i < IAS_L0R_OLI_TELEMETRY_GROUP_3_SPARE; i++)
        {
           telemetry_data[repeat].oli_telemetry_header_3.
              spare[i] = rand()%UINT8_MAX;
        }
        telemetry_data[repeat].oli_telemetry_header_3.warning_flag =
            rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              l0r_time.days_from_J2000 = generate_signed_32_int();
        telemetry_data[repeat].oli_telemetry_header_4.
              l0r_time.seconds_of_day = generate_double();
        telemetry_data[repeat].oli_telemetry_header_4.
              days_orig = generate_signed_16_int();
        telemetry_data[repeat].oli_telemetry_header_4.
              milliseconds_orig = generate_signed_16_int();
        telemetry_data[repeat].oli_telemetry_header_4.
              microseconds_orig = generate_signed_32_int();
        telemetry_data[repeat].oli_telemetry_header_4.
              sync_word = generate_signed_16_int();
        telemetry_data[repeat].oli_telemetry_header_4.id =
            rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              mech_command_reject_count =
                rand()%UINT8_MAX; /*Mechanism Control Command Rejected Count*/
        telemetry_data[repeat].oli_telemetry_header_4.
              mech_command_accept_count =
                rand()%UINT8_MAX; /*Mechanism Control Command Accept Counter */
        telemetry_data[repeat].oli_telemetry_header_4.shutter_active =
             rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              last_command_opcode =
            rand()%UINT8_MAX; /*Opcode of the last accepted_command */
        telemetry_data[repeat].oli_telemetry_header_4.
              diffuser_active = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.shutter_commanded_moves =
            rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              focus_motor_flags = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.diffuser_commanded_moves =
            rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              focus_motor_pulse_time_step_sec = generate_double();
        telemetry_data[repeat].oli_telemetry_header_4.
              focus_motor_pulse_length_sec = generate_double();
        telemetry_data[repeat].oli_telemetry_header_4.
              focus_motor_pulses =
            rand()%UINT16_MAX; /*The number of steps that will be used for a
            focus motor move*/
        telemetry_data[repeat].oli_telemetry_header_4.
              focus_mechanism_lvdt_relay_status = rand()%UINT8_MAX; 
        telemetry_data[repeat].oli_telemetry_header_4.
              focus_mechanism_motor_relay_status = rand()%UINT8_MAX; 
        telemetry_data[repeat].oli_telemetry_header_4.
              shutter_motor_pulse_length_sec = generate_double();
        telemetry_data[repeat].oli_telemetry_header_4.
              shutter_status_flags = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              diffuser_status_flags = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              shutter_motor_pulse_time_sec = generate_double();
         /*Time between shutter motor pulses  */
        telemetry_data[repeat].oli_telemetry_header_4.
              diffuser_motor_pulse_time_sec = generate_double();
         /*Time between diffuser motor pulses  */
        telemetry_data[repeat].oli_telemetry_header_4.
              diffuser_motor_pulse_length_sec = generate_double();
         /*Length of diffuser motor pulses*/
        telemetry_data[repeat].oli_telemetry_header_4.
              shutter_move_count =
            rand()%UINT16_MAX; /*The number of steps that will be used for a
            shutter motor move*/
        telemetry_data[repeat].oli_telemetry_header_4.
              shutter_resolver_position = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              diffuser_move_count =
            rand()%UINT16_MAX; /*The number of steps that will be used for a
            diffuser motor move*/
        telemetry_data[repeat].oli_telemetry_header_4.
              diffuser_resolver_position = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.
              diffuser_flags = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_4.stl_command_rejected_count
             = rand()%UINT8_MAX; /* stl_command_rejected_count */
        telemetry_data[repeat].oli_telemetry_header_4.stl_command_accepted_count
             = rand()%UINT8_MAX; /* stl_command_accepted_count */
        telemetry_data[repeat].oli_telemetry_header_4.stl_power_flags
             = rand()%UINT8_MAX; /* stl_power_flags */
        telemetry_data[repeat].oli_telemetry_header_4.stl_last_accepted_command
             = rand()%UINT8_MAX; /* stl_last_accepted_command */
        telemetry_data[repeat].oli_telemetry_header_4.stl_flags
             = rand()%UINT8_MAX; /* stl_flags */
        for(i = 0; i < IAS_L0R_OLI_TELEMETRY_GROUP_4_RESERVED; i++)
        {
           telemetry_data[repeat].oli_telemetry_header_4.
              reserved[i] = rand()%UINT8_MAX;
        }
        for(i = 0; i < IAS_L0R_OLI_TELEMETRY_GROUP_4_SPARE; i++)
        {
           telemetry_data[repeat].oli_telemetry_header_4.
              spare[i] = rand()%UINT8_MAX;
        }
        telemetry_data[repeat].oli_telemetry_header_4.warning_flag =
            rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
              l0r_time.days_from_J2000 = generate_signed_32_int();
        telemetry_data[repeat].oli_telemetry_header_5.
              l0r_time.seconds_of_day = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
              days_orig = generate_signed_16_int();
        telemetry_data[repeat].oli_telemetry_header_5.
              milliseconds_orig = generate_signed_32_int();
        telemetry_data[repeat].oli_telemetry_header_5.
              microseconds_orig = generate_signed_16_int();
        telemetry_data[repeat].oli_telemetry_header_5.
            sync_word = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            id = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            fpe_command_reject_count = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            fpe_command_accept_count = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            safe_mode_consecutive_requests = rand()%UINT8_MAX;
        /* Number of consecutive unacknowledged telemetry requests
            allowed before FSW transitions to safe mode.*/
        telemetry_data[repeat].oli_telemetry_header_5.
            last_command_opcode = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            single_bit_edac_errors_detected = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            consecutive_unacknowledged_requests = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            fpe_message_errors_detected = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            multi_bit_edac_errors_detected = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            messages_forwarded_to_fpe = rand()%UINT16_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            command_sequence_count = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            messages_reject_invalid_mode = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            fpe_telemetry_valid = rand()%UINT8_MAX;
        telemetry_data[repeat].oli_telemetry_header_5.
            dlvps_relay_pos_28vdc_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            dlvps_pos_5v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            dlvps_pos_15v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            dlvps_neg_15v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            dlvps_pos_3_3v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            alvps_hv_bias_pos_85v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            alvps_pos_12v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            alvps_pos_7_5v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            alvps_neg_2_5v_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            alvps_pos_12v_current_amps = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            alvps_pos_7_5v_current_amps = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            alvps_pos_2_5v_current_amps = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            lvps_temperature_sensor_celsius = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ctlr_temperature_sensor_celsius = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_temperature_sensor_celsius = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_1_temperature_sensor_celsius = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_0_vpa_bias_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_1_vpa_bias_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_2_vpa_bias_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_3_vpa_bias_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_4_vpa_bias_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_5_vpa_bias_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_6_vpa_bias_voltage = generate_double();
        telemetry_data[repeat].oli_telemetry_header_5.
            ana_0_ch_7_vpa_bias_voltage = generate_double();
        for(i = 0; i < IAS_L0R_OLI_TELEMETRY_GROUP_5_RESERVED; i++)
        {
           telemetry_data[repeat].oli_telemetry_header_5.reserved[i] =
             rand()%UINT8_MAX;
        }
        for(i = 0; i < IAS_L0R_OLI_TELEMETRY_GROUP_5_SPARE; i++)
        {
           telemetry_data[repeat].oli_telemetry_header_5.spare[i] =
               rand()%UINT8_MAX;
        }
        telemetry_data[repeat].oli_telemetry_header_5.warning_flag =
            rand()%UINT8_MAX;
    }

    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_ancillary(l0r_data, IAS_WRITE);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_open_ancillary failed");

    status = ias_l0r_set_ancillary_oli_telemetry(l0r_data, 0,
         TELEM_REPEAT_COUNT,
         telemetry_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_set_oli_telemetry failed");

    status = ias_l0r_get_ancillary_oli_telemetry(l0r_data,
         0, TELEM_REPEAT_COUNT, telemetry_data_from_file);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_get_ancillary_oli_telemetry failed");
   

    /* Verify that the values read from file match the values written */
    for (repeat = 0; repeat < TELEM_REPEAT_COUNT; repeat++)
    {
        status = ias_l0r_compare_ancillary_oli_telemetry(
            &(telemetry_data[repeat]),
            &(telemetry_data_from_file[repeat]), &different_elements_count);
        assert_true_with_message(status == SUCCESS,
           "ias_l0r_compare_ancillary_oli_telemetry failed");
        assert_true_with_message(different_elements_count == 0,
           "different_elements_count is %d for %d",
            different_elements_count, repeat);
    }

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_close failed");
}
static void test_tirs_telemetry_creation(void)
{
    int status = 0;
    int i = 0;
    int j = 0;
    int different_elements_count;
    int count;

    L0RIO *l0r_data = NULL;
    IAS_L0R_TIRS_TELEMETRY telemetry_data;
    IAS_L0R_TIRS_TELEMETRY telemetry_data_from_file;
    IAS_L0R_TIRS_SSM_ENCODER ssm_record;

    srand(time(NULL));

    memset(&telemetry_data, 0, sizeof(IAS_L0R_TIRS_TELEMETRY));
    memset(&telemetry_data_from_file, 0, sizeof(IAS_L0R_TIRS_TELEMETRY));

    telemetry_data.l0r_time.
        days_from_J2000 = generate_signed_32_int();
    telemetry_data.l0r_time.
        seconds_of_day = generate_double();
    telemetry_data.command.unaccepted_command_count = rand() % UINT8_MAX;
    telemetry_data.command.accepted_command_count = rand() % UINT8_MAX;
    telemetry_data.command.pulse_per_second_count = rand() % UINT8_MAX;
    telemetry_data.command.tod_command_counter = rand() % UINT8_MAX;
    telemetry_data.command.day = generate_signed_16_int();
    telemetry_data.command.millisecond = generate_signed_32_int();
    telemetry_data.command.mc_encoder_flags = rand() % UINT8_MAX;
    telemetry_data.command.science_data_frame_capture_count =
        rand() % UINT16_MAX;
    telemetry_data.command.science_acquisition_frame_rate = generate_float();
    telemetry_data.command.active_timing_table_pattern = rand() % UINT8_MAX;
    telemetry_data.command.mode_register = rand() % UINT16_MAX;
    for (i=0; i < IAS_L0R_TIRS_TELEMETRY_NUM_TIMING_TABLES; i++)
        telemetry_data.command.timing_table_pattern_id[i] = rand() % UINT8_MAX;
    telemetry_data.command.ssm_position_sel = rand() % UINT8_MAX;
    telemetry_data.command.ssm_mech_mode = rand() % UINT8_MAX;
    for (i=0; i < IAS_L0R_TIRS_TELEMETRY_SSM_ENCODER_POSITION_SAMPLE_COUNT; i++)
        telemetry_data.command.ssm_encoder_position_sample[i] =
            rand() % UINT32_MAX;
    telemetry_data.circuit.focal_plane_boards[0].vpe_sca_a_video_ref =
        generate_float();
    telemetry_data.circuit.focal_plane_boards[0].vpe_sca_b_video_ref =
        generate_float();
    telemetry_data.circuit.focal_plane_boards[0].vpe_sca_c_video_ref =
        generate_float();
    telemetry_data.circuit.focal_plane_boards[1].vpe_sca_a_video_ref =
        generate_float();
    telemetry_data.circuit.focal_plane_boards[1].vpe_sca_b_video_ref =
        generate_float();
    telemetry_data.circuit.focal_plane_boards[1].vpe_sca_c_video_ref =
        generate_float();

    telemetry_data.temperature.ssm_bearing_fwd_celsius = generate_float();
    telemetry_data.temperature.ssm_bearing_aft_celsius = generate_float();
    telemetry_data.temperature.optical_deck_celsius = generate_float();
    telemetry_data.temperature.
        structure_foot_a_neg_z_celsius = generate_float();
    telemetry_data.temperature.
        structure_nadir_aperture_celsius = generate_float();
    telemetry_data.temperature.
        structure_foot_c_pos_z_celsius = generate_float();
    telemetry_data.temperature.tcb_board_celsius = generate_float();
    telemetry_data.temperature.fpe1_fpe_a_asic_celsius = generate_float();
    telemetry_data.temperature.fpe2_fpe_b_asic_celsius = generate_float();
    telemetry_data.temperature.
        telescope_aft_barrel_pos_z_celsius = generate_float();
    telemetry_data.temperature.
        telescope_aft_barrel_neg_z_celsius = generate_float();
    telemetry_data.temperature.
        telescope_fwd_barrel_pos_z_celsius = generate_float();
    telemetry_data.temperature.
        telescope_fwd_barrel_neg_z_celsius = generate_float();
    telemetry_data.temperature.
        cryo_shroud_outer_at_tunnel_celsius = generate_float();
    telemetry_data.temperature.
        cryo_shroud_outer_flange_celsius = generate_float();
    for (i=0; i < IAS_L0R_TIRS_TELEMETRY_NUM_BLACK_BODY_TEMPS; i++)
        telemetry_data.temperature.
            blackbody_calibrator_celsius[i] = generate_float();
    telemetry_data.temperature.fp_f2_fine_sensor_1_celsius = generate_float();
    telemetry_data.temperature.fp_f6_fine_sensor_1_celsius = generate_float();
    telemetry_data.temperature.fp_f7_fine_sensor_2_celsius = generate_float();
    telemetry_data.temperature.fp_a_asic_celsius = generate_float();
    telemetry_data.temperature.fp_b_asic_celsius = generate_float();
    telemetry_data.temperature.telescope_stage_op2_a_celsius = generate_float();
    telemetry_data.temperature.telescope_aft_op3_a_celsius = generate_float();
    telemetry_data.temperature.telescope_fwd_op4_a_celsius = generate_float();
    telemetry_data.temperature.ssm_bh_op5_a_celsius = generate_float();
    telemetry_data.temperature.fp_op6_a_celsius = generate_float();
    telemetry_data.temperature.bbcal_op7_a_celsius = generate_float();
    telemetry_data.temperature.bbcal_supp_1_celsius = generate_float();
    telemetry_data.temperature.telescope_stage_op2_b_celsius = generate_float();
    telemetry_data.temperature.telescope_aft_op3_b_celsius = generate_float();
    telemetry_data.temperature.telescope_fwd_op4_b_celsius = generate_float();
    telemetry_data.temperature.ssm_bh_op5_b_celsius = generate_float();
    telemetry_data.temperature.fp_op6_b_celsius = generate_float();
    telemetry_data.temperature.bbcal_op7_b_celsius = generate_float();
    telemetry_data.temperature.
        ssm_encoder_remote_elec_celsius = generate_float();
    telemetry_data.temperature.ssm_motor_housing_celsius = generate_float();
    telemetry_data.temperature.
        ssm_enc_read_head_sensor_1_celsius = generate_float();
    telemetry_data.temperature.
        ssm_bearing_housing_d4_aft_hot_side_celsius = generate_float();
    telemetry_data.temperature.
        ssm_bearing_housing_d5_fwd_hot_side_celsius = generate_float();
    telemetry_data.temperature.
        ssm_bearing_housing_d6_aft_space_side_celsius = generate_float();
    telemetry_data.temperature.
        ssm_bearing_housing_d7_fwd_space_side_celsius = generate_float();
    telemetry_data.temperature.
        fixed_baff_nadir_aft_hot_corner_celsius = generate_float();
    telemetry_data.temperature.
        fixed_baff_nadir_fwd_hot_corner_celsius = generate_float();
    telemetry_data.temperature.
        fixed_baff_nadir_fwd_space_corner_celsius = generate_float();
    telemetry_data.temperature.
        fixed_baff_nadir_aft_space_corner_celsius = generate_float();
    telemetry_data.temperature.spare_4_thermistor_celsius = generate_float();
    telemetry_data.temperature.spare_5_thermistor_celsius = generate_float();
    telemetry_data.temperature.
        cryo_diode_t4_measured_celsius = generate_float();
    telemetry_data.temperature.
        cryo_diode_t3_measured_celsius = generate_float();
    telemetry_data.temperature.fp_f4_fine_sensor_3_celsius = generate_float();
    telemetry_data.temperature.
        cold_stage_heat_strap_cf_if_celsius = generate_float();

    for (i=0; i < IAS_L0R_TIRS_TELEMETRY_NUM_CIRCUIT_BOARDS; i++)
    {
        telemetry_data.circuit.focal_plane_boards[i].
            mon_pos_12v_volts = generate_float();
        for (j=0; j < IAS_L0R_TIRS_TELEMETRY_NUM_VPD_CURRENTS; j++)
           telemetry_data.circuit.focal_plane_boards[i].
               a_vpd_current_1_amps[j] = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            detector_substrate_conn_for_sca_a_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            detector_substrate_conn_for_sca_b_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            detector_substrate_conn_for_sca_c_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            digi_supply_mon_pos_5_5_for_sca_c_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            supply_mon_pos_5_5_for_sca_a_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            supply_mon_pos_5_5_for_sca_b_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            supply_mon_pos_5_5_for_sca_c_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            output_ref_level_mon_5_5_for_sca_c_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            supply_10v_for_sca_a_current_mon_amps = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            supply_10v_for_sca_b_current_mon_amps = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            supply_10v_for_sca_c_current_mon_amps = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            output_driver_pos_5_5_for_sca_c_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            output_ref_level_1_6_for_sca_c_roic_volts = generate_float();
        telemetry_data.circuit.focal_plane_boards[i].
            channel_ref_suppy_1_6_for_sca_c_roic_volts = generate_float();
    }
    telemetry_data.circuit.
        cosine_motor_drive_for_mce_current_amps = generate_float();
    telemetry_data.circuit.
        sine_motor_drive_for_mce_current_amps = generate_float();
    telemetry_data.circuit.
        cosine_dac_telemetry_for_mce_volts = generate_float();
    telemetry_data.circuit.sine_dac_telemetry_for_mce_volts = generate_float();
    telemetry_data.circuit.hsib_3_3_current_mon_amps = generate_float();
    telemetry_data.circuit.elec_enabled_flags = rand() % UINT8_MAX;


    for (i=0; i < IAS_L0R_TIRS_TELEMETRY_BLOCK_2_RESERVED; i++)
        telemetry_data.reserved_block_2[i] = rand() % UINT8_MAX;
    for (i=0; i < IAS_L0R_TIRS_TELEMETRY_BLOCK_3_RESERVED; i++)
        telemetry_data.reserved_block_3[i] = rand() % UINT8_MAX;
    for (i=0; i < IAS_L0R_TIRS_TELEMETRY_BLOCK_4_RESERVED; i++)
        telemetry_data.reserved_block_4[i] = rand() % UINT8_MAX;    
    telemetry_data.warning_flag = rand() % UINT8_MAX;

    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_ancillary(l0r_data, IAS_WRITE);
    assert_true_with_message(status == SUCCESS,
         "ias_l0r_open_ancillary failed");

    status = ias_l0r_set_ancillary_tirs_telemetry(l0r_data, 0, 1,
        &telemetry_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_set_tirs_telemetry failed");
   
    status = ias_l0r_get_ancillary_tirs_telemetry(l0r_data,
         0, 1, &telemetry_data_from_file);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_get_ancillary_tirs_telemetry failed");

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_tirs_telemetry(&telemetry_data,
        &telemetry_data_from_file, &different_elements_count);
    assert_true_with_message(status == SUCCESS,
       "ias_l0r_compare_ancillary_tirs_telemetry failed");
    assert_true_with_message(different_elements_count == 0,
        "different_elements_count is %d", different_elements_count);

    /* read the SSM information to confirm that routine returns the expected
       results */
    status = ias_l0r_get_ancillary_tirs_ssm_records_count(l0r_data, &count);
    assert_equal(status, SUCCESS);
    assert_equal(count, 1);
    status = ias_l0r_get_ancillary_tirs_ssm(l0r_data, 0, 1, &ssm_record);
    assert_equal(status, SUCCESS);
    assert_equal(ssm_record.l0r_time.days_from_J2000,
                 telemetry_data.l0r_time.days_from_J2000);
    assert_double_equal(ssm_record.l0r_time.seconds_of_day,
                 telemetry_data.l0r_time.seconds_of_day);
    for (i = 0; i < IAS_L0R_TIRS_TELEMETRY_SSM_ENCODER_POSITION_SAMPLE_COUNT;
            i++)
    {
        assert_equal(ssm_record.encoder_position[i],
            telemetry_data.command.ssm_encoder_position_sample[i]);
    }

    /* close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true_with_message(status == SUCCESS,
        "ias_l0r_close failed");
}

/**
*test_star_tracker_centroid_creation tests the creation of centroid L0R data
*
*Tests the creation of IAS_L0R_STAR_TRACKER_CENTROID
*data structures in L0R data by populating
*the structs with random data, writing the data to file, reading data from file
*into another structure, and comparing the two to verify the data is read as
*written.
*/
static void test_star_tracker_centroid_creation(void)
{
    int i = 0;
    int j = 0;
    const int repetitions = 91;
    int status;
    int different_elements_count;
    L0RIO *l0r_data = NULL;
    IAS_L0R_STAR_TRACKER_CENTROID centroid;
    IAS_L0R_STAR_TRACKER_CENTROID centroid_from_file;

    srand(time(NULL));

    for (j = 0; j < repetitions; j++)
    {
        memset(&centroid, 0, sizeof(IAS_L0R_STAR_TRACKER_CENTROID));
        memset(&centroid_from_file, 0, sizeof(IAS_L0R_STAR_TRACKER_CENTROID));
    
        centroid.quaternion_index = rand()%UINT16_MAX;

        for (i = 0 ; i < IAS_STAR_TRACKER_NUM_STARS; i++)
        {
            centroid.stars[i].valid = rand()%UINT8_MAX;
            centroid.stars[i].id = rand()%UINT16_MAX;
            centroid.stars[i].background_bias = rand()%UINT16_MAX;
            centroid.stars[i].intensity_mi = generate_float();
            centroid.stars[i].position_arcsec.x = generate_double();
            centroid.stars[i].position_arcsec.y = generate_double();
        }
        centroid.effective_focal_length = rand()%UINT16_MAX;
        centroid.warning_flag = rand()%UINT8_MAX;
    
        /* open access to L0R data */
        l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
        assert_true(l0r_data != NULL);
    
        ias_l0r_open_ancillary(l0r_data, IAS_WRITE);
     
        status = ias_l0r_set_ancillary_star_tracker_centroid(l0r_data,
                 0, 1, &centroid);
        assert_true_with_message(status == SUCCESS,
            "ias_l0r_set_ancillary_star_tracker_centroid failed");

     
        status = ias_l0r_get_ancillary_star_tracker_centroid(l0r_data,
                 0, 1, &centroid_from_file);
        assert_true_with_message(status == SUCCESS,
            "ias_l0r_get_ancillary_star_tracker_centroid failed");
     
        /* Verify that the values read from file match the values written */
        status = ias_l0r_compare_ancillary_star_tracker_centroid(&centroid,
            &centroid_from_file, &different_elements_count);
        assert_true_with_message(status == SUCCESS,
            "ias_l0r_compare_ancillary_star_tracker_centroid has failed");
        if (different_elements_count != 0)
        {
            assert_true_with_message(different_elements_count == 0,
                "ias_l0r_compare_ancillary_star_tracker_centroid"
                " shows different data");
            print_star_tracker_centroid(&centroid);
            print_star_tracker_centroid( &centroid_from_file);
        }

        /*close access to the L0R data */
        status = ias_l0r_close(l0r_data);
        assert_true_with_message(status == SUCCESS, "ias_l0r_close failed");
    }
}

static void test_star_tracker_quaternion_creation(void)
{
    int i = 0;
    int status = 0;
    int different_elements_count = 0;
    L0RIO *l0r_data = NULL;
    IAS_L0R_STAR_TRACKER_QUATERNION quaternion;
    IAS_L0R_STAR_TRACKER_QUATERNION quaternion_from_file;

    srand(time(NULL));

    memset(&quaternion, 0, sizeof(IAS_L0R_STAR_TRACKER_QUATERNION));
    memset(&quaternion_from_file, 0, sizeof(IAS_L0R_STAR_TRACKER_QUATERNION));

    /* Populate quaternion with random data */
    quaternion.quaternion_index = rand()%UINT16_MAX;
    quaternion.l0r_time.days_from_J2000 = generate_signed_32_int();
    quaternion.l0r_time.seconds_of_day = generate_double();
    quaternion.udl_time_sec_orig = generate_signed_32_int();
    quaternion.udl_time_subsec_orig = generate_signed_32_int();
    quaternion.sta_time_tag = generate_signed_32_int();
    quaternion.status_flags_1 = rand()%UINT8_MAX;
    quaternion.status_flags_2 = rand()%UINT8_MAX;
    quaternion.last_processed_command = rand()%UINT8_MAX;
    for(i = 0; i < IAS_L0R_STAR_TRACKER_NUM_VIRTUAL_STATES; i++)
    {
        quaternion.virtual_tracker_states[i] = rand()%UINT8_MAX;
    }
    quaternion.command_flags = rand()%UINT8_MAX;
    quaternion.time_message_value = rand()%UINT8_MAX;
    quaternion.camera_id = rand()%UINT8_MAX;
    quaternion.sw_version = rand()%UINT8_MAX;

    /* Populate the quaternion data with random data */
    quaternion.quaternion_seconds = generate_double();
    quaternion.quaternion_element_1 = generate_double();
    quaternion.quaternion_element_2 = generate_double();
    quaternion.quaternion_element_3 = generate_double();
    quaternion.quaternion_element_4 = generate_double();
    quaternion.loss_function_value = generate_double();
    for(i = 0; i < IAS_L0R_STAR_TRACKER_QUATERNION_RESERVED; i++)
    {
       quaternion.reserved[i] = rand()%UINT8_MAX;
    }
    quaternion.atm_frame_count = rand()%UINT16_MAX;
    quaternion.total_sa_writes = rand()%UINT8_MAX;
    quaternion.total_sa_reads = rand()%UINT8_MAX;
    quaternion.sa_15_writes = rand()%UINT8_MAX;
    quaternion.sa_15_reads = rand()%UINT8_MAX;
    quaternion.sa_26_writes = rand()%UINT8_MAX;
    quaternion.sa_29_reads = rand()%UINT8_MAX;
    quaternion.status_flags_3 = rand()%UINT8_MAX;
    quaternion.adm_separation_tolerance_arc_secs = rand()%UINT8_MAX;
    quaternion.adm_position_tolerance_arc_secs = rand()%UINT8_MAX;
    quaternion.adm_mag_tolerance = generate_float();
    quaternion.hot_pixel_count = rand()%UINT8_MAX;
    quaternion.hot_pixel_threshold = rand()%UINT8_MAX;
    quaternion.track_mode_pixel_threshold = rand()%UINT8_MAX;
    quaternion.acquisition_mode_pixel_threshold = rand()%UINT8_MAX;
    quaternion.tec_setpoint = generate_double();
    quaternion.boresight.x = generate_double(); 
    quaternion.boresight.y = generate_double();
    quaternion.ccd_temperature_celsius = generate_float();
    quaternion.lens_cell_temperature_celsius = generate_float();
    quaternion.warning_flag = rand()%UINT8_MAX;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    ias_l0r_open_ancillary(l0r_data, IAS_WRITE);

    status = ias_l0r_set_ancillary_star_tracker_quaternion(l0r_data,
         0, 1, &quaternion);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_star_tracker_quaternion(l0r_data, 0, 1,
        &quaternion_from_file);
    assert_true(status == SUCCESS);

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_star_tracker_quaternion(&quaternion,
        &quaternion_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    assert_true(different_elements_count == 0);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

static void test_temperature_gyro_creation(void)
{
    int i = 0;
    int status = 0;
    int different_elements_count = 0;
    L0RIO *l0r_data = NULL;
    IAS_L0R_GYRO_TEMPERATURE acs_temperatures;
    IAS_L0R_GYRO_TEMPERATURE acs_temperatures_from_file;

    srand(time(NULL));

    memset(&acs_temperatures, 0, sizeof(IAS_L0R_GYRO_TEMPERATURE));
    memset(&acs_temperatures_from_file, 0, sizeof(IAS_L0R_GYRO_TEMPERATURE));

    /* Populate quaternion with random data */
    acs_temperatures.l0r_time.days_from_J2000 = generate_signed_32_int();
    acs_temperatures.l0r_time.seconds_of_day = generate_double();
    for(i = 0; i < IAS_L0R_GYRO_TEMPERATURE_NUM_INDEXES; i++)
    {
        acs_temperatures.temperatures_celsius[i] = generate_float();
    }
    for(i = 0; i < IAS_L0R_GYRO_TEMPERATURE_RESERVED; i++)
    {
        acs_temperatures.reserved[i] = rand()%UINT8_MAX;
    }

    acs_temperatures.warning_flag = rand()%UINT8_MAX;


    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    ias_l0r_open_ancillary(l0r_data, IAS_WRITE);

    status = ias_l0r_set_ancillary_temperatures_gyro(l0r_data,
                                            0, 1, &acs_temperatures);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_gyro_temperature(l0r_data, 0, 1,
        &acs_temperatures_from_file);
    assert_true(status == SUCCESS);

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_gyro_temperature(&acs_temperatures,
        &acs_temperatures_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    assert_true(different_elements_count == 0);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

static void test_temperature_oli_tirs_creation(void)
{
    int i = 0;
    int status = 0;
    int different_elements_count = 0;
    L0RIO *l0r_data = NULL;
    IAS_L0R_OLI_TIRS_TEMPERATURE oli_tirs_temperatures;
    IAS_L0R_OLI_TIRS_TEMPERATURE oli_tirs_temperatures_from_file;

    srand(time(NULL));

    memset(&oli_tirs_temperatures, 0, sizeof(IAS_L0R_OLI_TIRS_TEMPERATURE));
    memset(&oli_tirs_temperatures_from_file, 0,
        sizeof(IAS_L0R_OLI_TIRS_TEMPERATURE));

    /* Populate quaternion with random data */
    oli_tirs_temperatures.l0r_time.days_from_J2000 = generate_signed_32_int();
    oli_tirs_temperatures.l0r_time.seconds_of_day = generate_double();
    for(i = 0; i < IAS_L0R_OLI_TIRS_TEMPERATURE_NUM_INDEXES; i++)
    {
        oli_tirs_temperatures.
            temperatures_celsius[i] = generate_float();
    }
    oli_tirs_temperatures.warning_flag = rand()%UINT8_MAX;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    ias_l0r_open_ancillary(l0r_data, IAS_WRITE);

    status = ias_l0r_set_ancillary_temperatures_oli_tirs(l0r_data,
                                0, 1, &oli_tirs_temperatures);
    assert_true(status == SUCCESS);

    status = ias_l0r_get_ancillary_oli_tirs_temperature(l0r_data, 0, 1,
        &oli_tirs_temperatures_from_file);
    assert_true(status == SUCCESS);

    /* Verify that the values read from file match the values written */
    status = ias_l0r_compare_ancillary_oli_tirs_temperature(
        &oli_tirs_temperatures,
        &oli_tirs_temperatures_from_file, &different_elements_count);
    assert_true(status == SUCCESS);
    assert_true(different_elements_count == 0);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

int main(int argc, char **argv)
{
    int status = 0;

    status = ias_log_initialize("L0R ANC Test");
    if (status == ERROR)
    {
        IAS_LOG_ERROR("Error encountered when initializing the ias logging "
            "library");
        return ERROR;
    }
    if (ias_sat_attr_initialize(IAS_L8) != SUCCESS)
    {
        IAS_LOG_ERROR("Error initializing attributes");
        return ERROR;
    }
    ias_log_set_output_level(IAS_LOG_LEVEL_ERROR);

    TestSuite *suite = create_test_suite();
    TestReporter *reporter = create_text_reporter();

    if (suite == NULL || reporter == NULL)
    {
        return ERROR;
    }

    add_test(suite, test_attitude_creation);
    add_test(suite, test_attitude_filter_states_creation);
    add_test(suite, test_copy_functionality);
    add_test(suite, test_ephemeris_creation);
    add_test(suite, test_gps_creation);
    add_test(suite, test_gps_range_creation);
    add_test(suite, test_imu_creation);
    add_test(suite, test_imu_latency_creation);
    add_test(suite, test_oli_telemetry_creation);
    add_test(suite, test_tirs_telemetry_creation);
    add_test(suite, test_star_tracker_centroid_creation);
    add_test(suite, test_star_tracker_quaternion_creation);
    add_test(suite, test_temperature_gyro_creation);
    add_test(suite, test_temperature_oli_tirs_creation);
  
    return run_test_suite(suite, reporter);
}
