#include <string.h>
#include <stdio.h>
#include <sys/stat.h>
#include <time.h>

#include "ias_logging.h"
#include "ias_l0r.h"
#include "ias_satellite_attributes.h"
#include "cgreen/cgreen.h"


static void test_l0r_create_oli_header(void)
{
    const int test_iterations = 99; /* number of test loops to run */
    const int lines_to_write = 4; /* number of lines that will be written to */
    int i = 0; /* loop index */
    int j = 0; /* loop index */
    int write_line = 0; /* the current line to perform a write to */
    int status = ERROR; /* SUCCESS/ERROR status from library routine execution*/

    IAS_L0R_OLI_IMAGE_HEADER image_header;
    IAS_L0R_OLI_IMAGE_HEADER image_header_from_file;
    IAS_L0R_OLI_FRAME_HEADER frame_header;
    IAS_L0R_OLI_FRAME_HEADER frame_header_from_file;
    L0RIO *l0r_data;
  
    srand(time(NULL));

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_header(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);

    /* No files should exist for the data yet */
    if(ias_l0r_present("./test") == TRUE)
    {
        assert_true(system("rm ./test*.h5") == 0);
    }

    for (j = 0; j < test_iterations; j++)
    {
        /* pick the line to write to at random */
        write_line = rand()%lines_to_write;

        memset(&image_header, 0, sizeof(IAS_L0R_OLI_IMAGE_HEADER));
        memset(&image_header_from_file, 0, sizeof(IAS_L0R_OLI_IMAGE_HEADER));
        memset(&frame_header, 0, sizeof(IAS_L0R_OLI_FRAME_HEADER));
        memset(&frame_header_from_file, 0, sizeof(IAS_L0R_OLI_FRAME_HEADER));

        /* Fill the structures with random data */
        image_header.frame_header.frame_number = rand()%UINT32_MAX;
        image_header.frame_header.l0r_time.days_from_J2000 = rand()%INT32_MAX;
        image_header.frame_header.l0r_time.seconds_of_day =
              (rand()%UINT32_MAX) / ((rand()%UINT16_MAX) + 1);
        image_header.frame_header.day = rand()%INT16_MAX;
        image_header.frame_header.milliseconds = rand()%INT32_MAX;
        image_header.frame_header.microseconds = rand()%INT16_MAX;
        image_header.frame_header.blind_data_included_in_frame =
            rand()%UINT8_MAX;
        image_header.frame_header.time_error = rand()%UINT8_MAX;
        for (i = 0; i <IAS_L0R_FRAME_HEADER_RESERVED_LENGTH; i++)
        {
            image_header.frame_header.reserved[i] = rand()%UINT8_MAX;
        }
        image_header.frame_header.frame_status = rand()%UINT16_MAX;
        image_header.length_of_image = rand()%UINT32_MAX;
        image_header.image_content_definition = rand()%UINT32_MAX;
        image_header.ms_integration_time = rand()%UINT16_MAX;
        image_header.pan_integration_time = rand()%UINT16_MAX;
        image_header.ms_data_word = rand()%UINT32_MAX;
        image_header.pan_data_word = rand()%UINT32_MAX;
        image_header.extended_integration_flag = rand()%UINT8_MAX;
        image_header.blind_band_record_rate = rand()%UINT8_MAX;
        image_header.test_pattern_setting = rand()%UINT8_MAX;
        image_header.current_detector_select_table = rand()%UINT8_MAX;
        for (i = 0; i <IAS_L0R_IMAGE_HEADER_RESERVED_LENGTH_1; i++)
        {
            image_header.reserved_1[i] = rand()%UINT8_MAX;
        }
        image_header.detector_select_table_id_number = rand()%UINT32_MAX;
        image_header.image_data_truncation_setting = rand()%UINT8_MAX;
        for (i = 0; i <IAS_L0R_IMAGE_HEADER_RESERVED_LENGTH_2; i++)
        {
            image_header.reserved_2[i] = rand()%UINT8_MAX;
        }
   
        frame_header.frame_number = rand()%UINT32_MAX;
        frame_header.l0r_time.days_from_J2000 = rand()%INT32_MAX;
        frame_header.l0r_time.seconds_of_day =
              (rand()%UINT32_MAX) / ((rand()%UINT16_MAX) + 1);
        frame_header.day = rand()%INT16_MAX;
        frame_header.milliseconds = rand()%INT32_MAX;
        frame_header.microseconds = rand()%INT16_MAX;
        frame_header.blind_data_included_in_frame = rand()%UINT8_MAX;
        frame_header.time_error = rand()%UINT8_MAX;
        for (i = 0; i <IAS_L0R_FRAME_HEADER_RESERVED_LENGTH; i++)
        {
            frame_header.reserved[i] = rand()%UINT8_MAX;
        }
        frame_header.frame_status = rand()%UINT16_MAX;
    
        status = ias_l0r_set_oli_image_header(l0r_data, &image_header);
        assert_true(status == SUCCESS);
    
        status = ias_l0r_get_oli_image_header(l0r_data,
            &image_header_from_file);
        assert_true(status == SUCCESS);

        /* Compare the contents of the frame header written and read in */
        assert_true(memcmp(&image_header, &image_header_from_file,
            sizeof(IAS_L0R_OLI_IMAGE_HEADER)) == 0);

        /* Perform different OLI frame header operations randomly */
        switch(rand()%2)
        {
            case 0:
                status = ias_l0r_append_oli_frame_headers(l0r_data, 1,
                    &frame_header);
                assert_true(status == SUCCESS);
            break;
            case 1: /* Test the ability to write and read frame headers */
                status = ias_l0r_set_oli_frame_headers(l0r_data, write_line,
                    1, &frame_header);
                assert_true(status == SUCCESS);
                /* Read the data in from file to another structure */
                status = ias_l0r_get_oli_frame_headers(l0r_data, write_line,
                    1, &frame_header_from_file);
                assert_true(status == SUCCESS);
                /* Verify the memory is identical for data written/read */
                assert_true(memcmp(&frame_header, &frame_header_from_file,
                    sizeof(IAS_L0R_OLI_FRAME_HEADER)) == 0);
            break;
            default:
                IAS_LOG_ERROR("Error in testing logic.");
        }
     
    }
 
    /* We should have an ANC file created at this point */
    assert_true(ias_l0r_present("./test") == TRUE);

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

static void test_l0r_create_tirs_header(void)
{
    const int test_iterations = 99; /* number of test loops to run */
    const int lines_to_write = 4; /* number of lines that will be written to */
    int i = 0; /* loop index */
    int j = 0; /* loop index */
    int k = 0; /* loop index */
    int iterations = 0; 
    int write_line = 0; /* the current line to perform a write to */
    int status = ERROR; /* SUCCESS/ERROR status from library routine execution*/
    int table_size = 0;

    IAS_L0R_TIRS_FRAME_HEADER frame_header;
    IAS_L0R_TIRS_FRAME_HEADER frame_header_from_file;
    L0RIO *l0r_data;

    srand(time(NULL));

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_header(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);

    for (iterations = 0; iterations < test_iterations; iterations += 1)
    {
        /* clear the data in the structure */
        memset(&frame_header,0,sizeof(frame_header));
        memset(&frame_header_from_file,0,sizeof(frame_header_from_file));

        /* pick the line to write to at random */
        write_line = rand()%lines_to_write;

        frame_header.l0r_time.days_from_J2000 = rand()%INT32_MAX;
        frame_header.l0r_time.seconds_of_day =
                (rand()%UINT32_MAX) / ((rand()%UINT16_MAX) + 1);
        frame_header.day = rand()%INT16_MAX;
        frame_header.milliseconds = rand()%INT32_MAX;
        frame_header.microseconds = rand()%INT16_MAX;
        frame_header.frame_number = rand()%UINT32_MAX;
        frame_header.sync_byte = rand() % UINT8_MAX;
        frame_header.reserved = rand() % UINT8_MAX;
        frame_header.data_set_type = rand() % UINT8_MAX;
        frame_header.integration_duration = 
            (rand()%UINT32_MAX) / ((rand()%UINT16_MAX) + 1);
        frame_header.total_frames_requested = rand() % UINT32_MAX;
        /* NOTE: Rather than cycling through each element of the 3-D arrays
            with 3 separate for loops,  I set the first 2 elements to 0,
            basically allowing me to treat them as 1-D arrays */
        for (i = 0; i < IAS_L0R_TIRS_NUM_BANDS; i++)
        {
            for (j = 0; j < IAS_L0R_TIRS_NUM_SCAS; j++)
            {
                for (k = 0; k < IAS_L0R_TIRS_NUM_ROWS; k++)
                    frame_header.row_offset[i][j][k] = rand()%UINT8_MAX;
            }
        }

        for (i = 0; i < IAS_L0R_TIRS_NUM_BANDS; i++)
        {
            frame_header.d_header[i].sync_byte = rand() % UINT16_MAX;
            frame_header.d_header[i].reserved_1 = rand() % UINT16_MAX;
            frame_header.d_header[i].reserved_2 = rand() % UINT16_MAX;
        }

        for (i = 0; i < IAS_L0R_TIRS_NUM_BANDS; i+=1)
        {
            for (j = 0; j < IAS_L0R_TIRS_NUM_SCAS; j+=1)
            {
                for (k = 0; k < IAS_L0R_TIRS_NUM_ROWS; k+=1) 
                {
                    frame_header.fpe_words[i][j][k].start_code = 
                        rand() % UINT16_MAX;
                    frame_header.fpe_words[i][j][k].block_length = 
                        rand() % UINT16_MAX;
                    frame_header.fpe_words[i][j][k].protocol_id = 
                        rand() % UINT8_MAX;
                    frame_header.fpe_words[i][j][k].frame_count = 
                        rand() % UINT8_MAX;
                    frame_header.fpe_words[i][j][k].detector_sync_a = 
                        rand() % UINT16_MAX;
                    frame_header.fpe_words[i][j][k].detector_sync_b = 
                        rand() % UINT16_MAX;
                    frame_header.fpe_words[i][j][k].detector_sync_c = 
                        rand() % UINT16_MAX;
                    frame_header.fpe_words[i][j][k].reserved = 
                        rand() % UINT16_MAX;
                }
            }
        }

        frame_header.frame_status = rand()%UINT16_MAX;
        frame_header.roic_crc_status_blind = rand()%UINT8_MAX;
        frame_header.roic_crc_status_10_8 = rand()%UINT8_MAX;
        frame_header.roic_crc_status_12 = rand()%UINT8_MAX;

        /* Randomly switch between writes and appends  */
        switch( rand()%2 )
        {
            case 0:
            status = ias_l0r_set_tirs_frame_headers(l0r_data, write_line, 1,
                &frame_header);
            assert_true_with_message(status == SUCCESS,
                "Unable to write header on line %d", write_line);
        
            status = ias_l0r_get_tirs_frame_headers(l0r_data, write_line, 1,
                &frame_header_from_file);
            assert_true_with_message(status == SUCCESS,
                "Unable to read header on line %d", write_line);
            
            /* Verify the memory is identical for data written/read */
            status = memcmp(&frame_header, &frame_header_from_file,
                sizeof(IAS_L0R_TIRS_FRAME_HEADER));
            assert_true_with_message(status == 0, "The result of memcmp %d",
                status);
            break;
            case 1:
            status = ias_l0r_get_tirs_frame_headers_records_count(l0r_data,
                &table_size);
            assert_true_with_message(status == SUCCESS,
                "Unable to get line size");

            status = ias_l0r_append_tirs_frame_headers(l0r_data, 1,
                &frame_header);
            assert_true_with_message(status == SUCCESS,
                "Unable to append header on line %d", table_size);
         
            status = ias_l0r_get_tirs_frame_headers(l0r_data, table_size, 1,
                &frame_header_from_file);
            assert_true_with_message(status == SUCCESS,
                "Unable to read header on line %d", table_size);
             
            /* Verify the memory is identical for data written/read */
            status = memcmp(&frame_header, &frame_header_from_file,
                sizeof(IAS_L0R_TIRS_FRAME_HEADER));
            assert_true_with_message(status == 0, "The result of memcmp %d",
                status);
            break;
            default:
                assert_true_with_message(0==1, "Problem with test logic.");
        }
    }

    /*close access to the L0R data */
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
}

static void test_l0r_truncate_oli_header(void)
{
    int status = ERROR; /* SUCCESS/ERROR status from library routine execution*/
   	int size = 0;
    int size_2 = 0;

    IAS_L0R_OLI_FRAME_HEADER *frame_headers;
    L0RIO *l0r_data;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_header(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);
    
	status = ias_l0r_get_oli_frame_headers_records_count(l0r_data, &size);
    assert_true(status == SUCCESS);
    
    frame_headers = calloc(size, sizeof(IAS_L0R_OLI_FRAME_HEADER));
    assert_true(frame_headers != NULL);

    /* store the headers so we can write them back after truncation */
	status = ias_l0r_get_oli_frame_headers(l0r_data, 0, size,
		frame_headers); 
    assert_true(status == SUCCESS);
    
    status = ias_l0r_truncate_oli_frame_headers(l0r_data, 0);
 
    /*Close and open file to ensure file is flushed */
    status = ias_l0r_close_header(l0r_data);
    assert_true(status == SUCCESS);
    status = ias_l0r_open_header(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);
    
    /* Check the truncate worked */
    status = ias_l0r_get_oli_frame_headers_records_count(l0r_data, &size_2);
    assert_true(size_2 == 0);
    
    /* Write the stored headers back to the file */
    status = ias_l0r_set_oli_frame_headers(l0r_data, 0, size,
    	frame_headers);

    /*close access to the L0R data */
    status = ias_l0r_close_header(l0r_data);
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
    free(frame_headers);
}

static void test_l0r_truncate_tirs_header(void)
{
    int status = ERROR; /* SUCCESS/ERROR status from library routine execution*/
   	int size = 0;
    int size_2 = 0;

    IAS_L0R_TIRS_FRAME_HEADER *frame_headers;
    L0RIO *l0r_data;

    /* open access to L0R data */
    l0r_data = ias_l0r_open("test", "./", IAS_L0R_COMPRESSION_ON);
    assert_true(l0r_data != NULL);

    status = ias_l0r_open_header(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);
    
	status = ias_l0r_get_tirs_frame_headers_records_count(l0r_data, &size);
    assert_true(status == SUCCESS);
    
    frame_headers = calloc(size, sizeof(IAS_L0R_TIRS_FRAME_HEADER));
    assert_true(frame_headers != NULL);

    /* store the headers so we can write them back after truncation */
	status = ias_l0r_get_tirs_frame_headers(l0r_data, 0, size,
		frame_headers); 
    assert_true(status == SUCCESS);
    
    status = ias_l0r_truncate_tirs_frame_headers(l0r_data, 0);
 
    /*Close and open file to ensure file is flushed */
    status = ias_l0r_close_header(l0r_data);
    assert_true(status == SUCCESS);
    status = ias_l0r_open_header(l0r_data, IAS_WRITE);
    assert_true(status == SUCCESS);
    
    /* Check the truncate worked */
    status = ias_l0r_get_tirs_frame_headers_records_count(l0r_data, &size_2);
    assert_true(size_2 == 0);
    
    /* Write the stored headers back to the file */
    status = ias_l0r_set_tirs_frame_headers(l0r_data, 0, size,
    	frame_headers);

    /*close access to the L0R data */
    status = ias_l0r_close_header(l0r_data);
    status = ias_l0r_close(l0r_data);
    assert_true(status == SUCCESS);
    free(frame_headers);
}

int main(int argc, char **argv)
{
    TestSuite *suite = create_test_suite();
    TestReporter *reporter = create_text_reporter();
    int status = 0;

    status = ias_log_initialize("L0R Header Test");
    if (status == ERROR)
    {
        IAS_LOG_ERROR("Error encountered when initializing the ias logging "
            "library");
        return ERROR;
    }
    if (ias_sat_attr_initialize(IAS_L8) != SUCCESS)
    {
        IAS_LOG_ERROR("Error initializing attributes");
        return ERROR;
    }
    ias_log_set_output_level(IAS_LOG_LEVEL_ERROR);

    add_test(suite, test_l0r_create_oli_header);
    add_test(suite, test_l0r_create_tirs_header);
    add_test(suite, test_l0r_truncate_oli_header);
    add_test(suite, test_l0r_truncate_tirs_header);

    return run_test_suite(suite, reporter);
}
