/************************************************************************

 NAME:             IAS ANCILLARY_ALLOCATION_TESTS

 PURPOSE:  Use CGreen to perform unit testing on the allocation routines
           in the Ancillary IO Library

*************************************************************************/
#include "ias_logging.h"
#include "cgreen.h"

#include "../ias_ancillary_io.h"


Ensure test_ias_ancillary_attitude_allocate()
{
    IAS_ANC_ATTITUDE_DATA *attitude_data;

    int nrecords_0 = 0;
    int nrecords_good = 5;
    int nrecords_bad  = -2;


    printf("Testing attitude data buffer allocation...\n");

    /* Turn off ERROR logging */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);

    /* Test the 0-record allocation */
    attitude_data = ias_ancillary_allocate_attitude(nrecords_0);
    assert_equal_with_message(attitude_data, NULL, "Attitude data buffer "
        "should be NULL");

    /* Now test the "valid" record allocation */
    attitude_data = ias_ancillary_allocate_attitude(nrecords_good);
    assert_not_equal_with_message(attitude_data, NULL, "Attitude data "
        "buffer should have been allocated");
    if (attitude_data == NULL)
        return;

    /* Free the good allocation, and reset the pointer to NULL */
    ias_ancillary_free_attitude(attitude_data);
    attitude_data = NULL;

    /* Test the "bad" record allocation */
    attitude_data = ias_ancillary_allocate_attitude(nrecords_bad);
    assert_equal_with_message(attitude_data, NULL, "Attitude data buffer "
        "should not have been allocated");

    /* Restore logging */
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}



Ensure test_ias_ancillary_ephemeris_allocate()
{
    IAS_ANC_EPHEMERIS_DATA *ephemeris_data;

    int nrecords_0 = 0;
    int nrecords_good = 5;
    int nrecords_bad  = -2;


    printf("Testing ephemeris data buffer allocation...\n");

    /* Turn off ERROR logging */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);

    /* Test the 0-record allocation first */
    ephemeris_data = ias_ancillary_allocate_ephemeris(nrecords_0);
    assert_equal_with_message(ephemeris_data, NULL, "Ephemeris data buffer "
       "should be NULL");

    /* Test the "valid" record allocation */
    ephemeris_data = ias_ancillary_allocate_ephemeris(nrecords_good);
    assert_not_equal_with_message(ephemeris_data, NULL, "Ephemeris data "
        "buffer should have been allocated");
    if (ephemeris_data == NULL)
        return;

    /* Free the good allocation, and reset the pointer to NULL */
    ias_ancillary_free_ephemeris(ephemeris_data);
    ephemeris_data = NULL;

    /* Test the "bad" record allocation */
    assert_true(ephemeris_data == NULL);
    ephemeris_data = ias_ancillary_allocate_ephemeris(nrecords_bad);
    assert_equal_with_message(ephemeris_data, NULL, "Ephemeris data buffer "
        "should not have been allocated");

    /* Restore logging */
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}



/************************************************************************
             MAIN "DRIVER"
*************************************************************************/
int main(int argc, char **argv)
{
    /* Build the test suite */
    TestSuite *suite = create_test_suite();
    add_test(suite, test_ias_ancillary_attitude_allocate);
    add_test(suite, test_ias_ancillary_ephemeris_allocate);

    /* Run the test(s) */
    if (argc > 1)
    {
        return run_single_test(suite, argv[1],  create_text_reporter());
    }

    return run_test_suite(suite, create_text_reporter());
}
