#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>
#include <math.h>

#include "lablib3.h"
#include "ias_satellite_attributes.h"
#include "ias_cpf.h"
#include "ias_odl.h"
#include "ias_logging.h"
#include "cgreen/cgreen.h"

/* Opens a CPF file in the IAS unit test library. */
struct IAS_CPF *open_cpf_by_filename
(
    const char *filename
)
{
    char fname_path[PATH_MAX];
    const char *test_data_dir;

    struct IAS_CPF *cpf;

    if (ias_sat_attr_initialize(IAS_L8) != SUCCESS)
    {
        IAS_LOG_ERROR("Error initializing L8 attributes");
        return NULL;
    }

    test_data_dir = getenv("IAS_UNIT_TEST_DATA_DIR");
    assert_true(test_data_dir != NULL);

    /* build cpf file name and path */

    snprintf(fname_path, sizeof(fname_path),
        "%s/ias_lib/cpf/%s", test_data_dir, filename);
    cpf = ias_cpf_read(fname_path);

    return cpf;
};
struct IAS_CPF *open_cpf()
{
    return open_cpf_by_filename("LC08CPF_20090101_20090331_01.99");
};
Ensure test_read_histogram_char();
Ensure test_read_los_model_correction();
Ensure test_read_file_attributes();
Ensure test_read_tirs_det_status_blind();
Ensure test_read_det_offsets();
Ensure test_read_tirs_det_response();
Ensure test_read_tirs_det_response_blind();
Ensure test_read_earth_const();
Ensure test_read_abs_gains();
Ensure test_read_tirs_abs_gains_blind();
Ensure test_read_ancil_qa_thresh();
Ensure test_read_ancil_conv();
Ensure test_read_attitude();
Ensure test_read_oli_b2b();
Ensure test_read_det_noise();
Ensure test_read_det_status();
Ensure test_read_diffuser_rad();
Ensure test_read_focal_plane();
Ensure test_read_nonuniformity();
Ensure test_read_focal_plane_cal();
Ensure test_read_gcp_corr();
Ensure test_read_geo_sys();
Ensure test_read_i2i();
Ensure test_read_rel_gains();
Ensure test_read_pre_rel_gains();
Ensure test_read_post_rel_gains();
Ensure test_read_tirs_rel_gains_blind();
Ensure test_read_tirs_pre_rel_gains_blind();
Ensure test_read_tirs_post_rel_gains_blind();
Ensure test_read_sat_level();
Ensure test_read_reflect_conv();
Ensure test_read_temp_sens();
Ensure test_read_oli_params();
Ensure test_read_tirs_params();
Ensure test_read_tirs_align_cal();
Ensure test_read_impulse_noise();
Ensure test_read_orbit();
Ensure test_read_sca_parms();
Ensure test_read_lamp_rad();
Ensure test_read_lunar_irrad();
Ensure test_read_radiance_rescale();
Ensure test_read_tirs_thermal_constants();
Ensure test_read_ut1_times();
Ensure test_read_detector_bias();
Ensure test_read_sort_earth_const();
Ensure test_read_cc_assessment();
Ensure test_framing_parameters();

/* main */
int main(int argc, char **argv)
{
    int status;

    TestSuite *suite = create_test_suite();

    add_test(suite, test_read_histogram_char);
    add_test(suite, test_read_los_model_correction);
    add_test(suite, test_read_tirs_det_status_blind);
    add_test(suite, test_read_tirs_det_response_blind);
    add_test(suite, test_read_tirs_det_response);
    add_test(suite, test_read_detector_bias);
    add_test(suite, test_read_tirs_abs_gains_blind);
    add_test(suite, test_read_oli_params);
    add_test(suite, test_read_tirs_params);
    add_test(suite, test_read_tirs_align_cal);
    add_test(suite, test_read_temp_sens);
    add_test(suite, test_read_ut1_times);
    add_test(suite, test_read_radiance_rescale);
    add_test(suite, test_read_tirs_thermal_constants);
    add_test(suite, test_read_lunar_irrad);
    add_test(suite, test_read_lamp_rad);
    add_test(suite, test_read_sca_parms);
    add_test(suite, test_read_orbit);
    add_test(suite, test_read_impulse_noise);
    add_test(suite, test_read_reflect_conv);
    add_test(suite, test_read_sat_level);
    add_test(suite, test_read_pre_rel_gains);
    add_test(suite, test_read_post_rel_gains);
    add_test(suite, test_read_rel_gains);
    add_test(suite, test_read_tirs_rel_gains_blind);
    add_test(suite, test_read_tirs_pre_rel_gains_blind);
    add_test(suite, test_read_tirs_post_rel_gains_blind);
    add_test(suite, test_read_i2i);
    add_test(suite, test_read_oli_b2b);
    add_test(suite, test_read_abs_gains);
    add_test(suite, test_read_geo_sys);
    add_test(suite, test_read_gcp_corr);
    add_test(suite, test_read_focal_plane);
    add_test(suite, test_read_focal_plane_cal);
    add_test(suite, test_read_nonuniformity);
    add_test(suite, test_read_det_status);
    add_test(suite, test_read_file_attributes); 
    add_test(suite, test_read_det_noise);
    add_test(suite, test_read_diffuser_rad);
    add_test(suite, test_read_attitude);
    add_test(suite, test_read_ancil_conv);
    add_test(suite, test_read_ancil_qa_thresh);
    add_test(suite, test_read_det_offsets);
    add_test(suite, test_read_cc_assessment);
    add_test(suite, test_read_earth_const);
    add_test(suite, test_read_sort_earth_const);
    add_test(suite, test_framing_parameters);

    if (argc > 1) {
        return run_single_test(suite, argv[1], create_text_reporter());
    }

    status = run_test_suite(suite, create_text_reporter());

    return status; 

} /* end of main */

Ensure test_read_cc_assessment()
{
    int i = 0;
    double cirrus_threshold[] = {0, 0, 1000, 0.02};
    double minimum_sun_elevation_degrees = 0.0;
    IAS_CPF *cpf;
    const struct IAS_CPF_CLOUD_COVER_ASSESSMENT *cc_assessment;

    printf("Test cloud cover assessment ........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;
    cc_assessment = ias_cpf_get_cloud_cover_assessment(cpf);
    assert_true(cc_assessment != NULL);
    if (cc_assessment == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }
    for (i = 0; i < IAS_CPF_CIRRUS_THRESHOLD_SIZE; i++)
    {
        assert_double_equal(cc_assessment->cirrus_threshold[i], 
            cirrus_threshold[i]);
    }
    assert_double_equal(cc_assessment->minimum_sun_elevation_degrees, 
        minimum_sun_elevation_degrees);

    /* free memory */
    ias_cpf_free(cpf);
}

Ensure test_read_histogram_char()
{
    int frames_top = 1;
    int frames_bottom = 2;

    IAS_CPF *cpf;
    const struct IAS_CPF_HISTOGRAM_CHAR *histogram_char;

    printf("Test histogram characterization ........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    histogram_char = ias_cpf_get_histogram_char(cpf);
    assert_true(histogram_char != NULL);

    if (histogram_char == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    assert_equal(histogram_char->frames_to_skip_top, frames_top);
    assert_equal(histogram_char->frames_to_skip_bottom, frames_bottom);

    /* free memory */
    ias_cpf_free(cpf);
}

Ensure test_read_los_model_correction()
{
    double attitude_apri[] = {1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 700.0, 800.0, 
        900.0, 5.1, 5.2, 5.3};
    double ephemeris_apri[] = {1.1, 2.1, 3.1, 4.1, 5.1, 6.1, 700.1, 800.1, 
        900.1, 5.4, 5.5, 5.6};
    double doq_observation_apri[] = {5.8, 5.9};
    double gls_observation_apri[] = {10.8, 10.9};

    int i; /* loop counter */

    IAS_CPF *cpf;
    const struct IAS_CPF_LOS_MODEL_CORRECTION *los_model_correction;

    printf("Test los model correction ........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    los_model_correction = ias_cpf_get_los_model_correction(cpf);
    assert_true(los_model_correction != NULL);
    if (los_model_correction == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 12; i++)
    {
        assert_double_equal(los_model_correction->attitude_apri[i],
                            attitude_apri[i]);
        assert_double_equal(los_model_correction->ephemeris_apri[i],
                            ephemeris_apri[i]);
    }

    for (i = 0; i < 2; i++)
    {
        assert_double_equal(los_model_correction->doq_observation_apri[i],
            doq_observation_apri[i]);
        assert_double_equal(los_model_correction->gls_observation_apri[i],
            gls_observation_apri[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
}

Ensure test_read_tirs_det_status_blind()
{
    int inopb15_count[] = {1, 0, 1};
    int inopb15s1[] = {20};
    int inopb15s2[] = {0};
    int inopb15s3[] = {640};
    int oosb15_count[] = {1, 0, 1};
    int oosb15s1[] = {1};
    int oosb15s2[] = {0};
    int oosb15s3[] = {640};

    int i;
    IAS_CPF *cpf;
    const struct IAS_CPF_DETECTOR_STATUS *tirs_det_status_blind;

    printf("Test tirs detector status blind band ........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_det_status_blind = ias_cpf_get_tirs_det_status_blind(cpf);
    assert_true(tirs_det_status_blind != NULL);
    if (tirs_det_status_blind == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 3; i++)
    {
       assert_equal(tirs_det_status_blind->inoperable_count[0][i], 
                    inopb15_count[i]);
       assert_equal(tirs_det_status_blind->out_of_spec_count[0][i], 
                    oosb15_count[i]);
    }
    assert_equal(tirs_det_status_blind->inoperable[0][0][0], inopb15s1[0]);
    assert_equal(tirs_det_status_blind->inoperable[0][1][0], inopb15s2[0]);
    assert_equal(tirs_det_status_blind->inoperable[0][2][0], inopb15s3[0]);
    assert_equal(tirs_det_status_blind->out_of_spec[0][0][0], oosb15s1[0]);
    assert_equal(tirs_det_status_blind->out_of_spec[0][1][0], oosb15s2[0]);
    assert_equal(tirs_det_status_blind->out_of_spec[0][2][0], oosb15s3[0]);

    /* free memory */
    ias_cpf_free(cpf);

} /* end of test read tirs det status blind band */

Ensure test_read_tirs_det_response_blind()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_TIRS_DETECTOR_RESPONSE *tirs_det_response_blind;

    printf("Test tirs detector response blind band ........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_det_response_blind = ias_cpf_get_tirs_det_response_blind(cpf);
    assert_true(tirs_det_response_blind != NULL);
    if (tirs_det_response_blind == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    /* background response response data tests */
    /* band 10 sca 1 first and last bucket */
    assert_double_equal(tirs_det_response_blind
                    ->background_response[0][0][0], 0.006805);
    assert_double_equal(tirs_det_response_blind
                    ->background_response[0][0][639], -0.035156);
    /* band 10 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response_blind
                    ->background_response[0][2][0], 0.054855);
    assert_double_equal(tirs_det_response_blind
                    ->background_response[0][2][639], 0.054749);

    /* gain function offset data tests */
    /* band 10 sca 1 first and last bucket */
    assert_double_equal(tirs_det_response_blind
                    ->gain_offsets[0][0][0], 0.000000);
    assert_double_equal(tirs_det_response_blind
                    ->gain_offsets[0][0][639], 0.000000);
    /* band 10 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response_blind
                    ->gain_offsets[0][2][0], 0.000000);
    assert_double_equal(tirs_det_response_blind
                    ->gain_offsets[0][2][639], 0.000000);

    /* baseline dark response data tests */
    /* band 15 sca 1 first and last bucket */
    assert_double_equal(tirs_det_response_blind
                    ->baseline_dark_response[0][0][0], 260.709198);
    assert_double_equal(tirs_det_response_blind
                    ->baseline_dark_response[0][0][639], 259.739166);
    /* band 15 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response_blind
                    ->baseline_dark_response[0][2][0], 200.581146);
    assert_double_equal(tirs_det_response_blind
                    ->baseline_dark_response[0][2][639], 211.549255);

    /* free memory */
    ias_cpf_free(cpf);
}

Ensure test_read_tirs_det_response()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_TIRS_DETECTOR_RESPONSE *tirs_det_response;
    double blackbody_thermistor_weights[] = {1.0, 0.0, 0.0, 0.0};
    int i;

    printf("Test tirs detector response ........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_det_response = ias_cpf_get_tirs_det_response(cpf);
    assert_true(tirs_det_response != NULL);
    if (tirs_det_response == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    /* background response data tests */
    /* band 10 sca 1 first and last bucket */
    assert_double_equal(tirs_det_response->background_response[0][0][0], 
        814.977966);
    assert_double_equal(tirs_det_response->background_response[0][0][639], 
        858.618713);
    /* band 10 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response->background_response[0][2][0], 
        584.532715);
    assert_double_equal(tirs_det_response->background_response[0][2][639], 
        620.449463);
    /* band 11 sca 1 first and last buckets */
    assert_double_equal(tirs_det_response->background_response[1][0][0], 
       812.403625);
    assert_double_equal(tirs_det_response->background_response[1][0][639], 
       855.367676);
    /* band 11 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response->background_response[1][2][0], 
        610.796631);
    assert_double_equal(tirs_det_response->background_response[1][2][639], 
        622.883850);
    
    /* gain function offset data tests */
    /* band 10 sca 1 first and last bucket */
    assert_double_equal(tirs_det_response->gain_offsets[0][0][0], 
        -627.543300);
    assert_double_equal(tirs_det_response->gain_offsets[0][0][639], 
        -725.305800);
    /* band 10 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response->gain_offsets[0][2][0], 
        -643.604000);
    assert_double_equal(tirs_det_response->gain_offsets[0][2][639], 
        -655.806100);
    /* band 11 sca 1 first and last buckets */
    assert_double_equal(tirs_det_response->gain_offsets[1][0][0], 
        -1145.363000);
    assert_double_equal(tirs_det_response->gain_offsets[1][0][639], 
        -1148.544000);
    /* band 11 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response->gain_offsets[1][2][0], 
        -1114.268000);
    assert_double_equal(tirs_det_response->gain_offsets[1][2][639], 
        -1134.076000);
    
    /* baseline dark response data tests */
    /* band 10 sca 1 first and last bucket */
    assert_double_equal(tirs_det_response->baseline_dark_response[0][0][0], 
        256.341980);
    assert_double_equal(tirs_det_response->baseline_dark_response[0][0][639], 
        257.469299);
    /* band 10 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response->baseline_dark_response[0][2][0], 
        200.449310);
    assert_double_equal(tirs_det_response->baseline_dark_response[0][2][639], 
        209.964539);
    /* band 11 sca 1 first and last buckets */
    assert_double_equal(tirs_det_response->baseline_dark_response[1][0][0], 
        254.158386);
    assert_double_equal(tirs_det_response->baseline_dark_response[1][0][639], 
        256.334351);
    /* band 11 sca 3 first and last buckets */
    assert_double_equal(tirs_det_response->baseline_dark_response[1][2][0], 
        200.383392);
    assert_double_equal(tirs_det_response->baseline_dark_response[1][2][639], 
        209.172180);

    for (i = 0; i < 4; i++)
    {
        assert_double_equal(tirs_det_response->blackbody_thermistor_weights[i],
                blackbody_thermistor_weights[i]);
    }
    /* free memory */
    ias_cpf_free(cpf);
}

Ensure test_read_tirs_align_cal()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_TIRS_ALIGN_CAL *align_cal;


    printf("Test tirs align cal ........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    align_cal = ias_cpf_get_tirs_align_cal(cpf);
    assert_true(align_cal != NULL);
    if (align_cal == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }
    
    assert_equal(align_cal->corr_window_size[0], 32);
    assert_equal(align_cal->corr_window_size[1], 32);
    assert_double_equal(align_cal->min_corr_strength, 3.00);
    assert_double_equal(align_cal->max_displacement_offset, 3.00);
    assert_double_equal(align_cal->fill_threshold, 0.1);
    assert_double_equal(align_cal->tie_point_weight, 0.14);
    assert_double_equal(align_cal->align_constraint_weight,1.0);
    assert_double_equal(align_cal->along_postfit_rmse_threshold, 50.0);
    assert_double_equal(align_cal->across_postfit_rmse_threshold, 50.0);
    assert_equal(align_cal->corr_fit_method, 1);
    assert_equal(align_cal->fit_order, 3);

    ias_cpf_free(cpf);
}/* end of align call */

Ensure test_read_detector_bias()
{
    int i;
    IAS_CPF *cpf;
    const struct IAS_CPF_AVERAGE_BIAS *oli_avg_bias;

    double avgbias_odd_b8s1[] 
        = {1104.920000,1104.910000,1104.900000,1104.890000};
    /* last 4 values of the band */
    double lastavgbias_odd_b8s1[] 
        = {1095.080000,1095.070000,1095.060000,1095.050000};

    printf("Test oli average bias ......\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    oli_avg_bias = ias_cpf_get_oli_avg_bias(cpf);
    assert_true(oli_avg_bias != NULL);

    if (oli_avg_bias != NULL)
    {
        /* check the first 4 values */
        for (i = 0; i < 4; i++)
        {
            /* band 8 sca 1 */
            assert_double_equal(oli_avg_bias->bias_odd_pan[0][i], 
                            avgbias_odd_b8s1[i]);
            assert_double_equal(oli_avg_bias->bias_odd_pan[0][i+984], 
                            lastavgbias_odd_b8s1[i]);
        }

        ias_cpf_free(cpf);
    } /* end of tests */


} /* end of test detector bias */

Ensure test_read_tirs_abs_gains_blind()
{
    int i;
    IAS_CPF *cpf;
    const struct IAS_CPF_ABSOLUTE_GAINS *tirs_abs_gains_blind;

    /* band 1 values */
    double gainb1[] = {-1.1E-06,-1.2E-06,-1.3E-06};
    printf("Test tirs abs gains blind band ......\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_abs_gains_blind = ias_cpf_get_tirs_abs_gains_blind(cpf);
    assert_true(tirs_abs_gains_blind != NULL);

    if (tirs_abs_gains_blind != NULL)
    {
        for (i = 0; i < 3; i++)  /* loop throught the scas */
            assert_double_equal(tirs_abs_gains_blind->gain[0][i], gainb1[i]); 
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read tirs abs gains blind band */

Ensure test_read_ut1_times()
{
    int i;

    int yrs[] = {2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 2008, 
    2008, 2008, 2008, 2008, 2008};
    
    double utc[] = {-0.39408, -0.39578, -0.39762, -0.39947, -0.40115, -0.40258, 
    -0.40367, -0.40456, -0.40542, -0.40636, -0.40749, -0.40888, 
    -0.41047, -0.41214, -0.41381, -0.41541, -0.41683, -0.41802, 
    -0.41902, -0.41981, -0.42037, -0.42076, -0.42104, -0.42133, 
    -0.42173, -0.4223, -0.42307, -0.42403, -0.42513, -0.42636, 
    -0.4276, -0.42873, -0.42968, -0.43034, -0.43078, -0.4311, 
    -0.43143, -0.4319, -0.43254, -0.43332, -0.43428, -0.4353, 
    -0.43619, -0.43685, -0.43731, -0.43757, -0.43766, -0.43761, 
    -0.43745, -0.43725, -0.43708, -0.43702, -0.43712, -0.43739, 
    -0.43785, -0.4385, -0.43925, -0.44001, -0.44067, -0.44114, 
    -0.44136, -0.44134, -0.44116, -0.44097, -0.44091, -0.44107, 
    -0.44147, -0.44205, -0.4427, -0.44332, -0.44381, -0.44412, 
    -0.44423, -0.44415, -0.4439, -0.44353, -0.4431, -0.44268, 
    -0.44235, -0.44218, -0.4422, -0.44241, -0.44279, -0.44326, 
    -0.44374, -0.44411, -0.44429, -0.44424, -0.44397, -0.44354, 
    -0.44308, -0.44272, -0.44256, -0.44266, -0.44298, -0.44342, 
    -0.44386, -0.4442, -0.44435, -0.44429, -0.44403, -0.44358, 
    -0.44301, -0.44238, -0.44176, -0.44123, -0.44087, -0.44071, 
    -0.4408, -0.44111, -0.44157, -0.4421, -0.44258, -0.44291, 
    -0.44303, -0.44295, -0.44271, -0.44243, -0.44224, -0.44225, 
    -0.44251, -0.44304, -0.44376, -0.44457, -0.44535, -0.446, 
    -0.44647, -0.44674, -0.44684, -0.44681, -0.4467, -0.44661, 
    -0.44659, -0.44673, -0.44709, -0.4477, -0.44856, -0.44962, 
    -0.4508, -0.45196, -0.453, -0.45383, -0.45441, -0.45481, 
    -0.45511, -0.45545, -0.45594, -0.45665, -0.4576, -0.45875, 
    -0.46002, -0.46131, -0.46252, -0.46356, -0.4644, -0.46506, 
    -0.46555, -0.46595, -0.46632, -0.46674, -0.46727, -0.46797, 
    -0.4689, -0.47007, -0.47146, -0.473, -0.47459, -0.4761, 
    -0.47741, -0.47847, -0.47929, -0.47997, -0.48063, -0.48141, 
    -0.48238, -0.48357, -0.48494, -0.48641, -0.4879, -0.48931};

    IAS_CPF *cpf;
    const struct IAS_CPF_UT1_TIME_PARAMETERS *ut1_times;

    printf("Test UT1 Time  read.....\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    ut1_times = ias_cpf_get_ut1_times(cpf);
    assert_true(ut1_times != NULL);
    if (ut1_times == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < IAS_UT1_PERIOD; i++)
    {
        assert_equal(ut1_times->ut1_year[i], yrs[i]);
        assert_double_equal(ut1_times->ut1_utc[i], utc[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read ut1 times */

Ensure test_read_radiance_rescale()
{
    int i;

    double rrb[] = {0.000000, 0.000000, 0.000000, 0.000000, 0.000000,  
    0.000000,  0.000000, 0.000000,  0.000000, 0.000000, 0.000000};
    double rrg[] = {1.000000, 1.000000, 1.000000, 1.000000, 1.000000,  
    1.000000,  1.000000, 1.000000,  1.000000, 1.000000, 1.000000};

    IAS_CPF *cpf;
    const struct IAS_CPF_RADIANCE_RESCALE *radiance_rescale;

    printf("Test radiance rescale read.....\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    radiance_rescale = ias_cpf_get_radiance_rescale(cpf);
    assert_true_with_message(radiance_rescale != NULL, "Get oli rad rescale");
    if (radiance_rescale == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 11; i++)
    {
        assert_double_equal(radiance_rescale->bias[i], rrb[i]);
        assert_double_equal(radiance_rescale->gain[i], rrg[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read radiance rescale */

Ensure test_read_tirs_thermal_constants()
{
    int i;

    double k1[] = {666.09, 697.56};
    double k2[] = {1282.71, 1282.71};

    IAS_CPF *cpf;
    const struct IAS_CPF_TIRS_THERMAL_CONSTANTS *tirs_thermal_constants;

    printf("Test tirs thermal constants read.....\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_thermal_constants = ias_cpf_get_tirs_thermal_constants(cpf);
    assert_true_with_message(tirs_thermal_constants != NULL, 
                             "Get tirs thermal constants");
    if (tirs_thermal_constants == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 2; i++)
    {
        assert_double_equal(tirs_thermal_constants->k1_constant[i], k1[i]);
        assert_double_equal(tirs_thermal_constants->k2_constant[i], k2[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read thermal constants */

Ensure test_read_lunar_irrad()
{
    int i;

    int median_filter_size = 5;
    double irradiance_conversion[] = {1.81077e-05, 1.81077e-05, 1.81077e-05, 
           1.81077e-05, 1.81077e-05, 1.81077e-05, 1.81077e-05, 4.52694e-06, 
           1.81077e-05};
    double itf[] = {0.08, 0.08, 0.08, 0.08,0.08, 0.08, 0.08, 0.08, 0.08};

    IAS_CPF *cpf;
    const struct IAS_CPF_LUNAR_IRRADIANCE *lunar_irrad;

    printf("Test lunar irradiance read.....\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    lunar_irrad = ias_cpf_get_lunar_irradiance(cpf);
    assert_true(lunar_irrad != NULL);
    if (lunar_irrad == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    assert_equal(lunar_irrad->median_filter_size, median_filter_size);
    for (i = 0; i < 9; i++)
    {
        assert_double_equal(lunar_irrad->irradiance_conversion[i],
                            irradiance_conversion[i]);
        assert_double_equal(lunar_irrad->integration_threshold_factor[i],
                            itf[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read lunar irrad */

Ensure test_read_lamp_rad()
{
    int i;

    /* effective rad backup bands 1 & 9, scas 1 & 14  first and last 12 */
    double erbb1s1[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                        1.000,  1.000,  1.000,  1.000,  1.000};
    /* band 8 first and last 12 detectors */
    double erbb8s1[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                        1.000,  1.000,  1.000,  1.000,  1.000};
    double erbb8s14[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                        1.000,  1.000,  1.000,  1.000,  1.000};
    /* band 9 sca 14 last 12 detectors */                    
    double erbb9s14[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                         1.000,  1.000,  1.000,  1.000,  1.000};

    /* effective rad pristine bands 1 & 9, scas 1 & 14  first and last 12 */
    double erpb1s1[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                        1.000,  1.000,  1.000,  1.000,  1.000};
    double erpb9s14[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                         1.000,  1.000,  1.000,  1.000,  1.000};

    /* effective rad working bands 1 & 9, scas 1 & 14  first and last 12 */
    double erwb1s1[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                        1.000,  1.000,  1.000,  1.000,  1.000};
    double erwb9s14[] = {1.000, 1.000, 1.000, 1.000, 1.000,  1.000,  1.000,  
                         1.000,  1.000,  1.000,  1.000,  1.000};

    IAS_CPF *cpf;
    const struct IAS_CPF_LAMP_RADIANCE *lamp_rad;

    printf("Test lamp radiance read.....\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    lamp_rad = ias_cpf_get_lamp_radiance(cpf);
    assert_true(lamp_rad != NULL);
    if (lamp_rad == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 12; i++)
    {
        /* effective rad backup tests */
        assert_double_equal(lamp_rad->effective_rad_backup[0][0][i], 
                            erbb1s1[i]);
        assert_double_equal(lamp_rad->effective_rad_backup[8][13][i+482], 
                            erbb9s14[i]);

        /* effective rad backup band 8 sca 1 first & sca 14last 12 detectors */
        assert_double_equal(lamp_rad->effective_rad_backup[7][0][i], 
                            erbb8s1[i]);
        assert_double_equal(lamp_rad->effective_rad_backup[7][13][i+976], 
                            erbb8s14[i]);

        /* effective rad pristine tests */
        assert_double_equal(lamp_rad->effective_rad_pristine[0][0][i], 
                            erpb1s1[i]);
        assert_double_equal(lamp_rad->effective_rad_pristine[8][13][i+482], 
                            erpb9s14[i]);

        /* effective rad working tests */
        assert_double_equal(lamp_rad->effective_rad_working[0][0][i], 
                            erwb1s1[i]);
        assert_double_equal(lamp_rad->effective_rad_working[8][13][i+482], 
                            erwb9s14[i]);

    }

    /* free memory */
    ias_cpf_free(cpf);
}
Ensure test_read_sca_parms()
{
    int i;

    double discontinuity_b1[] 
        = {1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.1};
    double discontinuity_b5[] 
        = {5.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5};
    double discontinuity_b9[] 
        = {9.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.9};

    double discontinuity_b10[] = {10.0, 0.10};
    double discontinuity_b11[] = {11.0, 0.11};

    /* These arrays hold both the oli and tirs test data (9 + 2) */
    double sca_overlap_threshold[]
                = {0.02, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.03, 0.02, 0.03};
    double stripe_co[] 
                = {2.2, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.2, 2.2, 0.2};
    int valid_corr_shift[] 
                = {3, 0, 0, 0, 0, 0, 2, 1, 0, 3, 1};
    int valid_neighbor_seg[] = {4, 0, 0, 0, 0, 0, 0, 0, 4, 4, 4};

    IAS_CPF *cpf;
    const struct IAS_CPF_SCA_PARAMETERS *sca;

    printf("Test OLI sca parameter read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    sca = ias_cpf_get_sca_parameters(cpf);
    assert_true(sca != NULL);
    if (sca == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 13; i++)
    {
        assert_double_equal(sca->discontinuity_ratio[0][i], 
                            discontinuity_b1[i]);
        assert_double_equal(sca->discontinuity_ratio[4][i], 
                            discontinuity_b5[i]);
        assert_double_equal(sca->discontinuity_ratio[8][i], 
                            discontinuity_b9[i]);
    }

    for (i = 0; i < 2; i++)
    {
        assert_double_equal(sca->discontinuity_ratio[9][i], 
                            discontinuity_b10[i]);
        assert_double_equal(sca->discontinuity_ratio[10][i], 
                            discontinuity_b11[i]);
    }

    /* This loop checks both the oli and tirs test data (9 + 2) */
    for (i = 0; i < 11; i++)
    {
        assert_double_equal(sca->stripe_cutoff[i], stripe_co[i]);
        assert_equal(sca->max_valid_correlation_shift[i], valid_corr_shift[i]);
        assert_equal(sca->min_valid_neighbor_segments[i], 
                     valid_neighbor_seg[i]);
        assert_double_equal(sca->sca_overlap_threshold[i],
                                 sca_overlap_threshold[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
}

Ensure test_read_orbit()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_ORBIT_PARAMETERS *orbit;

    printf("Test orbit parameter read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    orbit = ias_cpf_get_orbit(cpf);
    assert_true(orbit != NULL);
    if (orbit == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    assert_string_equal(orbit->launch_date, "2012-12-01T12:13:14");
    assert_equal(orbit->wrs_cycle_days, 16);
    assert_equal(orbit->wrs_cycle_orbits, 233);
    assert_equal(orbit->scenes_per_orbit, 248);
    assert_double_equal(orbit->orbital_period, 5907.437694);
    assert_double_equal(orbit->nominal_angular_momentum, 53058266910.0);
    assert_double_equal(orbit->nominal_orbit_radius, 7063.046473);
    assert_double_equal(orbit->semi_major_axis, 7063.050267);
    assert_double_equal(orbit->semi_minor_axis, 7063.04268);
    assert_double_equal(orbit->eccentricity, 0.001335);
    assert_double_equal(orbit->inclination_angle, 98.123559);
    assert_double_equal(orbit->argument_of_perigee, 90);
    assert_equal(orbit->descending_node_row, 60);
    assert_double_equal(orbit->long_path1_row60, -64.6);
    assert_double_equal(orbit->nodal_regression_rate, 0.985647366);
    assert_string_equal(orbit->descending_node_time_min, "09:45");
    assert_string_equal(orbit->descending_node_time_max, "10:15");

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read orbit */

Ensure test_read_impulse_noise()
{
    int i;                                  /* loop counter */

    int inlimit[] = {1, 2, 2, 2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 1,
                     1, 2, 2, 2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 1};
    int mfw[] = {1, 3, 3, 3, 3, 3, 3, 3, 1, 3, 3, 3, 3, 3, 1,
                 1, 3, 3, 3, 3, 3, 3, 3, 1, 3, 3, 3, 3, 3, 1};

    IAS_CPF *cpf;
    const struct IAS_CPF_IMPULSE_NOISE *impulse_noise;

    printf("Test impulse noise read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    impulse_noise = ias_cpf_get_impulse_noise(cpf);
    assert_true(impulse_noise != NULL);

    if (impulse_noise != NULL)
    {
       for (i = 0; i < IAS_MAX_TOTAL_BANDS; i++)
       {
            assert_equal(impulse_noise->in_limit[i], inlimit[i]);
            assert_equal(impulse_noise->median_filter_width[i], mfw[i]);
       }
    }
    else
        printf("Read impulse noise returned NULL...\n");

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read impulse noise */

Ensure test_read_oli_params()
{
    int i;
    
    int vrps[] = {12, 12, 12, 12, 12, 12, 12, 24, 12};

    IAS_CPF *cpf;
    const struct IAS_CPF_OLI_PARAMETERS *oli_parameters;

    printf("Test oli parameters read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    oli_parameters = ias_cpf_get_oli_parameters(cpf);
    assert_true(oli_parameters != NULL);
    if (oli_parameters == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 9; i++)
    {
        assert_equal(oli_parameters->vrp_count[i], vrps[i]);
    }

    assert_equal(oli_parameters->band_count, 9);
    assert_equal(oli_parameters->sca_count, 14);
    assert_double_equal(oli_parameters->nominal_frame_time, 4.236000);
    assert_double_equal(oli_parameters->nominal_integration_time_ms, 3.600);
    assert_double_equal(oli_parameters->nominal_integration_time_pan, 0.660);
    assert_double_equal(oli_parameters->integration_time_tolerance, 0.010);
    assert_double_equal(oli_parameters->integration_time_scale, 1.0E-6);
    assert_double_equal(oli_parameters->along_ifov_ms, 4.26E-05);
    assert_double_equal(oli_parameters->across_ifov_ms, 4.26E-05);
    assert_double_equal(oli_parameters->along_ifov_pan, 2.125E-05);
    assert_double_equal(oli_parameters->across_ifov_pan, 2.125E-05);
    assert_double_equal(oli_parameters->detector_settling_time_ms, .010);
    assert_double_equal(oli_parameters->detector_settling_time_pan, .010);
    assert_double_equal(oli_parameters->rollover_error_tolerance, 0.5E-03);
    assert_double_equal(oli_parameters->frame_time_fill_offset_tolerance, 
                        2.0E-06);
    assert_double_equal(oli_parameters->frame_time_clock_drift_tolerance, 
                        5.0E-05);
    
    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read oli parms  */

Ensure test_read_tirs_params()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_TIRS_PARAMETERS *tirs_parameters;

    double mirror_angle = 0.78539816339745;
    double mirror_angle_deviation = 0.0;
    double encoder_origin_side_a = 0.0;
    double encoder_origin_side_b = 6.207109447;
    double encoder_time_offset = 0.0;
    double tele_roll = 0.0;
    double tele_pitch = 0.0;
    double tele_yaw = 0.0;
    double ssm_tol = 2.0E-05;
    double along_ifov = 1.4184E-04;
    double across_ifov = 1.4184E-04;

    printf("Test tirs parameters read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_parameters = ias_cpf_get_tirs_parameters(cpf);
    assert_true(tirs_parameters != NULL);
    if (tirs_parameters == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    assert_double_equal(tirs_parameters->nominal_frame_time, 14.286);
    assert_double_equal(tirs_parameters->nominal_integration_time, 2.0); 
    assert_double_equal(tirs_parameters->integration_time_tolerance, 0.010);
    assert_double_equal(tirs_parameters->integration_time_scale, 40.0E-06);
    assert_double_equal(tirs_parameters->ssm_mirror_angle, mirror_angle);
    assert_double_equal(tirs_parameters->ssm_mirror_angle_deviation,
            mirror_angle_deviation);
    assert_double_equal(tirs_parameters->ssm_encoder_origin_side_a,
            encoder_origin_side_a);
    assert_double_equal(tirs_parameters->ssm_encoder_origin_side_b,
            encoder_origin_side_b);
    assert_double_equal(tirs_parameters->ssm_encoder_time_offset, 
            encoder_time_offset);
    assert_double_equal(tirs_parameters->ssm_telescope_roll_offset, tele_roll);
    assert_double_equal(tirs_parameters->ssm_telescope_pitch_offset,
            tele_pitch);
    assert_double_equal(tirs_parameters->ssm_telescope_yaw_offset, tele_yaw);
    assert_double_equal(tirs_parameters->ssm_tolerance, ssm_tol);
    assert_double_equal(tirs_parameters->along_ifov_thermal, along_ifov);
    assert_double_equal(tirs_parameters->across_ifov_thermal, across_ifov);
    assert_double_equal(tirs_parameters->frame_time_fill_offset_tolerance, 
            2.0E-06);
    assert_double_equal(tirs_parameters->frame_time_clock_drift_tolerance, 
            5.0E-05);

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read tirs params */

Ensure test_read_temp_sens()
{
    int i;

    double temp_sensb1s1[] = {0.100000, 0.200000, 0.300000, 0.400000};
    double temp_sensb9s14[] = {0.491000, 0.492000, 0.493000, 0.494000};
    double temp_sensb10s2[] = {0.491000, 0.492000, 0.493000, 0.494000};

    IAS_CPF *cpf;
    const struct IAS_CPF_TEMP_SENSITIVITY *temp_sens;

    printf("Test temperature sensitivity read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    temp_sens = ias_cpf_get_temp_sensitivity(cpf);
    assert_true(temp_sens != NULL);
    if (temp_sens == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    assert_double_equal(temp_sens->oli_reference_temp, -0.01);
    assert_double_equal(temp_sens->tirs_reference_temp, -0.01);
    assert_equal(temp_sens->oli_thermistor_flag[1], 1);
    assert_equal(temp_sens->tirs_thermistor_flag[1], 1);
    for (i = 0; i < 4; i++)
    {
        assert_double_equal(temp_sens->temp_sensitivity_coeff[0][0][i],
                            temp_sensb1s1[i]);
        assert_double_equal(temp_sens->temp_sensitivity_coeff[8][13][i+490],
                            temp_sensb9s14[i]);
        assert_double_equal(temp_sens->temp_sensitivity_coeff[9][1][i+636],
                            temp_sensb10s2[i]);
    }
    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read temp sens */

Ensure test_read_reflect_conv()
{
    int i;

    double rc_coeff[] = {0.100, 0.010, 0.001, 0.100,  0.010,  0.001,  
    0.100,  0.010, 0.001};

    IAS_CPF *cpf;
    const struct IAS_CPF_REFLECTANCE_CONVERSION *reflect_conv;

    printf("Test reflectance conversin level read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    reflect_conv = ias_cpf_get_reflect_conv(cpf);
    assert_true(reflect_conv != NULL);
    if (reflect_conv == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    for (i = 0; i < 9; i++)
    {
        assert_double_equal(reflect_conv->reflect_conv_coeff[i], rc_coeff[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read reflect conv */

Ensure test_read_sat_level()
{
    int i;

    /* analog low sat level */
    /* oli first 4 detectors */
    int start_analog_low_satb1s1[] = {1, 2, 3, 4};
    int start_analog_low_satb1s2[] = {9, 10, 11, 12};
    int start_analog_low_satb8s1[] = {17, 18, 19, 20};
    int start_analog_low_satb9s14[] = {25, 26, 27, 28};

    /* oli last 4 detectors */
    int end_analog_low_satb1s1[] = {5, 6, 7, 8};
    int end_analog_low_satb1s2[] = {13, 14, 15, 16};
    int end_analog_low_satb8s1[] = {21, 22, 23, 24};
    int end_analog_low_satb9s14[] = {29, 30, 31, 32};

    /* tirs first 4 detectors */
    int start_analog_low_satb10s1[] = {33, 34, 35, 36};
    int start_analog_low_satb10s3[] = {57, 58, 59, 60};
    int start_analog_low_satb11s1[] = {41, 42, 43, 44};
    int start_analog_low_satb11s3[] = {49, 50, 51, 52};

    /* tirs last 4 detectors */
    int end_analog_low_satb10s1[] = {37, 38, 39, 40};
    int end_analog_low_satb10s3[] = {61, 62, 63, 64};
    int end_analog_low_satb11s1[] = {45, 46, 47, 48};
    int end_analog_low_satb11s3[] = {53, 54, 55, 56};

     /* analog high sat level last 4 values */
    /* oli first 4 detectors */
    int start_analog_high_satb1s14[] = {4001, 4002, 4003, 4004};
    int start_analog_high_satb2s1[] = {4009, 4010, 4011, 4012};
    int start_analog_high_satb8s1[] = {4017, 4018, 4019, 4020};
    int start_analog_high_satb9s14[] = {4025, 4026, 4027, 4028};

    /* oli last 4 detectors */
    int end_analog_high_satb1s14[] = {4005, 4006, 4007, 4008};
    int end_analog_high_satb2s1[] = {4013, 4014, 4015, 4016};
    int end_analog_high_satb8s1[] = {4021, 4022, 4023, 4024};
    int end_analog_high_satb9s14[] = {4029, 4030, 4031, 4032};

    /* tirs first 4 detectors */
    int start_analog_high_satb10s1[] = {4033, 4034, 4035, 4036};
    int start_analog_high_satb11s1[] = {4041, 4042, 4043, 4044};
    int start_analog_high_satb11s3[] = {4049, 4050, 4051, 4052};

    /* tirs last 4 detectors */
    int end_analog_high_satb10s1[] = {4037, 4038, 4039, 4040};
    int end_analog_high_satb11s1[] = {4045, 4046, 4047, 4048};
    int end_analog_high_satb11s3[] = {4053, 4054, 4055, 4056};

    /* digital low/high sat level band 1 sca 1 and band 9 sca 14 */
    /* oli first 4 detectors */
    int start_digital_low_satb1s1[] = {57, 58, 59, 60};
    int start_digital_low_satb8s1[] = {65, 66, 67, 68};
    int start_digital_low_satb1s14[] = {73, 74, 75, 76};

    /* oli last 4 detectors */
    int end_digital_low_satb1s1[] = {61, 62, 63, 64};
    int end_digital_low_satb8s1[] = {69, 70, 71, 72};
    int end_digital_low_satb1s14[] = {77, 78, 79, 80};

    /* tirs first 4 detectors */
    int start_digital_low_satb10s1[] = {81, 82, 83, 84};
    int start_digital_low_satb11s2[] = {89, 90, 91, 92};

    /* tirs last 4 detectors */
    int end_digital_low_satb10s1[] = {85, 86, 87, 88};
    int end_digital_low_satb11s2[] = {93, 94, 95, 96};

    /* oli first 4 detectors */
    int start_digital_high_satb1s14[] = {4057, 4058, 4059, 4060};
    int start_digital_high_satb8s1[] = {4065, 4066, 4067, 4068};
    int start_digital_high_satb9s14[] = {4073, 4074, 4075, 4076};

    /* oli last 4 detectors */
    int end_digital_high_satb1s14[] = {4061, 4062, 4063, 4064};
    int end_digital_high_satb8s1[] = {4069, 4070, 4071, 4072};
    int end_digital_high_satb9s14[] = {4077, 4078, 4079, 4080};

    /* tirs first 4 detectors */
    int start_digital_high_satb10s1[] = {4081, 4082, 4083, 4084};
    int start_digital_high_satb11s3[] = {4089, 4090, 4091, 4092};

    /* tirs last 4 detectors */
    int end_digital_high_satb10s1[] = {4085, 4086, 4087, 4088};
    int end_digital_high_satb11s3[] = {4093, 4094, 4095, 4096};

    /* oli vrp first 4 detectors */
    int vrp_analog_low_b1s1[] = {97,98,99,100};
    int vrp_analog_low_b9s1[] = {101,102,103,104};
    int vrp_analog_low_b9s14[] = {105,106,107,108};

    /* oli vrp first 4 detectors */
    int vrp_analog_high_b1s1[] = {4097,4098,4099,4100};
    int vrp_analog_high_b1s14[] = {4101,4102,4103,4104};
    int vrp_analog_high_b9s14[] = {4105,4106,4107,4108};

    /* oli vrp digital low first 4 detectors */
    int vrp_digital_low_b1s1[] = {109,110,111,112};
    int vrp_digital_low_b9s1[] = {113,114,115,116};
    int vrp_digital_low_b8s14[] = {117,118,119,120};
    int vrp_digital_low_b9s14[] = {125,126,127,128};

    /* oli vrp digital low last 4 detectors */
    int end_vrp_digital_low_b8s14[] = {121,122,123,124};

    /* oli vrp digital high first 4 detectors */
    int vrp_digital_high_b1s1[] = {4109,4110,4111,4112};
    int vrp_digital_high_b8s5[] = {4113,4114,4115,4116};

    /* oli vrp digital high last 4 detectors */
    int end_vrp_digital_high_b8s5[] = {4117,4118,4119,4120};

    /* NEW oli vrp analog low sat first and last 4 dets */
    int start_vrp_analog_low_b28s1[] = {165, 166,167,168};
    int end_vrp_analog_low_b30s1[] = {169,170,171,172};

    /* NEW */
    int start_vrp_digital_high_b28s14[] = {4173,4174,4175,4176};
    int end_vrp_digital_high_b30s14[] = {4177,4178,4179,4180};

    /* oli blind analog low first and last 4 detectors */
    int start_analog_low_b12s1[] = {125,126,127,128};
    int end_analog_log_b12s1[] = {129,130,131,132};

    int start_analog_low_b14s1[] = {133,134,135,136};
    int end_analog_low_b14s1[] = {137,138,139,140};

    int start_analog_low_b14s14[] = {141,142,143,144};
    int end_analog_low_b14s14[] = {145,146,147,148};

    int start_analog_high_b13s1[] = {4121,4122,4123,4124};
    int end_analog_high_b13s1[] = {4125,4126,4127,4128};

    int start_digital_low_b13s1[] = {149,150,151,152};
    int end_digital_low_b13s1[] = {153,154,155,156};

    int start_digital_high_b12s1[] = {4129,4130,4131,4132};
    int end_digital_high_b12s1[] = {4133,4134,4135,4136};
    int end_digital_high_b14s14[] = {4137,4138,4139,4140};

    /* tirs blind band first and last 4 detectors */
    int start_analog_low_b15s1[] = {157,158,159,160};
    int end_analog_low_b15s1[] = {161,162,163,164};

    int start_analog_high_b15s2[] = {4141,4142,4143,4144};
    int end_analog_high_b15s2[] = {4145,4146,4147,4148};

    int start_digital_high_b15s3[] = {4149,4150,4151,4152};
    int end_digital_high_b15s3[] = {4153,4154,4155,4156};

    /* tirs secondary band first and last 4 detectors */
    int start_analog_low_b16s1[] = {16,17,18,19};
    int end_analog_low_b16s1[] = {20,21,22,23};

    int start_analog_high_b17s2[] = {4116,4117,4118,4119};
    int end_analog_high_b17s2[] = {4120,4121,4122,4123};

    int start_digital_low_b18s3[] = {7,8,9,10};
    int end_digital_low_b18s3[] = {11,12,13,14};

    double low_rad_sat[] = {-1.2516,-2.2516,-3.2516,-4.2516,-5.2516,-6.2516,
            -7.2516,-8.2516,-9.2516,-10.2516,-11.2516};
    double high_rad_sat[] = {50.1,50.2,50.3,50.4,50.5,50.6,50.7,50.8,50.9,
            50.10,50.11};

    IAS_CPF *cpf;
    const struct IAS_CPF_SATURATION_LEVEL *sat_level;

    printf("Test saturation level read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    sat_level = ias_cpf_get_saturation_level(cpf);
    assert_true(sat_level != NULL);
    if (sat_level == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }
    
    /* test the low and high radiance saturation */
    for (i = 0; i < 11; i++)
    {
        assert_double_equal(sat_level->low_radiance_saturation[i], 
                            low_rad_sat[i]);
        assert_double_equal(sat_level->high_radiance_saturation[i], 
                            high_rad_sat[i]);
    }

    /* test the analog and digital saturation levels */
    for (i = 0; i < 4; i++)
    {
        /* oli analog low first 4 detectors */
        assert_equal(sat_level->analog_low_saturation_level[0][0][i], 
                    start_analog_low_satb1s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[0][1][i], 
                    start_analog_low_satb1s2[i]);
        assert_equal(sat_level->analog_low_saturation_level[7][0][i], 
                    start_analog_low_satb8s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[8][13][i], 
                    start_analog_low_satb9s14[i]);
        assert_equal(sat_level->analog_low_saturation_level[18][0][i],
                    vrp_analog_low_b1s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[26][0][i],
                    vrp_analog_low_b9s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[26][13][i],
                    vrp_analog_low_b9s14[i]);  
        assert_equal(sat_level->analog_low_saturation_level[11][0][i],
                    start_analog_low_b12s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[13][0][i],
                    start_analog_low_b14s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[13][13][i],
                    start_analog_low_b14s14[i]);

        assert_equal(sat_level->analog_low_saturation_level[27][0][i],
                    start_vrp_analog_low_b28s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[27][13][i],
                    start_vrp_digital_high_b28s14[i]);

        /* oli analog low last 4 detectors */
        assert_equal(sat_level->analog_low_saturation_level[0][0][i+490], 
                    end_analog_low_satb1s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[0][1][i+490], 
                    end_analog_low_satb1s2[i]);
        assert_equal(sat_level->analog_low_saturation_level[7][0][i+984], 
                    end_analog_low_satb8s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[8][13][i+490], 
                    end_analog_low_satb9s14[i]);
        assert_equal(sat_level->analog_low_saturation_level[11][0][i+100],
                    end_analog_log_b12s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[13][0][i+99],
                    end_analog_low_b14s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[13][13][i+99],
                    end_analog_low_b14s14[i]);

        assert_equal(sat_level->analog_low_saturation_level[29][0][i+61],
                    end_vrp_analog_low_b30s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[29][13][i+61],
                    end_vrp_digital_high_b30s14[i]);

        /* tirs analog low first 4 dets */
        assert_equal(sat_level->analog_low_saturation_level[9][0][i], 
                    start_analog_low_satb10s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[9][2][i], 
                    start_analog_low_satb10s3[i]);
        assert_equal(sat_level->analog_low_saturation_level[10][0][i], 
                    start_analog_low_satb11s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[10][2][i], 
                    start_analog_low_satb11s3[i]);
        assert_equal(sat_level->analog_low_saturation_level[14][0][i],
                    start_analog_low_b15s1[i]);

        /* tirs analog low last 4 dets */
        assert_equal(sat_level->analog_low_saturation_level[9][0][i+636], 
                    end_analog_low_satb10s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[9][2][i+636], 
                    end_analog_low_satb10s3[i]);
        assert_equal(sat_level->analog_low_saturation_level[10][0][i+636], 
                    end_analog_low_satb11s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[10][2][i+636], 
                    end_analog_low_satb11s3[i]);
        assert_equal(sat_level->analog_low_saturation_level[14][0][i+636],
                    end_analog_low_b15s1[i]);

        /* tirs secondary bands */
        assert_equal(sat_level->analog_low_saturation_level[15][0][i], 
                    start_analog_low_b16s1[i]);
        assert_equal(sat_level->analog_low_saturation_level[15][0][i+636], 
                    end_analog_low_b16s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[16][1][i], 
                    start_analog_high_b17s2[i]);
        assert_equal(sat_level->analog_high_saturation_level[16][1][i+636], 
                    end_analog_high_b17s2[i]);
        assert_equal(sat_level->digital_low_saturation_level[17][2][i], 
                    start_digital_low_b18s3[i]);
        assert_equal(sat_level->digital_low_saturation_level[17][2][i+636], 
                    end_digital_low_b18s3[i]);

        /* oli analog high first 4 dets */
        assert_equal(sat_level->analog_high_saturation_level[0][13][i],
                    start_analog_high_satb1s14[i]);
        assert_equal(sat_level->analog_high_saturation_level[1][0][i],
                    start_analog_high_satb2s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[7][0][i],
                    start_analog_high_satb8s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[8][13][i],
                    start_analog_high_satb9s14[i]);
        assert_equal(sat_level->analog_high_saturation_level[18][0][i],
                    vrp_analog_high_b1s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[18][13][i],
                    vrp_analog_high_b1s14[i]);
        assert_equal(sat_level->analog_high_saturation_level[26][13][i],
                    vrp_analog_high_b9s14[i]);
        assert_equal(sat_level->analog_high_saturation_level[12][0][i],
                    start_analog_high_b13s1[i]);
        
        /* tirs analog high first 4 dets */
        assert_equal(sat_level->analog_high_saturation_level[9][0][i],
                    start_analog_high_satb10s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[10][0][i],
                    start_analog_high_satb11s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[10][2][i],
                    start_analog_high_satb11s3[i]);
        assert_equal(sat_level->analog_high_saturation_level[14][1][i],
                    start_analog_high_b15s2[i]);

        /* oli analog high last 4 dets */
        assert_equal(sat_level->analog_high_saturation_level[0][13][i+490],
                    end_analog_high_satb1s14[i]);
        assert_equal(sat_level->analog_high_saturation_level[1][0][i+490],
                    end_analog_high_satb2s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[7][0][i+984],
                    end_analog_high_satb8s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[8][13][i+490],
                    end_analog_high_satb9s14[i]);
        assert_equal(sat_level->analog_high_saturation_level[12][0][i+100],
                    end_analog_high_b13s1[i]);

        /* tirs analog high last 4 dets */
        assert_equal(sat_level->analog_high_saturation_level[9][0][i+636],
                    end_analog_high_satb10s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[10][0][i+636],
                    end_analog_high_satb11s1[i]);
        assert_equal(sat_level->analog_high_saturation_level[10][2][i+636],
                    end_analog_high_satb11s3[i]);
        assert_equal(sat_level->analog_high_saturation_level[14][1][i+636],
                    end_analog_high_b15s2[i]);


        /* oli digital low first 4 dets */
        assert_equal(sat_level->digital_low_saturation_level[0][0][i], 
                    start_digital_low_satb1s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[7][0][i], 
                    start_digital_low_satb8s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[0][13][i], 
                    start_digital_low_satb1s14[i]);
        assert_equal(sat_level->digital_low_saturation_level[18][0][i],
                    vrp_digital_low_b1s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[26][0][i],
                    vrp_digital_low_b9s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[25][13][i],
                    vrp_digital_low_b8s14[i]);
        assert_equal(sat_level->digital_low_saturation_level[26][13][i],
                    vrp_digital_low_b9s14[i]);
        assert_equal(sat_level->digital_low_saturation_level[12][0][i],
                    start_digital_low_b13s1[i]);

        /* oli digital low last 4 dets */
        assert_equal(sat_level->digital_low_saturation_level[0][0][i+490], 
                    end_digital_low_satb1s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[7][0][i+984], 
                    end_digital_low_satb8s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[0][13][i+490], 
                    end_digital_low_satb1s14[i]);
        assert_equal(sat_level->digital_low_saturation_level[25][13][i+20],
                    end_vrp_digital_low_b8s14[i]);
        assert_equal(sat_level->digital_low_saturation_level[12][0][i+100],
                    end_digital_low_b13s1[i]);

        /* tirs digital low first 4 dets */
        assert_equal(sat_level->digital_low_saturation_level[9][0][i], 
                    start_digital_low_satb10s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[10][1][i], 
                    start_digital_low_satb11s2[i]);

        /* tirs digital low last 4 dets */
        assert_equal(sat_level->digital_low_saturation_level[9][0][i+636], 
                    end_digital_low_satb10s1[i]);
        assert_equal(sat_level->digital_low_saturation_level[10][1][i+636], 
                    end_digital_low_satb11s2[i]);

        /* oli digital high first 4 dets */
        assert_equal(sat_level->digital_high_saturation_level[0][13][i],
                    start_digital_high_satb1s14[i]);
        assert_equal(sat_level->digital_high_saturation_level[7][0][i],
                    start_digital_high_satb8s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[8][13][i],
                    start_digital_high_satb9s14[i]);
        assert_equal(sat_level->digital_high_saturation_level[18][0][i],
                    vrp_digital_high_b1s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[25][4][i],
                    vrp_digital_high_b8s5[i]);
        assert_equal(sat_level->digital_high_saturation_level[11][0][i],
                    start_digital_high_b12s1[i]);

        /* oli digital high last 4 dets */
        assert_equal(sat_level->digital_high_saturation_level[0][13][i+490],
                    end_digital_high_satb1s14[i]);
        assert_equal(sat_level->digital_high_saturation_level[7][0][i+984],
                    end_digital_high_satb8s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[8][13][i+490],
                    end_digital_high_satb9s14[i]);
        assert_equal(sat_level->digital_high_saturation_level[11][0][i+100],
                    end_digital_high_b12s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[13][13][i+99],
                    end_digital_high_b14s14[i]);
        assert_equal(sat_level->digital_high_saturation_level[25][4][i+20],
                    end_vrp_digital_high_b8s5[i]);

        /* tirs */
        assert_equal(sat_level->digital_high_saturation_level[9][0][i],
                    start_digital_high_satb10s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[10][2][i],
                    start_digital_high_satb11s3[i]);
        assert_equal(sat_level->digital_high_saturation_level[14][2][i],
                    start_digital_high_b15s3[i]);

        assert_equal(sat_level->digital_high_saturation_level[9][0][i+636],
                    end_digital_high_satb10s1[i]);
        assert_equal(sat_level->digital_high_saturation_level[10][2][i+636],
                    end_digital_high_satb11s3[i]);
        assert_equal(sat_level->digital_high_saturation_level[14][2][i+636],
                end_digital_high_b15s3[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read sat level */

Ensure test_read_post_rel_gains()
{
    int i;
    double rgb1s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double rgb9s14[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */
    double trgb10s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double trgb11s3[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    IAS_CPF *cpf;
    const struct IAS_CPF_RELATIVE_GAINS *post_rel_gains;

    printf("Test post rel gains read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    post_rel_gains = ias_cpf_get_postlaunch_relative_gains(cpf);
    assert_true(post_rel_gains != NULL);

    if (post_rel_gains != NULL)
    {
        for (i = 0; i < 4; i++)
        {
            assert_double_equal(post_rel_gains->per_detector[0][0][i], 
                                rgb1s1[i]);
            assert_double_equal(post_rel_gains->per_detector[8][13][i+490], 
                                rgb9s14[i]);
            assert_double_equal(post_rel_gains->per_detector[9][0][i], 
                    trgb10s1[i]);
            assert_double_equal(post_rel_gains->per_detector[10][2][i+636], 
                    trgb11s3[i]);

        }
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read pre launch rel gains */

Ensure test_read_pre_rel_gains()
{
    int i;
    double rgb1s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double rgb9s14[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    double trgb10s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double trgb11s3[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    IAS_CPF *cpf;
    const struct IAS_CPF_RELATIVE_GAINS *pre_rel_gains;

    printf("Test pre rel gains read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    pre_rel_gains = ias_cpf_get_prelaunch_relative_gains(cpf);
    assert_true(pre_rel_gains != NULL);

    if (pre_rel_gains != NULL)
    {
        for (i = 0; i < 4; i++)
        {
            assert_double_equal(pre_rel_gains->per_detector[0][0][i], 
                                rgb1s1[i]);
            assert_double_equal(pre_rel_gains->per_detector[8][13][i+490], 
                                rgb9s14[i]);
            assert_double_equal(pre_rel_gains->per_detector[9][0][i], 
                    trgb10s1[i]);
            assert_double_equal(pre_rel_gains->per_detector[10][2][i+636], 
                    trgb11s3[i]);

        }
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read pre launch rel gains */

Ensure test_read_rel_gains()
{
    int i;
    double orgb1s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double orgb9s14[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    double trgb10s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double trgb11s3[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    IAS_CPF *cpf;
    const struct IAS_CPF_RELATIVE_GAINS *rel_gains;

    printf("Test rel gains read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    rel_gains = ias_cpf_get_relative_gains(cpf);
    assert_true(rel_gains != NULL);

    if (rel_gains != NULL)
    {
        for (i = 0; i < 4; i++)
        {
            assert_double_equal(rel_gains->per_detector[0][0][i], orgb1s1[i]);
            assert_double_equal(rel_gains->per_detector[8][13][i+490], 
                    orgb9s14[i]);
            assert_double_equal(rel_gains->per_detector[9][0][i], trgb10s1[i]);
            assert_double_equal(rel_gains->per_detector[10][2][i+636], 
                    trgb11s3[i]);
        }
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read rel gains */

/* tirs relative gains blind band */
Ensure test_read_tirs_rel_gains_blind()
{
    int i;
    double trgbb1s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double trgbb1s3[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    IAS_CPF *cpf;
    const struct IAS_CPF_RELATIVE_GAINS *rel_gains_blind;

    printf("Test tirs rel gains blind band read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    rel_gains_blind = ias_cpf_get_tirs_rel_gains_blind(cpf);
    assert_true(rel_gains_blind != NULL);

    if (rel_gains_blind != NULL)
    {
        for (i = 0; i < 4; i++)
        {
            assert_double_equal(rel_gains_blind->per_detector[0][0][i], 
                    trgbb1s1[i]);
            assert_double_equal(rel_gains_blind->per_detector[0][2][i+636], 
                    trgbb1s3[i]);
        }
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read tirs rel gains blind band */

/* tirs pre launch relative gains blind band */
Ensure test_read_tirs_pre_rel_gains_blind()
{
    int i;
    double tprergbb1s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double tprergbb1s3[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    IAS_CPF *cpf;
    const struct IAS_CPF_RELATIVE_GAINS *tirs_pre_rel_gains_blind;

    printf("Test tirs pre launch rel gains blind band read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_pre_rel_gains_blind = ias_cpf_get_tirs_pre_rel_gains_blind(cpf);
    assert_true(tirs_pre_rel_gains_blind != NULL);

    if (tirs_pre_rel_gains_blind != NULL)
    {
        for (i = 0; i < 4; i++)
        {
            assert_double_equal(
                    tirs_pre_rel_gains_blind->per_detector[0][0][i], 
                    tprergbb1s1[i]);
            assert_double_equal(
                    tirs_pre_rel_gains_blind->per_detector[0][2][i+636], 
                    tprergbb1s3[i]);
        }
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read tirs prelaunch rel gains blind band */

/* tirs post launch relative gains blind band */
Ensure test_read_tirs_post_rel_gains_blind()
{
    int i;
    double tpostrgbb1s1[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* first 4 dets */
    double tpostrgbb1s3[] 
            = {1.000000, 1.000000, 1.000000, 1.000000}; /* last 4 dets */

    IAS_CPF *cpf;
    const struct IAS_CPF_RELATIVE_GAINS *tirs_post_rel_gains_blind;

    printf("Test tirs post launch rel gains blind band read.......\n");
    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    tirs_post_rel_gains_blind = ias_cpf_get_tirs_post_rel_gains_blind(cpf);
    assert_true(tirs_post_rel_gains_blind != NULL);

    if (tirs_post_rel_gains_blind != NULL)
    {
        for (i = 0; i < 4; i++)
        {
            assert_double_equal(
                    tirs_post_rel_gains_blind->per_detector[0][0][i], 
                    tpostrgbb1s1[i]);
            assert_double_equal(
                    tirs_post_rel_gains_blind->per_detector[0][2][i+636], 
                    tpostrgbb1s3[i]);
        }
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read tirs postlaunch rel gains blind band */

Ensure test_read_i2i()
{
    int i;

    double trend_threshold_line[] = {10.000, 10.000, 10.000, 10.000, 
        10.000, 10.000, 10.000, 10.000, 10.000, 10.000, 10.000};
    double trend_threshold_sample[] = {10.000, 10.000, 10.000, 10.000, 
        10.000, 10.000, 10.000, 10.000, 10.000, 10.000, 10.000};
    double fill_threshold = 0.05;
    double max_displacement_offset = 32;
    double min_corr_strength = 3.00;
    int corr_pix_min = 1;
    int corr_pix_max = 4096;
    int corr_fit_method = 1;
    int corr_window_size[] = {64, 64};

    IAS_CPF *cpf;
    const struct IAS_CPF_I2I_ASSESSMENT *i2i_assess;

    printf("Test i2i assessment read........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    i2i_assess = ias_cpf_get_i2i_assessment(cpf);
    assert_true(i2i_assess != NULL);
    if (i2i_assess != NULL)
    {
        for (i = 0; i < 10; i++)
        {
            assert_double_equal(i2i_assess->trend_threshold_line[i], 
                trend_threshold_line[i]);   
            assert_double_equal(i2i_assess->trend_threshold_sample[i], 
                trend_threshold_sample[i]);   
        }
        assert_double_equal(i2i_assess->fill_threshold, fill_threshold);
        assert_double_equal(i2i_assess->max_displacement_offset, 
                            max_displacement_offset);
        assert_double_equal(i2i_assess->min_corr_strength, 
                            min_corr_strength);
        assert_equal(i2i_assess->corr_pix_min, corr_pix_min);
        assert_equal(i2i_assess->corr_pix_max, corr_pix_max);
        assert_equal(i2i_assess->corr_fit_method, corr_fit_method);
        assert_equal(i2i_assess->corr_window_size[0], corr_window_size[0]);
        assert_equal(i2i_assess->corr_window_size[1], corr_window_size[1]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read i2i */

Ensure test_read_geo_sys()
{
    double x_prefit_gcp = 1.000000;
    double y_prefit_gcp = 0.000000;
    double x_postfit_gcp_rms = 0.000000;
    double y_postfit_gcp_rms = 0.000000;
    double max_percent_gcp_outliers = 0.99;
    double percent_outlier = 0.98;
    double time_code_outlier_threshold = 0.000000;
    int ms_grid_elev = 500;
    int pan_grid_elev = 500;
    int tirs_grid_elev = 500;
    int ms_grid_lines = 10;
    int pan_grid_lines = 20;
    int tirs_grid_lines = 5;
    int ms_grid_samples = 40;
    int pan_grid_samples = 80;
    int tirs_grid_samples = 16;
    int band_order[] = {9, 7, 8, 4, 5, 6, 2, 3, 1, 10, 11};
    double low_pass_cutoff = 1.0;
    int minimum_number_correlated_validation_gcps = 20;
    int minimum_number_nonoutlier_control_gcps = 30;

    IAS_CPF *cpf;
    const struct IAS_CPF_GEO_SYSTEM *geo_sys;

    printf("Test geo system read........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    geo_sys = ias_cpf_get_geo_system(cpf);
    assert_true(geo_sys != NULL);
    if (geo_sys != NULL)
    {
        int i;

        assert_double_equal(geo_sys->x_prefit_gcp_rms, x_prefit_gcp);
        assert_double_equal(geo_sys->y_prefit_gcp_rms, y_prefit_gcp);
        assert_double_equal(geo_sys->x_postfit_gcp_rms,
                                     x_postfit_gcp_rms);
        assert_double_equal(geo_sys->y_postfit_gcp_rms,
                                     y_postfit_gcp_rms);
        assert_double_equal(geo_sys->max_percent_gcp_outliers,
                                     max_percent_gcp_outliers);
        assert_double_equal(geo_sys->percent_outlier_threshold, 
                            percent_outlier);
        assert_double_equal(geo_sys->time_code_outlier_threshold,
                                     time_code_outlier_threshold);
        assert_double_equal(geo_sys->low_pass_cutoff, low_pass_cutoff);

        assert_equal(geo_sys->ms_grid_density_elev, ms_grid_elev);
        assert_equal(geo_sys->pan_grid_density_elev, pan_grid_elev);
        assert_equal(geo_sys->tirs_grid_density_elev, tirs_grid_elev);
        assert_equal(geo_sys->ms_grid_density_lines, ms_grid_lines);
        assert_equal(geo_sys->pan_grid_density_lines, pan_grid_lines);
        assert_equal(geo_sys->tirs_grid_density_lines, tirs_grid_lines);
        assert_equal(geo_sys->ms_grid_density_samples, ms_grid_samples);
        assert_equal(geo_sys->pan_grid_density_samples, pan_grid_samples);
        assert_equal(geo_sys->tirs_grid_density_samples, tirs_grid_samples);
        assert_equal(geo_sys->minimum_number_correlated_validation_gcps,
                              minimum_number_correlated_validation_gcps);
        assert_equal(geo_sys->minimum_number_nonoutlier_control_gcps,
                              minimum_number_nonoutlier_control_gcps);
        /* test band order */
        for (i = 0; i < IAS_MAX_NBANDS; i++)
        {
           assert_equal(geo_sys->optimal_band_order[i], band_order[i]);
        }

    }

    ias_cpf_free(cpf);
} /* end of test read geo sys */

Ensure test_read_gcp_corr()
{
    int winsize[] = {64, 64};
    double fill_threshold = 0.95;
    int max_displacement_offset = 32;
    int fill_value = 0;
    IAS_CPF *cpf;
    const struct IAS_CPF_GCP_CORRELATION *gcp_corr;

    printf("Test gcp correlation read........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    gcp_corr = ias_cpf_get_gcp_correlation(cpf);
    assert_true(gcp_corr != NULL);
    if (gcp_corr != NULL)
    {
        assert_equal(gcp_corr->corr_window_size[0], winsize[0]);
        assert_equal(gcp_corr->corr_window_size[1], winsize[1]);
        assert_double_equal(gcp_corr->fill_threshold, fill_threshold);
        assert_equal(gcp_corr->max_displacement_offset, 
                     max_displacement_offset);
        assert_equal(gcp_corr->corr_fill_value, fill_value);
    }
    else
        printf("Get gcp correlate returned NULL.....\n");

    ias_cpf_free(cpf);
} /* end of test read gcp corr */

Ensure test_read_focal_plane_cal()
{
    double alongtt = 10.0;
    double acrosstt = 10.0;
    int winsize[] = {32, 32};
    double fill = 0.10;
    int corr_fit_method = 1;
    int fit_order = 2;
    double max_displacement_offset = 3;
    double min_corr_strength = 3.0;
    double tie_point = 0.14;

    IAS_CPF *cpf;
    const struct IAS_CPF_FOCAL_PLANE_CAL *fp_cal;

    printf("Test focal plane cal read........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    fp_cal = ias_cpf_get_focal_plane_cal(cpf);
    assert_true(fp_cal != NULL);

    if (fp_cal != NULL)
    {
        assert_double_equal(fp_cal->along_postfit_rmse_threshold, alongtt);
        assert_double_equal(fp_cal->across_postfit_rmse_threshold, acrosstt);
        assert_equal(fp_cal->corr_window_size[0], winsize[0]);
        assert_equal(fp_cal->corr_window_size[1], winsize[1]);
        assert_double_equal(fp_cal->fill_threshold, fill);
        assert_equal(fp_cal->corr_fit_method, corr_fit_method);
        assert_equal(fp_cal->fit_order, fit_order);
        assert_double_equal(fp_cal->max_displacement_offset, 
                            max_displacement_offset);
        assert_double_equal(fp_cal->min_corr_strength, min_corr_strength);
        assert_double_equal(fp_cal->tie_point_weight, tie_point);
    }
    else
        printf("Get focal plane cal returned NULL.....\n");

   /* free memory */
    ias_cpf_free(cpf);
} /* end of test focal plane cal */

Ensure test_read_nonuniformity()
{
    /* oli band 1 sca 1 first four dets */
    double primary_scaleb1s1[] = {1.000, 2.000, 3.000, 4.000};
    double pristine_scaleb1s1[] = {1.100, 2.200, 3.300, 4.400};

    /* oli band 8 sca 1 first four detectors */
    double primary_scaleb8s1[] = {17.000, 18.000, 19.000, 20.000};
    double pristine_scaleb8s1[] = {17.170, 18.180, 19.190, 20.200};
    
    /* oli band 8 sca 14 last four detectors */
    double primary_scaleb8s14[] = {21.000, 22.000, 23.000, 24.000};
    double pristine_scaleb8s14[] = {21.210, 22.220, 23.230, 24.240};
    
    /* oli band 9 sca 14 last four dets */
    double primary_scaleb9s14[] = {5.000, 6.000, 7.000, 8.000};
    double pristine_scaleb9s14[] = {5.500, 6.600, 7.700, 8.800};

    /* tirs band 10 sca 1 first four dets */
    double blackbody_scaleb10s1[] = {9.000, 10.000, 11.000, 12.000};

    /* tirs band 11 sca 3 last four dets */
    double blackbody_scaleb11s3[] = {13.000, 14.000, 15.000, 16.000};
    
    int i;                                  /* loop control */
    
    IAS_CPF *cpf;
    const struct IAS_CPF_NONUNIFORMITY *nonuniformity;

    printf("Test nonuniformity read........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    nonuniformity = ias_cpf_get_nonuniformity(cpf);
    assert_true(nonuniformity != NULL);
    if (nonuniformity != NULL)
    {
        for (i = 0; i < 4; i++)
        {
            /* oli first 4 detectors */
            assert_double_equal(nonuniformity
                ->scale_factor_1[0][0][i], primary_scaleb1s1[i]);
            assert_double_equal(nonuniformity
                ->scale_factor_2[0][0][i], 
                  pristine_scaleb1s1[i]);
            assert_double_equal(nonuniformity
                ->scale_factor_1[7][0][i], 
                  primary_scaleb8s1[i]);
            assert_double_equal(nonuniformity
                ->scale_factor_2[7][0][i], 
                  pristine_scaleb8s1[i]);

            /* oli last 4 detectors */
            assert_double_equal(nonuniformity
                ->scale_factor_1[7][13][i+984], 
                  primary_scaleb8s14[i]);
            assert_double_equal(nonuniformity
                ->scale_factor_2[7][13][i+984], 
                  pristine_scaleb8s14[i]);
            assert_double_equal(nonuniformity
                ->scale_factor_1[8][13][i+490], 
                  primary_scaleb9s14[i]);
            assert_double_equal(nonuniformity
                ->scale_factor_2[8][13][i+490], 
                  pristine_scaleb9s14[i]);

            /* tirs first 4 detectors */
            assert_double_equal(nonuniformity
                ->scale_factor_1[9][0][i], blackbody_scaleb10s1[i]);

            /* tirs last 4 detectors */
            assert_double_equal(nonuniformity
                ->scale_factor_1[10][2][i+636], 
                  blackbody_scaleb11s3[i]);
        }
    }
    else
        printf("Get nonuniformity returned NULL.....\n");

   /* free memory */
    ias_cpf_free(cpf);
} /* end of test read nonuniformity */


Ensure test_read_focal_plane()
{
    int i, j;

    IAS_CPF *cpf;
    const struct IAS_CPF_FOCAL_PLANE *focal_plane;

    /* along data */
    double allosb1s1[] = {6.12996743E-03,-3.40913843E-04,3.48686841E-06,0.0};
    double allosb2s1[] = {4.89319847E-03,-3.39247764E-04,3.44373123E-06,0.0};
    double allosb10s1[] 
        = {1.71024957E-02, 4.00361077E-05, 8.70207135E-06, -6.37228030E-07};
    double allosb11s1[] 
        = {4.12358426E-02, -1.77475070E-05, 2.16460323E-05, -1.59306996E-06}; 
    double allosb10s3[] 
        = {2.90070911E-02, -1.21115433E-05, 1.49779764E-05, 1.10369370E-06};
    double allosb11s3[] 
        = {5.31586025E-02, 4.84881391E-05, 2.84599175E-05, 2.08543317E-06};
    double allosb9s14[] = {-1.38396756E-02,2.89951333E-04,2.75554930E-06,0.0};

    /* across data */
    double axlosb1s1[] ={1.24858766E-01,-1.02376168E-02,1.15934748E-05,0.0};
    double axlosb10s1[] 
        = {8.68689697E-02, -4.55323788E-02, 1.14618304E-04, -1.74606567E-05};
    double axlosb11s1[] 
        = {8.69478562E-02, -4.55570690E-02, 1.17694651E-04, -1.78467658E-05};
    double axlosb10s3[] 
        = {-8.69041246E-02, -4.55419647E-02, -1.15817131E-04, -1.76100210E-05};
    double axlosb11s3[] 
        = {-8.69988315E-02, -4.55771304E-02, -1.20172156E-04, -1.81634586E-05};
    double axlosb9s14[] = {-1.24507750E-01,-1.02054457E-02,-1.15069330E-05,0.0};
    int det_count[] = {494, 494, 494, 494, 494, 494, 494, 988, 494, 640, 640};
    char band_names[11][20] = {"OLI_Coastal_Aerosol", "OLI_Blue", "OLI_Green", 
                            "OLI_Red", "OLI_NIR", "OLI_SWIR1", "OLI_SWIR2", 
                            "OLI_PAN", "OLI_CIRRUS", "TIRS_THERMAL_1", 
                            "TIRS_THERMAL_2"};
    /* overlap */
    int overlap[] = {2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0};

    /* focal plane band order starting from the closest to the center */
    int border[] = {8, 2, 1, 5, 4, 3, 7, 6, 9};

    /* offsets */
    int boffset[] = {1, 0, 0, 0, 0, 0, 0, 0, 1, 10, 11};
    int soffset[][14] 
      = {{369, 142, 369, 142, 369, 142, 369, 142, 369, 142, 369, 142, 369, 142},
         {349, 162, 349, 162, 349, 162, 349, 162, 349, 162, 349, 162, 349, 162},
         {429,  82, 429,  82, 429,  82, 429,  82, 429,  82, 429,  82, 429,  82},
         {409, 102, 409, 102, 409, 102, 409, 102, 409, 102, 409, 102, 409, 102},
         {389, 122, 389, 122, 389, 122, 389, 122, 389, 122, 389, 122, 389, 122},
         {467,  40, 467,  40, 467,  40, 467,  40, 467,  40, 467,  40, 467,  40},
         {449,  62, 449,  62, 449,  62, 449,  62, 449,  62, 449,  62, 449,  62},
         {443,  68, 443,  68, 443,  68, 443,  68, 443,  68, 443,  68, 443,  68},
         {487,  20, 487,  20, 487,  20, 487,  20, 487,  20, 487,  20, 487,  20},
         {1, 0, 0},
         {2, 0, 0}};

    int nfob1[] = {2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2};
    int nfob9[] = {4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4};
    int nfob10[] = {0, 0, 0};
    int nfob11[] = {0, 0, 0};

    /* tirs primary and alternate row offsets */
    int tpro1[] = {2,4,6};
    int tpro2[] = {1,3,5};

    int taro1[] = {6,4,2};
    int taro2[] = {5,3,1};

    printf("Test focal plane read........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    focal_plane = ias_cpf_get_focal_plane(cpf);

    assert_true(focal_plane != NULL);
    if (focal_plane != NULL)
    {
        for (i = 0; i < 11; i++)
        {
            assert_equal(focal_plane->detectors_per_band[i], det_count[i]);
            assert_equal(focal_plane->sca_overlap[i], overlap[i]);
        }

        for (i = 0; i < 9; i++)
        {
            assert_equal(focal_plane->band_offset[i], boffset[i]);
            assert_equal(focal_plane->band_order[i], border[i]);
            for (j = 0; j < 14; j++)
            {
                assert_equal(focal_plane->sca_offset[i][j],soffset[i][j]);
            }
        }

        /* test the oli nominal fill offsets */
        for (i = 0; i < 14; i++)
        {
            assert_equal(focal_plane->nominal_fill_offset[0][i], nfob1[i]);
            assert_equal(focal_plane->nominal_fill_offset[8][i], nfob9[i]); 
        }

        /* test the tirs nominal fill, primary & alternate row offsets */
        for (i = 0; i < 3; i++)
        {
            assert_equal(focal_plane->nominal_fill_offset[9][i], nfob10[i]); 
            assert_equal(focal_plane->nominal_fill_offset[10][i], nfob11[i]); 
            assert_equal(focal_plane->primary_row_offsets[9][i], tpro1[i]); 
            assert_equal(focal_plane->primary_row_offsets[10][i], tpro2[i]); 
            assert_equal(focal_plane->alternate_row_offsets[9][i], taro1[i]); 
            assert_equal(focal_plane->alternate_row_offsets[10][i], taro2[i]); 
        }
        /* test band names */
        for (i = 0; i < 11; i++)
        {
           assert_string_equal(focal_plane->band_names[i], band_names[i]);

        }

        /* test selected los legendre coeffients */
        for (i = 0; i < 4; i++)
        {
            assert_double_equal(focal_plane->along_los_legendre[0][0][i],
                                allosb1s1[i]); 
            assert_double_equal(focal_plane->along_los_legendre[1][0][i],
                                allosb2s1[i]); 
            assert_double_equal(focal_plane->along_los_legendre[9][0][i],
                                allosb10s1[i]); 
            assert_double_equal(focal_plane->along_los_legendre[10][0][i],
                                allosb11s1[i]); 
            assert_double_equal(focal_plane->along_los_legendre[9][2][i],
                                allosb10s3[i]); 
            assert_double_equal(focal_plane->along_los_legendre[10][2][i],
                                allosb11s3[i]); 
            assert_double_equal(focal_plane->along_los_legendre[8][13][i],
                                allosb9s14[i]); 

            assert_double_equal(focal_plane->across_los_legendre[0][0][i],
                                axlosb1s1[i]); 
            assert_double_equal(focal_plane->across_los_legendre[9][0][i],
                                axlosb10s1[i]); 
            assert_double_equal(focal_plane->across_los_legendre[10][0][i],
                                axlosb11s1[i]); 
            assert_double_equal(focal_plane->across_los_legendre[9][2][i],
                                axlosb10s3[i]); 
            assert_double_equal(focal_plane->across_los_legendre[10][2][i],
                                axlosb11s3[i]); 
            assert_double_equal(focal_plane->across_los_legendre[8][13][i],
                                axlosb9s14[i]); 
        } /* end of los legendre coeff tests */

   }
   else
        printf("Get focal_plane returned NULL......\n");
        
   /* free memory */
    ias_cpf_free(cpf);
} /* end of test read focal plane */

Ensure test_read_diffuser_rad()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_DIFFUSER_RADIANCE *diff_rad;

    printf("Test diffuser radiance read...........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    diff_rad = ias_cpf_get_diffuser_rad(cpf);
    assert_true(diff_rad != NULL);

    if (diff_rad != NULL)
    {
        assert_equal_with_message(diff_rad->diff_bidir_refl_pris[0][0][158],
          0.001590 , "band 1 sca 1 det 159 not equal: %f", 
           diff_rad->diff_bidir_refl_pris[0][0][158]);
    }
    else
        printf("Get diffuser radiance returned NULL....\n");

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read diffuser rad */

Ensure test_read_det_status()
{
    int i;
    /* oli inoperable dets */
    int inopb1_count[] = {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1};
    int inopb2_count[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
    int inopb9_count[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2};
    int inopb14_count[] = {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2};
    int inopb1s1[] = {5, 494};
    int inopb1s2[] = {0};
    int inopb1s14[] = {200};
    int inopb9s14[] = {1, 300};
    int inopb14s1[] = {13, 17};
    int inopb14s14[] = {11, 13};
    /* tirs in op */
    int inopb10_count[] = {1,0,2};
    int inopb11_count[] = {0,2,0};
    int inopb17_count[] = {0,2,0};
    int inopb10s1[] = {10};
    int inopb10s3[] = {1, 640};
    int inopb11s2[] = {1, 639};
    int inopb17s2[] = {1, 11};

    /* oli out of spec detectors */
    int out_of_spec_b1_count[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
    int out_of_spec_b2_count[] = {0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0};
    int out_of_spec_b9_count[] = {0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0};
    int out_of_spec_b14_count[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3};
    int out_of_spec_b1s1[] = {0};
    int out_of_spec_b2s2[] = {10, 50};
    int out_of_spec_b2s13[] = {1, 250, 494};
    int out_of_spec_b9s3[] = {100, 300};
    int out_of_spec_b9s13[] = {400};
    int out_of_spec_b14s14[] = {1, 13, 137};
    /* tirs out of spec */
    int out_of_spec_b10_count[] = {0, 2, 0};
    int out_of_spec_b11_count[] = {2, 0, 1};
    int out_of_spec_b18_count[] = {2, 0, 2};
    int out_of_spec_b10s2[] = {50, 60};
    int out_of_spec_b11s1[] = {1, 640};
    int out_of_spec_b11s2[] = {0};
    int out_of_spec_b11s3[] = {5};
    int out_of_spec_b18s1[] = {17, 77};
    int out_of_spec_b18s3[] = {11, 33};

    /* oli vrp inoperable dets */
    int vrp_inop_b1_count[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
    int vrp_inop_b4_count[] = {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2};
    int vrp_inop_b6_count[] = {0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0};
    int vrp_inop_b8_count[] = {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3};
    int vrp_inop_b14_count[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1};
    int vrp_inop_b1s1[] = {0};
    int vrp_inop_b4s1[] = {1, 494};
    int vrp_inop_b4s14[] = {3, 493};
    int vrp_inop_b6s2[] = {5, 105, 401};
    int vrp_inop_b6s13[] = {40};
    int vrp_inop_b8s1[] = {1};
    int vrp_inop_b8s14[] = {1, 202, 988};
    int vrp_inop_b14s14[] = {100};

    /* oli vrp out of spec dets */
    int vrp_out_of_spec_b3_count[] = {0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0};
    int vrp_out_of_spec_b5_count[] = {0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
    int vrp_out_of_spec_b7_count[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0};
    int vrp_out_of_spec_b14_count[]= {0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0};
    int vrp_out_of_spec_b3s7[] = {3, 491};
    int vrp_out_of_spec_b5s2[] = {333};
    int vrp_out_of_spec_b7s12[] = {7, 12};
    int vrp_out_of_spec_b14s7[] = {37, 137};

    IAS_CPF *cpf;
    const struct IAS_CPF_DETECTOR_STATUS *det_status;

    printf("Test detector status read...........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;
    det_status = ias_cpf_get_det_status(cpf);
    assert_true(det_status != NULL);
    if (det_status != NULL)
    {
        assert_equal(det_status->oli_detector_select_table, 1);
        assert_equal(det_status->oli_detector_select_table_id, 1);
        for (i = 0; i < 14; i++)
        {
            /* inoperable dets */
           assert_equal(det_status->inoperable_count[0][i], inopb1_count[i]);
           assert_equal(det_status->inoperable_count[1][i], inopb2_count[i]);
           assert_equal(det_status->inoperable_count[8][i], inopb9_count[i]);
           assert_equal(det_status->inoperable_count[13][i], inopb14_count[i]);
            /* Out of spec dets */
           assert_equal(det_status->out_of_spec_count[0][i],
                        out_of_spec_b1_count[i]);
           assert_equal(det_status->out_of_spec_count[1][i],
                        out_of_spec_b2_count[i]);
           assert_equal(det_status->out_of_spec_count[8][i],
                        out_of_spec_b9_count[i]);
           assert_equal(det_status->out_of_spec_count[13][i],
                        out_of_spec_b14_count[i]);
           /* vrp inop dets */
           assert_equal(det_status->inoperable_count[18][i],
                        vrp_inop_b1_count[i]);
           assert_equal(det_status->inoperable_count[21][i],
                        vrp_inop_b4_count[i]);
           assert_equal(det_status->inoperable_count[23][i],
                        vrp_inop_b6_count[i]);
           assert_equal(det_status->inoperable_count[25][i],
                        vrp_inop_b8_count[i]);
           assert_equal(det_status->inoperable_count[29][i],
                        vrp_inop_b14_count[i]);
           /* vrp out of spec detectors */
           assert_equal(det_status->out_of_spec_count[20][i],
                        vrp_out_of_spec_b3_count[i]);
           assert_equal(det_status->out_of_spec_count[22][i],
                        vrp_out_of_spec_b5_count[i]);
           assert_equal(det_status->out_of_spec_count[24][i],
                        vrp_out_of_spec_b7_count[i]);
           assert_equal(det_status->out_of_spec_count[29][i],
                        vrp_out_of_spec_b14_count[i]);
        }
        /* inoperable dets */
        assert_equal(det_status->inoperable[0][0][0], inopb1s1[0]);
        assert_equal(det_status->inoperable[0][1][0], inopb1s2[0]);
        assert_equal(det_status->inoperable[0][13][0], inopb1s14[0]);
        assert_equal(det_status->inoperable[8][13][0], inopb9s14[0]);
        assert_equal(det_status->inoperable[13][0][0], inopb14s1[0]);
        assert_equal(det_status->inoperable[13][0][1], inopb14s1[1]);
        assert_equal(det_status->inoperable[13][13][0], inopb14s14[0]);
        assert_equal(det_status->inoperable[13][13][1], inopb14s14[1]);
        /* out of spec dets */
        assert_equal(det_status->out_of_spec[0][0][0], out_of_spec_b1s1[0]);
        assert_equal(det_status->out_of_spec[1][1][0], out_of_spec_b2s2[0]);
        assert_equal(det_status->out_of_spec[1][1][1], out_of_spec_b2s2[1]);
        assert_equal(det_status->out_of_spec[1][12][0], out_of_spec_b2s13[0]);
        assert_equal(det_status->out_of_spec[1][12][1], out_of_spec_b2s13[1]);
        assert_equal(det_status->out_of_spec[1][12][2], out_of_spec_b2s13[2]);
        assert_equal(det_status->out_of_spec[8][2][0], out_of_spec_b9s3[0]);
        assert_equal(det_status->out_of_spec[8][2][1], out_of_spec_b9s3[1]);
        assert_equal(det_status->out_of_spec[8][12][0], out_of_spec_b9s13[0]);
        assert_equal(det_status->out_of_spec[13][13][0], out_of_spec_b14s14[0]);
        assert_equal(det_status->out_of_spec[13][13][1], out_of_spec_b14s14[1]);
        assert_equal(det_status->out_of_spec[13][13][2], out_of_spec_b14s14[2]);
        /* vrp inop dets */
        assert_equal(det_status->inoperable[18][0][0], vrp_inop_b1s1[0]);
        assert_equal(det_status->inoperable[21][0][0], vrp_inop_b4s1[0]);
        assert_equal(det_status->inoperable[21][0][1], vrp_inop_b4s1[1]);
        assert_equal(det_status->inoperable[21][13][0], vrp_inop_b4s14[0]);
        assert_equal(det_status->inoperable[21][13][1], vrp_inop_b4s14[1]);
        assert_equal(det_status->inoperable[23][1][0], vrp_inop_b6s2[0]);
        assert_equal(det_status->inoperable[23][1][1], vrp_inop_b6s2[1]);
        assert_equal(det_status->inoperable[23][1][2], vrp_inop_b6s2[2]);
        assert_equal(det_status->inoperable[23][12][0], vrp_inop_b6s13[0]);
        assert_equal(det_status->inoperable[25][0][0], vrp_inop_b8s1[0]);
        assert_equal(det_status->inoperable[25][13][0], vrp_inop_b8s14[0]);
        assert_equal(det_status->inoperable[25][13][1], vrp_inop_b8s14[1]);
        assert_equal(det_status->inoperable[25][13][2], vrp_inop_b8s14[2]);
        assert_equal(det_status->inoperable[29][13][0], vrp_inop_b14s14[0]);
        /* vrp out of spec dets */
        assert_equal(det_status->out_of_spec[20][6][0], 
                     vrp_out_of_spec_b3s7[0]);
        assert_equal(det_status->out_of_spec[20][6][1], 
                     vrp_out_of_spec_b3s7[1]);
        assert_equal(det_status->out_of_spec[22][1][0], 
                     vrp_out_of_spec_b5s2[0]);
        assert_equal(det_status->out_of_spec[24][11][0], 
                     vrp_out_of_spec_b7s12[0]);
        assert_equal(det_status->out_of_spec[24][11][1], 
                     vrp_out_of_spec_b7s12[1]);
        assert_equal(det_status->out_of_spec[29][6][0],
                     vrp_out_of_spec_b14s7[0]);
        assert_equal(det_status->out_of_spec[29][6][1],
                     vrp_out_of_spec_b14s7[1]);
        /* TIRS */
        for (i = 0; i < 3; i++)
        {
            assert_equal(det_status->inoperable_count[9][i], inopb10_count[i]);
            assert_equal(det_status->inoperable_count[10][i], inopb11_count[i]);
            assert_equal(det_status->inoperable_count[16][i], inopb17_count[i]);

            assert_equal(det_status->out_of_spec_count[9][i], 
                         out_of_spec_b10_count[i]);
            assert_equal(det_status->out_of_spec_count[10][i], 
                         out_of_spec_b11_count[i]);
            assert_equal(det_status->out_of_spec_count[17][i],
                         out_of_spec_b18_count[i]);
        }
        /* tirs inop dets */
        assert_equal(det_status->inoperable[9][0][0], inopb10s1[0]);
        assert_equal(det_status->inoperable[9][2][0], inopb10s3[0]);
        assert_equal(det_status->inoperable[9][2][1], inopb10s3[1]);
        assert_equal(det_status->inoperable[10][1][0], inopb11s2[0]);
        assert_equal(det_status->inoperable[10][1][1], inopb11s2[1]);
        assert_equal(det_status->inoperable[16][1][0], inopb17s2[0]);
        assert_equal(det_status->inoperable[16][1][1], inopb17s2[1]);
        assert_equal(det_status->out_of_spec[9][1][0], out_of_spec_b10s2[0]);
        assert_equal(det_status->out_of_spec[9][1][1], out_of_spec_b10s2[1]);
        assert_equal(det_status->out_of_spec[10][0][0], out_of_spec_b11s1[0]);
        assert_equal(det_status->out_of_spec[10][0][1], out_of_spec_b11s1[1]);
        assert_equal(det_status->out_of_spec[10][1][0], out_of_spec_b11s2[0]);
        assert_equal(det_status->out_of_spec[10][2][0], out_of_spec_b11s3[0]);
        assert_equal(det_status->out_of_spec[17][0][0], out_of_spec_b18s1[0]);
        assert_equal(det_status->out_of_spec[17][0][1], out_of_spec_b18s1[1]);
        assert_equal(det_status->out_of_spec[17][2][0], out_of_spec_b18s3[0]);
        assert_equal(det_status->out_of_spec[17][2][1], out_of_spec_b18s3[1]);

        /* tirs detector map ID */
        assert_equal(det_status->tirs_detector_map_id, 1);
    }
    else
        printf("Get det status returned NULL");

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test read det stats */

Ensure test_read_det_noise()
{
    int i;

    /* first 10 detectors band 1 sca 1*/
    double det_noise_b1s1[] = {1.100000, 1.200000, 1.300000, 1.400000,
        1.001000, 1.002000, 1.003000, 1.004000, 1.005000, 1.006000}; 
    /* last 10 detectors band 1 sca 1*/
    double det_noise_end_b1s1[] = {1.481000, 1.482000,1.483000,1.484000,
        1.485000,1.486000,1.487000,1.488000,1.489000, 1.000320};
    /* first 10 detectors band 9 sca 14 */
    double det_noise_b9s14[] = {9.100000, 9.200000, 9.300000, 9.400000,
        9.001000, 9.002000, 9.003000, 9.004000, 9.005000, 9.006000}; 
    /* last 10 detectors band 9 sca 14 */
    double det_noise_end_b9s14[] = {9.481000, 9.482000,9.483000,9.484000,
        9.485000,9.486000,9.487000,9.488000,9.489000, 9.000320};

    /* oli blind band det noise band 12 sca 1, first 10 dets */
    double det_noise_b12s1[] = {12.001, 12.002, 12.003, 12.004, 12.005, 
            12.006, 12.007, 12.008, 12.009, 12.010};
    /* oli blind band det noise band 12 sca 1, last 10 dets */
    double det_noise_end_b12s1[] = {12.095, 12.096, 12.097, 12.098, 
            12.099, 12.100, 12.101, 12.102, 12.103, 12.104};
    /* oli blind band det noise band 14 sca 14, first 10 dets */
    double det_noise_b14s14[] = {14.001, 14.002, 14.003, 14.004, 14.005, 
            14.006, 14.007, 14.008, 14.009, 14.010};
    /* oli blind band det noise band 14 sca 14, last 10 dets */
    double det_noise_end_b14s14[] = {14.094, 14.095, 14.096, 14.097, 
            14.098, 14.099, 14.100, 14.101, 14.102, 14.103};

    /* vrp det noise band 19 sca 1 */
    double vrp_det_noise_b19s1[] = {19.001,19.002,19.003,19.004,19.005,19.006,
            19.007,19.008,19.009,19.010,19.011,19.012};
    /* vrp det noise band 27 sca 14 */
    double vrp_det_noise_b27s14[] = {27.001,27.002,27.003,27.004,27.005,27.006,
            27.007,27.008,27.009,27.010,27.011,27.012};
    /* vrp det noise band 28 sca 1 */
    double vrp_det_noise_b28s1[] = {28.001,28.002,28.003,28.004,28.005,28.006,
            28.007,28.008,28.009,28.010,28.011,28.012};
    /* vrp det noise band 30 sca 14 */
    double vrp_det_noise_b30s14[] = {30.001,30.002,30.003,30.004,30.005,30.006,
            30.007,30.008,30.009,30.010,30.011,30.012};

    /* tirs blind band 15 sca 1, first 10 dets */
    double det_noise_b15s1[] = {151.010000,151.020000,151.030000,151.040000, 
        151.000100, 151.000200,151.000300,151.000400, 151.000500,151.000600};
    /* tirs blind band 15 sca 1, last 10 dets */
    double det_noise_end_b15s1[] = {151.062700,151.062800,151.062900,151.063000,
        151.063100, 151.063200,151.063300, 151.063400,151.063500,151.000999};
    /* tirs blind band 15 sca 3, first 10 dets  */
    double det_noise_b15s3[] = {153.010000,153.020000,153.030000, 153.040000, 
        153.000100, 153.000200,153.000300,153.000400,153.000500,153.000600};
    /* tirs blind band 15 sca 3, last 10 dets  */
    double det_noise_end_b15s3[] = {153.062700,153.062800,153.062900,153.063000,
        153.063100, 153.063200,153.063300, 153.063400,153.063500,153.000999};
    /* tirs blind band 16 sca 1, first 10 dets */
    double det_noise_b16s1[] = {16.000100,16.000200,16.000300,
       16.000400,16.000500,16.000600,16.000700,16.000800,16.000900,16.001000};
    /* tirs blind band 16 sca 1, last 10 dets */
    double det_noise_end_b16s1[] = {16.063100,16.063200,16.063300,
       16.063400,16.063500,16.063600,16.063700,16.063800,16.063900,16.064000};
    /* tirs blind band 18 sca 3, first 10 dets  */
    double det_noise_b18s3[] = {18.000100,18.000200,18.000300,
       18.000400,18.000500,18.000600,18.000700,18.000800,18.000900,18.001000};
    /* tirs blind band 18 sca 3, last 10 dets  */
    double det_noise_end_b18s3[] = {18.063100,18.063200,18.063300,
       18.063400,18.063500,18.063600,18.063700,18.063800,18.063900,18.064000};


    IAS_CPF *cpf;
    const struct IAS_CPF_DETECTOR_NOISE *det_noise;

    printf("Test detector noise read...........\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    det_noise = ias_cpf_get_det_noise(cpf);
    assert_true(det_noise != NULL);

    if (det_noise != NULL)
    {
        /* test the first and last 10 detectors */
        for (i = 0; i< 10; i++)
        {
            /* test band 1 sca 1 */
            assert_double_equal(det_noise->per_detector[0][0][i], 
                                det_noise_b1s1[i]);
            assert_double_equal(det_noise->per_detector[0][0][i+484], 
                                det_noise_end_b1s1[i]);
            /* test band 9 sca 14 */
            assert_double_equal(det_noise->per_detector[8][13][i], 
                                det_noise_b9s14[i]);
            assert_double_equal(det_noise->per_detector[8][13][i+484], 
                                det_noise_end_b9s14[i]);
        
            /* test the first and last 10 of band 12 sca 1 */
            assert_double_equal(det_noise->per_detector[11][0][i], 
                        det_noise_b12s1[i]);
            assert_double_equal(det_noise->per_detector[11][0][i+94], 
                        det_noise_end_b12s1[i]);
            /* test the first and last 10 of band 14 sca 14 */
            assert_double_equal(det_noise->per_detector[13][13][i], 
                        det_noise_b14s14[i]);
            assert_double_equal(det_noise->per_detector[13][13][i+93], 
                        det_noise_end_b14s14[i]);

            /* test the first and last 10 of band 15 sca 1 */
            assert_double_equal(det_noise->per_detector[14][0][i], 
                     det_noise_b15s1[i]);
            assert_double_equal(det_noise->per_detector[14][0][i+630],
                     det_noise_end_b15s1[i]);
            /* test the first and last 10 of band 15 sca 3 */
            assert_double_equal(det_noise->per_detector[14][2][i], 
                     det_noise_b15s3[i]);
            assert_double_equal(det_noise->per_detector[14][2][i+630],
                     det_noise_end_b15s3[i]);

            /* test the first and last 10 of band 16 sca 1 */
            assert_double_equal(det_noise->per_detector[15][0][i],
                     det_noise_b16s1[i]);
            assert_double_equal(det_noise->per_detector[15][0][i+630],
                     det_noise_end_b16s1[i]);
            /* test the first and last 10 of band 18 sca 3 */
            assert_double_equal(det_noise->per_detector[17][2][i],
                     det_noise_b18s3[i]);
            assert_double_equal(det_noise->per_detector[17][2][i+630],
                     det_noise_end_b18s3[i]);
        }
        /* test the vrp group */
        for (i = 0; i< 12; i++)
        {
            /* test band 19 sca 1 */
            assert_double_equal(det_noise->per_detector[18][0][i],
                    vrp_det_noise_b19s1[i]);
            /* test band 27 sca 14 */
            assert_double_equal(det_noise->per_detector[26][13][i],
                    vrp_det_noise_b27s14[i]);
            /* test band 28 sca 1 */
            assert_double_equal(det_noise->per_detector[27][0][i],
                    vrp_det_noise_b28s1[i]);
            /* test band 30 sca 14 */
            assert_double_equal(det_noise->per_detector[29][13][i],
                    vrp_det_noise_b30s14[i]);
        }
    }
    else
        printf("DET NOISE returned as NULL\n");

    /* free memory */
    ias_cpf_free(cpf);

} /* end of test det noise */

Ensure test_read_oli_b2b()
{
    int i;

    /* oli bands */
    int corr_window_size[] = {64,64};
    int corr_pix_min = 1;
    int corr_pix_max = 4096;
    int corr_fit_method = 1;
    int max_displacement_offset = 32;
    double fill_threshold = 0.05;
    double min_corr_strength = 3.0;
    double threshold_line_B01[] 
      = {1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0};
    double threshold_line_B09[] 
      = {1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0};
    double threshold_line_B10[] = {1.0, 1.0, 1.0};
    double threshold_line_B11[] = {1.0, 1.0, 1.0};

    double threshold_sample_B01[] 
      = {1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0};
    double threshold_sample_B09[] 
      = {1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0};
    double threshold_sample_B10[] = {1.0, 1.0, 1.0};
    double threshold_sample_B11[] = {1.0, 1.0, 1.0};

    IAS_CPF *cpf;
    const struct IAS_CPF_B2B_ASSESSMENT *b2b;

    printf("Test oli b2b parameter read......\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    b2b = ias_cpf_get_b2b_assessment(cpf);
    assert_true(b2b != NULL);
    if (b2b == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    assert_equal(b2b->corr_window_size[0], corr_window_size[0]);
    assert_equal(b2b->corr_window_size[1], corr_window_size[1]);
    assert_equal(b2b->corr_pix_min, corr_pix_min);
    assert_equal(b2b->corr_pix_max, corr_pix_max);
    assert_equal(b2b->corr_fit_method, corr_fit_method);
    assert_equal(b2b->max_displacement_offset, max_displacement_offset);
    assert_double_equal(b2b->fill_threshold, fill_threshold);
    assert_double_equal(b2b->min_corr_strength, min_corr_strength);

    for (i = 0; i < 14; i++)
    {
        assert_double_equal(b2b->trend_threshold_line[0][i], 
                            threshold_line_B01[i]);
        assert_double_equal(b2b->trend_threshold_line[8][i], 
                            threshold_line_B09[i]);
        /* sample */
        assert_double_equal(b2b->trend_threshold_sample[0][i], 
                            threshold_sample_B01[i]);
        assert_double_equal(b2b->trend_threshold_sample[8][i], 
                            threshold_sample_B09[i]);
    }
    for (i = 0; i < 3; i++)
    {
        assert_double_equal(b2b->trend_threshold_line[0][i], 
                            threshold_line_B10[i]);
        assert_double_equal(b2b->trend_threshold_line[1][i], 
                            threshold_line_B11[i]);
        /* sample */
        assert_double_equal(b2b->trend_threshold_sample[0][i], 
                            threshold_sample_B10[i]);
        assert_double_equal(b2b->trend_threshold_sample[1][i], 
                            threshold_sample_B11[i]);
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of read b2b */

/* test attitude parameters data */
Ensure test_read_attitude()
{
    int i,j;

    double offsets[] = {2.556, -0.669, 0.082};

    double iru_align[][3] = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
    
    double acs2oli_rotation_matrix[][3] = 
                            {{0.999998525, -0.00150454392, 0.000828929988}, 
                             {0.0015036322, 0.999998265, 0.00109939374}, 
                             {-0.000830582636, -0.00109814572, 0.999999052}}; 

    double acs2tirs_rotation_matrix[][3] = 
                            {{0.999998525, -0.00150454392, 0.000828929988}, 
                             {0.0015036322, 0.999998265, 0.00109939374}, 
                             {-0.000830582636, -0.00109814572, 0.999999052}}; 

    double siru_a[] = {0.57735027, 0.57735027, 0.57735027};
    double siru_b[] = {0.57735027, -0.57735027, 0.57735027,}; 
    double siru_c[] = {-0.57735027, -0.57735027, 0.57735027}; 
    double siru_d[] = {-0.57735027, 0.57735027, 0.57735027};

    IAS_CPF *cpf;
    const struct IAS_CPF_ATTITUDE_PARAMETERS *attitude;

    printf("Test attitude parameters read.....\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    attitude = ias_cpf_get_attitude_params(cpf);
    assert_true(attitude != NULL);

    if (attitude != NULL)
    {
        for (i = 0; i < 3; i++)
        {
            assert_double_equal_with_message(attitude->cm_to_oli_offsets[i], 
            offsets[i], 
            "ATTUTUDE: OFFSETs != offsets: %f, test: %f, bucket: %d",
            attitude->cm_to_oli_offsets[i], offsets[i], i);

            assert_double_equal_with_message(attitude->cm_to_tirs_offsets[i], 
            offsets[i], 
            "ATTUTUDE: OFFSETs != offsets: %f, test: %f, bucket: %d",
            attitude->cm_to_tirs_offsets[i], offsets[i], i);

            /* take care of the second dimention arrays */
            for (j = 0; j < 3; j++)
            {
                assert_double_equal_with_message(
                attitude->iru_to_acs_align_matrix[i][j], 
                iru_align[i][j], 
                "ATTITUDE iru align not equal: %f, test: %f, bucket: %d",
                attitude->iru_to_acs_align_matrix[i][j], iru_align[i][j]);

                assert_double_equal( attitude->acs_to_oli_rotation_matrix[i][j],
                                    acs2oli_rotation_matrix[i][j]);
                assert_double_equal( attitude
                                ->acs_to_tirs_rotation_matrix[i][j],
                                    acs2tirs_rotation_matrix[i][j]);
            }
        }
        for (i = 0; i < 3; i++)
        {
            assert_double_equal(attitude->siru_axis_a[i], siru_a[i]);
            assert_double_equal(attitude->siru_axis_b[i], siru_b[i]);
            assert_double_equal(attitude->siru_axis_c[i], siru_c[i]);
            assert_double_equal(attitude->siru_axis_d[i], siru_d[i]);
        }
    }
    else
        printf("Attitude parameters are NULL\n");

    /* free memory */
    ias_cpf_free(cpf);
}
/* test ancillary eng conv data */
Ensure test_read_ancil_conv()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_ANCILLARY_ENG_CONV *ancil_eng_conv;

    printf("Test ancillary eng conv read.....\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    ancil_eng_conv = ias_cpf_get_ancil_conv(cpf);
    assert_true(ancil_eng_conv != NULL);

    if (ancil_eng_conv != NULL)
    {
        assert_double_equal(ancil_eng_conv->quaternion_eng_conv, 1E-09);
        assert_double_equal(ancil_eng_conv->quaternion_conv_vector, 1.0E-09);
        assert_double_equal(ancil_eng_conv->quaternion_conv_scalar, 1.0E-09);
        assert_double_equal(ancil_eng_conv->star_conv_time, 0.064);
        assert_double_equal(ancil_eng_conv->star_conv_position, 0.5);
        assert_double_equal(ancil_eng_conv->star_conv_intensity, 0.0625);
        assert_double_equal(ancil_eng_conv->gyro_conv_angle, 0.05);
        assert_double_equal(ancil_eng_conv->gyro_conv_time, 4.0E-06);
        assert_double_equal(ancil_eng_conv->tirs_integration_time_scale,
            31.25);
        assert_double_equal(ancil_eng_conv->oli_integration_time_scale,
            1.0);
        assert_equal(ancil_eng_conv->oli_integration_time_ms_offset_nominal,
            4219);
        assert_equal(ancil_eng_conv->oli_integration_time_pan_offset_nominal,
            2101);
        assert_equal(ancil_eng_conv->oli_integration_time_ms_offset_8x,
            33871);
        assert_equal(ancil_eng_conv->oli_integration_time_pan_offset_8x,
            16927);
    }
    else
        printf("Ancil env conv is NULL\n");

    /* free memory */
    ias_cpf_free(cpf);
}

/* test ancillary data read */
Ensure test_read_ancil_qa_thresh()
{
    int i;
    IAS_CPF *cpf;
    const struct IAS_CPF_ANCILLARY_QA_THRESHOLDS *ancil_qa_thresholds;

    double iru_outlier[] = {0.001, 0.002, 0.003, 0.004};

    printf("Test ancillary data read.....\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    ancil_qa_thresholds = ias_cpf_get_ancil_qa_thresholds(cpf);
    assert_true(ancil_qa_thresholds != NULL);
    if (ancil_qa_thresholds == NULL)
    {
        ias_cpf_free(cpf);
        return;
    }

    assert_double_equal_with_message(
            ancil_qa_thresholds->orbit_radius_tolerance,
            50.0E+03, "ANCILLARY DATA: orbit radius tolerance not equal");

    assert_double_equal_with_message(
            ancil_qa_thresholds->angular_momentum_tolerance,
            150.0E+06, "ANCILLARY DATA: angular momentum tolerance not equal");

    assert_double_equal_with_message(
            ancil_qa_thresholds->spacecraft_clock_tai_epoch,
            12345678, "ANCILLARY DATA: spacecraft clock not equal");

    assert_double_equal(
            ancil_qa_thresholds->quaternion_normalization_outlier_threshold,
            0.000001);

    for (i = 0; i < 4; i++)
    {
        assert_double_equal_with_message(
            ancil_qa_thresholds->iru_outlier_threshold[i],
            iru_outlier[i], "ANCIL DATA: iru_outlier: %f, test: %f, bucket: %d",
            ancil_qa_thresholds->iru_outlier_threshold[i], iru_outlier[i], i);
    }

    /* free memory */
    ias_cpf_free(cpf);
}

/* test abs gains read */
Ensure test_read_abs_gains()
{
    int i;                  /* loop counter */

    IAS_CPF *cpf;
    const struct IAS_CPF_ABSOLUTE_GAINS *abs_gains;

    /* declare data file to verify */
    double oli_gainband01[] = {0.0, -5.96, 0.0, 0.0, -2.33, -2.39, 
    -2.38, 0.0, 0.0, 9.286, 0.0, 0.0, 0.0, 1.1E-06};

    double oli_gainband02[] = {0.0, -5.96E-06, 0.0, 0.0, -2.33E-05, -2.39E-05, 
    -2.38E-05, 0.0, 0.0, 9.28E-06, 0.0, 0.0, 0.0, 1.1E-06};

    double oli_gainband09[] = {-5.96E-06, 0.0, 0.0, -2.33E-05, -2.39E-05, 
    -2.38E-05, 0.0, 0.0, 9.28E-06, 0.0, 0.0, 0.0, 0.0, 1.1E-06};

    double tirs_gainband01[] = {-1.1E-06, -1.2E-06, -1.3E-06};

    double tirs_gainband02[] = {-2.1E-06, -2.2E-06, -2.3E-06};

    printf("Test abs gains......\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    abs_gains = ias_cpf_get_abs_gains(cpf);
    assert_true(abs_gains != NULL);

    if (abs_gains != NULL)
    {
        /* test oli band 9 data */
        for (i = 0; i < 14; i++)
        {
            assert_double_equal_with_message(
               abs_gains->gain[0][i],
               oli_gainband01[i], 
               "Error: oli abs gains Band 01: CPF: %f, test: %f, bucket: %d", 
               abs_gains->gain[0][i], oli_gainband01[i], i);

            assert_double_equal_with_message(
               abs_gains->gain[1][i],
               oli_gainband02[i], 
               "Error: oli abs gains Band 02: CPF: %f, test: %f, bucket: %d", 
               abs_gains->gain[1][i], oli_gainband02[i], i);

            assert_double_equal_with_message(
               abs_gains->gain[8][i],
               oli_gainband09[i], 
               "Error: oli abs gains Band 09: CPF: %f, test: %f, bucket: %d", 
               abs_gains->gain[8][i], oli_gainband09[i], i);
        }
        for (i = 0; i < 3; i++)
        {
            assert_double_equal_with_message(
               abs_gains->gain[9][i],
               tirs_gainband01[i], 
               "Error: tirs abs gains Band 1: CPF: %f, test: %f, bucket: %d", 
               abs_gains->gain[9][i], tirs_gainband01[i], i);

            assert_double_equal_with_message(
               abs_gains->gain[10][i],
               tirs_gainband02[i], 
               "Error: tirs abs gains: CPF: %f, test: %f, bucket: %d", 
               abs_gains->gain[10][i], tirs_gainband02[i], i);
        }
    }
    else
    {
        printf("Abs gains are NULL....\n");
    }

    /* free memory */
    ias_cpf_free(cpf);
} /* end of test abs gains */

Ensure test_read_earth_const()
{
    int i;
    IAS_CPF *cpf;
    const struct IAS_CPF_EARTH_CONSTANTS *earth;

    int lyears[] = {1972,1973,1974,1975,1976,1977,1978,1979,1980,1981,
      1982,1983,1985,1988,1990,1991,1992,1993,1994,1996,1997,1999,2006,2009};
    int ldays[] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1};
    int lseconds[] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1};
    char lmonths[24] = {7,1,1,1,1,1,1,1,1,7,7,7,7,1,1,1,7,7,7,1,7,1,1,1};

    int total_leap_seconds;

    printf("Test earth constants.....\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    earth = ias_cpf_get_earth_const(cpf);
    assert_true(earth != NULL);

    if (earth != NULL)
    {
        assert_double_equal_with_message(earth->semi_major_axis, 6378137,
                "EARTH CONST: semi major axis not equal");

        assert_double_equal_with_message(earth->semi_minor_axis, 6356752.3142,
                "EARTH CONST: semi minor axis not equal");

        assert_double_equal_with_message(earth->earth_angular_velocity, 
                7.2921158553E-05,
                "EARTH CONST: angular velocity not equal");

        assert_string_equal(earth->ellipsoid_name, "WGS84");
        
        total_leap_seconds = earth->leap_seconds_data.leap_seconds_count;
        assert_equal(total_leap_seconds, 24);

        for (i = 0; i < total_leap_seconds; i++)
        {
            assert_equal(earth->leap_seconds_data.leap_years[i], lyears[i]);
            assert_equal(earth->leap_seconds_data.leap_days[i], ldays[i]);
            assert_equal(earth->leap_seconds_data.num_leap_seconds[i], 
                                        lseconds[i]);
            assert_equal(earth->leap_seconds_data.leap_months[i], lmonths[i]);
        }
    }
    else
    {
        printf("EARTH struct is NULL.....\n");
    }

    ias_cpf_free(cpf);
} /* end of read earth const */

Ensure test_read_sort_earth_const()
{
    int i;
    IAS_CPF *cpf;
    const struct IAS_CPF_EARTH_CONSTANTS *earth;

    int lyears[] = {1975,1975,1975,1977,1993,1994,2008,2008};
    int ldays[] = {15,31,1,1,30,28,31,1};
    int lseconds[] = {4,5,7,6,3,8,2,1};
    char lmonths[] = {1,1,7,12,11,2,1,7};

    int total_leap_seconds;

    printf("Test leap second sorting in earth constants.....\n");

    cpf = open_cpf_by_filename("L8CPF_leap_second_sort_test");
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    earth = ias_cpf_get_earth_const(cpf);
    assert_true(earth != NULL);

    if (earth != NULL)
    {
        total_leap_seconds = earth->leap_seconds_data.leap_seconds_count;
        assert_equal(total_leap_seconds, 8);

        for (i = 0; i < total_leap_seconds; i++)
        {
            assert_equal(earth->leap_seconds_data.leap_years[i], lyears[i]);
            assert_equal(earth->leap_seconds_data.leap_days[i], ldays[i]);
            assert_equal(earth->leap_seconds_data.num_leap_seconds[i], 
                                        lseconds[i]);
            assert_equal(earth->leap_seconds_data.leap_months[i], lmonths[i]);
        }
    }
    else
    {
        printf("EARTH struct is NULL.....\n");
    }

    ias_cpf_free(cpf);
} /* end of test_read_sort_earth_const */

Ensure test_read_det_offsets()
{
    int i;                  /* loop counter */

    const struct IAS_CPF_DETECTOR_OFFSETS *detector_offsets;
    IAS_CPF *cpf;

    /* declare data file to compare */
    /* across det offsets band 1 sca 1 dets 1 - 247 */
    double oacrossb1s1[] = {+0.005,+0.008,+0.004,+0.007,+0.004,+0.007,
               +0.004,+0.007,+0.004,+0.007,+0.004,+0.007,+0.003,+0.006,+0.003};

    double oacrossb9s1[] = {+0.005,+0.010,+0.004,+0.009,+0.004,+0.009,
               +0.004,+0.009,+0.004,+0.009,+0.004,+0.008,+0.003,+0.008,+0.003};
    
    double talongb1s1[] = {0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 
                0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}; 

    double tacrosb2s3[]= { -0.009, -0.008, -0.008, -0.008, -0.008, -0.007, 
               -0.007, -0.007, -0.007, -0.006, -0.006, -0.006, -0.006, -0.006};

    printf("Test detector offsets.......\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    detector_offsets = ias_cpf_get_det_offsets(cpf);
    assert_true(detector_offsets != NULL);

    if (detector_offsets != NULL)
    {
        for (i = 0; i < 15; i++)
        {
            assert_double_equal_with_message(
               detector_offsets->across_per_detector[0][0][i],
               oacrossb1s1[i], 
               "Error: Det Offsets: CPF: %f, test: %f, bucket: %d", 
               detector_offsets->across_per_detector[0][0][i],
                    oacrossb1s1[i], i);

            assert_double_equal_with_message(
                detector_offsets->across_per_detector[8][0][i], 
                oacrossb9s1[i],
               "Error: Det Offsets: CPF: %f, test: %f, bucket: %d", 
               detector_offsets->across_per_detector[9][0][i], 
                    oacrossb9s1[i], i);
        }
        for (i = 0; i < 14; i++)
        {
            assert_double_equal(detector_offsets->along_per_detector[9][0][i],
                talongb1s1[i]);
            assert_double_equal(detector_offsets->across_per_detector[10][2][i],
                tacrosb2s3[i]);
        }
    }
    else
    {
        printf("get det offsets returned NULL.....\n");
    }
    ias_cpf_free(cpf);
} /* end of test det offsets */

Ensure test_read_file_attributes()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_FILE_ATTRIBUTES *file_atts;

    printf("Test file attributes.....\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    file_atts = ias_cpf_get_file_attributes(cpf);
    assert_true(file_atts != NULL);
  
    if (file_atts != NULL)
    {
        /* test file attributes group */
        assert_string_equal(file_atts->effective_date_begin, 
                        "2009-01-01T00:00:00");
        assert_string_equal(file_atts->effective_date_end, 
                        "2009-03-31T23:59:59");
        assert_equal(file_atts->collection_number, 1);
        assert_equal(file_atts->version, 99);

    }
    else
    { 
       printf("file attributes returned as null.....\n");
    }
    ias_cpf_free(cpf);
}

Ensure test_framing_parameters()
{
    IAS_CPF *cpf;
    const struct IAS_CPF_FRAMING_PARAMETERS *framing_params;

    printf("Test framing parameters.....\n");

    cpf = open_cpf();
    assert_true(cpf != NULL);
    if (cpf == NULL)
        return;

    /* Test the OLI framing parameters */
    framing_params = ias_cpf_get_oli_framing_parameters(cpf);
    assert_true(framing_params != NULL);
    if (framing_params != NULL)
    {
        /* test parameters for the correct values */
        assert_equal(framing_params->frames_per_scene, 7501);
        assert_equal(framing_params->min_scene_overlap_frames, 1020);
    }

    /* Test the TIRS framing parameters */
    framing_params = ias_cpf_get_tirs_framing_parameters(cpf);
    assert_true(framing_params != NULL);
    if (framing_params != NULL)
    {
        /* test parameters for the correct values */
        assert_equal(framing_params->frames_per_scene, 2701);
        assert_equal(framing_params->min_scene_overlap_frames, 600);
    }

    ias_cpf_free(cpf);
}
