#ifndef LOCAL_DEFINES_H
#define LOCAL_DEFINES_H

#include "ias_types.h"  /* IAS_ACCESS_MODE definition */

/* Defining some macro routines to work with the data buffers regarding
   endianness.
   For GCPs, the chips will always be little endian format on disk, so need to
   byte-swap the data buffer read and for writing if on a big endian system. */

#ifndef HAVE_LITTLE_ENDIAN
#define SWAP_BYTES_16(x)                                \
{                                                       \
    unsigned short data_macro = *(unsigned short*)&(x); \
    data_macro = (((data_macro & 0xff00) >> 8)          \
               |  ((data_macro & 0x00ff) << 8));        \
    *(unsigned short*)&(x) = data_macro;                \
}
#define SWAP_BYTES_32(x)                                \
{                                                       \
    unsigned int data_macro = *(unsigned int*)&(x);     \
    data_macro = (((data_macro & 0xff000000) >> 24)     \
               |  ((data_macro & 0x00ff0000) >> 8)      \
               |  ((data_macro & 0x0000ff00) << 8)      \
               |  ((data_macro & 0x000000ff) << 24));   \
    *(unsigned int*)&(x) = data_macro;                  \
}
#else
#define SWAP_BYTES_16(x)
#define SWAP_BYTES_32(x)
#endif

/* Define a structure for tracking image chips when read/written in a tarball.
   The memory for the chip is allocated and needs to be freed. */
typedef struct image_chip
{
    char name[IAS_GCP_CHIP_NAME_SIZE];  /* Name of the image chip */
    unsigned char *chip;                /* Pointer to the chip image data */
    int bytes;                          /* Count of bytes in the chip */
} IMAGE_CHIP;

struct ias_gcp_image_chip_io
{
    char *container_name;           /* Directory or tarball name */
    IAS_GCP_CONTAINER_TYPE type;    /* Indicates the type of container */
    IMAGE_CHIP *image_chips;        /* Array of image chips */
    int allocated_chip_count;       /* Count of elements that can be stored in
                                       image_chips */
    int image_chip_count;           /* Count of elements currently stored in
                                       image_chips */
    IAS_ACCESS_MODE mode;           /* Read or write flag */
    int last_search_index;          /* Chip index last returned by a search */
};

#endif
