#!/usr/bin/perl -w

# convert old GCPLIB data file to new format

use strict;
use POSIX;

# lines written out
my @out;

# open input gcplib file
open FILE, "gcplib_old_test_data.txt" or die $!;
# read in the file
my @lines = <FILE>;

foreach my $line (@lines)
{
    chomp $line;
    # skip data start marker
    next if $line =~ /^BEGIN/;
    # skip comments
    next if $line =~ /^#/;
    # remove every other line, specifically lines that begin with space
    next if $line =~ /^\s/;
    my (
        $point_id, 
        $chip_name, 
        $reference_line,
        $reference_sample, 
        $latitude, 
        $longitude,
        $projection_y, 
        $projection_x, 
        $elevation,
        $pixel_size_x, 
        $pixel_size_y,
        $chip_size_lines, 
        $chip_size_sample, 
        $source,
        $date, 
        $absolute_relative_flag
       ) = split (/\s/, $line, 16);
    # deal with changes in file format:
    # no longer two lines per chip, just one line of data; added GCP type, 
    # projection, zone, and absolute/relative flag, added GCP chip data
    # type
    my $chip_type = "CONTROL";
    my $projection = "UTM";
    my $zone = 1;
    my $chip_data_type = 'BYTE';

    my $formatted_line = sprintf(
        "%d %s %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %s %s " .
        "%s %s %s %s\n", 
        $point_id, 
        $chip_name, 
        $reference_line,
        $reference_sample, 
        $latitude, 
        $longitude,
        $projection_y, 
        $projection_x, 
        $elevation,
        $pixel_size_x, 
        $pixel_size_y, 
        $chip_size_lines, 
        $chip_size_sample,
        $source, 
        $chip_type, 
        $projection, 
        $zone,
        $date, 
        $chip_data_type
        );

    push @out, $formatted_line;
}

my $total = $#out + 1;
# open output gcplib file
open OUTPUT, ">gcplib_new_test_data.txt" or die $!;
print OUTPUT "# Unique Ground Control Point ID - integer\n"
    . "# Name of the chip image - string\n"
    . "# Reference line - double\n"
    . "# Reference sample - double\n"
    . "# True latitude of reference point in degrees - double\n"
    . "# True longitude of reference point in degrees - double\n"
    . "# Projection x value of reference point in meters - double\n"
    . "# Projection y value of reference point in meters - double\n"
    . "# Elevation at the Ground Control Point in meters - double\n"
    . "# Pixel size x value in meters - double\n"
    . "# Pixel size y value in meters - double\n"
    . "# Chip size in lines - double\n"
    . "# Chip size in samples - double\n"
    . "# Ground Control Point source - string\n"
    . "# Ground Control Point type - string\n"
    . "# Chip projection - string\n"
    . "# Projection UTM zone - integer\n"
    . "# Acquisition date - string in form mm-dd-yyyy\n"
    . "# Absolute or relative flag - string, should be ABS or REL\n"
    . "# Image chip data type - string\n"
    . "BEGIN\n";
print OUTPUT "$total\n";

# write new file
foreach my $line (@out)
{
    print OUTPUT "$line";
}

close OUTPUT;
