/* ******************************** */
/* if we haven't used this file yet */
/* ******************************** */
#ifndef _OLI_MODEL_H
#define _OLI_MODEL_H 1


/* ************* */
/* include files */
/* ************* */
//#include "xxx_structures.h"
//#include "xxx_const.h"
#include "oli_structures.h"

/* ********* */
/* constants */
/* ********* */

#define        MS_SS           0.0
#define        PAN_SS          0.0
#define MAX_PREC_COEFF  3

/* ********** */
/* structures */
/* ********** */

typedef struct OLIMODEL
    {
    int satnum;                 /* Satellite number                         */
    int l0r_fmt_version[3];     /* Level 0R generation software version #   */
    int wrs_path;               /* WRS path number                          */
    double wrs_row;             /* WRS row number                           */
    AcqType acq_type;           /* Acquisition type:  Earth or Stellar      */
    EARTH_MODEL earth;    /* Earth orientation corrections            */
    OLI_IMAGE_MODEL image;      /* OLI image information                    */
    OLI_SENSOR_MODEL sensor;    /* OLI sensor information                   */
    OLI_ATTITUDE_MODEL att;    /* Spacecraft attitude                      */
    OLI_EPHEMERIS_MODEL eph;   /* Spacecraft ephemeris                     */
    OLI_PRECISION_MODEL prec;   /* Spacecraft precision correction factors  */
    } OLIMODEL;

/********************************************/
/* Prototypes for the OLI model I/O routines. */
/********************************************/
int  oli_get_model (
  const char olimodel_filename[STRLEN], /* I: HDF input file name             */
  OLIMODEL *olimodel);                  /* O: OLI model structure to be read  */

int  oli_put_model (
  const char olimodel_filename[STRLEN], /* I: HDF output file name            */
  const OLIMODEL *olimodel);            /* I: OLI model structure to be output*/

int  oli_free_model (
  OLIMODEL *olimodel);                  /* I: OLI model structure to free */

/*********************************************/
/* include files (more at beginning of file) */
/*********************************************/
//#include "oli_init_model.h"
//#include "oli_forward_model.h"

#endif
