#ifndef _OLI_STRUCTURES_H_
#define _OLI_STRUCTURES_H_

//#include "math_quaternion.h"
#include "ias_structures.h"
#include "xxx_const.h"

#define     NPREC       3

typedef struct QUATERNION
{
    IAS_VECTOR v;           /* Vector component */
    double w;               /* Scalar component */
} QUATERNION;

typedef struct EARTH_MODEL
{
   double ut1_utc_correction; /* UT1-UTC conversion */
   double pole_wander_x;      /* Earth's polar wander */
   double pole_wander_y;      /* Earth's polar wander */
   double semi_major;         /* Earth's semi-major axis */
   double semi_minor;         /* Earth's semi-minor axis */
   double eccentricity;       /* Earth's eccentricity */
   double earth_angular_velocity;  /* Earth's inertial rotational rate, or angular velocity */
   double speed_of_light;     /* Speed of light */
} EARTH_MODEL;

typedef struct OLI_IMAGE_MODEL
{  
   int number_image_lines;        /* Number of lines in imagery */
   double utc_epoch_time[3];      /* Year, day of year, seconds of day for start of image */
   double *time_from_epoch;       /* Time of each line present in image data */
   int l0r_fill_pan[NSCA][NUM_DETS_PAN];             /* Fill inserted in L0R */
   int l0r_fill_ms[NSCA][NBANDS-1][NUM_DETS_MS];     /* Fill inserted in L0R */
   int nominal_fill[NBANDS][NSCA];/* Fill needed to ensure positive pixel locations in L0R */
   IAS_VECTOR *pan_table;             /* Panchromatic jitter table */
} OLI_IMAGE_MODEL;

typedef struct OLI_SENSOR_MODEL
{
  double oli2acs[3][3];      /* Sensor to Attitude Control System transformation */
  double cm2oli[3];          /* Offset between SC center of mass and OLI sensor */
  double int_times[2];       /* Pan and MS integration times (microseconds) */ 
  double samp_times[2];      /* Pan and MS sampling times */ 
  double settle_times[2];    /* Pan and MS settling times */
  int number_scas;           /* Number of SCAs in OLI instruments */
  int number_bands;          /* Number of bands in OLI instruments */
  double along_ifov[2];      /* Along track IFOV */
  double across_ifov[2];     /* Across track IFOV */
  int number_det_sca[NBANDS];/* Number of detectors in SCA */
  double sca_coef_x[NSCA][NBANDS][3];
  /* Along-track SCA LOS Legendre coeffs. Note that "_x" refers to
     the sensor coordinate system where the x direction is in the
     direction of satellite motion. */
  double sca_coef_y[NSCA][NBANDS][3];
  /* Across-track SCA LOS Legendre coeffs.  Note that "_y" refers to
     the sensor coordinate system where the y direction is
     perpendicular to the plane formed by the x axis (satellite
     motion) and the z axis pointing to the earth's center. */
  double det_delays_ms[NSCA][NBANDS-1][2][NUM_DETS_MS]; /* Across, along, per -> SCA, Band, detector */
  double det_delays_pan[NSCA][2][NUM_DETS_PAN]; /* Across, along, per -> SCA, Band, detector */
  /* Detector offsets per SCA per Band for each detector.  Contains integer and
     fractional component */
} OLI_SENSOR_MODEL;

typedef struct OLI_TIME_RECORD
{
   double utc_epoch_time[3]; /* year, day of year, seconds of day */
   double nominal_samp_time;
} OLI_TIME_RECORD;

typedef struct OLI_ATTITUDE_RECORD
{
   double time_from_epoch;    /* seconds */
   IAS_VECTOR sat_att;            /* radians */
   IAS_VECTOR prec_att;           /* radians */
} OLI_ATTITUDE_RECORD;

typedef struct OLI_ATTITUDE_ANCILLARY_RECORD
{
   double time_from_epoch;   /* seconds */
   QUATERNION eci_quat;       
   QUATERNION ecf_quat;       
   IAS_VECTOR body_rates;        /* radians per second */    
   IAS_VECTOR rpy;               /* radians */
} OLI_ATTITUDE_ANCILLARY_RECORD;

typedef struct OLI_EPHEMERIS_RECORD
{
   double time_from_epoch;       /* radians */
   IAS_VECTOR eci_position;          /* X, Y, Z (meters) */
   IAS_VECTOR eci_velocity;          /* Vx, Vy, Vz (meters/sec) */
   IAS_VECTOR ecef_position;         /* X, Y, Z (meters) */
   IAS_VECTOR ecef_velocity;         /* Vx, Vy, Vz (meters/sec) */
   IAS_VECTOR prec_eci_position;     /* X, Y, Z (meters) */
   IAS_VECTOR prec_eci_velocity;     /* Vx, Vy, Vz (meters/sec) */
   IAS_VECTOR prec_ecef_position;    /* X, Y, Z (meters) */
   IAS_VECTOR prec_ecef_velocity;    /* Vx, Vy, Vz (meters/sec) */
} OLI_EPHEMERIS_RECORD;

typedef struct OLI_ATTITUDE_MODEL
{
   double utc_epoch_time[3]; /* year, day of year, seconds of day */
   double nominal_samp_time;
   int samples;
   OLI_ATTITUDE_RECORD *records;
} OLI_ATTITUDE_MODEL;

typedef struct OLI_ATTITUDE_ANCILLARY
{
   double utc_epoch_time[3]; 
   double nominal_samp_time;
   int samples;
   OLI_ATTITUDE_ANCILLARY_RECORD *records;
} OLI_ATTITUDE_ANCILLARY;

typedef struct OLI_EPHEMERIS_MODEL
{
   double utc_epoch_time[3]; /* year, day of year, seconds of day */
   double nominal_samp_time;
   int samples;
   OLI_EPHEMERIS_RECORD *records;
} OLI_EPHEMERIS_MODEL;

typedef struct OLI_PRECISION_MODEL
{
  double secs_from_image_epoch;   /* Seconds from epoch */
  int eph_order;            /* Number of ephemeris correction coefficients */
  double x[NPREC];          /* Ephemeric correction X direction */
  double y[NPREC];          /* Ephemeric correction Y direction */
  double z[NPREC];          /* Ephemeric correction Z direction */
  int att_order;            /* Number of attitude correction coefficients */
  double roll[NPREC];       /* Attitude correction roll axis */
  double pitch[NPREC];      /* Attitude correction pitch axis */
  double yaw[NPREC];        /* Attitude correction yaw axis */
} OLI_PRECISION_MODEL;

#endif
