/* ******************************** */
/* if we haven't used this file yet */
/* ******************************** */
#ifndef _OLI_MODEL_H
#define _OLI_MODEL_H 1


/* ************* */
/* include files */
/* ************* */
//#include "xxx_structures.h"
//#include "xxx_const.h"
//#include "oli_structures.h"
//#include "oli_sensor_structure.h"
#include "tirs_structures.h"

#include <hdf5.h>

/* ********* */
/* constants */
/* ********* */

#define	MS_SS			0.0
#define	T1A_SS			0.0
#define MAX_PREC_COEFF		3
#define NUM_COEFF_PER_BAND	4

/* ********** */
/* structures */
/* ********** */

typedef struct OLIMODEL
    {
    int satnum;                 /* Satellite number                         */
    int l0r_fmt_version[3];     /* Level 0R generation software version #   */
    int wrs_path;               /* WRS path number                          */
    double wrs_row;             /* WRS row number                           */
    AcqType acq_type;           /* Acquisition type:  Earth or Stellar      */
    EARTH_MODEL earth;          /* Earth orientation corrections            */
    OLI_IMAGE_MODEL image;      /* OLI image information                    */
    OLI_SENSOR_MODEL sensor;    /* OLI sensor information                   */
    OLI_ATTITUDE_MODEL att;     /* Spacecraft attitude                      */
    OLI_EPHEMERIS_MODEL eph;    /* Spacecraft ephemeris                     */
    TIRS_SCENE_SELECT_MIRROR tirs_ssm;   /* TIRS scene select mirror        */
    OLI_PRECISION_MODEL prec;   /* Spacecraft precision correction factors  */
    } OLIMODEL;

typedef struct OLIPRECMODEL
    {
    int satnum;                 /* Satellite number                         */
    int l0r_fmt_version[3];     /* Level 0R generation software version #   */
    int wrs_path;               /* WRS path number                          */
    double wrs_row;             /* WRS row number                           */
    AcqType acq_type;           /* Acquisition type:  Earth or Stellar      */
    EARTH_MODEL earth;          /* Earth orientation corrections            */
    OLI_IMAGE_MODEL image;      /* OLI image information                    */
    OLI_SENSOR_MODEL sensor;    /* OLI sensor information                   */
    OLI_ATTITUDE_MODEL att;     /* Spacecraft attitude                      */
    OLI_EPHEMERIS_MODEL eph;    /* Spacecraft ephemeris                     */
    TIRS_SCENE_SELECT_MIRROR tirs_ssm;   /* TIRS scene select mirror        */
    OLI_PRECISION_MODEL prec;   /* Spacecraft precision correction factors  */
    } OLIPRECMODEL;

/********************************************/
/* Prototypes for the OLI model I/O routines. */
/********************************************/
int  oli_get_model (
  const char olimodel_filename[STRLEN], /* I: HDF input file name             */
  OLIMODEL *olimodel);                  /* O: OLI model structure to be read  */

int  oli_put_model (
  const char olimodel_filename[STRLEN], /* I: HDF output file name            */
  const OLIMODEL *olimodel);            /* I: OLI model structure to be output*/

int  oli_free_model (
  OLIMODEL *olimodel);                  /* I: OLI model structure to free */

int  oli_get_prec_model (
  const char olimodel_filename[STRLEN], /* I: HDF input file name             */
  OLIPRECMODEL *olimodel);              /* O: OLI model structure to be read  */

int  oli_put_prec_model (
  const char olimodel_filename[STRLEN], /* I: HDF output file name            */
  const OLIPRECMODEL *olimodel);        /* I: OLI model structure to be output*/

int  oli_free_prec_model (
  OLIPRECMODEL *olimodel);              /* I: OLI model structure to free     */

/*********************************************/
/* include files (more at beginning of file) */
/*********************************************/
//#include "oli_init_model.h"
//#include "oli_forward_model.h"

#endif
