#ifndef _XXX_CONST_H_
#define _XXX_CONST_H_

#include "ias_types.h"
//#include "../libs/ipe/io/misc/ias_types.h" /* for the IPE_DATA_TYPE */

/*
 * System-wide definitions
 */
/* Data field sizes */
#define PTIDLEN 16	/* length of a point id */
#define STRLEN 795	/* length of a string */

/* OLI Configuration */
#define NUM_DETS_MS     494
#define NUM_DETS_PAN    988
#define	NSCA		14	/* number of OLI SCAs */
#define	EPHEM_TIME	1.0	/* ephemeris sampling interval */
#define	EPA_TIME	1.0	/* quaternion sampling interval */
#define	IRU_TIME	1.0	/* IRU sampling interval */
#define	LAGRANGE_PTS	4	/* Number of points to use in
				   Lagrange interpolation */
#define PAN_BAND         0   /* 0-referenced index to pan band */

#define	PAN_SCALE	2.0     /* Scale of PAN to MS in resolution */
#define MAX_DET_DELAY	10.0	/* Maximum detector offset or delay */

#define OUTSIDE 99                /* code for a point outside the image   */
#define LINES_TO_BUFFER 2
/* defines the number of lines to buffer at a time for exx_gpyramid. */

/* Model structure definitions */
#define NAXIS           3       /* Number of axis (X, Y, Z) */
#define NPCD_EPH        400     /* 200 Max number of ephemeris records */
#define NPCD_ATT        16384   /* Max number of attitude PCD records */

/* File access modes */
typedef enum access_mode
 {access_error=-1, READ, WRITE, UPDATE}
  AccessMode;

/* redefine this type until everyone converts to the correct IPE_DATA_TYPE */
typedef IAS_DATA_TYPE DataType;
#if 0
/* Valid data types */
typedef enum data_type
 {type_error=-1,  /* invalid type 		*/
  BYTE, 	/* 1-byte  			*/
  I2, 		/* 2-byte signed integer 	*/
  UI2, 		/* 2-byte unsigned integere 	*/
  I4, 		/* 4-byte signed integer 	*/
  UI4, 		/* 4-byte signed integer 	*/
  R4, 		/* 4-byte floating point	*/
  R8, 		/* 8-byte floating point	*/
  NDTYPES}  /* number of different data types */
 DataType;
#endif

typedef enum band_number
 {berror=-1, pan, b1, b2, b3, b4, b5, b6, b7, b9, NBANDS, OPTICAL_AXIS}
 BandNumber;

/* band indexing method, OPTICAL_AZIS is the center of the optical/focal plane */
typedef enum hyp_band_number
 {herror=-1,h1,h2,h3,h4,h5,h6,h7,h8,h9,h10,h11,h12,h13,h14,h15,h16,h17,h18,h19,
            h20,h21,h22,h23,h24,h25,h26,h27,h28,h29,h30,h31,h32,h33,h34,h35,h36,
            h37,h38,h39,h40,h41,h42,h43,h44,h45,h46,h47,h48,h49,h50,h51,h52,h53,
            h54,h55,h56,h57,h58,h59,h60,h61,h62,h63,h64,h65,h66,h67,h68,h69,h70,
            h71,h72,h73,h74,h75,h76,h77,h78,h79,h80,h81,h82,h83,h84,h85,h86,h87,
            h88,h89,h90,h91,h92,h93,h94,h95,h96,h97,h98,h99,h100,h101,h102,h103,
            h104,h105,h106,h107,h108,h109,h110,h111,h112,h113,h114,h115,h116,h117,
            h118,h119,h120,h121,h122,h123,h124,h125,h126,h127,h128,h129,h130,h131,
            h132,h133,h134,h135,h136,h137,h138,h139,h140,h141,h142,h143,h144,h145,
            h146,h147,h148,h149,h150,h151,h152,h153,h154,h155,h156,h157,h158,h159,
            h160,h161,h162,h163,h164,h165,h166,h167,h168,h169,h170,h171,h172,h173,
            h174,h175,h176,h177,h178,h179,h180,h181,h182,h183,h184,h185,h186,h187,
            h188,h189,h190,h191,h192,h193,h194,h195,h196,h197,h198,h199,h200,h201,
            h202,h203,h204,h205,h206,h207,h208,h209,h210,h211,h212,h213,h214,h215,
            h216,h217,h218,h219,h220,h221,h222,h223,h224,h225,h226,h227,h228,h229,
            h230,h231,h232,h233,h234,h235,h236,h237,h238,h239,h240,h241,h242,
            HYP_NBANDS,HYP_OPTICAL_AXIS}
 HBandNumber;

/* resolutions for the different OLI bands */
typedef enum raw_pixel_size 
 {unknown_size=-1, _30m=30, _15m=15}
 RawPixelSize; 

/* detector location options for LOS modelling */
typedef enum detector_type
 {derror = -1,     /* invalid type                        */
  NOMINAL,         /* nominal (central) detector location */
  ACTUAL,          /* location including even/odd offset  */
  EXACT,           /* location including detector delays  */
  MAXIMUM}         /* Maximum detector delay              */
 DetType;

/* ephemeris selection type */
typedef enum ephemeris_type
 {dephem = -1,     /* invalid type               */
  ACSPTS,          /* ephemeris from ACS records */
  GPSPTS,          /* ephemeris from GPS records */
  DEFEPH}          /* definitive ephemeris */
 EphemType;

/* ephemeris selection type */
typedef enum acquisition_type
 {dacquis = -1,     /* invalid type               */
  EARTH_ACQ,        /* Earth based acquisition*/
  STELLAR_ACQ,      /* Stellar based acquisition */
  LUNAR_ACQ}        /* Lunar based acquisition */
 AcqType;

/* fit method used in correlation */
typedef enum corr_fit_method
 {FIT_ERROR=-1, FIT_ELLIP_PARA=1, FIT_ELLIP_GAUSS, FIT_RECIP_PARA, FIT_ROUND}
 CorrFitMethod;

/* type of correction being used */
typedef enum correction_type
 {correction_type_error=-1, SYSTEMATIC=1, PRECISION, TERRAIN}
 CorrectionType;

/* additional error codes */
#define EO1_EXISTS -2

#define	HYP_FRAME_RATE (1.0 / 223.38)	/* Hyperion frame rate		*/
#define MAX_PATH_WRS 233		/* maximum WRS path		*/
#define MAX_ROW_WRS 248			/* maximum WRS row		*/
#define EPOCH_2000      2451545.0       /* Julian date of epoch 2000    */
#define JULIAN_CENTURY      36525.0     /* Julian century		*/
#define HALFPIE 1.5707963267948966      /* One half PI                  */
#define PIE  3.141592653589793238       /* PI                           */
#define PIE2 6.283185307179586476       /* two PI                       */
#define LITESPEED 2.99793e8             /* Speed of light               */
#define ABER_CORRECTION -25.2267e-6     /* aberration correction for
                                           across_angle calculation     */
#define WE  7.272205217e-5              /* Solar earth rotation rate    */
#define WEI 7.292115428e-5              /* Inertial earth rotation rate */
#define RPD (PIE / 180.0)               /* Radians per degree           */
#define DPR (180.0 / PIE)               /* Degrees per radian           */
#define A2R 4.848136811e-6		/* arc seconds to radians	*/
#define MU 3.986012e14                  /* MU                           */
#define REM 6.378165000e6               /* Mean radius of the earth at equator*/

#define SEC_PER_DAY     86400        /* Seconds Per Day                      */
#define MIL_PER_DAY     86400000     /* Milliseconds Per Day                 */
#define MIL_PER_HOUR    3600000      /* Milliseconds Per Hour                */
#define MIL_PER_MIN     60000        /* Milliseconds Per Hour                */
#define MIL_PER_SEC     1000         /* Milliseconds Per Second              */
 
#define MJD		2400000.5 /* The Modified Julian Date Constant
				    Modified Julian Date = FullJuilanDate - MDJ
				    (where FullJulianDate is a running day count
				    since Jan 1 4713 B.C.		     */

#define MAX_YEAR 2099		/* Max year allowed in xxx_TimeConvert routine*/
#define MIN_YEAR 1980		/* GPS epoch year (arbitrary) */
#define MAX_YDAY 366
#define MIN_YDAY 1
#define MAX_DAY 31
#define MIN_DAY 1
#define MAX_MONTH 12
#define MIN_MONTH 1
#define MAX_HOUR 24
#define MIN_HOUR 0
#define MAX_MIN 59
#define MIN_MIN 0
#define MAX_SEC 59
#define MIN_SEC 0
#define MAX_MICRO 99999999
#define MIN_MICRO 0

#define SECS2RADS 206264.806247096355	/* conversion from Seconds to Radians*/

#ifndef D2R
#define D2R     1.745329251994328e-2 /* conversion for Degrees to Radians    */
#endif

#ifndef R2D
#define R2D     57.295779513082321   /* conversion for Radians to Degrees    */
#endif

/* NOTE: the MIN and MAX definitions must appear the same as sys/param.h */
#ifndef MIN                          /* macro for min of two numbers         */
#define MIN(a,b) (((a)<(b))?(a):(b))
#endif
#ifndef MAX                          /* macro for max of two numbers         */
#define MAX(a,b) (((a)>(b))?(a):(b))
#endif

/*
  Define a macro for the quadradic function
*/
#define QF(c,t) (c[0] + \
                 c[1] * (t) + \
                 c[2] * (t) * (t) + \
                 c[3] * (t) * (t) * (t) + \
                 c[4] * (t) * (t) * (t) * (t) + \
                 c[5] * (t) * (t) * (t) * (t) * (t))

#endif
