/******************************************************************************
NAME:    ias_los_model_get_utc_time_at_location.c

PURPOSE: Finds the time using the forward model.

RETURNS: SUCCESS or ERROR

******************************************************************************/
#include "ias_los_model.h"
#include "ias_logging.h"

int ias_los_model_get_utc_time_at_location
(
    const IAS_LOS_MODEL *model,     /* I: LOS model information */
    double line,                    /* I: Line of interest (target) */
    double sample,                  /* I: Sample of interest (target) */
    int band_index,                 /* I: Band the line/sample are in */
    int sca_index,                  /* I: SCA the line/sample are in */
    IAS_SENSOR_DETECTOR_TYPE dettype, /* I: Detector type */
    double utc_time_at_location[3]  /* O: UTC time (year, doy, and sod) */
)
{
    const IAS_SENSOR_BAND_MODEL *band = &model->sensor.bands[band_index];

    /* Compute image time for input line/sample */
    if (ias_sensor_find_time(line, sample, band_index, sca_index,
                &model->sensor, dettype, &utc_time_at_location[2]) != SUCCESS)
    {
        IAS_LOG_ERROR("Finding time of SCA %d, Band %d, L1R line %f, "
                "L1R samp %f", sca_index, band_index, line, sample);
        return ERROR;
    }

    /* Load the time values */
    utc_time_at_location[0] = band->utc_epoch_time[0];
    utc_time_at_location[1] = band->utc_epoch_time[1];
    utc_time_at_location[2] += band->utc_epoch_time[2];

    return SUCCESS;
}
