/* Standard Library Includes */
#include <string.h>

/* IAS Library Includes */
#include "ias_const.h"
#include "ias_logging.h"
#include "ias_sensor_model.h"

/*********************************************************************
 NAME:      ias_sensor_convert_ssm_position_status_to_string

 PURPOSE:   Converts a given IAS_SENSOR_SSM_POSITION_STATUS 
            to a string representation

 RETURNS:   SUCCESS or ERROR
**********************************************************************/
int ias_sensor_convert_ssm_position_status_to_string
(
    IAS_SENSOR_SSM_POSITION_STATUS position_status,/* I: SSM position status */
    const char **status_string    /* O: The SSM status converted to a string */
)
{
    /* Convert the status to a string representation */
    switch (position_status)
    {
        case IAS_SSM_POSITION_NOMINAL:
            *status_string = "NOMINAL";
            break;
        case IAS_SSM_POSITION_ESTIMATED:
            *status_string = "ESTIMATED";
            break;
        case IAS_SSM_POSITION_DEFAULT:
            *status_string = "DEFAULT";
            break;
        case IAS_SSM_POSITION_SWITCHED:
            *status_string = "SWITCHED";
            break;
        default:
            IAS_LOG_ERROR("Invalid SSM position status %d", position_status);
            *status_string = "UNKNOWN";
            return ERROR;
    }

    return SUCCESS;
}

/*********************************************************************
 NAME:      ias_sensor_convert_string_to_ssm_position_status

 PURPOSE:   Converts a given string representation of an IAS sensor 
            scene select mirror status to the 
            IAS_SENSOR_SSM_POSITION_STATUS equivalent.

 RETURNS:   SUCCESS or ERROR
**********************************************************************/
int ias_sensor_convert_string_to_ssm_position_status
(
    const char *status_string,              /* I: SSM poistion status string */
    IAS_SENSOR_SSM_POSITION_STATUS *position_status/* O: SSM position status */
)
{
    if (strcasecmp(status_string, "NOMINAL") == 0)
        *position_status = IAS_SSM_POSITION_NOMINAL;
    else if (strcasecmp(status_string, "ESTIMATED") == 0)
        *position_status = IAS_SSM_POSITION_ESTIMATED;
    else if (strcasecmp(status_string, "DEFAULT") == 0)
        *position_status = IAS_SSM_POSITION_DEFAULT;
    else if (strcasecmp(status_string, "SWITCHED") == 0)
        *position_status = IAS_SSM_POSITION_SWITCHED;
    else
    {
        IAS_LOG_ERROR("Invalid SSM position status string %s", status_string);
        *position_status = IAS_SSM_POSITION_UNKNOWN;
        return ERROR;
    }

    return SUCCESS;
}
