#ifndef LOCAL_DEFINES_H
#define LOCAL_DEFINES_H
#include "ias_sensor_model.h"

/* Maximum detector offset or delay. In general use, the maximum_detector_delay
   field of the sampling characteristics should be used since it is initialized
   to this value. */
#define MAX_DET_DELAY 10.0

/* Scale of PAN to MS in resolution */
#define PAN_SCALE 2.0

/* Lines per image frame */
#define FRAME_LINES_MS 1
#define FRAME_LINES_PAN 2

/* Define a mask for the bits that are used in the SSM encoder position
   for TIRS */
#define TIRS_SSM_BIT_MASK 0x00ffffff

/* Define the point where the SSM encoder is considered to have overflowed */
#define TIRS_SSM_OVERFLOW 0x01000000

/* Define the point where TIRS has entered signed overflow */
#define TIRS_SSM_LIMIT (TIRS_SSM_OVERFLOW/2)

/* Define the estimated SSM encoder data structure */
typedef struct ias_sensor_estimated_ssm_encoder
{
    double ssm_time[3];
    double ssm_j2000_seconds;
    uint32_t encoder_position;
    IAS_SSM_POSITION_QUALITY ssm_position_quality;
} IAS_SENSOR_ESTIMATED_SSM_ENCODER;

int ias_sensor_load_estimated_ssm
(
    double start_time,             /* I: Seconds from  J2000 epoch time for
                                         which SSM data are needed - start */
    double stop_time,              /* I: Seconds from  J2000 epoch time for
                                         which SSM data are needed - stop */
    const char *ssm_position_filename,/* I: SSM Position Filename */
    IAS_SENSOR_ESTIMATED_SSM_ENCODER **est_ssm_data,/* O: Pointer to allocated 
                                        and populated estimated SSM encoder data
                                        structure array */
    int *number_estimated_encoder_positions/* O: The number of estimated encoder
                                                 positions */
);

int ias_sensor_get_estimated_ssm
( 
    int number_est_encoder_positions,/* I: Number of entries in the estimated 
                                           SSM data array */
    int field_index,                 /* I: SSM data starting field index */
    double start_seconds,            /* I: Starting time offset */
    const IAS_SENSOR_ESTIMATED_SSM_ENCODER *est_ssm_data, /* I: Array containing
                                                   estimated SSM encoder data */
    const IAS_SENSOR_SSM_RECORD *ssm_data, /* I: SSM data */
    IAS_SSM_POSITION_QUALITY *ssm_position_quality,/* I/O: SSM position quality 
                                                       flag */
    IAS_L0R_TIRS_SSM_ENCODER *record /* O: Pointer to SSM record */   
); 

#endif
