#ifndef _IAS_ANGLE_GEN_H_
#define _IAS_ANGLE_GEN_H_

/* IAS Library Includes */
#include "ias_structures.h"       /* IAS_VECTOR and IAS_CORNERS */
#include "ias_grid.h"             /* IAS_GRID_TYPE and IAS_GRID_BAND_TYPE */
#include "ias_los_model.h"        /* IAS_LOS_MODEL */
#include "ias_geo.h"              /* IAS_PROJECTION */
#include "ias_angle_gen_distro.h" /* Angle generation structs */ 

/**********************  FUNCTION PROTOTYPES START  ***************************/

int ias_angle_gen_calculate_angles_rigor
(
    const IAS_ANGLE_GEN_METADATA *metadata,/* I: Metadata structure */
    double l1t_line,    /* I: Output space line coordinate */
    double l1t_samp,    /* I: Output space sample coordinate */
    const double *elev, /* I: Pointer to input elevation or NULL if
                              mean scene height should be used */
    int band_index,     /* I: Current band index */
    IAS_ANGLE_GEN_TYPE sat_or_sun_type, /* I: Angle calculation type */
    int *outside_image_flag,/* O: Flag indicating return was outside image */
    double *angle       /* O: Array containing zenith and azimuth angles */
);

int ias_angle_gen_calculate_band_rpc
(
    const IAS_GRID_BAND_TYPE *gridband, /* I: Grid structure for current band */
    int band_index,                     /* I: Current band index */
    IAS_ANGLE_GEN_METADATA *metadata    /* O: Metadata structure */
);

int ias_angle_gen_create_ang_filename
(
    const char *base_filename, /* I: Base filename */
    int filename_size,         /* I: Filename size */
    char *filename             /* O: Output file name to use */
);

void ias_angle_gen_free_transformation
(
    IAS_ANGLE_GEN_METADATA *metadata /* I: Metadata structure */
);

int ias_angle_gen_initialize_transformation
(
    IAS_ANGLE_GEN_METADATA *metadata /* I/O: Angle metadata struct */
);    

int ias_angle_gen_get_band_data
(
    int band_index,                  /* I: Input band index */
    const IAS_GRID_TYPE *grid,       /* I: Input Grid */
    const IAS_LOS_MODEL *model,      /* I: Input LOS Model */
    IAS_ANGLE_GEN_METADATA *metadata /* O: Output metadata structure */
);

int ias_angle_gen_populate_metadata
(
    double major_axis,               /* I: WGS84 Major Axis */
    double minor_axis,               /* I: WGS84 Minor Axis */
    const IAS_GRID_TYPE *grid,       /* I: Grid data struct */
    const IAS_LOS_MODEL *model,      /* I: LOS model struct */
    IAS_ANGLE_GEN_METADATA *metadata /* O: Metadata struct */
);

int ias_angle_gen_write_ang
(
    const char *ang_filename,     /* I: Filename to write the ANG filename to */
    const IAS_ANGLE_GEN_METADATA *metadata/* I: Metadata struct to write from */
);

#endif
