/* Standard Library Includes */
#include <stdlib.h>

/* IAS Library Includes */
#include "ias_logging.h"
#include "ias_geo.h"
#include "ias_angle_gen.h"
#include "ias_angle_gen_includes.h"

/*******************************************************************************
Name: ias_angle_gen_initialize_transformation

Purpose: Initialize the angle generation metadata transformation

Return:
    Type = Integer
    SUCCESS / ERROR
 ******************************************************************************/
int ias_angle_gen_initialize_transformation
(
    IAS_ANGLE_GEN_METADATA *metadata /* I/O: Angle metadata struct */
)           
{
    int index;                             /* Loop variable */
    int projection_units;                  /* Input units code */
    double parameters[IAS_PROJ_PARAM_SIZE];/* Geo parameter array */
    IAS_PROJECTION in_projection;          /* Source projection */
    IAS_PROJECTION out_projection;         /* Destination projection */

    /* Initialize the geographic projection parameters */
    for (index = 0; index < IAS_PROJ_PARAM_SIZE; index++)
    { 
        parameters[index] = 0.0;
    }

    /* Set the input units code */
    if (ias_geo_get_units(metadata->units, &projection_units) != SUCCESS)
    {
        IAS_LOG_ERROR("Getting the projection units for %s", metadata->units);
        return ERROR;
    }
    
    /* Load the projection structures */
    ias_geo_set_projection(metadata->projection.proj_code, 
        metadata->projection.zone, projection_units, 
        metadata->projection.spheroid, metadata->projection.parameters, 
        &in_projection);
    ias_geo_set_projection(GEO, NULLZONE, RADIAN, metadata->projection.spheroid,
        parameters, &out_projection);

    /* Initialize the projection transformation */
    metadata->transformation = ias_geo_create_proj_transformation(
        &in_projection, &out_projection);   
    if (!metadata->transformation)
    {
        IAS_LOG_ERROR("Initializing the projection transformation");
        return ERROR;
    }

    return SUCCESS;
}

/*******************************************************************************
Name: ias_angle_gen_free_transformation
  
Purpose: Free the angle generation metadata transformation if it has been
    initialized.

Return:
    Type = void
 ******************************************************************************/
void ias_angle_gen_free_transformation
(
    IAS_ANGLE_GEN_METADATA *metadata /* I: Metadata structure */
)           
{
    if (metadata->transformation)
    {
        ias_geo_destroy_proj_transformation(metadata->transformation);
        metadata->transformation = NULL;
    }
}
