
/*---------------------------------------------------------------------------
 NAME:     ias_misc_retrieve_file_from_url

 PURPOSE:  Retrieves a file from any URL that can be used with wget.

 RETURNS:  Integer status code of SUCCESS or ERROR
----------------------------------------------------------------------------*/

#include <stdlib.h>
#include <limits.h>
#include <sys/types.h>
#include <sys/wait.h>

#include "ias_const.h"
#include "ias_logging.h"

int ias_misc_retrieve_file_from_url
(
    const char *url,     /* I: URL to retrieve */
    const char *filename /* I: Filename to create */
)
{
    char wget_command[PATH_MAX + PATH_MAX + PATH_MAX];
        /* System call command string, large enough for mutiple paths */
    int count;  /* snprintf error checking */
    int status; /* Status of the system and command */

    /* Build the wget command to execute */
    count = snprintf (wget_command, sizeof(wget_command), 
        "wget --quiet -O \"%s\" \"%s\"", filename, url);
    if ((count < 0) || (count >= sizeof(wget_command)))
    {
        IAS_LOG_ERROR("Command string truncated by snprintf");
        return ERROR;
    }
    IAS_LOG_DEBUG("Command %s", wget_command);

    status = system(wget_command);
    if (status == -1 || WEXITSTATUS(status) != 0)
    {
        IAS_LOG_ERROR("Retrieving url %s", url);
        return ERROR;
    }

    return SUCCESS;
}

