#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <limits.h>
#include <sys/stat.h>
#include <sys/types.h>

#include "ias_const.h"
#include "ias_miscellaneous.h"

#include "cgreen.h"

/* Environment variable locating the IAS CPS services.  If this isn't
   defined, this test cannot be run. */
static char *ias_services = NULL;


Ensure test_ias_misc_get_rlut()
{
    struct stat stat_buff;

    char sys_command[1000];
    char date_acquired[100] = "2013-05-01T17:00:45";
    char rlut_basename[100] = "L8RLUT20130211_20241231v05.h5";
    int status;


    printf("Testing retrieval of RLUT %s...\n", rlut_basename);

    /* Get the RLUT.  The function will put a symbolic link to the cached
       RLUT file in the directory where this test is executed. */
    status = ias_misc_retrieve_rlut(date_acquired, ias_services,
        rlut_basename, sizeof(rlut_basename));
    assert_equal_with_message(status, SUCCESS, "Error getting RLUT file "
        "from service");

    /* Get stat information about the symbolic link to the cached RLUT file. */
    status = lstat(rlut_basename, &stat_buff);
    assert_equal_with_message(status, 0, "Error retrieving information "
        "about RLUT symbolic link %s", rlut_basename);
    if (status != 0)
    {
        sprintf(sys_command, "rm %s", rlut_basename);
        status = system(sys_command);
        if (status != 0)
        {
            assert_true_with_message(FALSE, "Error removing RLUT symbolic "
                "link %s", rlut_basename);
        }
        return;
    }

    /* A path to the cached RLUT file should be defined for the link, and
       it should be classed as a symbolic link. */
    assert_true_with_message(stat_buff.st_size, "Invalid path length in "
        "symbolic link %s", rlut_basename);
    assert_true_with_message(S_ISLNK(stat_buff.st_mode), "%s is not "
        "classed as a symbolic link", rlut_basename);

    /* Clear out the current stat information. */
    memset(&stat_buff, 0, sizeof(struct stat));

    /* Get stat information for the cached RLUT file itself. */
    status = stat(rlut_basename, &stat_buff);
    assert_equal_with_message(status, 0, "Error retrieving information for "
        "the cached RLUT file pointed to by %s", rlut_basename);
    if (status != 0)
    {
        sprintf(sys_command, "rm %s", rlut_basename);
        status = system(sys_command);
        if (status != 0)
        {
            assert_true_with_message(FALSE, "Error removing RLUT symbolic "
                "link %s", rlut_basename);
        }
        return;
    }

    /* The cached RLUT file itself should:
         i. have a nonzero size
        ii. be classed as a regular file */
    assert_true_with_message(stat_buff.st_size, "Cached RLUT file size is "
        "not defined");
    assert_true_with_message(S_ISREG(stat_buff.st_mode),
        "Cached RLUT file is not a regular file");

    /* Remove the symbolic link to the RLUT file */
    status = snprintf(sys_command, sizeof(sys_command), "rm %s",
        rlut_basename);
    if ((status < 0) || (status >= sizeof(sys_command)))
    {
        assert_true_with_message(FALSE, "Error constructing command to "
            "remove RLUT file symbolic link %s");
    }
    status = system(sys_command);
    assert_equal_with_message(status, 0, "Error removing RLUT file symbolic "
        "link %s", rlut_basename);
}

Ensure test_ias_misc_get_rlut_by_date()
{
    struct stat stat_buff;

    char sys_command[1000];
    char date_acquired[100] = "2013-05-01T17:00:45";
    char rlut_basename[100] = "";
    int status;

    printf("Testing retrieval of RLUT by date %s...\n", date_acquired);

    /* Get the RLUT.  The function will put a symbolic link to the cached
       RLUT file in the directory where this test is executed. */
    status = ias_misc_retrieve_rlut(date_acquired, ias_services,
        rlut_basename, sizeof(rlut_basename));
    assert_equal_with_message(status, SUCCESS, "Error getting RLUT file "
        "from service");

    /* Get stat information about the symbolic link to the cached RLUT file. */
    status = lstat(rlut_basename, &stat_buff);
    assert_equal_with_message(status, 0, "Error retrieving information "
        "about RLUT symbolic link %s", rlut_basename);
    if (status != 0)
    {
        sprintf(sys_command, "rm %s", rlut_basename);
        status = system(sys_command);
        if (status != 0)
        {
            assert_true_with_message(FALSE, "Error removing RLUT symbolic "
                "link %s", rlut_basename);
        }
        return;
    }

    /* A path to the cached RLUT file should be defined for the link, and
       it should be classed as a symbolic link. */
    assert_true_with_message(stat_buff.st_size, "Invalid path length in "
        "symbolic link %s", rlut_basename);
    assert_true_with_message(S_ISLNK(stat_buff.st_mode), "%s is not "
        "classed as a symbolic link", rlut_basename);

    /* Clear out the current stat information. */
    memset(&stat_buff, 0, sizeof(struct stat));

    /* Remove the symbolic link to the RLUT file */
    status = snprintf(sys_command, sizeof(sys_command), "rm %s",
        rlut_basename);
    if ((status < 0) || (status >= sizeof(sys_command)))
    {
        assert_true_with_message(FALSE, "Error constructing command to "
            "remove RLUT file symbolic link %s");
    }
    status = system(sys_command);
    assert_equal_with_message(status, 0, "Error removing RLUT file symbolic "
        "link %s", rlut_basename);
}


int main(int argc, char *argv[])
{
    TestSuite *suite;

    /* Use the current directory for the services */
    ias_services = getenv("PWD");

    /* Create the test suite */
    suite = create_test_suite();
    add_test(suite, test_ias_misc_get_rlut);
    add_test(suite, test_ias_misc_get_rlut_by_date);

    /* Run the test */
    if (argc > 1)
    {
        return run_single_test(suite, argv[1], create_text_reporter());
    }
    return run_test_suite(suite, create_text_reporter());
}
