#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "lablib3.h"
#include "ias_odl.h"
#include "ias_logging.h"
#include "cgreen/cgreen.h"

#define NUM_DETS 10
#define NUM_PIXS 600

Ensure odl_test( void );
Ensure odl_test_file( void );
Ensure odl_test_long( void );

int main( int argc, char *argv[] )
{
    TestSuite *suite = create_test_suite();
    add_test( suite, odl_test );
    add_test( suite, odl_test_file );
    add_test( suite, odl_test_long );
    if (argc > 1) {
        return run_single_test( suite, argv[1], create_text_reporter());
    }
    return run_test_suite( suite, create_text_reporter() );
}

Ensure odl_test( void )
{
    OBJDESC *otop, *o1, *o2, *o2a, *o2b, *o3, *o4, *o5, *otmp1;
    IAS_ODL_KEYWORD *keyword;
    int f1, f2, count, status, i;
    char str1[16];
    char str2[16];
    char arr_str1[32];
    char arr_str2[32];
    char arr_arr1[3][32];
    char *arr_arr2[3];
    char *arr_arr3[4];
    char a[] = "TEST1";
    char b[] = "FIELD2";
    char c[] = "FIELD1";
    char **group_names = NULL;
    ODL_LIST_TYPE list[2];
    
    otop = ias_odl_create_tree();
    assert_not_equal(otop, NULL);
    
    o1 = ias_odl_add_group(otop, "TEST1");
    assert_not_equal(o1, NULL);

    o2 = ias_odl_add_group(otop, "TEST2");
    assert_not_equal(o2, NULL);

    o2a = ias_odl_add_group(o2, "TEST2a");
    assert_not_equal(o2a, NULL);

    o2b = ias_odl_add_group(o2, "TEST2b");
    assert_not_equal(o2b, NULL);

    o3 = ias_odl_add_group(otop, "TEST3");
    assert_not_equal(o3, NULL);

    f1 = 12;
    status = ias_odl_add_field(o1, "FIELD1", IAS_ODL_Int, sizeof(f1), &f1, 1);
    assert_equal(status, SUCCESS);
    f1 = 15;
    status = ias_odl_add_field(o1, "FIELD2", IAS_ODL_Int, sizeof(f1), &f1, 1);
    assert_equal(status, SUCCESS);
    f2 = 0;
    status = ias_odl_get_field(&f2, sizeof(f1), IAS_ODL_Int, o1, 
                              "TEST1", "FIELD2", &count);
    assert_equal(status, SUCCESS);
    assert_equal(count, 1);
    assert_equal(f1, f2);

    strcpy(str1,"Hello");
    status = ias_odl_replace_field(o1, "FIELD2", IAS_ODL_String, 
                               strlen(str1), str1, 1);
    assert_equal(status, SUCCESS);

    strcpy(str2,"");
    status = ias_odl_get_field(str2, sizeof(str2), IAS_ODL_String, o1, 
                               "TEST1", "FIELD2", &count);
    assert_equal(status, SUCCESS);
    assert_equal(count, 1);
    assert_string_equal(str1, str2);

    /* test strings with spaces */
    o4 = ias_odl_add_group(otop, "STRINGS");
    assert_not_equal(o4, NULL);

    strcpy(arr_str1, "String 1");
    status = ias_odl_add_field(o4, "FIELD3", IAS_ODL_String, sizeof(arr_str1), 
                               arr_str1, 1);
    assert_equal(status, SUCCESS);

    status = ias_odl_get_field(&arr_str2, sizeof(arr_str1), IAS_ODL_String,
                                o4, "STRINGS", "FIELD3", &count);
    assert_equal(status, SUCCESS);
    assert_equal(count, 1);
    assert_string_equal(arr_str1, arr_str2);

    /* test array of strings */
    o5 = ias_odl_add_group(otop, "ARRofSTRINGS");
    assert_not_equal(o5, NULL);

    strcpy(arr_arr1[0], "String 0");
    strcpy(arr_arr1[1], "String 1");
    strcpy(arr_arr1[2], "String 2");
    status = ias_odl_add_field(o5, "FIELD4", IAS_ODL_ArrayOfString,
                               sizeof(arr_arr1), arr_arr1, 3);
    assert_equal(status, SUCCESS);

    status = ias_odl_get_field(&arr_arr2, sizeof(arr_arr1), 
                 IAS_ODL_ArrayOfString, o5, "ARRofSTRINGS", "FIELD4", &count);
    assert_equal(status, SUCCESS);
    assert_equal(count, 3);

    /* An array of strings should allow each quoted string in the array to
       contain spaces, however the library code uses strtok to parse out the 
       values when the ODL field is a set or sequence, therefore the spaces
       are removed in this case */
    assert_string_equal(arr_arr2[0], "String0");
    assert_string_equal(arr_arr2[1], "String1");
    assert_string_equal(arr_arr2[2], "String2");
    free(arr_arr2[0]);
    arr_arr2[0] = NULL;
    free(arr_arr2[1]);
    arr_arr2[1] = NULL;
    free(arr_arr2[2]);
    arr_arr2[2] = NULL;

    /* Read using ias_odl_get_field_list and make sure it errors if enough
       values aren't available */
    memset(arr_arr3, 0, sizeof(arr_arr3));
    list[0].group_name = "ARRofSTRINGS";
    list[0].attribute = "FIELD4";
    list[0].parm_ptr = arr_arr3;
    list[0].parm_size = sizeof(arr_arr3);
    list[0].parm_type = IAS_ODL_ArrayOfString;
    list[0].parm_count = 4;
    /* Disable logging for this call since it is expected to fail */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    status = ias_odl_get_field_list(o5, list, 1);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
    assert_equal(status, ERROR);

    /* In this case, the pointers still need to be freed */
    assert_string_equal(arr_arr3[0], "String0");
    assert_string_equal(arr_arr3[1], "String1");
    assert_string_equal(arr_arr3[2], "String2");
    free(arr_arr3[0]);
    arr_arr3[0] = NULL;
    free(arr_arr3[1]);
    arr_arr3[1] = NULL;
    free(arr_arr3[2]);
    arr_arr3[2] = NULL;
    free(arr_arr3[3]);
    arr_arr3[3] = NULL;
   
    /* test the get list function */
    list[0].group_name = a;
    list[0].attribute = b;
    list[0].parm_ptr = str1;
    list[0].parm_size = sizeof(str1);
    list[0].parm_type = IAS_ODL_String;
    list[0].parm_count = 1;
    list[1].group_name = a;
    list[1].attribute = c;
    list[1].parm_ptr = &f1;
    list[1].parm_size = sizeof(f1);
    list[1].parm_type = IAS_ODL_Int;
    list[1].parm_count = 1;
    status = ias_odl_get_field_list(otop, list, 2);
    assert_equal(status, SUCCESS);

    status = ias_odl_add_field_list(o3, list, 2);
    assert_equal(status, SUCCESS);

    otmp1 = ias_odl_get_group(otop, "TEST1");
    assert_equal(otmp1, o1);

    status = ias_odl_get_group_names(otop, &group_names, &count);
    assert_equal(status, SUCCESS);
    assert_equal(count, 5);
    assert_not_equal(group_names, NULL);
    assert_not_equal(group_names[0], NULL);
    assert_not_equal(group_names[1], NULL);
    assert_not_equal(group_names[2], NULL);
    assert_string_equal(group_names[0], "TEST1");
    assert_string_equal(group_names[1], "TEST2");
    assert_string_equal(group_names[2], "TEST3");
    for (i=0; i<count; i++) {
         free(group_names[i]);
    }
    free(group_names);

    otmp1 = ias_odl_find_object_description(otop, "TEST1", NULL, NULL, 2);

    assert_not_equal(otmp1, NULL);

    keyword = ias_odl_find_keyword(otop, "FIELD1", NULL, 1);

    assert_not_equal(keyword, NULL);

    ias_odl_free_tree(otop);

}  /* END odl_test */

Ensure odl_test_file( void )
{
    OBJDESC *o;

    o = ias_odl_read_tree ("test.odl");
    assert_not_equal(o, NULL);

    remove("test_out.odl");
    ias_odl_write_tree(o, "test_out.odl");

    ias_odl_free_tree(o);

    o = ias_odl_parse_file("test.odl", NULL);
    assert_not_equal(o, NULL);

    ias_odl_free_tree(o);

    o = ias_odl_parse_label_string( "test.odl");
    assert_not_equal(o, NULL);
 
    ias_odl_free_tree(o);

}  /* END odl_test_file */

Ensure odl_test_long( void )
{
    IAS_OBJ_DESC * odlFile;
    int log_level;

    /* Disable logging because this test causes an ERROR to be logged */
    log_level = ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);

    /* try to read the file with too long of lines - it should get an error */
    odlFile = ias_odl_read_tree ("long.odl");
    ias_log_set_output_level(log_level);

    assert_equal_with_message(odlFile, NULL,
        "Should have received an error opening long.odl");

    ias_odl_free_tree(odlFile);

}  /* END odl_test_long */
