#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "../pm_local.h"
#include "ias_pixel_mask.h"
#include "ias_linked_list.h"
#include "ias_logging.h"
#include "cgreen/cgreen.h"

Ensure bug_test( void );

int main( int argc, char *argv[] )
{
    TestSuite *suite = create_test_suite();
    add_test( suite, bug_test );
    return run_single_test( suite, "bug_test", create_text_reporter() );
    return run_test_suite( suite, create_text_reporter() );
}

Ensure bug_test( void )
{
    IAS_PIXEL_MASK *pm;
    int det;
    IAS_PIXEL_MASK_ITERATOR *it;
    IAS_PIXEL_MASK_SPAN span;
    int response;
    int expected_results[40][4] = 
    {
        { 1,  1,  4,  0 }, { 1,  5,  1,  2 }, { 1,  6,  5,  0 },
        { 1, 11,  1,  2 }, { 1, 12,  1,  0 }, { 2,  1,  4,  0 },
        { 2,  5,  1,  2 }, { 2,  6,  5,  0 }, { 2, 11,  1,  2 },
        { 2, 12,  1,  0 }, { 3,  1,  4,  0 }, { 3,  5,  1,  2 },
        { 3,  6,  5,  0 }, { 3, 11,  1,  2 }, { 3, 12,  1,  0 },
        { 4,  1,  4,  1 }, { 4,  5,  1,  3 }, { 4,  6,  5,  1 },
        { 4, 11,  1,  3 }, { 4, 12,  1,  1 }, { 5,  1,  4,  0 },
        { 5,  5,  1,  2 }, { 5,  6,  5,  0 }, { 5, 11,  1,  2 },
        { 5, 12,  1,  0 }, { 6,  1,  4,  0 }, { 6,  5,  1,  2 },
        { 6,  6,  5,  0 }, { 6, 11,  1,  2 }, { 6, 12,  1,  0 },
        { 7,  1,  4,  1 }, { 7,  5,  1,  3 }, { 7,  6,  5,  1 },
        { 7, 11,  1,  3 }, { 7, 12,  1,  1 }, { 8,  1,  4,  0 },
        { 8,  5,  1,  2 }, { 8,  6,  5,  0 }, { 8, 11,  1,  2 },
        { 8, 12,  1,  0 }
    };

    /* This is the image with the artifacts that caused the issue.  Included
       here for reference.  It is 8 detectors by 12 lines.  The issue is
       caused by setting detector 4 (1-based) as dead.
    {
        { 400,650,399,2  ,402,400,2  ,400 },
        { 399,400,400,2  ,412,408,2  ,401 },
        { 500,399,399,2  ,399,400,2  ,394 },
        { 400,600,401,2  ,401,399,2  ,400 },
        { 4  ,4  ,4  ,2  ,4  ,4  ,2  ,4   },
        { 401,400,401,2  ,400,200,2  ,400 },
        { 401,399,300,2  ,280,400,2  ,401 },
        { 550,520,399,2  ,400,500,2  ,600 },
        { 550,402,400,2  ,280,150,2  ,420 },
        { 399,400,401,50 ,401,400,2  ,399 },
        { 4  ,4  ,80 ,2  ,4  ,4  ,2  ,4   },
        { 400,400,400,2  ,400,60 ,2  ,400 }
    }; */

    pm = ias_pm_create( 1, 1, 8, 12 );
    if ( !pm )
    {
        assert_true_with_message(0, "Error creating pixel mask");
        return;
    }

    /* Add the dead detectors */
    assert_false( ias_pm_add_pixels( pm, 4-1, 1-1, 12, 0x1 ));
    assert_false( ias_pm_add_pixels( pm, 7-1, 1-1, 12, 0x1 ));
    /* Add the dropped frames */
    for ( det = 1-1; det <= 8-1; det++ )
    {
        assert_false( ias_pm_add_pixels( pm, det,  5-1, 1, 0x2 ));
        assert_false( ias_pm_add_pixels( pm, det, 11-1, 1, 0x2 ));
    }

    it = ias_pm_get_iterator( pm, IAS_PM_ALL, 0x0 );
    assert_not_equal( it, NULL );

    response = 0;
    while ( ias_pm_get_next_span( it, &span ))
    {
        assert_equal( span.detector_index+1, expected_results[response][0] );
        assert_equal( span.starting_pixel_index+1,
            expected_results[response][1] );
        assert_equal( span.length_of_span,   expected_results[response][2] );
        assert_equal( span.pixel_mask,       expected_results[response][3] );
        response++;
    }
    if ( response != 40 )
    {
        assert_true_with_message( 0,
            "Should have 40 spans instead of %d", response );
    }
    ias_pm_destroy_iterator( it );
    ias_pm_destroy( pm );
}
