/*************************************************************************

NAME: sate_attributes_test.c

PURPOSE: Using Cgreen for testing Satellite Attributes library files 

**************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "ias_satellite_attributes.h"
#include "ias_const.h"
#include "ias_logging.h"
#include "cgreen/cgreen.h"

#define OLI_DETECTORS_PER_SCA_NORMAL 494
#define OLI_DETECTORS_PER_SCA_PAN 988
#define OLI_DETECTORS_PER_SCA_VRP 12
#define OLI_DETECTORS_PER_SCA_SWIR_BLIND 104 
#define OLI_DETECTORS_PER_SCA_CIRRUS_BLIND 103
#define OLI_DETECTORS_PER_SCA_BLIND_VRP 65
#define OLI_DETECTORS_PER_SCA_PAN_VRP 24
#define TIRS_DETECTORS_PER_SCA_NORMAL 640
#define TIRS_DETECTORS_PER_SCA_BLIND 640
#define OLI_PIXEL_RESOLUTION_NORMAL 30
#define OLI_PIXEL_RESOLUTION_PAN 15
#define TIRS_PIXEL_RESOLUTION 100
#define OLI_NUMBER_OF_SCA 14
#define TIRS_NUMBER_OF_SCA 3
#define TOTAL_NUMBER_OF_NORMAL_BANDS 11
#define TOTAL_NUMBER_OF_BANDS 30

Ensure test_ias_sat_attr_initialize()
{
    int status;

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    
}

Ensure test_ias_sat_attr_initialize_landsat8()
{
    int band_number;
    int status;
   
    const IAS_SATELLITE_ATTRIBUTES *sat_attribs;
    const IAS_BAND_ATTRIBUTES *band;

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    assert_equal(ias_sat_attr_get_satellite_id(), IAS_L8);
    assert_equal(ias_sat_attr_get_satellite_number(), 8);
    assert_equal(ias_sat_attr_get_sensor_count(), 2);

    sat_attribs = ias_sat_attr_get_attributes();
    assert_equal(sat_attribs->sensors, 2);
    assert_equal(sat_attribs->bands, TOTAL_NUMBER_OF_NORMAL_BANDS);
    assert_equal(sat_attribs->sensor_ids[0], IAS_OLI);
    assert_equal(sat_attribs->sensor_ids[1], IAS_TIRS);

    /* test an illegal band number */
    band_number = 0;
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band = ias_sat_attr_get_band_attributes(band_number);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
    assert_equal(band, NULL);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number,1);
    assert_equal(band->band_index, 0);
    assert_string_equal(band->band_name, "OLI_Coastal_Aerosol");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_COASTAL_AEROSOL_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 1); 
    assert_equal(band->vrp_band_number, 19); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 433);
    assert_equal(band->wavelength_nm_range[1], 453);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number,2);
    assert_equal(band->band_index, 1);
    assert_string_equal(band->band_name, "OLI_Blue");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_BLUE_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 2); 
    assert_equal(band->vrp_band_number, 20); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 450);
    assert_equal(band->wavelength_nm_range[1], 515);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 3);
    assert_equal(band->band_index, 2);
    assert_string_equal(band->band_name, "OLI_Green");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_GREEN_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 3); 
    assert_equal(band->vrp_band_number, 21); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 525);
    assert_equal(band->wavelength_nm_range[1], 600);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 4);
    assert_equal(band->band_index, 3);
    assert_string_equal(band->band_name, "OLI_Red");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_RED_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 4); 
    assert_equal(band->vrp_band_number, 22); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 630);
    assert_equal(band->wavelength_nm_range[1], 680);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number,5);
    assert_equal(band->band_index, 4);
    assert_string_equal(band->band_name, "OLI_NIR");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_NIR_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 5); 
    assert_equal(band->vrp_band_number, 23); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 845);
    assert_equal(band->wavelength_nm_range[1], 885);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 6);
    assert_equal(band->band_index, 5);
    assert_string_equal(band->band_name, "OLI_SWIR1");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR1_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 6); 
    assert_equal(band->vrp_band_number, 24); 
    assert_equal(band->blind_band_number, 12); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 1560);
    assert_equal(band->wavelength_nm_range[1], 1660);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 7);
    assert_equal(band->band_index, 6);
    assert_string_equal(band->band_name, "OLI_SWIR2");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR2_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 7); 
    assert_equal(band->vrp_band_number, 25); 
    assert_equal(band->blind_band_number, 13); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 2100);
    assert_equal(band->wavelength_nm_range[1], 2300);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 8);
    assert_equal(band->band_index, 7);
    assert_string_equal(band->band_name, "OLI_PAN");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_PAN_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_PAN);
    assert_equal(band->normal_band_number, 8); 
    assert_equal(band->vrp_band_number, 26); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_PAN);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_PAN);
    assert_equal(band->wavelength_nm_range[0], 500);
    assert_equal(band->wavelength_nm_range[1], 680);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 9);
    assert_equal(band->band_index, 8);
    assert_string_equal(band->band_name, "OLI_CIRRUS");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_CIRRUS_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 9); 
    assert_equal(band->vrp_band_number, 27); 
    assert_equal(band->blind_band_number, 14); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 1360);
    assert_equal(band->wavelength_nm_range[1], 1390);
    assert_equal(band->can_saturate, TRUE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 10);
    assert_equal(band->band_index, 9);
    assert_string_equal(band->band_name, "TIRS_THERMAL1");
    assert_equal(band->sensor_id, IAS_TIRS);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_THERMAL1_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_THERMAL);
    assert_equal(band->normal_band_number, 10); 
    assert_equal(band->vrp_band_number, 0); 
    assert_equal(band->blind_band_number, 15); 
    assert_equal(band->secondary_band_number, 16);
    assert_equal(band->scas, TIRS_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, TIRS_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, TIRS_PIXEL_RESOLUTION);
    assert_equal(band->wavelength_nm_range[0], 1030);
    assert_equal(band->wavelength_nm_range[1], 1130);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 11);
    assert_equal(band->band_index, 10);
    assert_string_equal(band->band_name, "TIRS_THERMAL2");
    assert_equal(band->sensor_id, IAS_TIRS);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_THERMAL2_BAND);
    assert_equal(band->band_classification, IAS_NORMAL_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_THERMAL);
    assert_equal(band->normal_band_number, 11); 
    assert_equal(band->vrp_band_number, 0); 
    assert_equal(band->blind_band_number, 15); 
    assert_equal(band->secondary_band_number, 17);
    assert_equal(band->scas, TIRS_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, TIRS_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, TIRS_PIXEL_RESOLUTION);
    assert_equal(band->wavelength_nm_range[0], 1150);
    assert_equal(band->wavelength_nm_range[1], 1250);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 12);
    assert_equal(band->band_index, 11);
    assert_string_equal(band->band_name, "OLI_BLIND_SWIR1");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR1_BAND);
    assert_equal(band->band_classification, IAS_BLIND_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 6); 
    assert_equal(band->vrp_band_number, 28); 
    assert_equal(band->blind_band_number, 12); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_SWIR_BLIND);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 0);
    assert_equal(band->wavelength_nm_range[1], 0);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 13);
    assert_equal(band->band_index, 12);
    assert_string_equal(band->band_name, "OLI_BLIND_SWIR2");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR2_BAND);
    assert_equal(band->band_classification, IAS_BLIND_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 7); 
    assert_equal(band->vrp_band_number, 29); 
    assert_equal(band->blind_band_number, 13); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_SWIR_BLIND);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 0);
    assert_equal(band->wavelength_nm_range[1], 0);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 14);
    assert_equal(band->band_index, 13);
    assert_string_equal(band->band_name, "OLI_BLIND_CIRRUS");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_CIRRUS_BAND);
    assert_equal(band->band_classification, IAS_BLIND_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 9); 
    assert_equal(band->vrp_band_number, 30); 
    assert_equal(band->blind_band_number, 14); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_CIRRUS_BLIND);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 0);
    assert_equal(band->wavelength_nm_range[1], 0);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 15);
    assert_equal(band->band_index, 14);
    assert_string_equal(band->band_name, "TIRS_BLIND");
    assert_equal(band->sensor_id, IAS_TIRS);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_THERMAL1_BAND);
    assert_equal(band->band_classification, IAS_BLIND_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_THERMAL);
    assert_equal(band->normal_band_number, 10); 
    assert_equal(band->vrp_band_number, 0); 
    assert_equal(band->blind_band_number, 15); 
    assert_equal(band->secondary_band_number, 18);
    assert_equal(band->scas, TIRS_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, TIRS_DETECTORS_PER_SCA_BLIND);
    assert_equal(band->pixel_resolution, TIRS_PIXEL_RESOLUTION);
    assert_equal(band->wavelength_nm_range[0], 0);
    assert_equal(band->wavelength_nm_range[1], 0);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 16);
    assert_equal(band->band_index, 15);
    assert_string_equal(band->band_name, "TIRS_THERMAL1_SECONDARY");
    assert_equal(band->sensor_id, IAS_TIRS);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_THERMAL1_BAND);
    assert_equal(band->band_classification, IAS_SECONDARY_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_THERMAL);
    assert_equal(band->normal_band_number, 16); 
    assert_equal(band->vrp_band_number, 0); 
    assert_equal(band->blind_band_number, 18); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, TIRS_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, TIRS_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, TIRS_PIXEL_RESOLUTION);
    assert_equal(band->wavelength_nm_range[0], 1030);
    assert_equal(band->wavelength_nm_range[1], 1130);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 17);
    assert_equal(band->band_index, 16);
    assert_string_equal(band->band_name, "TIRS_THERMAL2_SECONDARY");
    assert_equal(band->sensor_id, IAS_TIRS);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_THERMAL2_BAND);
    assert_equal(band->band_classification, IAS_SECONDARY_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_THERMAL);
    assert_equal(band->normal_band_number, 17); 
    assert_equal(band->vrp_band_number, 0); 
    assert_equal(band->blind_band_number, 18); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, TIRS_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, TIRS_DETECTORS_PER_SCA_NORMAL);
    assert_equal(band->pixel_resolution, TIRS_PIXEL_RESOLUTION);
    assert_equal(band->wavelength_nm_range[0], 1150);
    assert_equal(band->wavelength_nm_range[1], 1250);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 18);
    assert_equal(band->band_index, 17);
    assert_string_equal(band->band_name, "TIRS_BLIND_SECONDARY");
    assert_equal(band->sensor_id, IAS_TIRS);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_THERMAL1_BAND);
    assert_equal(band->band_classification, 
                 IAS_BLIND_BAND | IAS_SECONDARY_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_THERMAL);
    assert_equal(band->normal_band_number, 16); 
    assert_equal(band->vrp_band_number, 0); 
    assert_equal(band->blind_band_number, 18); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, TIRS_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, TIRS_DETECTORS_PER_SCA_BLIND);
    assert_equal(band->pixel_resolution, TIRS_PIXEL_RESOLUTION);
    assert_equal(band->wavelength_nm_range[0], 0);
    assert_equal(band->wavelength_nm_range[1], 0);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 19);
    assert_equal(band->band_index, 18);
    assert_string_equal(band->band_name, "OLI_VRP_Coastal_Aerosol");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_COASTAL_AEROSOL_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 1); 
    assert_equal(band->vrp_band_number, 19); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 433);
    assert_equal(band->wavelength_nm_range[1], 453);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 20);
    assert_equal(band->band_index, 19);
    assert_string_equal(band->band_name, "OLI_VRP_Blue");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_BLUE_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 2); 
    assert_equal(band->vrp_band_number, 20); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 450);
    assert_equal(band->wavelength_nm_range[1], 515);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 21);
    assert_equal(band->band_index, 20);
    assert_string_equal(band->band_name, "OLI_VRP_Green");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_GREEN_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 3); 
    assert_equal(band->vrp_band_number, 21); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 525);
    assert_equal(band->wavelength_nm_range[1], 600);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 22);
    assert_equal(band->band_index, 21);
    assert_string_equal(band->band_name, "OLI_VRP_Red");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_RED_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 4); 
    assert_equal(band->vrp_band_number, 22); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 630);
    assert_equal(band->wavelength_nm_range[1], 680);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 23);
    assert_equal(band->band_index, 22);
    assert_string_equal(band->band_name, "OLI_VRP_NIR");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_NIR_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_VNIR);
    assert_equal(band->normal_band_number, 5); 
    assert_equal(band->vrp_band_number, 23); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 845);
    assert_equal(band->wavelength_nm_range[1], 885);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 24);
    assert_equal(band->band_index, 23);
    assert_string_equal(band->band_name, "OLI_VRP_SWIR1");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR1_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 6); 
    assert_equal(band->vrp_band_number, 24); 
    assert_equal(band->blind_band_number, 28); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 1560);
    assert_equal(band->wavelength_nm_range[1], 1660);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 25);
    assert_equal(band->band_index, 24);
    assert_string_equal(band->band_name, "OLI_VRP_SWIR2");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR2_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 7); 
    assert_equal(band->vrp_band_number, 25); 
    assert_equal(band->blind_band_number, 29); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 2100);
    assert_equal(band->wavelength_nm_range[1], 2300);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 26);
    assert_equal(band->band_index, 25);
    assert_string_equal(band->band_name, "OLI_VRP_PAN");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_PAN_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_PAN);
    assert_equal(band->normal_band_number, 8); 
    assert_equal(band->vrp_band_number, 26); 
    assert_equal(band->blind_band_number, 0); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_PAN_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_PAN);
    assert_equal(band->wavelength_nm_range[0], 500);
    assert_equal(band->wavelength_nm_range[1], 680);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 27);
    assert_equal(band->band_index, 26);
    assert_string_equal(band->band_name, "OLI_VRP_CIRRUS");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_CIRRUS_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 9); 
    assert_equal(band->vrp_band_number, 27); 
    assert_equal(band->blind_band_number, 30); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 1360);
    assert_equal(band->wavelength_nm_range[1], 1390);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 28);
    assert_equal(band->band_index, 27);
    assert_string_equal(band->band_name, "OLI_VRP_BLIND_SWIR1");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR1_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND | IAS_BLIND_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 12);
    assert_equal(band->vrp_band_number, 28); 
    assert_equal(band->blind_band_number, 12); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_BLIND_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 1560);
    assert_equal(band->wavelength_nm_range[1], 1660);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number, 29);
    assert_equal(band->band_index, 28);
    assert_string_equal(band->band_name, "OLI_VRP_BLIND_SWIR2");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_SWIR2_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND | IAS_BLIND_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 13); 
    assert_equal(band->vrp_band_number, 29); 
    assert_equal(band->blind_band_number, 13); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_BLIND_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 2100);
    assert_equal(band->wavelength_nm_range[1], 2300);
    assert_equal(band->can_saturate, FALSE);

    band_number++;
    band = ias_sat_attr_get_band_attributes(band_number);
    assert_not_equal(band, NULL);
    assert_equal(band->band_number,30);
    assert_equal(band->band_index, 29);
    assert_string_equal(band->band_name, "OLI_VRP_BLIND_CIRRUS");
    assert_equal(band->sensor_id, IAS_OLI);
    assert_equal(band->sensor_type, IAS_PUSHBROOM_SENSOR);
    assert_equal(band->band_type, IAS_CIRRUS_BAND);
    assert_equal(band->band_classification, IAS_VRP_BAND | IAS_BLIND_BAND);
    assert_equal(band->spectral_type, IAS_SPECTRAL_SWIR);
    assert_equal(band->normal_band_number, 14);
    assert_equal(band->vrp_band_number, 30); 
    assert_equal(band->blind_band_number, 14); 
    assert_equal(band->secondary_band_number, 0);
    assert_equal(band->scas, OLI_NUMBER_OF_SCA);
    assert_equal(band->detectors_per_sca, OLI_DETECTORS_PER_SCA_BLIND_VRP);
    assert_equal(band->pixel_resolution, OLI_PIXEL_RESOLUTION_NORMAL);
    assert_equal(band->wavelength_nm_range[0], 1360);
    assert_equal(band->wavelength_nm_range[1], 1390);
    assert_equal(band->can_saturate, FALSE);

    /* test an illegal band above the defined band numbers */
    band_number++;
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band = ias_sat_attr_get_band_attributes(band_number);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
    assert_equal(band, NULL);
}

Ensure test_ias_sat_attr_get_normal_band_count()
{
    int status;
    int bands;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    bands = ias_sat_attr_get_normal_band_count();
    assert_equal(bands, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    bands = ias_sat_attr_get_normal_band_count();
    assert_equal(bands, TOTAL_NUMBER_OF_NORMAL_BANDS);
}

Ensure test_ias_attr_get_sensor_band_numbers()
{
    int status;
    int band_no[30];
    int no_of_bands;
    int oli_norm_blind_band_no[] = {1,2,3,4,5,6,7,8,9,12,13,14};
    int i;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    status = ias_sat_attr_get_sensor_band_numbers(IAS_OLI,IAS_NORMAL_BAND,
                                                  0, band_no, 24, &no_of_bands);
    assert_equal(status, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    /* test not passing a large enough buffer */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    status = ias_sat_attr_get_sensor_band_numbers(IAS_OLI,IAS_NORMAL_BAND,
                                                  0, band_no, 2, &no_of_bands);
    assert_equal(status, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_get_sensor_band_numbers(IAS_OLI,IAS_NORMAL_BAND,
                                                  0, band_no, 24, &no_of_bands);
    assert_equal(status, SUCCESS);
    if (status == SUCCESS)
    {
        assert_equal(no_of_bands, 9);
        assert_equal(band_no[0], 1);
        assert_equal(band_no[8], 9);
    } 
    status = ias_sat_attr_get_sensor_band_numbers(IAS_TIRS,IAS_NORMAL_BAND,
                                                  0, band_no, 24, &no_of_bands);
    assert_equal(status, SUCCESS);
    if (status == SUCCESS)
    {
        assert_equal(no_of_bands, 2);
        assert_equal(band_no[0], 10);
        assert_equal(band_no[1], 11);
    }

    status = ias_sat_attr_get_sensor_band_numbers(IAS_TIRS, 
                IAS_BLIND_BAND | IAS_SECONDARY_BAND, 0, band_no, 24,
                &no_of_bands);
    assert_equal(status, SUCCESS);
    if (status == SUCCESS)
    {
        assert_equal(no_of_bands, 1);
        assert_equal(band_no[0], 18);
    }

    /* test the oli normal and blind */
    status = ias_sat_attr_get_any_sensor_band_numbers(IAS_OLI, 
                                IAS_NORMAL_BAND | IAS_BLIND_BAND,
                                IAS_VRP_BAND, 
                                band_no, 30,
                                &no_of_bands);
    assert_equal(status, SUCCESS);
    if (status == SUCCESS)
    {
        assert_equal(no_of_bands, 12);
        for (i = 0; i < 12; i++)
        {
            assert_equal(band_no[i], oli_norm_blind_band_no[i]);
        }
    }

    /* test the tirs normal and blind band get */
    status = ias_sat_attr_get_any_sensor_band_numbers(IAS_TIRS, 
                        IAS_NORMAL_BAND | IAS_BLIND_BAND,
                        IAS_SECONDARY_BAND, 
                        band_no, 30,
                        &no_of_bands);
    assert_equal(status, SUCCESS);
    if (status == SUCCESS)
    {
        assert_equal(no_of_bands, 3);
        assert_equal(band_no[0], 10);
        assert_equal(band_no[1], 11);
        assert_equal(band_no[2], 15);
    }

    /* try all sensors together */
    status = ias_sat_attr_get_sensor_band_numbers(IAS_MAX_SENSORS, 
                IAS_NORMAL_BAND, 0, band_no, 24, &no_of_bands);
    assert_equal(status, SUCCESS);
    if (status == SUCCESS)
    {
        assert_equal(no_of_bands, 11);
        assert_equal(band_no[0], 1);
        assert_equal(band_no[10], 11);
    }
}

Ensure test_ias_sat_attr_band_classification_matchs()
{
    int status;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    assert_equal(ias_sat_attr_band_classification_matches(1, IAS_NORMAL_BAND),
        FALSE);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    assert_equal(ias_sat_attr_band_classification_matches(1, IAS_NORMAL_BAND),
        TRUE);
    assert_equal(ias_sat_attr_band_classification_matches(1, IAS_BLIND_BAND),
        FALSE);
    assert_equal(ias_sat_attr_band_classification_matches(12, IAS_NORMAL_BAND),
        FALSE);
    assert_equal(ias_sat_attr_band_classification_matches(12, IAS_BLIND_BAND),
        TRUE);
    assert_equal(ias_sat_attr_band_classification_matches(12,
        IAS_SECONDARY_BAND), FALSE);
    assert_equal(ias_sat_attr_band_classification_matches(16,
        IAS_SECONDARY_BAND), TRUE);
    assert_equal(ias_sat_attr_band_classification_matches(19, IAS_VRP_BAND),
        TRUE);
    assert_equal(ias_sat_attr_band_classification_matches(19,
        IAS_VRP_BAND | IAS_BLIND_BAND), FALSE);
    assert_equal(ias_sat_attr_band_classification_matches(28,
        IAS_VRP_BAND | IAS_BLIND_BAND), TRUE);

    /* test an invalid band classification */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    assert_equal(ias_sat_attr_band_classification_matches(31, IAS_BLIND_BAND),
        FALSE);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_convert_band_number_to_name()
{
    int status;
    const char *band_name;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_name = ias_sat_attr_convert_band_number_to_name(1);
    assert_true(band_name == NULL);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    band_name = ias_sat_attr_convert_band_number_to_name(1);
    assert_true(band_name != NULL);
    if (band_name != NULL)
    {
        assert_string_equal(band_name,"OLI_Coastal_Aerosol");  
    }

    /* test an invalid band number */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_name = ias_sat_attr_convert_band_number_to_name(0);
    assert_true(band_name == NULL);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_convert_band_index_to_number()
{
    int status;
    int band_number;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_number = ias_sat_attr_convert_band_index_to_number(5);
    assert_true(band_number == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    band_number = ias_sat_attr_convert_band_index_to_number(5);
    assert_equal(band_number, 6);    

    /* test an invalid band index */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_number = ias_sat_attr_convert_band_index_to_number(-1);
    assert_true(band_number == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_convert_band_number_to_index()
{
    int status;
    int band_index;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_index = ias_sat_attr_convert_band_number_to_index(6);
    assert_true(band_index == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    band_index = ias_sat_attr_convert_band_number_to_index(6);
    assert_equal(band_index, 5);    

    /* test invalid band numbers */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_index = ias_sat_attr_convert_band_number_to_index(0);
    assert_true(band_index == ERROR);
    band_index = ias_sat_attr_convert_band_number_to_index(31);
    assert_true(band_index == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_band_number_from_type()
{
    int band_index;
    int band_number;
    int status;
    IAS_BAND_TYPE band_type[] = {IAS_COASTAL_AEROSOL_BAND,
        IAS_BLUE_BAND, IAS_GREEN_BAND, IAS_RED_BAND, IAS_NIR_BAND,
        IAS_SWIR1_BAND, IAS_SWIR2_BAND, IAS_PAN_BAND, IAS_CIRRUS_BAND,
        IAS_THERMAL1_BAND, IAS_THERMAL2_BAND};

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_number 
            = ias_sat_attr_get_band_number_from_type(band_type[IAS_RED_BAND]);
    assert_true(band_number == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    for (band_index = 0; band_index < sizeof(band_type)/sizeof(IAS_BAND_TYPE);
         band_index++)
    {
        band_number
            = ias_sat_attr_get_band_number_from_type(band_type[band_index]);
        /* take advantage of the fact that the types are defined in the same
           order as the bands */
        assert_equal(band_number, band_index + 1);
    }

    /* make sure errors are returned for invalid types */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    assert_equal(ias_sat_attr_get_band_number_from_type(-1), ERROR);
    assert_equal(ias_sat_attr_get_band_number_from_type(IAS_THERMAL2_BAND+1),
                 ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_scas_per_band()
{
    int status;
    int number_scas;
    int band_index;
    int band_number;
    const IAS_BAND_ATTRIBUTES *band_attr;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_attr = ias_sat_attr_get_band_attributes(1);
    assert_true(band_attr == NULL);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    
    
    for (band_index = 0; band_index < TOTAL_NUMBER_OF_NORMAL_BANDS;
         band_index++)
    {
        band_number = ias_sat_attr_convert_band_index_to_number(band_index);

        band_attr = ias_sat_attr_get_band_attributes(band_number);
        assert_true(band_attr != NULL);

        if (band_attr != NULL)
        {
            number_scas = ias_sat_attr_get_scas_per_band(band_number);
            assert_equal(band_attr->scas, number_scas);
        }
    }

    /* test invalid band numbers */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    band_attr = ias_sat_attr_get_band_attributes(0);
    assert_true(band_attr == NULL);
    band_attr = ias_sat_attr_get_band_attributes(31);
    assert_true(band_attr == NULL);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_detectors_per_sca()
{
    int status;
    int number_dets;
    int band_index;
    int band_number;
    const IAS_BAND_ATTRIBUTES *band_attr;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    number_dets = ias_sat_attr_get_detectors_per_sca(1);
    assert_true(number_dets == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    
    
    for (band_index = 0; band_index < TOTAL_NUMBER_OF_NORMAL_BANDS;
         band_index++)
    {
        band_number = ias_sat_attr_convert_band_index_to_number(band_index);

        band_attr = ias_sat_attr_get_band_attributes(band_number);
        assert_true(band_attr != NULL);

        if (band_attr != NULL)
        {
            number_dets = ias_sat_attr_get_detectors_per_sca(band_number);
            assert_equal(band_attr->detectors_per_sca, number_dets);
        }
    }

    /* test invalid band numbers */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    number_dets = ias_sat_attr_get_detectors_per_sca(0);
    assert_true(number_dets == ERROR);
    number_dets = ias_sat_attr_get_detectors_per_sca(31);
    assert_true(number_dets == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_sensor_name()
{
    assert_false(strcmp(ias_sat_attr_get_sensor_name(IAS_OLI), "OLI"));
    assert_false(strcmp(ias_sat_attr_get_sensor_name(IAS_TIRS), "TIRS"));
    assert_false(strcmp(ias_sat_attr_get_sensor_name(-1), "Unknown"));
    assert_false(strcmp(ias_sat_attr_get_sensor_name(IAS_MAX_SENSORS),
                        "Unknown"));
}

Ensure test_ias_sat_attr_get_sensor_sca_count()
{
    int sca_count;
    int status;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    sca_count = ias_sat_attr_get_sensor_sca_count(IAS_OLI);
    assert_true(sca_count == ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    assert_equal_with_message(ias_sat_attr_get_sensor_sca_count(IAS_OLI), 
                               OLI_NUMBER_OF_SCA,
                               "Numer of oli scas returned: %d", 
                                ias_sat_attr_get_sensor_sca_count(IAS_OLI));

    assert_equal_with_message(ias_sat_attr_get_sensor_sca_count(IAS_TIRS), 
                                TIRS_NUMBER_OF_SCA,
                                "Numer of tirs scas returned: %d", 
                                ias_sat_attr_get_sensor_sca_count(IAS_TIRS));

    /* test invalid band numbers */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    sca_count = ias_sat_attr_get_sensor_sca_count(-1); 
    assert_equal(sca_count, ERROR);
    sca_count = ias_sat_attr_get_sensor_sca_count(IAS_MAX_SENSORS); 
    assert_equal(sca_count, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_convert_band_number_to_band_index()
{
    int status;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            1), ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    /*  band number to index tests */
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            1), 0);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            2), 1);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            3), 2);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            4), 3);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            5), 4);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            6), 5);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            7), 6);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            8), 7);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            9), 8);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            12), 9);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            13), 10);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            14), 11);

    /* TIRS tests */
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_TIRS,
            10), 0);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_TIRS,
            11), 1);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_TIRS,
            15), 2);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_TIRS,
            16), 3);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_TIRS,
            17), 4);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_TIRS,
            18), 5);

    /* Test invalid sensor and band combinations */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(-1,
            10), ERROR);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(
            IAS_MAX_SENSORS, 10), ERROR);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_OLI,
            10), ERROR);
    assert_equal(ias_sat_attr_convert_band_number_to_sensor_band_index(IAS_TIRS,
            1), ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_spectral_type_from_band_number()
{
    int status;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(1), ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);
    if (status != SUCCESS)
    {
        printf("Cannot initialize satellite attributes library\n");
        return;
    }

    /* Run through the normal OLI/TIRS imaging band numbers */
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(1),
            IAS_SPECTRAL_VNIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(2),
            IAS_SPECTRAL_VNIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(3),
            IAS_SPECTRAL_VNIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(4),
            IAS_SPECTRAL_VNIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(5),
            IAS_SPECTRAL_VNIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(6),
            IAS_SPECTRAL_SWIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(7),
            IAS_SPECTRAL_SWIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(8),
            IAS_SPECTRAL_PAN);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(9),
            IAS_SPECTRAL_SWIR);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(10),
            IAS_SPECTRAL_THERMAL);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(11),
            IAS_SPECTRAL_THERMAL);

    /* Should return unknown type here */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    assert_equal(ias_sat_attr_get_spectral_type_from_band_number(0), ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_sensor_max_normal_detectors()
{
    int num_returned_detectors;
    int status;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    num_returned_detectors =
        ias_sat_attr_get_sensor_max_normal_detectors(IAS_OLI);
    assert_equal(num_returned_detectors, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);
    if (status != SUCCESS)
    {
        printf("Cannot initialize satellite attributes library\n");
        return;
    }

    /* Check OLI first */
    num_returned_detectors =
        ias_sat_attr_get_sensor_max_normal_detectors(IAS_OLI);
    assert_equal(num_returned_detectors, OLI_DETECTORS_PER_SCA_PAN);

    /* Now TIRS */
    num_returned_detectors =
        ias_sat_attr_get_sensor_max_normal_detectors(IAS_TIRS);
    assert_equal(num_returned_detectors, TIRS_DETECTORS_PER_SCA_NORMAL);

    /* Now both together */
    num_returned_detectors =
        ias_sat_attr_get_sensor_max_normal_detectors(IAS_MAX_SENSORS);
    assert_equal(num_returned_detectors, OLI_DETECTORS_PER_SCA_PAN);

    /* Check an invalid sensor ID.  This should return ERROR */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    num_returned_detectors =
        ias_sat_attr_get_sensor_max_normal_detectors(IAS_MAX_SENSORS + 1);
    assert_equal(num_returned_detectors, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_convert_band_name_to_number()
{
    char band_name[IAS_BAND_NAME_SIZE];

    int band_number;
    int status;

    /* test trying to use the routine without initializing the library */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    strcpy(band_name, "TIRS_THERMAL1");
    band_number = ias_sat_attr_convert_band_name_to_number(band_name);
    assert_equal(band_number, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);
    if (status != SUCCESS)
    {
        printf("Cannot initialize satellite attributes library\n");
        return;
    }

    /* Try a few "legitimate" band names */
    strcpy(band_name, "TIRS_THERMAL1");
    band_number = ias_sat_attr_convert_band_name_to_number(band_name);
    assert_equal(band_number, 10);

    strcpy(band_name, "OLI_VRP_Green");
    band_number = ias_sat_attr_convert_band_name_to_number(band_name);
    assert_equal(band_number, 21);

    strcpy(band_name, "TIRS_BLIND_SECONDARY");
    band_number = ias_sat_attr_convert_band_name_to_number(band_name);
    assert_equal(band_number, 18);

    /* Now an "invalid" band name */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    strcpy(band_name, "FRED");
    band_number = ias_sat_attr_convert_band_name_to_number(band_name);
    assert_equal(band_number, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_satellite_id_from_satellite_number()
{
    int sat_num;

    /* disable logging output since this test is going to cause a lot of
       errors */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);

    /* make sure only satellite number 8 provides a valid return */
    for (sat_num = -1; sat_num < 15; sat_num++)
    {
        int id = ias_sat_attr_get_satellite_id_from_satellite_number(sat_num);

        if (sat_num == 8)
            assert_equal(id, IAS_L8);
        else
            assert_equal(id, ERROR);
    }
}

Ensure test_ias_sat_attr_get_band_name_from_type_and_class()
{
    IAS_BAND_TYPE band_type = IAS_THERMAL1_BAND;
    IAS_BAND_CLASSIFICATION band_classification = IAS_BLIND_BAND;

    char band_name[IAS_BAND_NAME_SIZE] = "";
    char expected_band_name[IAS_BAND_NAME_SIZE] = "";

    int status = SUCCESS;

    /* Initialize the library */
    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    /* Find the band name */
    status = ias_sat_attr_get_band_name_from_type_and_class(
        band_type, band_classification, band_name);
    assert_equal_with_message(status, SUCCESS, "Could not find band name");
    if (status != SUCCESS)
    {
        return;
    }

    /* Is it the right one */
    strcpy(expected_band_name, "TIRS_BLIND");
    assert_string_equal_with_message(band_name, expected_band_name,
        "Band names not equal");

    /* Check the OLI green band */
    band_type = IAS_GREEN_BAND;
    band_classification = IAS_NORMAL_BAND;
    strcpy(expected_band_name, "OLI_Green");

    status = ias_sat_attr_get_band_name_from_type_and_class(
        band_type, band_classification, band_name);
    assert_equal_with_message(status, SUCCESS, "Could not find band name");
    assert_string_equal_with_message(expected_band_name, band_name,
         "Band names not equal");

    /* Check the secondary TIRS 10.8 band */
    band_type = IAS_THERMAL1_BAND;
    band_classification = IAS_SECONDARY_BAND;
    strcpy(expected_band_name, "TIRS_THERMAL1_SECONDARY");

    status = ias_sat_attr_get_band_name_from_type_and_class(
        band_type, band_classification, band_name);
    assert_equal_with_message(status, SUCCESS, "Could not find band name");
    assert_string_equal_with_message(expected_band_name, band_name,
        "Band names not equal");

    /* Check the OLI NIR VRP band */
    band_type = IAS_NIR_BAND;
    band_classification = IAS_VRP_BAND;
    strcpy(expected_band_name, "OLI_VRP_NIR");

    status = ias_sat_attr_get_band_name_from_type_and_class(
        band_type, band_classification, band_name);
    assert_equal_with_message(status, SUCCESS, "Could not find band name");
    assert_string_equal_with_message(expected_band_name, band_name,
        "Band names not equal");

    /* Done */
}


Ensure test_ias_sat_attr_get_band_type_from_band_number()
{
    int test_band_number_1 = 10;      /* TIRS band 10 */
    int test_band_number_2 =  5;      /* OLI normal band 5 (VNIR band) */
    int test_band_number_3 = 17;      /* TIRS secondary blind band */
    int test_band_number_4 = 20;      /* OLI VRP blue band */
    int status;

    IAS_BAND_TYPE expected_type_1 = IAS_THERMAL1_BAND;
    IAS_BAND_TYPE expected_type_2 = IAS_NIR_BAND;
    IAS_BAND_TYPE expected_type_3 = IAS_THERMAL2_BAND;
    IAS_BAND_TYPE expected_type_4 = IAS_BLUE_BAND;
    IAS_BAND_TYPE test_type_1;
    IAS_BAND_TYPE test_type_2;
    IAS_BAND_TYPE test_type_3;
    IAS_BAND_TYPE test_type_4;

    /* Initialize the library */
    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal_with_message(status, SUCCESS, "Error initializing "
        "satellite attributes library");
    if (status != SUCCESS)
        return;

    /* Get the band types for the test band numbers and compare them
       against the expected results */
    test_type_1 =
        ias_sat_attr_get_band_type_from_band_number(test_band_number_1);
    test_type_2 =
        ias_sat_attr_get_band_type_from_band_number(test_band_number_2);
    test_type_3 =
        ias_sat_attr_get_band_type_from_band_number(test_band_number_3);
    test_type_4 =
        ias_sat_attr_get_band_type_from_band_number(test_band_number_4);

    assert_equal_with_message(test_type_1, expected_type_1,
        "Returned type %d does not match expected type %d for band %d",
        test_type_1, expected_type_1, test_band_number_1);
    assert_equal_with_message(test_type_2, expected_type_2,
        "Returned type %d does not match expected type %d for band %d",
        test_type_2, expected_type_2, test_band_number_2);
    assert_equal_with_message(test_type_3, expected_type_3,
        "Returned type %d does not match expected type %d for band %d",
        test_type_3, expected_type_3, test_band_number_3);
    assert_equal_with_message(test_type_4, expected_type_4,
        "Returned type %d does not match expected type %d for band %d",
        test_type_4, expected_type_4, test_band_number_4);

    /* Now throw in an obviously invalid band number, say 45.  This should
       return IAS_UNKNOWN_BAND_TYPE (and display an error message
       relating to determining the band index, which will be suppressed
       here) */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    test_band_number_4 = 45;
    expected_type_4 = IAS_UNKNOWN_BAND_TYPE;
    test_type_4 =
        ias_sat_attr_get_band_type_from_band_number(test_band_number_4);
    assert_equal_with_message(test_type_4, expected_type_4,
        "Returned type %d does not match expected type %d for band %d",
        test_type_4, expected_type_4, test_band_number_4);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

}   /* END -- test_ias_sat_get_band_type_from_band_number() */


Ensure test_ias_sat_attr_get_sensor_id_from_band_number()
{
    int test_band_number_1 = 10;      /* TIRS band 10 */
    int test_band_number_2 =  5;      /* OLI normal band 5 (VNIR band) */
    int test_band_number_3 = 17;      /* TIRS secondary blind band */
    int test_band_number_4 = 20;      /* OLI VRP blue band */
    int status;

    IAS_SENSOR_ID expected_id_1 = IAS_TIRS;
    IAS_SENSOR_ID expected_id_2 = IAS_OLI;
    IAS_SENSOR_ID expected_id_3 = IAS_TIRS;
    IAS_SENSOR_ID expected_id_4 = IAS_OLI;
    IAS_SENSOR_ID test_id_1;
    IAS_SENSOR_ID test_id_2;
    IAS_SENSOR_ID test_id_3;
    IAS_SENSOR_ID test_id_4;

    /* Initialize the library */
    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal_with_message(status, SUCCESS, "Error initializing "
        "satellite attributes library");
    if (status != SUCCESS)
        return;

    /* Get the sensor IDs for the test band numbers and compare them
       against the expected results */
    test_id_1 =
        ias_sat_attr_get_sensor_id_from_band_number(test_band_number_1);
    test_id_2 =
        ias_sat_attr_get_sensor_id_from_band_number(test_band_number_2);
    test_id_3 =
        ias_sat_attr_get_sensor_id_from_band_number(test_band_number_3);
    test_id_4 =
        ias_sat_attr_get_sensor_id_from_band_number(test_band_number_4);

    assert_equal_with_message(test_id_1, expected_id_1,
        "Returned ID %d does not match expected ID %d for band %d",
        test_id_1, expected_id_1, test_band_number_1);
    assert_equal_with_message(test_id_2, expected_id_2,
        "Returned ID %d does not match expected ID %d for band %d",
        test_id_2, expected_id_2, test_band_number_2);
    assert_equal_with_message(test_id_3, expected_id_3,
        "Returned ID %d does not match expected ID %d for band %d",
        test_id_3, expected_id_3, test_band_number_3);
    assert_equal_with_message(test_id_4, expected_id_4,
        "Returned ID %d does not match expected ID %d for band %d",
        test_id_4, expected_id_4, test_band_number_4);

    /* Now throw in an obviously invalid band number, say 45.  This 
       should return IAS_INVALID_SENSOR_ID (and display an error message
       relating to determining the band index, which will be suppressed
       here) */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    test_band_number_4 = 45;
    expected_id_4 = IAS_INVALID_SENSOR_ID;
    test_id_4 =
        ias_sat_attr_get_sensor_id_from_band_number(test_band_number_4);
    assert_equal_with_message(test_id_4, expected_id_4,
        "Returned ID %d does not match expected ID %d for band %d",
        test_id_4, expected_id_4, test_band_number_4);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

}   /* END -- test_ias_sat_get_sensor_id_from_band_number() */


Ensure test_lines_per_frame()
{
    int status;
    int band_number;

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    /* check the values for each band (all should be 1, except for the pan
       band and PAN VRP band) */
    for (band_number = 1; band_number <= 30; band_number++)
    {
        int lines_per_frame = ias_sat_attr_get_lines_per_frame(band_number);

        if ((band_number == 8) || (band_number == 26))
            assert_equal(lines_per_frame, 2);
        else
            assert_equal(lines_per_frame, 1);
    }

    /* make sure the errors are detected */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    status = ias_sat_attr_get_lines_per_frame(0);
    assert_equal(status, ERROR);
    status = ias_sat_attr_get_lines_per_frame(31);
    assert_equal(status, ERROR);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_qcal_min_max()
{
    int status;
    int band_number;
    int value;

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);    

    /* check the values for each band (all should be 1, except for the pan
       band and PAN VRP band) */
    for (band_number = 1; band_number <= 30; band_number++)
    {
        int qcal_min;
        int qcal_max;

        status = ias_sat_attr_get_quantization_cal_min(band_number, &qcal_min);
        assert_equal(status, SUCCESS);
        status = ias_sat_attr_get_quantization_cal_max(band_number, &qcal_max);
        assert_equal(status, SUCCESS);

        assert_equal(qcal_min, 1);
        assert_equal(qcal_max, 65535);
    }

    /* make sure the errors are detected */
    ias_log_set_output_level(IAS_LOG_LEVEL_DISABLE);
    status = ias_sat_attr_get_quantization_cal_min(0, &value);
    assert_equal(status, ERROR);
    status = ias_sat_attr_get_quantization_cal_min(31, &value);
    assert_equal(status, ERROR);
    status = ias_sat_attr_get_quantization_cal_max(0, &value);
    assert_equal(status, ERROR);
    status = ias_sat_attr_get_quantization_cal_max(31, &value);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_sat_attr_get_satellite_sensor_name_initialized()
{
    const char *exp_satellite_name = IAS_SATELLITE_NAME_L8;
    const char *exp_sensor_name = IAS_SENSOR_NAME_L8;
    const char *satellite_name = NULL;
    const char *sensor_name = NULL;

    /* Initialize the satellite attributes library. */
    int status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);

    /* Get the satellite name. */
    satellite_name = ias_sat_attr_get_satellite_name();
    assert_string_equal(exp_satellite_name, satellite_name);

    /* Get the sensor name. */
    sensor_name = ias_sat_attr_get_satellite_sensor_name();
    assert_string_equal(exp_sensor_name, sensor_name);
}

Ensure test_ias_sat_attr_get_satellite_sensor_name_uninitialized()
{
    const char *exp_satellite_name = IAS_SATELLITE_NAME_UNKNOWN;
    const char *exp_sensor_name = IAS_SENSOR_NAME_UNKNOWN;
    const char *satellite_name = NULL;
    const char *sensor_name = NULL;

    /* Get the satellite name. */
    satellite_name = ias_sat_attr_get_satellite_name();
    assert_string_equal(exp_satellite_name, satellite_name);

    /* Get the sensor name. */
    sensor_name = ias_sat_attr_get_satellite_sensor_name();
    assert_string_equal(exp_sensor_name, sensor_name);
}

Ensure test_ias_sat_attr_report_saturation_for_band()
{
    int status;
    int band_number;
    int band_index;
    int should_report_saturation[30];

    status = ias_sat_attr_initialize(IAS_L8);
    assert_equal(status, SUCCESS);

    /* Initialize the saturation report flags */
    for (band_index = 0; band_index < 30; band_index++)
    {
        should_report_saturation[band_index] = FALSE;
    }
    should_report_saturation[0] = TRUE;
    should_report_saturation[1] = TRUE;
    should_report_saturation[2] = TRUE;
    should_report_saturation[3] = TRUE;
    should_report_saturation[4] = TRUE;
    should_report_saturation[5] = TRUE;
    should_report_saturation[6] = TRUE;
    should_report_saturation[7] = TRUE;
    should_report_saturation[8] = TRUE;

    /* check the report values for each band */
    for (band_number = 1; band_number <= 30; band_number++)
    {
        int should_report_saturation_flag;

        status = ias_sat_attr_report_saturation_for_band(band_number,
            &should_report_saturation_flag);
        assert_equal(status, SUCCESS);
        assert_equal_with_message(should_report_saturation_flag,
            should_report_saturation[band_number - 1], "Band %d failed",
            band_number);
    }
}


int main(int argc, char **argv)
{
    TestSuite *suite = create_test_suite();
    add_test(suite, test_ias_sat_attr_initialize);
    add_test(suite, test_ias_sat_attr_initialize_landsat8);
    add_test(suite, test_ias_sat_attr_get_normal_band_count);
    add_test(suite, test_ias_attr_get_sensor_band_numbers);
    add_test(suite, test_ias_sat_attr_band_classification_matchs);
    add_test(suite, test_ias_sat_attr_convert_band_number_to_name);
    add_test(suite, test_ias_sat_attr_convert_band_name_to_number);
    add_test(suite, test_ias_sat_attr_convert_band_index_to_number);
    add_test(suite, test_ias_sat_attr_convert_band_number_to_index);
    add_test(suite, test_ias_sat_attr_get_band_number_from_type);
    add_test(suite, test_ias_sat_attr_get_scas_per_band);
    add_test(suite, test_ias_sat_attr_get_sensor_name);
    add_test(suite, test_ias_sat_attr_get_detectors_per_sca);
    add_test(suite, test_ias_sat_attr_get_sensor_sca_count);
    add_test(suite, test_ias_sat_attr_convert_band_number_to_band_index);
    add_test(suite, test_ias_sat_attr_get_spectral_type_from_band_number);
    add_test(suite, test_ias_sat_attr_get_sensor_max_normal_detectors);
    add_test(suite, test_ias_sat_attr_get_satellite_id_from_satellite_number);
    add_test(suite, test_ias_sat_attr_get_band_name_from_type_and_class);
    add_test(suite, test_ias_sat_attr_get_band_type_from_band_number);
    add_test(suite, test_ias_sat_attr_get_sensor_id_from_band_number);
    add_test(suite, test_lines_per_frame);
    add_test(suite, test_qcal_min_max);
    add_test(suite, test_ias_sat_attr_get_satellite_sensor_name_initialized);
    add_test(suite, test_ias_sat_attr_get_satellite_sensor_name_uninitialized);
    add_test(suite, test_ias_sat_attr_report_saturation_for_band);

    if (argc > 1)
        return run_single_test(suite, argv[1], create_text_reporter());

    return run_test_suite(suite, create_text_reporter());
}

