/*************************************************************************

NAME: logging_test.c

PURPOSE: Using Cgreen for testing logging library files (ias_logging.c 
         and ias_logging.h)

Algorithm References: None

NOTES:
    1. Now the output logging messages are outputted to both the stdout 
       and the output files.
    2. The used routine name below clearly indicates the logging library
       routine it is testing.

**************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <time.h>

#include "ias_logging.h"
#include "ias_const.h"
#include "cgreen/cgreen.h"

Ensure test_ias_log_initialize()
{
    int status;
    status = ias_log_initialize("test");
    assert_equal(status, SUCCESS);    

    /* set log level to INFO for test */
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);

    if (status == SUCCESS)
    {
        assert_equal(ias_log_message_level, IAS_LOG_LEVEL_INFO);
    }
}

Ensure test_ias_log_set_output_level()
{
    int status;
    int old_level;
    status = ias_log_initialize("test");
    assert_equal(status, SUCCESS);                 
    old_level = ias_log_set_output_level(IAS_LOG_LEVEL_WARN);
    assert_equal(ias_log_message_level, IAS_LOG_LEVEL_WARN);
    assert_equal(old_level, IAS_LOG_LEVEL_INFO);
}

Ensure test_ias_log_set_output_target()
{
    int status;
    int fdLog;
    FILE *fp;
    char LocalLogFilename[80];
    struct stat info;

    status = ias_log_initialize("more_test");
    assert_equal(status, SUCCESS);                 
    strcpy(LocalLogFilename, "test1.txt");
    if (stat(LocalLogFilename, &info) == -1)
    {
        if ((fdLog = open(LocalLogFilename, O_CREAT | O_WRONLY,
                        S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH
                        | S_IWOTH )) == -1)
        {
            printf("Unable to open the file");  
        }
    }
    else
    {
        if ((fdLog = open(LocalLogFilename, O_WRONLY | O_APPEND)) == -1)
        {
            printf("Unable to open the file");
        }
    }
    fp = fdopen(fdLog, "w");
    if (fp == NULL)
    {
        printf("Unable to fdopen the file");
    }
    status = ias_log_set_output_target(fp);
    assert_equal(status, SUCCESS); 
    char fmt1 [] = "%s  %s  %s\n";
    IAS_LOG_ERROR(fmt1, "Sat", "Tues", "Wed");
    close(fdLog); 
}

Ensure test_ias_log_message()
{
    int status;
    char fmt1 [] = "%s  %s  %s\n";

    status = ias_log_initialize("tst");
    assert_equal(status, SUCCESS);        
    ias_log_set_output_level(IAS_LOG_LEVEL_ERROR); 
    ias_log_message(IAS_LOG_LEVEL_ERROR,__FILE__,__LINE__,fmt1, \
        "Mon", "Tues", "Wed");
    assert_equal(ias_log_message_level, IAS_LOG_LEVEL_ERROR);
}

Ensure test_ias_log_error()
{
    int status;
    char fmt1 [] = "%s  %s  %s\n";
    FILE *fp1, *fp2;
    char LocalLogFilename[80];
    char time_stamp[18];
    char pname[10];
    char fname[10];
    char year[10], month[10], day[10], pid[10], lnumber[10], mlevel[30];
    char str1[10], str2[10], str3[10];
    char loc_year[40];
    char loc_month[40];
    char loc_day[40];
    time_t curtime;
    struct tm *loctime;

    /* Get current year and time */
    curtime = time(NULL);
    loctime = localtime(&curtime);
    strftime(loc_year, 40, "%Y", loctime);
    strftime(loc_month, 40, "%m", loctime);
    strftime(loc_day, 40, "%d", loctime);

    status = ias_log_initialize("proname");
    ias_log_set_output_level(IAS_LOG_LEVEL_ERROR);
    strcpy(LocalLogFilename, "test.txt");
    if (status == SUCCESS)
    {
        IAS_LOG_ERROR(fmt1, "Mon", "Tues", "Wed");
        fp1 = fopen(LocalLogFilename, "w"); 
        if (fp1 == NULL)
        {
            printf("Unable to open the file");
        }
        
        status = ias_log_set_output_target(fp1);
        IAS_LOG_ERROR(fmt1, "Mon", "Tues", "Wed");
        fclose(fp1); 
        fp2 = fopen(LocalLogFilename, "r");    
        if (fp2 == NULL) 
        {
            printf("Unable to open the file");
        }

        fscanf(fp2, "%4s-%2s-%2s %s %s %s %s %s %s %s %s %s",
            year, month, day, time_stamp, pname, pid, fname, lnumber, mlevel,
            str1, str2, str3);

        assert_string_equal(year, loc_year);
        assert_string_equal(month, loc_month);
        assert_string_equal(day, loc_day);
        assert_string_equal(fname,"logging_test.c");
        assert_equal(atoi(pid),getpid());
        assert_string_equal(mlevel,"ERROR");  
        assert_string_equal(str1,"Mon");
        assert_string_equal(str2,"Tues");
        assert_string_equal(str3,"Wed");
        fclose(fp2);
    } 
}

Ensure test_ias_log_warning()
{
    int status;
    char fmt1 [] = "%s  %s  %s\n";
    FILE *fp1, *fp2;
    char LocalLogFilename[80];
    char time_stamp[18];
    char pname[10];
    char fname[10];
    char year[10], month[10], day[10], pid[10], lnumber[10], mlevel[30];
    char str1[10], str2[10], str3[10];
    char loc_year[40];
    char loc_month[40];
    char loc_day[40];
    time_t curtime;
    struct tm *loctime;

    /* Get current year and time */
    curtime = time(NULL);
    loctime = localtime(&curtime);
    strftime(loc_year, 40, "%Y", loctime);
    strftime(loc_month, 40, "%m", loctime);
    strftime(loc_day, 40, "%d", loctime);

    status = ias_log_initialize("proname");
    assert_equal(status, SUCCESS);
    ias_log_set_output_level(IAS_LOG_LEVEL_WARN);
    strcpy(LocalLogFilename, "test2.txt");

    IAS_LOG_WARNING(fmt1, "Mon", "Tues", "Wed");
    fp1 = fopen(LocalLogFilename, "w"); 
    if (fp1 == NULL)
    {
        printf("Unable to open the file");
    }

    status = ias_log_set_output_target(fp1);
    assert_equal(status, SUCCESS);
    IAS_LOG_WARNING(fmt1, "Mon", "Tues", "Wed");
    fclose(fp1); 
    fp2 = fopen(LocalLogFilename, "r");    
    if (fp2 == NULL) 
    {
        printf("Unable to open the file");
    }

    fscanf(fp2, "%4s-%2s-%2s %s %s %s %s %s %s %s %s %s",
        year, month, day, time_stamp, pname, pid, fname, lnumber, mlevel,
        str1, str2, str3);

    assert_string_equal(year, loc_year);
    assert_string_equal(month, loc_month);
    assert_string_equal(day, loc_day);
    assert_string_equal(fname,"logging_test.c");
    assert_equal(atoi(pid),getpid());
    assert_string_equal(mlevel,"WARN");  
    assert_string_equal(str1,"Mon");
    assert_string_equal(str2,"Tues");
    assert_string_equal(str3,"Wed");
    fclose(fp2);
}

Ensure test_ias_log_info()
{
    int status;
    char fmt1 [] = "%s  %s  %s\n";
    FILE *fp1, *fp2;
    char LocalLogFilename[80];
    char time_stamp[18];
    char pname[10];
    char fname[10];
    char year[10], month[10], day[10], pid[10], lnumber[10], mlevel[30];
    char str1[10], str2[10], str3[10];
    char loc_year[40];
    char loc_month[40];
    char loc_day[40];
    time_t curtime;
    struct tm *loctime;

    /* Get current year and time */
    curtime = time(NULL);
    loctime = localtime(&curtime);
    strftime(loc_year, 40, "%Y", loctime);
    strftime(loc_month, 40, "%m", loctime);
    strftime(loc_day, 40, "%d", loctime);

    status = ias_log_initialize("proname");
    assert_equal(status, SUCCESS);
    ias_log_set_output_level(IAS_LOG_LEVEL_INFO);
    strcpy(LocalLogFilename, "test3.txt");
    if (status == SUCCESS)
    {
        IAS_LOG_INFO(fmt1, "Mon", "Tues", "Wed");
        fp1 = fopen(LocalLogFilename, "w"); 
        if (fp1 == NULL)
        {
            printf("Unable to open the file");
        }
        
        status = ias_log_set_output_target(fp1);
        assert_equal(status, SUCCESS);
        IAS_LOG_INFO(fmt1, "Mon", "Tues", "Wed");
        fclose(fp1); 
        fp2 = fopen(LocalLogFilename, "r");    
        if (fp2 == NULL) 
        {
            printf("Unable to open the file");
        }

        fscanf(fp2, "%4s-%2s-%2s %s %s %s %s %s %s %s %s %s",
            year, month, day, time_stamp, pname, pid, fname, lnumber, mlevel,
            str1, str2, str3);

        assert_string_equal(year, loc_year);
        assert_string_equal(month, loc_month);
        assert_string_equal(day, loc_day);
        assert_string_equal(fname,"logging_test.c");
        assert_equal(atoi(pid),getpid());
        assert_string_equal(mlevel,"INFO");  
        assert_string_equal(str1,"Mon");
        assert_string_equal(str2,"Tues");
        assert_string_equal(str3,"Wed");
        fclose(fp2);
    } 
}

Ensure test_ias_log_debug()
{
    int status;
    char fmt1 [] = "%s  %s  %s\n";
    FILE *fp1, *fp2;
    char LocalLogFilename[80];
    char time_stamp[18];
    char pname[10];
    char fname[10];
    char year[10], month[10], day[10], pid[10], lnumber[10], mlevel[30];
    char str1[10], str2[10], str3[10];
    char loc_year[40];
    char loc_month[40];
    char loc_day[40];
    time_t curtime;
    struct tm *loctime;

    /* Get current year and time */
    curtime = time(NULL);
    loctime = localtime(&curtime);
    strftime(loc_year, 40, "%Y", loctime);
    strftime(loc_month, 40, "%m", loctime);
    strftime(loc_day, 40, "%d", loctime);

    status = ias_log_initialize("proname");
    assert_equal(status, SUCCESS);
    ias_log_set_output_level(IAS_LOG_LEVEL_DEBUG);
    strcpy(LocalLogFilename, "test4.txt");
    if (status == SUCCESS)
    {
        IAS_LOG_DEBUG(fmt1, "Mon", "Tues", "Wed");
        fp1 = fopen(LocalLogFilename, "w"); 
        if (fp1 == NULL)
        {
            printf("Unable to open the file");
        }
        
        status = ias_log_set_output_target(fp1);
        assert_equal(status, SUCCESS);
        IAS_LOG_DEBUG(fmt1, "Mon", "Tues", "Wed");
        fclose(fp1); 
        fp2 = fopen(LocalLogFilename, "r");    
        if (fp2 == NULL) 
        {
            printf("Unable to open the file");
        }

        fscanf(fp2, "%4s-%2s-%2s %s %s %s %s %s %s %s %s %s",
            year, month, day, time_stamp, pname, pid, fname, lnumber, mlevel,
            str1, str2, str3);

        assert_string_equal(year, loc_year);
        assert_string_equal(month, loc_month);
        assert_string_equal(day, loc_day);
        assert_string_equal(fname,"logging_test.c");
        assert_equal(atoi(pid),getpid());
        assert_string_equal(mlevel,"DEBUG");  
        assert_string_equal(str1,"Mon");
        assert_string_equal(str2,"Tues");
        assert_string_equal(str3,"Wed");
        fclose(fp2);
    } 
}

int main(int argc, char **argv)
{
    TestSuite *suite = create_test_suite();
    add_test(suite, test_ias_log_initialize);
    add_test(suite, test_ias_log_set_output_level);
    add_test(suite, test_ias_log_set_output_target); 
    add_test(suite, test_ias_log_message);
    add_test(suite, test_ias_log_error);
    add_test(suite, test_ias_log_warning);
    add_test(suite, test_ias_log_info);
    add_test(suite, test_ias_log_debug); 
    
    return run_test_suite(suite, create_text_reporter());
}
