#!/usr/bin/perl -w -I..

# ----------------------------------------------------------------------------
# This is just a quick and dirty developer test script to help test changes to
# the Logger.pm module.
# ----------------------------------------------------------------------------

use strict;
use Fcntl;
use POSIX qw{:unistd_h};
use Logger;

use constant PROG => "test_logger.pl";

# ----------------------------------------------------------------------------
# File Testing

my $test_log_file = "test.log";
my $test_log_file2 = "test2.log";
my $test_log_file3 = "test3.log";

my $file_logger = Logger->new($test_log_file);

if (!$file_logger)
{
    print PROG . ": ERROR: Unable to establish a logger object :: " .
          $test_log_file . "\n";
    return 1;
}

$file_logger->set_module_name(PROG);

set_default_log($file_logger);

# $IAS_LOG_LEVEL environemnt variable is not set, therefore, default
# value of "INFO" is used, "INFO", "WARN", and "Fatal" messages are outputted
# to "test.log" file
$file_logger->info_msg(__FILE__, __LINE__, "Info Message");
$file_logger->warn_msg(__FILE__, __LINE__, "Warn Message");
$file_logger->debug_msg(__FILE__, __LINE__, "Debug Message");
$file_logger->fatal_msg(__FILE__, __LINE__, "Fatal Message");

# The Logger object LOG_MSG_LEVEL is set to "WARN" by using the 
# set_log_msg_level method, therefore, only "WARN" and "Fatal" messages 
# are outputted to "test2.log" file
my $file_logger2 = Logger->new($test_log_file2);

if (!$file_logger2)
{
    print PROG . ": ERROR: Unable to establish a logger object :: " .
          $test_log_file2 . "\n";
    return 1;
}

$file_logger2->set_log_msg_level(IAS_LOG_LEVEL_WARN);
$file_logger2->set_module_name(PROG);

set_default_log($file_logger2);

$file_logger2->info_msg(__FILE__, __LINE__, "Info Message");
$file_logger2->warn_msg(__FILE__, __LINE__, "Warn Message");
$file_logger2->debug_msg(__FILE__, __LINE__, "Debug Message");
$file_logger2->fatal_msg(__FILE__, __LINE__, "Fatal Message");

# $IAS_LOG_LEVEL environemnt variable is set to "DEBUG", therefore, "DEBUG", 
# "INFO", "WARN" and "Fatal" messages are outputted to the "test3.log" file
$ENV{IAS_LOG_LEVEL} = "DEBUG";

my $file_logger3 = Logger->new($test_log_file3);

if (!$file_logger3)
{
    print PROG . ": ERROR: Unable to establish a logger object :: " .
          $test_log_file3 . "\n";
    return 1;
}

$file_logger3->set_module_name(PROG);

set_default_log($file_logger3);

$file_logger3->info_msg(__FILE__, __LINE__, "Info Message");
$file_logger3->warn_msg(__FILE__, __LINE__, "Warn Message");
$file_logger3->debug_msg(__FILE__, __LINE__, "Debug Message");
$file_logger3->fatal_msg(__FILE__, __LINE__, "Fatal Message");

# --------------------------------------------------------------------------
# Test file locking
# We open a file handle the same way the logger does, then lock the file.
# We then write a message to the test log file, spawn a child process that
# will log to the same file, wait and log a second message. If locking is
# working correctly the two Block Message lines will be together with
# the log message from test_lock following.
# --------------------------------------------------------------------------
my $mode = 0664;
$file_logger2 = Logger->new($test_log_file);


my $fh = $file_logger2->{FILEHANDLE};

my $lock = pack('s s l! l! l', F_WRLCK, SEEK_SET, 0, 0, 0);
fcntl($fh,  F_SETLKW, $lock);  # Lock Exclusive

print($fh "Block Message 1\n");

unless ( fork())
{
    exec("./test_lock.pl");
    exit(0);
}

print "Sleeping for 10 seconds to force child to wait.\n";
sleep 10;

print($fh "Block Message 2\n");

$lock = pack('s s l! l! l', F_UNLCK, SEEK_SET, 0, 0, 0);
fcntl($fh,  F_SETLKW, $lock);  # Lock Exclusive

$file_logger->close_log();
$file_logger2->close_log();
# ----------------------------------------------------------------------------
# STDOUT Testing

$file_logger = Logger->new("STDOUT");

if (!$file_logger)
{
    print PROG . ": ERROR: Unable to establish a logger object :: " .
          $test_log_file . "\n";
    return 1;
}

$file_logger->set_module_name(PROG);

set_default_log($file_logger);

$file_logger->info_msg(__FILE__, __LINE__, "Info Message");
$file_logger->warn_msg(__FILE__, __LINE__, "Warn Message");
$file_logger->debug_msg(__FILE__, __LINE__, "Debug Message");
$file_logger->fatal_msg(__FILE__, __LINE__, "Fatal Message");

$file_logger->close_log();

