#!/usr/bin/env python3
""" CPF OLI Absolute and Relative gains
"""

from ias.misc import satellite_attributes as sa

ABS_NAME = 'OLI_ABSOLUTE_GAINS'
SUBABS_NAME = 'Gain_B{0:0=2d}'
REL_NAME = 'OLI_RELATIVE_GAINS'
SUBREL_NAME = 'Rel_Gains_B{0:0=2d}_SCA{1:0=2d}'


class RELATIVE_GAINS(list):
    """ OLI Relative gains list class """

    def __init__(self, cpf, sat_attr, combined=None):
        """ Initializes the relative gains using the read in cpf object

            Returns: List of Absolute Gains
        """

        # Initialize using list inheritance
        super(list, self).__init__()

        # Add all gains for the OLI bands
        for band_number in sat_attr.band_numbers(sa.SensorId.OLI):
            band_index = sat_attr.convert_band_number_to_index(band_number)
            number_of_scas = sat_attr.get_scas_per_band(band_number)

            # Add all gains for every sca in the current band
            self.append(list())
            for sca in range(number_of_scas):
                rgbs = SUBREL_NAME.format(band_number, sca + 1)

                # Check if user wants SCAs combined or in separate lists
                if combined:
                    self[band_index].extend(cpf.data[REL_NAME][rgbs]['value'])
                else:
                    self[band_index].append(cpf.data[REL_NAME][rgbs]['value'])


class ABSOLUTE_GAINS(list):
    """ OLI ABSOLUTE_GAINS list class """

    def __init__(self, cpf, sat_attr):
        """ Initializes the absolute gains using the read in cpf object

            Returns: List of Absolute Gains
        """

        # Initialize using list inheritance
        super(list, self).__init__()

        # Add all gains for the OLI bands
        for band_number in sat_attr.band_numbers(sa.SensorId.OLI):
            abs = SUBABS_NAME.format(band_number)
            self.append(cpf.data[ABS_NAME][abs]['value'])
