#!/usr/bin/env python3
""" Contains all of the standard parameters use the following format:

"NAME": ["NAME", REQUIRED, HELP, DEFAULT, LOWER_RANGE, UPPER_RANGE, DATATYPE,
         VALID_OPTIONS, IS_LIST]

"""
# Column indexes for each parameter
NAME = 0
REQUIRED = 1
HELP = 2
DEFAULT = 3
LORANGE = 4
UPRANGE = 5
DATATYPE = 6
VALID_OPTIONS = 7
IS_LIST = 8

# Standard parameters dictionary
standard_parms = {
    "WORK_ORDER_ID": [
        "WORK_ORDER_ID", True, "Identification string for Work Order", None,
        None, None, str, None, False],

    "STORE_CHARACTERIZATION_IN_DB": [
        "STORE_CHARACTERIZATION_IN_DB", True,
        "Indicates characterization data should be stored in the "
        "characterization database: 1 to store data, 0 don't store data",
        1, 0, 1, int, None, False],

    "BAND_LIST": [
        "BAND_LIST", True, "Defines the bands to process",
        (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11), None, None, int, None, True],

    "OUTPUT_DIRECTORY": [
        "OUTPUT_DIRECTORY", True, "Name of the output directory", None,
        None, None, str, None, False],

    "CAL_PARM_FILENAME": [
        "CAL_PARM_FILENAME", True, "Calibration parameter file", None, None,
        None, str, None, False],

    "MAX_PROCESSORS_TO_USE": [
        "MAX_PROCESSOR_TO_USE", True, "Max processors to use for processing",
        4, None, None, int, None, False],

    "GENERATE_REPORT": [
        "GENERATE_REPORT", True, "1 = generate report files, 0 = don't "
        "generate reports", 1, 0, 1, int, None, False],


    "REPORT_FILENAME": [
        "REPORT_FILENAME", True, "Name of the report file", 1, 0, 1, int,
        None, False],

    "SATELLITE": [
        "SATELLITE", False, "Satellite ID (8 for Landsat 8)", 8, None, None,
        int, ["8"], False]
}
