#!/usr/bin/env python3
""" test_parameters.py

   Test the ParameterParser class and all associated methods
"""
import imp
import unittest
import sys
import filecmp
import os
import parameter_file as ps


class TestParameterParser(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        pass

    def test_parameter_parser(self):
        parser = ps.ParameterParser()

        # Start of the parameter file parameters
        parser.add_standard_parameter("WORK_ORDER_ID", "work_order_id",
                                      valid_options=("I7", "test2"))
        parser.add_standard_parameter("BAND_LIST", "band_list", data_type=int,
                                      is_list=True)
        parser.add_parameter("REF_BAND_LIST", "ref_band_list", is_list=True)
        parser.add_parameter("WO_DIRECTORY", "wo_dir")
        parser.add_parameter("APPLY_RADIANCE_RESCALING", "apply_rad", True)
        parser.add_parameter("BACKGROUND", "background", True, "No help")
        parser.add_parameter("COMBINE_SCAS", "combine_scas", True, "SCAS",
                             0, 0, 1)
        parser.add_parameter("L1G_FILENAME", "l1g", False, "L1G Filename",
                             data_type=str)
        parser.add_parameter("MINMAX_OUTPUT_DN", "minmax", is_list=True,
                             data_type=float)
        parser.add_parameter("ODTYPE", "odtype")
        parser.add_parameter("PCCALPHA", "pcalpha")
        parser.add_parameter("PROCESSING_PASS", "processing_pass")
        parser.add_parameter("RESAMPLE", "resample")
        parser.add_parameter("TERRAIN_FLAG", "tflag")
        parser.add_parameter("NO_FLAG", "no_flag", required = False,
                             default = False)

        with self.assertRaises(Exception):
            parser.add_standard_parameter("PARM_DNE", "p")

        # Start of the OMF parameters
        omf = ps.ParameterParser()
        omf.add_parameter("BIAS_PARM_FILENAME_OLI", "bias_parm_filename_oli")
        omf.add_parameter("BIAS_PARM_FILENAME_TIRS", "bias_parm_filename_tirs")
        omf.add_parameter("CAL_PARM_FILENAME", "cal_parm_filename")
        omf.add_parameter("RLUT_FILENAME", "rlut_filename")
        omf.add_parameter("L0R_FILENAME", "l0r_filename")
        omf.add_parameter("SOFTWARE_VERSION", "software_version")
        omf.add_parameter("SPACECRAFT", "spacecraft")
        omf.add_parameter("PROCESSING_CENTER", "processing_center")
        omf.add_parameter("MAX_PROCESSORS_TO_USE", "max_processors_to_use")
        omf.add_parameter("ACQUISITION_TYPE", "acquisition_type")
        omf.add_parameter("PRODUCT_REQUEST_ID", "product_request_id")
        omf.add_parameter("SENSOR", "sensor")
        omf.add_parameter("SATELLITE", "satellite")
        omf.add_parameter("UL_BOUNDARY_LAT_LON", "ul_boundary_lat_lon",
                          is_list=True)
        omf.add_parameter("UR_BOUNDARY_LAT_LON", "ur_boundary_lat_lon",
                          is_list=True)
        omf.add_parameter("LL_BOUNDARY_LAT_LON", "ll_boundary_lat_lon",
                          is_list=True)
        omf.add_parameter("LR_BOUNDARY_LAT_LON", "lr_boundary_lat_lon",
                          is_list=True)
        omf.add_parameter("TARGET_WRS_PATH", "target_wrs_path")
        omf.add_parameter("TARGET_WRS_ROW", "target_wrs_row")
        omf.add_parameter("TARGET_PROJECTION", "target_projection")
        omf.add_parameter("UTM_ZONE", "utm_zone")
        omf.add_parameter("DEM_FILENAME", "dem_filename")
        omf.add_parameter("MIN_ELEVATION", "min_elevation")
        omf.add_parameter("MAX_ELEVATION", "max_elevation")
        omf.add_parameter("ANCILLARY_FILENAME", "ancillary_filename")
        omf.add_parameter("MODEL_FILENAME_PASS_1", "model_filename_pass_1")
        omf.add_parameter("TIRS_SSM_POSITION_STATUS",
                          "tirs_ssm_position_status")
        omf.add_parameter("GCP_DIRECTORY", "gcp_directory")
        omf.add_parameter("GROUND_CONTROL_POINTS_VERSION",
                          "ground_control_points_version")
        omf.add_parameter("L1R_FILENAME", "l1r_filename")
        omf.add_parameter("PIXEL_MASK_FILENAME", "pixel_mask_filename")
        omf.add_parameter("GRID_FILENAME_PASS_1", "grid_filename_pass_1")
        omf.add_parameter("GEOM_GRID_FILENAME_PASS_1",
                          "geom_grid_filename_pass_1")
        omf.add_parameter("DEM_FILENAME_PASS_1", "dem_filename_pass_1")
        omf.add_parameter("L1G_FILENAME_PASS_1", "l1g_filename_pass_1")
        omf.add_parameter("MEASURED_GCP_FILENAME_PASS_1",
                          "measured_gcp_filename_pass_1")
        omf.add_parameter("PRECISION_SUCCEEDED_FLAG_PASS_1",
                          "precision_succeeded_flag_pass_1")
        omf.add_parameter("PRECISION_RESIDUALS_FILENAME_PASS_1",
                          "precision_residuals_filename_pass_1")
        omf.add_parameter("MODEL_FILENAME_PASS_2", "model_filename_pass_2")
        omf.add_parameter("GROUND_CONTROL_POINTS_MODEL",
                          "ground_control_points_model")
        omf.add_parameter("GEOMETRIC_RMSE_MODEL", "geometric_rmse_model")
        omf.add_parameter("GEOMETRIC_RMSE_MODEL_Y", "geometric_rmse_model_y")
        omf.add_parameter("GEOMETRIC_RMSE_MODEL_X", "geometric_rmse_model_x")
        omf.add_parameter("GRID_FILENAME_PASS_2", "grid_filename_pass_2")
        omf.add_parameter("GEOM_GRID_FILENAME_PASS_2",
                          "geom_grid_filename_pass_2")
        omf.add_parameter("DEM_FILENAME_PASS_2", "dem_filename_pass_2")
        omf.add_parameter("L1G_FILENAME_PASS_2", "l1g_filename_pass_2")
        omf.add_parameter("ANGLE_COEF_FILENAME_PASS_2",
                          "angle_coef_filename_pass_2")
        omf.add_parameter("OCCLUSION_FILENAME", "occlusion_filename")
        omf.add_parameter("CLOUD_COVER_SCORE", "cloud_cover_score")
        omf.add_parameter("CLOUD_COVER_LAND_SCORE", "cloud_cover_land_score")
        omf.add_parameter("SNOW_ICE_SCORE", "snow_ice_score")
        omf.add_parameter("QUALITY_BAND_FILENAME", "quality_band_filename")
        omf.add_parameter("CLOUD_COVER_ALGORITHM_1", "cloud_cover_algorithm_1")
        omf.add_parameter("CLOUD_COVER_WEIGHTS_1", "cloud_cover_weights_1",
                          is_list=True)
        omf.add_parameter("CLOUD_COVER_ALGORITHM_2", "cloud_cover_algorithm_2")
        omf.add_parameter("CLOUD_COVER_WEIGHTS_2", "cloud_cover_weights_2",
                          is_list=True)
        omf.add_parameter("CLOUD_COVER_ALGORITHM_3", "cloud_cover_algorithm_3")
        omf.add_parameter("CLOUD_COVER_WEIGHTS_3", "cloud_cover_weights_3",
                          is_list=True)
        omf.add_parameter("CLOUD_COVER_ALGORITHM_4", "cloud_cover_algorithm_4")
        omf.add_parameter("CLOUD_COVER_WEIGHTS_4", "cloud_cover_weights_4",
                          is_list=True)
        omf.add_parameter("CLOUD_COVER_ALGORITHM_5", "cloud_cover_algorithm_5")
        omf.add_parameter("CLOUD_COVER_WEIGHTS_5", "cloud_cover_weights_5",
                          is_list=True)

        parms = parser.parse_parameters("./odl")
        omf_parms = omf.parse_parameters("omf", ps.OMF)

        # Verify the parameters
        self.assertEqual(parms.work_order_id, "I7")
        self.assertEqual(parms.band_list, [6])
        self.assertEqual(parms.ref_band_list,
                         [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11])
        self.assertEqual(parms.wo_dir,
                         "/data/ias_sys/proddata/wo/I7")
        self.assertEqual(parms.apply_rad, 1)
        self.assertEqual(parms.background, 0.0)
        self.assertEqual(parms.combine_scas, 1)
        self.assertEqual(parms.l1g, "l1t.h5")
        self.assertEqual(parms.minmax, [1.000000, 65535.000000])
        self.assertEqual(parms.odtype, "UI*2")
        self.assertEqual(parms.pcalpha, -0.50)
        self.assertEqual(parms.processing_pass, 2)
        self.assertEqual(parms.resample, "CC")
        self.assertEqual(parms.tflag, 1)
        self.assertEqual(parms.no_flag, False)
        self.assertEqual(omf_parms.bias_parm_filename_oli,
                         "LO8BPF20140129084455_20140129092930.02")
        self.assertEqual(omf_parms.bias_parm_filename_tirs,
                         "LT8BPF20140129084101_20140129093023.02")
        self.assertEqual(omf_parms.cal_parm_filename,
                         "L8CPF20140101_20140331.05")
        self.assertEqual(omf_parms.rlut_filename,
                         "L8RLUT20130211_20150302v10.h5")
        self.assertEqual(omf_parms.l0r_filename,
                         "l0r_symlink/LC81810402014029LGN00")
        self.assertEqual(omf_parms.software_version, "43128zdicu")
        self.assertEqual(omf_parms.spacecraft, "LANDSAT_8")
        self.assertEqual(omf_parms.processing_center, "EROS")
        self.assertEqual(omf_parms.max_processors_to_use, 4)
        self.assertEqual(omf_parms.acquisition_type, 0)
        self.assertEqual(omf_parms.product_request_id, "")
        self.assertEqual(omf_parms.sensor, "OLITIRS")
        self.assertEqual(omf_parms.satellite,  8)
        self.assertEqual(omf_parms.ul_boundary_lat_lon,
                         [30.516984790967, 23.124969317858])
        self.assertEqual(omf_parms.ur_boundary_lat_lon,
                         [30.143246083322, 25.132911176239])
        self.assertEqual(omf_parms.ll_boundary_lat_lon,
                         [27.639038240016, 22.521350855701])
        self.assertEqual(omf_parms.lr_boundary_lat_lon,
                         [27.273732072391, 24.49281189209])
        self.assertEqual(omf_parms.target_wrs_path, 181)
        self.assertEqual(omf_parms.target_wrs_row, 40)
        self.assertEqual(omf_parms.target_projection, 1)
        self.assertEqual(omf_parms.utm_zone, 34)
        self.assertEqual(omf_parms.dem_filename, "source_dem.h5")
        self.assertEqual(omf_parms.min_elevation, -14)
        self.assertEqual(omf_parms.max_elevation, 308)
        self.assertEqual(omf_parms.ancillary_filename, "ancillary_file.h5")
        self.assertEqual(omf_parms.model_filename_pass_1, "systematic_model.h5")
        self.assertEqual(omf_parms.tirs_ssm_position_status, "NOMINAL")
        self.assertEqual(omf_parms.gcp_directory, "gcp_lib")
        self.assertEqual(omf_parms.ground_control_points_version, 2)
        self.assertEqual(omf_parms.l1r_filename, "l1r_image.h5")
        self.assertEqual(omf_parms.pixel_mask_filename, "pixel_mask.dat")
        self.assertEqual(omf_parms.grid_filename_pass_1, "systematic_grid.h5")
        self.assertEqual(omf_parms.geom_grid_filename_pass_1, "geomgrid.h5")
        self.assertEqual(omf_parms.dem_filename_pass_1, "elev.h5")
        self.assertEqual(omf_parms.l1g_filename_pass_1, "sys_l1g.h5")
        self.assertEqual(omf_parms.measured_gcp_filename_pass_1, "measured.gcp")
        self.assertEqual(omf_parms.precision_succeeded_flag_pass_1, 1)
        self.assertEqual(omf_parms.precision_residuals_filename_pass_1,
                         "precision.residuals")
        self.assertEqual(omf_parms.model_filename_pass_2, "precision_model.h5")
        self.assertEqual(omf_parms.ground_control_points_model, 315)
        self.assertEqual(omf_parms.geometric_rmse_model, 6.8525613156217)
        self.assertEqual(omf_parms.geometric_rmse_model_y, 5.2500929931335)
        self.assertEqual(omf_parms.geometric_rmse_model_x, 4.4038755826891)
        self.assertEqual(omf_parms.grid_filename_pass_2, "precision_grid.h5")
        self.assertEqual(omf_parms.geom_grid_filename_pass_2,
                         "geomgrid_pass_2.h5")
        self.assertEqual(omf_parms.dem_filename_pass_2, "elev_pass_2.h5")
        self.assertEqual(omf_parms.l1g_filename_pass_2, "l1t.h5")
        self.assertEqual(omf_parms.angle_coef_filename_pass_2, "l1t_ANG.txt")
        self.assertEqual(omf_parms.occlusion_filename, "occlusion_mask.h5")
        self.assertEqual(omf_parms.cloud_cover_score, 0)
        self.assertEqual(omf_parms.cloud_cover_land_score, 0)
        self.assertEqual(omf_parms.snow_ice_score, 0)
        self.assertEqual(omf_parms.quality_band_filename, "quality_band.h5")
        self.assertEqual(omf_parms.cloud_cover_algorithm_1, "ACCA")
        self.assertEqual(omf_parms.cloud_cover_weights_1,
                         [0.7, 0, 0.7, 0, 0.7, 0])
        self.assertEqual(omf_parms.cloud_cover_algorithm_2, "Cirrus")
        self.assertEqual(omf_parms.cloud_cover_weights_2, [0, 1, 0, 0, 0, 0])
        self.assertEqual(omf_parms.cloud_cover_algorithm_3, "See5")
        self.assertEqual(omf_parms.cloud_cover_weights_3, [1, 0, 0, 0, 0, 0])
        self.assertEqual(omf_parms.cloud_cover_algorithm_4, "")
        self.assertEqual(omf_parms.cloud_cover_weights_4, [0, 0, 0, 0, 0, 0])
        self.assertEqual(omf_parms.cloud_cover_algorithm_5, "")
        self.assertEqual(omf_parms.cloud_cover_weights_5, [0, 0, 0, 0, 0, 0])

        # Test the Help and Template methods
        old_stdout = sys.stdout
        sys.stdout = open("parm_help.txt", "w")
        status = parser.provide_help("--help", ps.PARAMETERS)
        sys.stdout.close()
        sys.stdout = old_stdout
        self.assertEqual(status, True)

        sys.stdout = open("omf_help.txt", "w")
        status = omf.provide_help("--help", ps.OMF)
        sys.stdout.close()
        sys.stdout = old_stdout
        self.assertEqual(status, True)

        sys.stdout = open("parm_template.txt", "w")
        status = parser.provide_help("--template", ps.PARAMETERS)
        sys.stdout.close()
        sys.stdout = old_stdout
        self.assertEqual(status, True)

        sys.stdout = open("omf_template.txt", "w")
        status = omf.provide_help("--template", ps.OMF)
        sys.stdout.close()
        sys.stdout = old_stdout
        self.assertEqual(status, True)

        status = parser.provide_help("not_help", ps.PARAMETERS)
        self.assertEqual(status, False)

        # Compare the output files
        self.assertEqual(filecmp.cmp("parm_help.txt",
                         "verify/parm_help.verify"), True)
        self.assertEqual(filecmp.cmp("parm_template.txt",
                         "verify/parm_template.verify"), True)
        self.assertEqual(filecmp.cmp("omf_help.txt",
                         "verify/omf_help.verify"), True)
        self.assertEqual(filecmp.cmp("omf_template.txt",
                         "verify/omf_template.verify"), True)

        # Remove the files
        os.remove("parm_help.txt")
        os.remove("parm_template.txt")
        os.remove("omf_help.txt")
        os.remove("omf_template.txt")

    def test_parser_bad_parameters(self):

        # Add a parameter with bad options
        parser = ps.ParameterParser()
        parser.add_standard_parameter(
            "WORK_ORDER_ID", "work_order_id", valid_options=("I10", "I12"))
        with self.assertRaises(ps.ParameterOptionError):
            parser.parse_parameters("./odl")

        parser = ps.ParameterParser()
        parser.add_parameter("REF_BAND_LIST", "ref_band_list", is_list=True,
                             valid_options=(1, 2, 4, 5, 6, 7, 8, 9, 10))
        with self.assertRaises(ps.ParameterOptionError):
            parser.parse_parameters("./odl")

        # Make sure the options work
        parser = ps.ParameterParser()
        parser.add_standard_parameter(
            "WORK_ORDER_ID", "work_order_id", valid_options=("I7", "I12"))
        parser.parse_parameters("./odl")

        parser = ps.ParameterParser()
        parser.add_parameter("REF_BAND_LIST", "ref_band_list",  is_list=True,
                             valid_options=(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11))
        parser.parse_parameters("./odl")

        # Test that required parameters are caught
        parser = ps.ParameterParser()
        valid_list = ["I7", "I12"]
        parser.add_parameter(
            "WORK_ORDER_ID_REQ", "work_order_id", valid_options=valid_list,
            is_list=True, required=True)
        with self.assertRaises(ps.ParameterRequiredError):
            parser.parse_parameters("./odl")

        # Test that ranged parameters are caught
        parser = ps.ParameterParser()
        parser.add_parameter("APPLY_RADIANCE_RESCALING", "apply_rad", True,
                             lower_range=-3, upper_range=-1)
        with self.assertRaises(ps.ParameterRangeError):
            parser.parse_parameters("./odl")

        parser = ps.ParameterParser()
        parser.add_parameter("MINMAX_OUTPUT_DN", "minmax_dn", True,
                             is_list=True, lower_range = 0.0,
                             upper_range = 64000.0)
        with self.assertRaises(ps.ParameterRangeError):
            parser.parse_parameters("./odl")

        # Test that bad datatypes are caught
        parser = ps.ParameterParser()
        parser.add_parameter("WO_DIRECTORY", "wo_dir", data_type=float)
        with self.assertRaises(ps.ParameterTypeError):
            parser.parse_parameters("./odl")

        # Make sure that the band standard parameter is caught
        parser = ps.ParameterParser()
        with self.assertRaises(ps.ParameterNoStandardError):
            parser.add_standard_parameter(
                "WORK_ORDER_ID2", "work_order_id", valid_options=("I7", "I12"))

        # Check that both options and range throw an exception
        parser = ps.ParameterParser()
        with self.assertRaises(Exception):
            parser.add_parameter("COMBINE_SCAS", "combine_scas", True, "SCAS",
                             0, 0, 1, valid_options=(0, 1, 3, 4))

        # Make sure requesting a non-list that is a list in the file is caught
        parser = ps.ParameterParser()
        parser.add_parameter("REF_BAND_LIST", "ref_band_list",  is_list=False)
        with self.assertRaises(ps.ParameterTypeError):
            parser.parse_parameters("./odl")

    @classmethod
    def tearDownClass(cls):
        pass

if __name__ == '__main__':
    unittest.main()
