#!/usr/bin/env python3
""" test_log

    Unit tests for the ias_log/logger.py module
"""
import unittest
from ias.log import logger as lg
from subprocess import call
import os
import filecmp
import imp
import logger as lg


class TestLogger(unittest.TestCase):

    @staticmethod
    def rm_silent(filename):
        """ Removal of testing files if they exist """
        try:
            os.remove(filename)
        except OSError as e:
            pass

    def test_log_debug(self):
        """ Testing the debug logging call """

        file_logger = "Test_DEBUG.log"
        verf_logger = "verify/Test_DEBUG.verify"

        TestLogger.rm_silent(file_logger)

        logger = lg.Logger("Test Logger", file_logger)
        logger.setLevel(lg.CRITICAL)
        self.assertEqual(logger.getEffectiveLevel(), lg.CRITICAL)
        logger.debug("This should not be logged to file for CRITICAL")

        logger.setLevel(lg.ERROR)
        self.assertEqual(logger.getEffectiveLevel(), lg.ERROR)
        logger.debug("This should not be logged to file for ERROR")

        logger.setLevel(lg.WARNING)
        self.assertEqual(logger.getEffectiveLevel(), lg.WARNING)
        logger.debug("This should not be logged to file for WARNING")

        logger.setLevel(lg.INFO)
        self.assertEqual(logger.getEffectiveLevel(), lg.INFO)
        logger.debug("This should not be logged to file for INFO")

        logger.setLevel(lg.DEBUG)
        self.assertEqual(logger.getEffectiveLevel(), lg.DEBUG)
        logger.debug("This should be logged to file for DEBUG")

        logger.setLevel(lg.NOTSET)
        self.assertEqual(logger.getEffectiveLevel(), lg.NOTSET)
        logger.debug("This should be logged to file for NOTSET")
        logger.close()

        call(['sed', '-i', '-e', 's/[0-9]//g', "-e", 's/\s\s*/:/g',
             file_logger])

        self.assertEqual(filecmp.cmp(file_logger, verf_logger), True)
        TestLogger.rm_silent(file_logger)

    def test_log_info(self):
        """ Testing the info logging call """

        file_logger = "Test_INFO.log"
        verf_logger = "verify/Test_INFO.verify"

        TestLogger.rm_silent(file_logger)

        logger = lg.Logger("Test Logger", file_logger)
        logger.setLevel(lg.CRITICAL)
        self.assertEqual(logger.getEffectiveLevel(), lg.CRITICAL)
        logger.info("This should not be logged to file for CRITICAL")

        logger.setLevel(lg.ERROR)
        self.assertEqual(logger.getEffectiveLevel(), lg.ERROR)
        logger.info("This should not be logged to file for ERROR")

        logger.setLevel(lg.WARNING)
        self.assertEqual(logger.getEffectiveLevel(), lg.WARNING)
        logger.info("This should not be logged to file for WARNING")

        logger.setLevel(lg.INFO)
        self.assertEqual(logger.getEffectiveLevel(), lg.INFO)
        logger.info("This should be logged to file for INFO")

        logger.setLevel(lg.DEBUG)
        self.assertEqual(logger.getEffectiveLevel(), lg.DEBUG)
        logger.info("This should be logged to file for DEBUG")

        logger.setLevel(lg.NOTSET)
        self.assertEqual(logger.getEffectiveLevel(), lg.NOTSET)
        logger.info("This should be logged to file for NOTSET")
        logger.close()

        call(['sed', '-i', '-e', 's/[0-9]//g', "-e", 's/\s\s*/:/g',
             file_logger])

        self.assertEqual(filecmp.cmp(file_logger, verf_logger), True)
        TestLogger.rm_silent(file_logger)

    def test_log_warning(self):
        """ Testing the warning logging call """

        file_logger = "Test_WARNING.log"
        verf_logger = "verify/Test_WARNING.verify"

        TestLogger.rm_silent(file_logger)

        logger = lg.Logger("Test Logger", file_logger)
        logger.setLevel(lg.CRITICAL)
        self.assertEqual(logger.getEffectiveLevel(), lg.CRITICAL)
        logger.warning("This should not be logged to file for CRITICAL")

        logger.setLevel(lg.ERROR)
        self.assertEqual(logger.getEffectiveLevel(), lg.ERROR)
        logger.warning("This should not be logged to file for ERROR")

        logger.setLevel(lg.WARNING)
        self.assertEqual(logger.getEffectiveLevel(), lg.WARNING)
        logger.warning("This should be logged to file for WARNING")

        logger.setLevel(lg.INFO)
        self.assertEqual(logger.getEffectiveLevel(), lg.INFO)
        logger.warning("This should be logged to file for INFO")

        logger.setLevel(lg.DEBUG)
        self.assertEqual(logger.getEffectiveLevel(), lg.DEBUG)
        logger.warning("This should be logged to file for DEBUG")

        logger.setLevel(lg.NOTSET)
        self.assertEqual(logger.getEffectiveLevel(), lg.NOTSET)
        logger.warning("This should be logged to file for NOTSET")
        logger.close()

        call(['sed', '-i', '-e', 's/[0-9]//g', "-e", 's/\s\s*/:/g',
             file_logger])

        self.assertEqual(filecmp.cmp(file_logger, verf_logger), True)
        TestLogger.rm_silent(file_logger)

    def test_log_error(self):
        """ Testing the error logging call """

        file_logger = "Test_ERROR.log"
        verf_logger = "verify/Test_ERROR.verify"

        TestLogger.rm_silent(file_logger)

        logger = lg.Logger("Test Logger", file_logger)
        logger.setLevel(lg.CRITICAL)
        self.assertEqual(logger.getEffectiveLevel(), lg.CRITICAL)
        logger.error("This should not be logged to file for CRITICAL")

        logger.setLevel(lg.ERROR)
        self.assertEqual(logger.getEffectiveLevel(), lg.ERROR)
        logger.error("This should be logged to file for ERROR")

        logger.setLevel(lg.WARNING)
        self.assertEqual(logger.getEffectiveLevel(), lg.WARNING)
        logger.error("This should be logged to file for WARNING")

        logger.setLevel(lg.INFO)
        self.assertEqual(logger.getEffectiveLevel(), lg.INFO)
        logger.error("This should be logged to file for INFO")

        logger.setLevel(lg.DEBUG)
        self.assertEqual(logger.getEffectiveLevel(), lg.DEBUG)
        logger.error("This should be logged to file for DEBUG")

        logger.setLevel(lg.NOTSET)
        self.assertEqual(logger.getEffectiveLevel(), lg.NOTSET)
        logger.error("This should be logged to file for NOTSET")
        logger.close()

        call(['sed', '-i', '-e', 's/[0-9]//g', "-e", 's/\s\s*/:/g',
             file_logger])

        self.assertEqual(filecmp.cmp(file_logger, verf_logger), True)
        TestLogger.rm_silent(file_logger)

    def test_log_critical(self):
        """ Testing the critical logging call """

        file_logger = "Test_CRITICAL.log"
        verf_logger = "verify/Test_CRITICAL.verify"

        TestLogger.rm_silent(file_logger)

        logger = lg.Logger("Test Logger", file_logger)
        logger.setLevel(lg.CRITICAL)
        self.assertEqual(logger.getEffectiveLevel(), lg.CRITICAL)
        logger.critical("This should be logged to file for CRITICAL")

        logger.setLevel(lg.ERROR)
        self.assertEqual(logger.getEffectiveLevel(), lg.ERROR)
        logger.critical("This should be logged to file for ERROR")

        logger.setLevel(lg.WARNING)
        self.assertEqual(logger.getEffectiveLevel(), lg.WARNING)
        logger.critical("This should be logged to file for WARNING")

        logger.setLevel(lg.INFO)
        self.assertEqual(logger.getEffectiveLevel(), lg.INFO)
        logger.critical("This should be logged to file for INFO")

        logger.setLevel(lg.DEBUG)
        self.assertEqual(logger.getEffectiveLevel(), lg.DEBUG)
        logger.critical("This should be logged to file for DEBUG")

        logger.setLevel(lg.NOTSET)
        self.assertEqual(logger.getEffectiveLevel(), lg.NOTSET)
        logger.critical("This should be logged to file for NOTSET")
        logger.close()

        call(['sed', '-i', '-e', 's/[0-9]//g', "-e", 's/\s\s*/:/g',
             file_logger])
        self.assertEqual(filecmp.cmp(file_logger, verf_logger), True)
        TestLogger.rm_silent(file_logger)

    def test_logger_instances(self):
        """ Testing to ensure all logging instances are save correctly
            and removed when a log has been closed.
        """

        loggers = list(("Log0", "Log1", "Log2", "Log3", "Log4", "Log5"))
        logger_obj = list()

        # Create the main logger to use for the default
        mainlogger = lg.Logger("Main")
        self.assertEqual(lg.Logger.default_instance, mainlogger)
        loggercount = 1

        # Create all of the loggers (verify the instance count)
        for log in loggers:
            logger = lg.Logger(log)
            logger_obj.append(logger)
            loggercount += 1
            self.assertEqual(len(lg.Logger.instances), loggercount, log)

        # Retrieve the instance from the dictionary and compare to the locally
        # save loggers
        for i in range(len(loggers)):
            logger = lg.Logger.get_default_logger(loggers[i])
            isequal = (logger == logger_obj[i])
            self.assertEqual(isequal, True)
            self.assertNotEqual(logger == mainlogger, True)
            logger.close()

        # Again retrieve the loggers by name, this time it will retrieve
        # the default logger since the loggers have been closed
        for log in loggers:
            logger = lg.Logger.get_default_logger(log)
            isequal = (logger == mainlogger)
            self.assertEqual(isequal, True)
        mainlogger.close()

        # Ensure there is no default instance and there are no saved instances
        self.assertEqual(lg.Logger.default_instance, None)
        self.assertEqual(len(lg.Logger.instances), 0)

if __name__ == '__main__':
    unittest.main()
