#!/usr/bin/env python3
""" Band specifications module
"""
import numpy as np
import os
import imp

# FIXME - This file does not belong in the IAS library.  It is specific to
# a few IAS specific toolkit applications.  The functionality here is only
# useful to those applications.  So, move it there at some point.
class BandSpecs():

    # Band Specs data file
    __bs_filename = "landsat{0}_band_specs.data"

    def __init__(self, satellite_id):
        self.band_specs = list()

        # Read in the band specification data file
        filename = os.path.join(os.path.dirname(__file__),
                                BandSpecs.__bs_filename.format(satellite_id))
        with open(filename) as f:
            lines = f.readlines()

        # Loop over all lines in the file
        for line in lines:
            line = line.strip()
            attr = line.split()
            self.band_specs.append(_BandSpecification(*attr))


class _BandSpecification():
    """ Per Band Attributes Class """

    def __init__(self, band_number, band_color, center_wavelength,
                 center_wavelength_tol, lower_edge, upper_edge, le_slope_c1,
                 le_slope_c2, ue_slope_c1, ue_slope_c2, ltypical, lhigh, lmax,
                 snr_ltyp, snr_lhigh):
        """ Default Constructor """

        self.band_number = int(band_number)
        self.band_color = str(band_color)
        self.center_wavelength = int(center_wavelength)
        self.center_wavelength_tolerance = int(center_wavelength_tol)
        self.lower_edge = int(lower_edge)
        self.upper_edge = int(upper_edge)
        self.lower_edge_slope_c1 = int(le_slope_c1)
        self.lower_edge_slope_c2 = int(le_slope_c2)
        self.upper_edge_slope_c1 = int(ue_slope_c1)
        self.upper_edge_slope_c2 = int(ue_slope_c2)
        self.ltypical = float(ltypical)
        self.lhigh = float(lhigh)
        self.lmax = float(lmax)
        self.snr_at_ltyp = float(snr_ltyp)
        self.snr_at_lhigh = float(snr_lhigh)

    def __str__(self):
        """ String method for convert attributes to a readable string """
        return "\t" + str(self.__dict__) + "\n"
