#!/usr/bin/env python3
import unittest
import imp
import pprint
import sys
import json
import filecmp
import odl

class TestBandSpecs(unittest.TestCase):

    def test_boolify(self):
        self.assertEqual(True, odl._boolify("True"))
        self.assertEqual(False, odl._boolify("False"))
        with self.assertRaises(ValueError):
            odl._boolify("Fail")
        with self.assertRaises(ValueError):
            odl._boolify("Tru")
        with self.assertRaises(ValueError):
            odl._boolify("1")
        with self.assertRaises(ValueError):
            odl._boolify("Fasle")

    def test_autoconvert(self):
        strings = list((
            ("List", "N/a"), "Testing.", "3.4", "5", "True", "False",
            "3.45556.", 554, "554", "\"554\"", "\"StringInString\"",
            {"s": 1}, "{\"s\": 1}", "false", "true", 5.333
            ))
        converted = list((
            ("List", "N/a"), "Testing.", 3.4, 5, True, False,
            "3.45556.", 554, 554, "554", "StringInString",
            {"s": 1}, "{s: 1}", False, True, 5.333
            ))

        for i in range(len(strings)):
            ret = odl._autoconvert(strings[i])
            self.assertEqual(ret, converted[i])


    def test_parser(self):
        try:
            os.remove("odl.out")
        except Exception:
            pass

        f = open("odl.out", "w")
        odlparser = odl.ODLParser()
        odlparser.read_odl("L8CPF20130101_20130331.20")
        old_stdout = sys.stdout
        sys.stdout = f
        print(json.dumps(odlparser.contents, sort_keys=True, indent=4))
        sys.stdout = old_stdout
        f.close()

        # Verify the get_groups method
        groups = odlparser.get_groups()
        self.assertEqual(len(groups), 5)
        self.assertIn("FILE_ATTRIBUTES", groups)
        self.assertIn("TIRS_DETECTOR_RESPONSE", groups)
        self.assertIn("OLI_PARAMETERS", groups)
        self.assertIn("TIRS_PARAMETERS", groups)
        self.assertIn("ATEST", groups)

        # Verify the get_parameter_names method
        parameters = odlparser.get_parameter_names("OLI_PARAMETERS")
        self.assertEqual(len(parameters), 17)

        # Verify the group retrieval
        value = odlparser.get_parameter_value("OLI_PARAMETERS", "SCA_Count")
        self.assertEqual(value, 14)
        # Parameter that doesn't exist
        value = odlparser.get_parameter_value("OLI_PARAMETERS", "No_Parm")
        self.assertEqual(value, None)

        # Compare the ODL files
        self.assertEqual(filecmp.cmp("odl.out", "verify/odl.verify"), True)

        with self.assertRaises(Exception):
            odlparser.read_odl("L8CPF20130101_20130331.20.bad")


if __name__ == '__main__':
    unittest.main()
