/**********************************************************************
 NAME:                ias_rps_calculate_radiance

 PURPOSE:    Calculates per-detector radiance given a set of DN values,
             an absolute gain, and a set of relative gains

 RETURNS:    None

 NOTES:      Assumes input data buffer covers all detectors in a band.
             The input pointer represents the first detector in the current
             SCA.

             The calling routine is responsible for checking whether
             the pointer parameters are valid.
***********************************************************************/
#include "ias_logging.h"
#include "ias_radiometry.h"


void ias_rps_calculate_radiance
(
    const double *data_buffer,     /* I: Input data buffer */
    int num_detectors_per_sca,     /* I: Number of detectors in an SCA */
    double abs_gain,               /* I: Absolute band gain */
    const double *relative_gains,  /* I: Relative gain data buffer */
    double *radiance_buffer        /* O: Band-wide detector radiance data
                                      buffer starting with the first
                                      detector representing the current SCA */
)
{
    double *rad_ptr = NULL;
    double detector_gain;
    int detector_index;


    /* Calculate the radiance for each detector */
    rad_ptr = radiance_buffer;
    for (detector_index = 0; detector_index < num_detectors_per_sca;
         detector_index++)
    {
        detector_gain = abs_gain * relative_gains[detector_index];
        *rad_ptr = data_buffer[detector_index] / detector_gain;
        rad_ptr++;
    }
}
