#ifndef IAS_RPS_DB_BIAS_MODEL_CALIBRATION_H
#define IAS_RPS_DB_BIAS_MODEL_CALIBRATION_H
#include "ias_bpf.h"
#include "ias_cpf.h"

typedef struct ias_bmc_workorders
{
    char **workorder_ids; /*RWOC IDs for collections*/
    char *workorder_buffer; /*Buffer for the RWOC ID strings*/
    int workorder_count; /*Number of workorders loaded*/
}IAS_BMC_WORKORDERS;

/* Other than the band_number, these arrays are set up to allow the pan band
   to have odd and even values.  For non-pan band index 1 is not set nor
   allocated. */
typedef struct ias_rps_db_band_residual
{
    int band_number;
    int lineset[2];
    double *r_squared_a0[2];  /* Sized as number SCAs */
    double **r_squared_a1[2]; /* Sized as number SCAs x number detectors */
} IAS_RPS_DB_BAND_RESIDUAL;

/* Residuals structure should be allocated and freed using the
       ias_rps_bias_residuals_allocate and ias_rps_bias_residuals_free
   routines.  The band residuals are stored in the array by band index */
typedef struct ias_rps_db_bias_model_residuals
{
    char radiometric_wo_common_id[20];
    IAS_RPS_DB_BAND_RESIDUAL band_residuals[IAS_MAX_NBANDS];
} IAS_RPS_DB_BIAS_MODEL_RESIDUALS;

int ias_rps_db_bmc_insert_bpf(
    struct ias_db_connection *database,
    const char *post_workorder,
    const char *pre_workorder,
    IAS_BPF *bpf);

int ias_rps_db_bmc_populate_start_stop(
    struct ias_db_connection *database,
    const char *post_workorder,
    const char *pre_workorder,
    IAS_BPF *bpf);

IAS_BMC_WORKORDERS* ias_rps_db_get_bias_model_previous_workorders(
    IAS_CPF *cpf,
    struct ias_db_connection *db_connection,
    const char *post_collection_work_order,
    const int previous_collections_requested);

IAS_BMC_WORKORDERS* ias_rps_db_get_bias_model_previous_workorders_tirs(
    IAS_CPF *cpf,
    struct ias_db_connection *db_connection,
    const char *post_collection_work_order,
    const int previous_collections_requested);

void ias_rps_db_free_bias_model_workorders(IAS_BMC_WORKORDERS **workorders);

int ias_rps_db_get_bias_model_effective_dates(
    struct ias_db_connection *dbase,
    const char* pre_workorder_id,
    const char* post_workorder_id,
    char start_date[],
    char end_date[]);

int ias_rps_db_get_bias_model_orbit(
    struct ias_db_connection *dbase,
    const char interval_id[],
    int *orbit);

int ias_rps_db_get_bias_model_residual_a0(
    struct ias_db_connection *dbase,
    const char *work_order_id,
    const int band_number,
    const int sca_number,
    const int lineset,
    double *r_squared);

int ias_rps_db_get_bias_model_residual_a1(
    struct ias_db_connection *dbase,
    const char *work_order_id,
    const IAS_BAND_ATTRIBUTES *band_attributes,
    int sca_number,
    int lineset,
    double* residuals_squared);

int ias_rps_db_set_bias_model_residual_a0(
    struct ias_db_connection *dbase,
    const double r_squared,
    const char *work_order_id,
    const int band_number,
    const int sca_number,
    const int lineset);

int ias_rps_db_set_bias_model_residual_a1(
    struct ias_db_connection *dbase,
    double* residuals_squared,
    const char *work_order_id,
    const IAS_BAND_ATTRIBUTES *band_attributes,
    int sca_number,
    int lineset);

int ias_rps_db_create_oli_bias_model_where_clause
(
    char       *where_clause_string,          /* O: Populated common part
                                                 of the total 'where'
                                                 clause */
    int        sizeof_where_clause_string,    /* I: Total size of the common
                                                 'where' clause (including
                                                 NULL terminator) */
    const char *source_table_name,            /* I: Name of source table */
    double     integration_time_oli_ms,       /* I: OLI MS band integration
                                                 time */
    double     integration_time_oli_pan       /* I: OLI PAN band integration
                                                 time */
);

int ias_rps_db_create_tirs_bias_model_where_clause
(
    char       *where_clause_string,          /* O: Populated common part
                                                 of the total 'where'
                                                 clause */
    int        sizeof_where_clause_string,    /* I: Total size of the common
                                                 'where' clause (including
                                                 NULL terminator) */
    const char *source_table_name             /* I: Name of source table */


);

IAS_RPS_DB_BIAS_MODEL_RESIDUALS *ias_rps_bias_residuals_allocate(void);

int ias_rps_bias_residuals_free(
    IAS_RPS_DB_BIAS_MODEL_RESIDUALS *residuals);
#endif
