/**************************************************************************
 NAME:      ias_rps_frame_averages.h

 PURPOSE:   Declaration of the ias_rps_frame_averages routines.

 ROUTINES:  ias_rps_calculate_frame_averages
            ias_rps_db_allocate_frame_averages
            ias_rps_db_free_frame_averages
            ias_rps_db_store_frame_averages

****************************************************************************/
#ifndef IAS_RPS_FRAME_AVERAGES_H
#define IAS_RPS_FRAME_AVERAGES_H

#include "ias_const.h"
#include "ias_pixel_mask.h"
#include "ias_types.h"

/* Structure used to store the results of the frame average computation */
typedef struct ias_rps_db_frame_averages
{
    struct ias_db_connection *dbase;
    char rad_common_id[IAS_CHAR_ID_SIZE];  

    int band_number;  /* Band number, 1-based */
    int sca;          /* SCA number, 1-based */
    int num_lines; 
    int *line_number;  
    double *line_average;
}IAS_RPS_DB_FRAME_AVERAGES;

int ias_rps_calculate_frame_averages(
    const void *input_buffer,      /* I: One SCA of data */
    const IAS_DATA_TYPE data_type, /* I: Data type may be float or uint16_t */
    const int band_number,         /* I: Band number, 1-based */
    const int sca_number,          /* I: SCA number, 1-based */
    const int num_detectors,       /* I: Number of detectors in the SCA */
    const int starting_line_number,/* I: Number of the first line, 1 based */
    const int num_lines,           /* I: Number of lines in the data */
    const int frames_to_skip_top,  /* I: Number of frames to skip at the 
                                       top (beginning) of image */
    const int frames_to_skip_bottom,  /* I: Number of frames to skip at the 
                                       bottom (end) of image */
    IAS_PIXEL_MASK *pixel_mask, /* I: Contains pixel artifacts */

    /* I/O: Pointer to results of the calculation. Allocate structure using: 
       ias_rps_db_allocate_frame_averages */
    IAS_RPS_DB_FRAME_AVERAGES *averages
);

IAS_RPS_DB_FRAME_AVERAGES *ias_rps_db_allocate_frame_averages
(
    const int number_of_lines /* I: Number of array elements to allocate */
);

void ias_rps_db_free_frame_averages
(
    IAS_RPS_DB_FRAME_AVERAGES **db_results /*I: address of the pointer to free*/
);

int ias_rps_db_store_frame_averages
(
    void *message /* I: Pointer to IAS_RPS_DB_FRAME_AVERAGES
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

IAS_RPS_DB_FRAME_AVERAGES* ias_rps_db_get_frame_averages
(
    struct ias_db_connection *dbase, /*I: database connection */
    const char *rad_common_id, /*I: common work order ID */
    const int band_number,  /*I: Band number, 1-based */
    const int sca          /*I: SCA number, 1-based */
);
#endif
