/*------------------------------------------------------------------------
NAME:    ias_rps_get_report_file_name

PURPOSE: Returns the ias report output file name which is dependent on
         band and SCA number. If a -1 is given for the band, then neither
         the band or SCA is appended and if a -1 is given for the SCA, then
         the SCA is not appended. The user is responsible for freeing the
         memory allocated here.

RETURNS: IAS report output file name
         NULL if there's an allocation error
------------------------------------------------------------------------*/
#include <stdlib.h>
#include <string.h>
#include "ias_radiometry.h"

char *ias_rps_get_report_file_name
(
    const IAS_REPORT *report_info,  /* I: Report info structure pointer */ 
    int band_number,                /* I: Band number */
    int sca_number,                 /* I: SCA number */
    const char *file_base_name      /* I: Base file name */
)
{
    char dot[] = "."; 
    char *file_name;
    char *directory;
    int length;

    /* See if a subdirectory was specified and get its size.  If not point
       to the current directory.  */
    if ( report_info->directory )
    {
        length = strlen( report_info->directory ) + 1; /* Add one for slash */
        directory = report_info->directory;
    }
    else
    {
        length = 2; /* Length of dot plus slash */
        directory = dot;
    }

    /* Build the report file name.  Add one to the length for the NULL
       terminator and 10 for the band, SCA and file extension: '_BB_SS.rpt' */
    length += strlen( file_base_name ) + 1 + 10;
    file_name = malloc( sizeof(char) * length );
    if ( file_name )
    {
        /* Do not include the band or SCA if -1 is detected */
        if ( band_number == -1 )
        {
            sprintf( file_name, "%s/%s.rpt", directory, file_base_name );
        }
        else if ( sca_number == -1 )
        {
            sprintf( file_name, "%s/%s_%02d.rpt", directory,
                file_base_name, band_number );
        }
        else
        {
            sprintf( file_name, "%s/%s_%02d_%02d.rpt", directory,
                file_base_name, band_number, sca_number );
        }
    }

    /* Return the allocated pointer (if it was successfully allocated),
       or return NULL if it wasn't.  It will be the responsibility of
       the calling routine to check whether this pointer is valid before
       using it */
    return file_name;
}
