#ifndef IAS_RPS_IDENTIFY_DIFFUSER_PANEL_H
#define IAS_RPS_IDENTIFY_DIFFUSER_PANEL_H


/* Defines used in identification of the diffuser panel deployed for OLI
   solar collects.  These are the expected 'stops' for the diffuser panel
   stepper motor for each panel.  Based on current information supplied
   in the OLI command and telemetry handbook (May 2011 revision) */
#define IAS_RPS_OLI_DIFFUSER_POSITION_WORKING_LOW      8741
#define IAS_RPS_OLI_DIFFUSER_POSITION_WORKING_HIGH     8763
#define IAS_RPS_OLI_DIFFUSER_POSITION_PRISTINE_LOW     3682
#define IAS_RPS_OLI_DIFFUSER_POSITION_PRISTINE_HIGH    3704


int ias_rps_identify_diffuser_panel
(
    const char   *l0r_filename,            /* I: Name of L0R data file */
    const struct IAS_CPF_EARTH_CONSTANTS *earth_constants,
                                           /* I: CPF Earth constants data */
    IAS_DATETIME  starting_date,           /* I: Starting date/time
                                              components */
    uint16_t *diffuser_resolver_position,  /* O: Diffuser position telemetry
                                              value (optional-- pass in
                                              NULL if it isn't needed) */
    int *panel_type                        /* O: Enumerated value
                                              representing the
                                              deployed panel (possible
                                              values are
                                           IAS_RPS_OLI_DIFFUSER_TYPE_PRISTINE
                                              and
                                           IAS_RPS_OLI_DIFFUSER_TYPE_WORKING)
                                           */
);

#endif
