#ifndef IAS_RPS_IMPULSE_NOISE_CHARACTERIZATION_H
#define IAS_RPS_IMPULSE_NOISE_CHARACTERIZATION_H

/* This structure is used to pass parameters to the database storage routine
   ias_rps_store_impulse_noise_in_database. */
typedef struct ias_rps_db_impulse_noise_char_results
{
    struct ias_db_connection *dbase;
    char rad_common_id[IAS_CHAR_ID_SIZE];  
    int band;
    int sca;
    int num_detectors;
    int *in_counts;    /* Per-detector inpulse noise counts */
} IAS_RPS_DB_IMPULSE_NOISE_CHAR_RESULTS;

int ias_rps_impulse_noise_characterization
(
    const uint16_t *l0r_data,    /* I: One SCA of level 0 data in DN */
    int band,                    /* I: Band number, 1-based */
    int sca,                     /* I: SCA number, 1-based */
    int num_detectors,           /* I: Number of detectors in the SCA */
    int num_lines,               /* I: Number of lines in the data */
    int median_filter_width,     /* I: Filter width from CPF */
    const double *detector_noise,/* I: Per detector noise from CPF */
    int impulse_noise_limit,     /* I: Limit of minimum detectable impulse
                                       noise */
    IAS_PIXEL_MASK *pixel_mask,  /* I: Contains dead detector and dropped
                                       frame locations
                                    O: Impulse noise locations */
    const IAS_REPORT *report_info,/* I: General information for the test
                                       report.  If no report is desired pass
                                       NULL. */
    IAS_RPS_DB_IMPULSE_NOISE_CHAR_RESULTS *db_results
                                 /* I/O: General information on the database
                                         connection.  If database output is
                                         not desired pass NULL. */
);

int ias_rps_store_impulse_noise_counts_in_database
(
    void *message   /* I: Pointer to the
                               IAS_RPS_DB_IMPULSE_NOISE_CHAR_RESULTS
                           structure defined in
                               ias_rps_db_allocate_impulse_noise_results
                           A void pointer is used since it is called from the
                           threading routines and a void pointer is used to
                           support passing messages to different routines */
);

IAS_RPS_DB_IMPULSE_NOISE_CHAR_RESULTS *ias_rps_db_allocate_impulse_noise_results
(
    int number_of_detectors /* I: Number of detector array elements to
                                  allocate */
);

void ias_rps_db_free_impulse_noise_results
(
    IAS_RPS_DB_IMPULSE_NOISE_CHAR_RESULTS *db_results
                            /* I - Structure to be freed */
);

#endif
