#ifndef IAS_RPS_SATURATED_PIXEL_CHARACTERIZATION_H
#define IAS_RPS_SATURATED_PIXEL_CHARACTERIZATION_H

typedef struct ias_rps_db_saturated_characterization_results
{
    struct ias_db_connection *dbase;
    char rad_common_id[IAS_CHAR_ID_SIZE];  
    int  band;
    int  sca;
    int  num_detectors;
    int  *detector; /* This is allocated for the number of detectors in the
                       SCA.  Since the resulting datastructure is expected
                       to be sparce, the database store routine will squeeze
                       the zero count values out.  This member is for
                       keeping track of the detector number for the
                       remaining data. */
    int  *counts_digital_high; /* Per-detector saturation count */
    int  *counts_digital_low;  /* Per-detector saturation count */
    int  *counts_analog_high;  /* Per-detector saturation count */
    int  *counts_analog_low;   /* Per-detector saturation count */
} IAS_RPS_DB_SATURATED_CHARACTERIZATION_RESULTS;

int ias_rps_saturated_pixel_characterization
(
    const uint16_t *l0r_data,   /* I: One SCA of level 0 data in DN */
    int band,                   /* I: Band number, 1-based */
    int sca,                    /* I: SCA number, 1-based */
    int num_detectors,          /* I: Number of detectors in the SCA */
    int num_lines,              /* I: Number of lines in the data */
    const int *digital_low_saturated, /* I: Digital low saturated level */
    const int *digital_high_saturated,/* I: Digital high saturated level */
    const int *analog_low_saturated,  /* I: Analog low saturated level */
    const int *analog_high_saturated, /* I: Analog high saturated level */
    IAS_PIXEL_MASK *pixel_mask, /* I: Contains dead detector and dropped
                                       frame locations
                                   O: Impulse noise locations */
    const IAS_REPORT *report_info,  /* I: General information for the test
                                       report.  If no report is desired pass
                                       NULL. */
    IAS_RPS_DB_SATURATED_CHARACTERIZATION_RESULTS *db_results
                                /* I/O: Pointer to results of the 
                                       characterization.      */
);

IAS_RPS_DB_SATURATED_CHARACTERIZATION_RESULTS 
    *ias_rps_db_allocate_saturated_results
(
    int number_of_detectors /* I: Number of array elements to allocate */
);

int ias_rps_store_saturated_pixels_in_database
(
    void *message /* I: Pointer to IAS_RPS_DB_HISTOGRAM_CHARACTERIZATION_RESULTS
                         structure.  A void pointer is used since it is
                         called from the threading routines and a void
                         pointer is used to support passing messages to
                         different routines */
);

void ias_rps_db_free_saturated_results
(
    IAS_RPS_DB_SATURATED_CHARACTERIZATION_RESULTS *db_results /* I: structure
                                                                 to free */
);

#endif
