/**************************************************************************
 NAME:       bias_model_functional_tests

 PURPOSE:    Module implementing CGreen unit tests for various
             functions/routines related to bias model calibration

 ROUTINES:   test_ias_rps_create_bmc_common_where_clause
***************************************************************************/
#include <stdio.h>
#include <string.h>

#include "cgreen.h"

#include "ias_radiometry.h"
#include "../ias_rps_db_bias_model_calibration.h"

Ensure test_create_where_clauses()
{
    char test_where_clause_string[384];
    char expected_where_clause_string[384];
    char table_source[30];
    double oli_integration_time_ms = 3.600;
    double oli_integration_time_pan = 0.660;
    int status;


    printf("Checking creation of OLI and TIRS bias model query "
        "'where' clause substrings...\n");

    /* For the first two tests, set the table source as the bias frame
       averages table.  */
    sprintf(table_source, "bias_frame_averages");

    /* Populate the expected where clause assuming we're dealing with OLI. */
    status = snprintf(expected_where_clause_string,
        sizeof(expected_where_clause_string),
        "COLLECTION_TYPE='%s' AND VALID='Y' "
        "AND INTEGRATION_TIME_OLI_MS=%lf "
        "AND INTEGRATION_TIME_OLI_PAN=%lf "
        "AND RADIOMETRIC_WO_COMMON_ID IN "
        "  (SELECT DISTINCT RADIOMETRIC_WO_COMMON_ID "
        "   FROM %s) ",
        IAS_RPS_OLI_SHUTTER_COLLECT,
        oli_integration_time_ms,
        oli_integration_time_pan,
        table_source);
    if ((status < 0) || (status >= sizeof(expected_where_clause_string)))
    {
        assert_true_with_message(FALSE, "Error constructing expected "
            "OLI 'where' clause string");
        return;
    }

    status = ias_rps_db_create_oli_bias_model_where_clause(
        test_where_clause_string, sizeof(test_where_clause_string),
        table_source, oli_integration_time_ms, oli_integration_time_pan);
    assert_equal_with_message(status, SUCCESS, "Error constructing "
        "'where' clause substring for OLI bias model query");
    assert_string_equal(test_where_clause_string,
        expected_where_clause_string);

    /* Now assume we're dealing with TIRS.  */
    status = snprintf(expected_where_clause_string,
        sizeof(expected_where_clause_string),
        "COLLECTION_TYPE='%s' AND VALID='Y' "
        "AND RADIOMETRIC_WO_COMMON_ID IN "
        "  (SELECT DISTINCT RADIOMETRIC_WO_COMMON_ID "
        "   FROM %s) ",
        IAS_RPS_TIRS_DEEPSPACE_COLLECT,
        table_source);
    if ((status < 0) || (status >= sizeof(expected_where_clause_string)))
    {
        assert_true_with_message(FALSE, "Error constructing expected "
            "TIRS 'where' clause string");
        return;
    }

    status = ias_rps_db_create_tirs_bias_model_where_clause(
        test_where_clause_string, sizeof(test_where_clause_string),
        table_source);
    assert_equal_with_message(status, SUCCESS, "Error constructing 'common' "
        "where clause substring");
    assert_string_equal(test_where_clause_string,
        expected_where_clause_string);
}


int main(int argc, char *argv[])
{
    /* Construct the test suite */
    TestSuite *suite = create_test_suite();

    /* Add the test to the suite */
    add_test(suite, test_create_where_clauses);

    /* Run the test.  Right now, there's only one functional unit
       test implemented.  If/when other tests are implemented, change the
       logic to allow for the possibility of running an individual test or
       the entire suite. */
    return run_test_suite(suite, create_text_reporter());
}
