#include <stdio.h>
#include <stdlib.h>
#include "ias_pixel_mask.h"
#include "ias_radiometry.h"
#include "cgreen.h"


Ensure test_get_invalid_data_flags()
{
    IAS_PIXEL_MASK *pm = NULL;
    PIXEL_MASK_TYPE artifacts_to_flag =
        IAS_RPS_INOP_DETECTOR | IAS_RPS_OUTOFSPEC_DETECTOR;
    int outofspec_detectors[4] = {10, 160, 310, 460};
    int inoperable_detectors[3] = {5, 155, 305};
    int detector_index;
    int number_of_inoperable_detectors = 3;
    int number_of_outofspec_detectors = 4;
    int flagged_detectors = number_of_inoperable_detectors +
        number_of_outofspec_detectors;
    int test_inop_detector_count = 0;
    int flag_buffer_diffs = 0;
    int status;
    int band_number = 1;
    int sca_number = 1;
    int number_of_detectors = 494;
    int number_of_frames = 500;
    int *test_flag_buffer = NULL;
    int *expected_flag_buffer = NULL;

    /* Create the pixel mask */
    pm = ias_pm_create(band_number, sca_number, number_of_detectors,
        number_of_frames);
    if (pm == NULL)
    {
        assert_true_with_message(FALSE, "Error creating test pixel mas");
        return;
    }

    /* Allocate the expected and test flag buffers */
    test_flag_buffer = malloc(number_of_detectors * sizeof(int));
    expected_flag_buffer = calloc(number_of_detectors, sizeof(int));
    if ((test_flag_buffer == NULL) || (expected_flag_buffer == NULL))
    {
        assert_true_with_message(FALSE, "Error allocating flag data buffers");
        free(test_flag_buffer);
        free(expected_flag_buffer);
        ias_pm_destroy(pm);
        return;
    }

    /* Populate the expected flag buffer */
    expected_flag_buffer[4] = 1;
    expected_flag_buffer[9] = 1;
    expected_flag_buffer[154] = 1;
    expected_flag_buffer[159] = 1;
    expected_flag_buffer[304] = 1;
    expected_flag_buffer[309] = 1;
    expected_flag_buffer[459] = 1;

    /* Identify the inoperable detectors */
    status = ias_rps_inoperable_detector_identification(inoperable_detectors,
        number_of_inoperable_detectors, band_number, sca_number,
        number_of_detectors, number_of_frames, pm);
    assert_equal_with_message(status, SUCCESS, "Error adding "
        "inoperable detector information to mask in band 1 SCA 1");
    if (status != SUCCESS)
    {
        free(test_flag_buffer);
        free(expected_flag_buffer);
        ias_pm_destroy(pm);
        return;
    }

    /* Identify the out-of-spec detectors */
    status = ias_rps_outofspec_detector_identification(outofspec_detectors,
        number_of_outofspec_detectors, band_number, sca_number,
        number_of_detectors, number_of_frames, pm);
    assert_equal_with_message(status, SUCCESS, "Error adding "
        "out-of-spec detector information to mask in band 1 SCA 1");
    if (status != SUCCESS)
    {
        free(test_flag_buffer);
        free(expected_flag_buffer);
        ias_pm_destroy(pm);
        return;
    }

    /* Populate the test flag data buffer */
   status = ias_rps_get_invalid_data_flags(pm, artifacts_to_flag,
       number_of_detectors, test_flag_buffer);
    assert_equal_with_message(status, SUCCESS, "Error populating test "
        "detector flag data buffer");
    ias_pm_destroy(pm);
    if (status != SUCCESS)
    {
        free(test_flag_buffer);
        free(expected_flag_buffer);
        return;
    }

    /* Now compare the test flag data buffer to the expected buffer.
       Check the flag values for each detector AND the flagged detector
       counts */
    for (detector_index = 0; detector_index < number_of_detectors;
         detector_index++)
    {
        if (test_flag_buffer[detector_index] == 1)
            test_inop_detector_count++;

        if ((test_flag_buffer[detector_index]
            - expected_flag_buffer[detector_index]) != 0)
        {
            flag_buffer_diffs++;
        }
    }
    assert_equal_with_message(test_inop_detector_count,
        flagged_detectors, "%d detectors flagged as invalid; "
        "%d should be flagged", test_inop_detector_count,
        flagged_detectors);

    assert_equal_with_message(flag_buffer_diffs, 0, "%d differences found "
        "between test flag buffer and expected flag buffer",
        flag_buffer_diffs);

    /* Clean up */
    free(expected_flag_buffer);
    free(test_flag_buffer);
}


int main(int argc, char *argv[])
{
    /* Define the test suite */
    TestSuite *suite = create_test_suite();
    add_test(suite, test_get_invalid_data_flags);

    /* Run the tests */
    if (argc > 1)
    {
        return run_single_test(suite, argv[1], create_text_reporter());
    }
    else
    {
        return run_test_suite(suite, create_text_reporter());
    }
}
