#!/usr/bin/perl

# Use a plain LWP::UserAgent to post an XML request to the CPS services
# to get the names of available CPF, BPF, and RLUT files.
use LWP::UserAgent;
use HTTP::Request;
use HTTP::Request::Common;

my $userAgent = LWP::UserAgent->new();

# ----------------- CPFs -------------------------------------------------------
my $message = qq{<soapenv:Envelope 
  xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" 
  xmlns:cpf="uri:CpfQueryService">
   <soapenv:Header/>
   <soapenv:Body>
      <cpf:getAllCpfNames>
        <getAllCpfRequest>
           <source>PROD</source>
        </getAllCpfRequest>
      </cpf:getAllCpfNames>
   </soapenv:Body>
</soapenv:Envelope>};

my $endpoint = "$ENV{IAS_SERVICES}/dataservices/CpfService";
my $request = HTTP::Request->new(POST => $endpoint);
$request->header(SOAPAction => 
    '"uri:CpfQueryService/getAllCpfNames"');
$request->content($message);
$request->content_type("text/xml; charset=utf-8");
my $response = $userAgent->request($request);

if($response->code == 200) {
    #print $response->as_string;
    print "CPFs\n";
    print_files($response->as_string);
}
else {
    print $response->error_as_HTML;
    die "Error getting CPF list";
}

# ----------------- BPFs -------------------------------------------------------
my $message = qq{<soapenv:Envelope 
  xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" 
  xmlns:bpf="uri:BpfQueryService">
   <soapenv:Header/>
   <soapenv:Body>
      <bpf:getAllBpfNames>
        <getAllBpfRequest>
          <source>PROD</source>
        </getAllBpfRequest>
      </bpf:getAllBpfNames>
   </soapenv:Body>
</soapenv:Envelope>};

my $endpoint = "$ENV{IAS_SERVICES}/dataservices/BpfService";
my $request = HTTP::Request->new(POST => $endpoint);
$request->header(SOAPAction => 
    '"uri:BpfQueryService/getAllBpfNames"');
$request->content($message);
$request->content_type("text/xml; charset=utf-8");
my $response = $userAgent->request($request);

if($response->code == 200) {
    #print $response->as_string;
    print "BPFs\n";
    print_files($response->as_string);
}
else {
    print $response->error_as_HTML;
    die "Error getting BPF list";
}

# ----------------- RLUTs ------------------------------------------------------
my $message = qq{<soapenv:Envelope 
  xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" 
  xmlns:rlut="uri:RlutQueryService">
   <soapenv:Header/>
   <soapenv:Body>
      <rlut:getAllRlutNames>
        <getAllRlutRequest>
           <source>PROD</source>
        </getAllRlutRequest>
      </rlut:getAllRlutNames>
   </soapenv:Body>
</soapenv:Envelope>};

my $endpoint = "$ENV{IAS_SERVICES}/dataservices/RlutService";
my $request = HTTP::Request->new(POST => $endpoint);
$request->header(SOAPAction => 
    '"uri:RlutQueryService/getAllRlutNames"');
$request->content($message);
$request->content_type("text/xml; charset=utf-8");
my $response = $userAgent->request($request);

if($response->code == 200) {
    #print $response->as_string;
    print "RLUTs\n";
    print_files($response->as_string);
}
else {
    print $response->error_as_HTML;
    die "Error getting RLUT list";
}

exit 0;


sub print_files() {
    my $response = shift;
    my $fileList;
    $response =~ /<return>(.*)<\/return>/ and do {
        $fileList = $1;
    };
    $response =~ /<bpf>(.*)<\/bpf>/ and do {
        $fileList = $1;
    };
    $fileList =~ s/<filename>/\n<filename>/g;
    $fileList =~ s/<.*?>/\t/g;
    print "$fileList\n\n";
}

exit 0;
