#!/bin/csh -f
#***************************************************************************
# NAME:   update_ssm_pos_quality.csh
#
#  PURPOSE: Updates the quality of a specified SSM Position Quality record 
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./update_ssm_pos_quality.csh quality(0/1/2) Date(YYYY:DDD:SSSSS)
#****************************************************************************
set SUCCESS = 0
set ERROR = 1

if ( -e test_case_id ) then
    set tcnum = `cat test_case_id`
    set log = tc${tcnum}.log
    set woid_file = tc${tcnum}_woids.txt
else
    echo "Error: The test_case_id file is missing"
    exit $SUCCESS
endif

# Must have two arguments
if ( ${#argv} != 2 ) then
    echo "" |& tee -a $log
    echo "    Usage: $0 quality(0/1/2) Date(YYYY:DDD:SSSSS)" |& tee -a $log
    echo "" |& tee -a $log
    exit $ERROR
endif

if ($1 < 0 || $1 > 2) then
    echo "" |& tee -a $log
    echo "    $1 is not a valid quality " |& tee -a $log
    echo "" |& tee -a $log
    exit $ERROR
endif

set quality = $1
set year = `echo $2 | awk -F: '{print $1;}'`
set day_of_year = `echo $2 | awk -F: '{print $2;}'`
set seconds_of_day = `echo $2 | awk -F: '{print $3;}'`

set records = `sqlplus -s ${IAS_DB_L8_OLITIRS}` << END
    set head off; 
    SELECT count(*) FROM tirs_ssm_pos_estimates
    WHERE year = $year and day_of_year = $day_of_year and seconds_of_day = 
    $seconds_of_day;
    exit;
END

if ( $records != 1) then
    echo "" |& tee -a $log
    echo "   Expected 1 record for $2 got $records" |& tee -a $log
    echo "" |& tee -a $log
    exit $ERROR
endif

sqlplus -s ${IAS_DB_L8_OLITIRS} << END
    set head off; 
    UPDATE tirs_ssm_pos_estimates set quality_flag = $quality
    WHERE year = $year and day_of_year = $day_of_year and seconds_of_day = 
    $seconds_of_day;
END
 
exit $SUCCESS
