#!/usr/bin/perl
##############################################################################
# Name: replace_scenes.pl
#
# Description: Replaces the scenes in a tram_mass_loader.pl or 
#   dev_tram_loader.pl with a scene in a new scene file.
#
# Usage:
#   replace_scenes.pl <massloader_file> <new_scene_file> <output_file>
#       <massloader_file> is the current mass loader script input file
#       <new_scene_file> is the file containing the new scene list.  The number
#           of scene must greater than or equal to the number of units in the
#           <massloader_file>.
#       <output_file> the new mass loader script input file. The output file
#           will be identical to the <massloader_file> except the new scenes
#           will replace the old scenes in the unit list. 
##############################################################################

use strict;
use warnings;

use IO::File;

if ($#ARGV != 2)
{
    print "Invalid parameters\n";
    print "Usage: replace_scenes.pl <loaderfile> <newscenefile> <outputfile>\n";
    exit 1;
}

my $currfilename = $ARGV[0];
my $newscenes    = $ARGV[1];
my $outfile      = $ARGV[2];

# load the new scenes
my $newfh = IO::File->new($newscenes, "r");
my @newlist;
while(<$newfh>)
{
    chomp;
    push(@newlist, $_);
}
$newfh->close();

# create the new file
my $outfh = IO::File->new($outfile, "w");
my $currfh = IO::File->new($currfilename, "r");
my $startRewrite = 0;
my $i = 0;
while (<$currfh>)
{
    chomp;
    if ($_ =~ /^\[units\]$/)
    {
        $startRewrite = 1;
        print $outfh "$_\n";
        next;
    }

    if ($startRewrite)
    {
        my @parts = split(/\|/, $_);
        if (not defined $parts[3]) { $parts[3] = ""; }
        print $outfh "$newlist[$i]|$parts[1]|$parts[2]|$parts[3]\n"; 
        $i++; 
    }
    else
    {
        print $outfh "$_\n";
    }
}
$currfh->close();
$outfh->close();

