#!/usr/bin/perl
##############################################################################
# Name: verify_MDS_access.pl
#
# Description: Verifies SELECT permission on the WORK_ORDER_LOG table has been 
#   granted to the MDS user role.
#
# Usage:
#   verify_MDS_access.pl
##############################################################################
use warnings;
use strict;

use db_utils;
use ias_const;

my $error_count = 0;

# Get the work order common database info
my ($username, $password) = db_GetConnectionInfo();

# On the test server, the wo_common_lpgs schema has to be used,
# and on the development server, the normal user name can be used
my $test_server_user = 'ops';
if ($username eq  $test_server_user)
{
    $username = 'wo_common_lpgs';
}

# Connect using the MDS user
my $dbh = db_Connect($username, $password);
if (not defined $dbh)
{
    print "Error: connecting to the database\n";
    exit 1;
}

# Get all of tables with select granted to the MDS role
my $sql = "SELECT table_name "
        . "  FROM user_tab_privs_made "
        . " WHERE grantee = 'WO_COMMON_LPGS_TO_MDS' "
        . "   AND privilege = 'SELECT'";
my $table_list = db_FetchAll($dbh, $sql, "table_name");

# Verify access to the work_order_log table
print "Verifying the MDS user can read the WORK_ORDER_LOG...";
if (defined $table_list->{"WORK_ORDER_LOG"})
{
    print "PASS\n";
}
else
{
    print "FAIL\n";
    print "Error: access to the work_order_log table has not been granted\n";
    $error_count++;
}

db_Disconnect($dbh);

if ($error_count > 0)
{
    print "Verification failed \n";
    exit 1;
}
else
{
    print "Verification passed\n";
    exit 0;
}
