#!/usr/bin/perl
#
# This perl script uses the ../tools/get_inv_data.pm perl module to retrieve a
# Cloud Cover Score for a single scene that is stored in the Inventory tables
# for LPGS.  When running in a development environment you don't have access to
# these tables so fake tables can be prepopulated so that this script can be
# tested.
#
# When running in a development environment you'll need to ensure these
# inventory tables are added by running the command:
#
#	sqlplus $IAS_DB_COM @../tools/build_inventory_tables.sql
#
# Once the tables have been created, they can be populated by running the
# command:
#
#	sqlplus $IAS_DB_COM @loadFakeInventory.sql
#
# Then when querying these tables in the development environment you'll need to
# have the environment variable IAS_DB_COM defined.  The variable's value
# doesn't matter, just that you have it defined.  If the variable isn't defined
# it will attempt to access the real Inventory tables and you'll get an error
# message about connecting to the database with an invalid username and
# password.
#
use warnings;
use strict;

# Add the ../tools directory to the module include path
use lib '../tools';

use get_inv_data;
use ias_const;

if ($#ARGV != 1)
{
    print "Usage: dump_inv_var <scene_id> <parameter>\n";
    exit 1;
}

my $scene_id = $ARGV[0];
my $param    = $ARGV[1];
#print "$scene_id : $param \n";

my $scene_data = {};
my $r = get_data_by_scene_id($scene_id, $scene_data);

if ($r == ERROR)
{
    print "Error returning scene data: \n";
    print "    |-> $get_inv_data::error_message\n";
    exit 1;
}

if (not defined $scene_data->{$param})
{
    print "Error invalid parameter: $param\n";
    exit 1;
}

print "$scene_data->{$param}\n";
