#!/bin/csh
#
# This script will extract all of the scene IDs from the batch1.txt file and
# retrieve the cloud cover score from the Inventory database tables for those
# scenes.  These values can then be verified against the results contained
# within the work order directories and against the expected results.

# Obtain the scene IDs stored in batch1.txt
set sceneIds = `cat batch1.txt | egrep "^L[COT]8" | awk -F\| '{print $1}'`

echo ""
if ($?IAS_DEV_TEST) then
    echo "Accessing fake tables in developer's ${IAS_DB_COM} schema"
else
    echo "Accessing real inventory tables"
endif
echo "----------------------------------------------------------------------"

set nErrors = 0
set dataSet = 0
foreach sceneId ( ${sceneIds} )
    @ dataSet += 1

    # Obtain the CLOUD_COVER_AUTOMATED (e.g. cloud cover score) using the
    # supplied perl scripts
    set score = `./getInventoryCloudScore.pl ${sceneId} CLOUD_COVER`

    # Examine the output from the perl script to see if it contains the word
    # "error"
    set errorStatus = `echo "${score}" | grep -i error | wc -l`

    # Print either an error message or the cloud cover score of the scene
    if (${errorStatus} != 0) then
	echo "    Data set ${dataSet} ${sceneId}: ERROR"
	@ nErrors += 1
    else
	echo "    Data set ${dataSet} ${sceneId}: ${score}"
    endif
end

if (${nErrors} > 0) then
    exit 1
endif
exit 0
