#!/bin/csh
#
# This script accepts an LPGS work order ID and will retrieve the cloud cover
# score and the cloud cover algorithms run on that work order so that the
# results can be compared against the expected results.

# Validate the arguments and the required environment variables

set results = results.txt

if ($#argv < 1) then
    echo "validate.csh <workOrder> [<workOrder>...]"
    echo ""
    echo "This script accepts an LPGS work order ID and will retrieve the cloud"
    echo "cover score and the cloud cover algorithms run on that work order so"
    echo "that the results can be compared against the expected results."
    echo ""
    echo "Once run, this script will leave the output in ${results}"
    echo ""
    exit 1
endif

if (! $?IAS_WO) then
    echo "Environment variable not defined: IAS_WO"
    exit 1
endif

rm -f ${results}
while ($#argv > 0)
    set workOrderId = ${1}
    shift

    echo "Verification: ${workOrderId}" >> ${results}
    echo "----------------------------------------" >> ${results}

    # Ensure the directories associated with the arguments eixst
    set workOrderDir = ${IAS_WO}/${workOrderId}
    if (! -d ${workOrderDir}) then
	echo "  Does not exist: ${workOrderDir}" >> ${results}
    else
	grep CLOUD_COVER ${workOrderDir}/*_MTL.txt >> ${results}
	grep CLOUD_COVER_ALGORITHM ${workOrderDir}/*.omf >> ${results}
    endif
    echo "" >> ${results}
end

cat ${results}

exit 0
