#!/bin/csh -f
#  The purpose of this script is to automatically monitor the input list of
#  work order IDs. It will update the WOs to the correct states.
#
#  Usage: monitor_work_orders.csh
#-------------------------------------------------------------------------------
set SUCCESS = 0
set ERROR = 1

# Create a log file
if ( -e test_case_id ) then
    set id = `cat test_case_id`
    set log = tc${id}.log
    set woid_file = tc${id}_woids.txt
else
    echo "Error: File 'test_case_id' missing"
    exit $ERROR
endif

if ( -e $woid_file ) then
    set wos = `cat $woid_file`
else
    echo "Error: Work order ids file $file missing"
    exit $ERROR
endif

set num_wos = ${#wos}
set num_l0r_request_failed = 0
set num_transfer_failed = 0
set num_halted = 0
set num_complete = 0
set num_wo_complete = 0
set not_done = 1
set num_anomalies = 0

echo "" |& tee -a $log
echo "Monitoring work orders..." |& tee -a $log
while ( $not_done )
    set i = 0
    set temp_wos
    foreach wo ($wos)
        @ i++
        if ( $wo == "" ) then
            continue
        endif
        set wostate = `sqlplus -s $IAS_DB_COM` << END 
            set head off;
            select state from work_orders where work_order_id='$wo';
            exit;
END

        # The states that are probably important are Pending, Running, Halted
        # and Evaluate.  We want all to go to E.
        if ( $wostate == "N" && $num_l0r_request_failed < 6 ) then
            set wostate = `sqlplus -s $IAS_DB_COM` << END 
            set head off;
            update work_orders set state = 'RF' where work_order_id='$wo';
            exit;
END

            set $wos[$i] = ""
            @ num_l0r_request_failed++
            @ num_complete++
            if ( $num_l0r_request_failed == 6 ) then
                echo "`date` The first 6 new work orders have been set to a "\
                    "request failed state" |& tee -a $log
            endif

        else if ( $wostate == "RS" && $num_transfer_failed < 6 ) then
            set wostate = `sqlplus -s $IAS_DB_COM` << END 
            set head off;
            update work_orders set state = 'TF' where work_order_id='$wo';
            exit;
END

            set $wos[$i] = ""
            @ num_complete++
            @ num_transfer_failed++
            if ( $num_transfer_failed == 6 ) then
                echo "`date` The first 6 ready to ship work orders have been" \
                    "set to a transfer failed state" |& tee -a $log
            endif

        else if ( $wostate == "P" && $num_halted < 11 ) then
            set wostate = `sqlplus -s $IAS_DB_COM` << END 
            set head off;
            update work_orders set state = 'H' where work_order_id='$wo';
            exit;
END
            set prodreq = `sqlplus -s $IAS_DB_COM` << END 
            set head off;
            select product_request_id from work_orders where work_order_id='$wo';
            exit;
END

            if ( $num_anomalies < 5 ) then
                echo "Creating anomaly for $wo" |& tee -a $log
                set amo_id = `sqlplus -s $IAS_DB_COM` << END 
                set head off;
                SELECT anomalies_seq.nextval FROM DUAL;
                exit;
END

                set result = `sqlplus -s $IAS_DB_COM` << END
                set head off;
                Insert into ANOMALIES (ANOMALY_ID,PRODUCT_REQUEST_ID,
                ORIGIN,DATE_ENTERED,STATE,ASSIGNEE,DATE_CLOSED,CLASS,
                CURRENT_WO_ID,TROUBLE_TICKET_ID,TITLE,FAILED_PROD_LOC,
                RETURNED_PROD_LOC,PROBLEM_DESCRIPTION,PROBLEM_RESOLUTION)
                values ($amo_id,'$prodreq',1,
                to_date('19-FEB-15','DD-MON-RR'),5,null,null,null,'$wo',
                null,'DSW failed',null,null,null,
                ' Closed by PWC. WO completed successfully. Closed by PWC.
                WO completed successfully.');
                exit;
END
                echo $result |& tee -a $log
                @ num_anomalies++
            endif
            @ num_complete++
            @ num_halted++ 
            if ( $num_halted == 11 ) then
             echo "`date` The first 11 pending work orders have been set to a "\
                "halted state" |& tee -a $log
            endif

        else if ( $wostate == "C" && $num_wo_complete < 2 ) then
            @ num_complete++
            @ num_wo_complete++ 

            if ( $num_wo_complete == 2 ) then
             echo "`date` The last 2 work orders have been completed" \
                    |& tee -a $log
            endif
        else
            set temp_wos = ($temp_wos $wo)
        endif
    end
    set wos = ($temp_wos)
    sleep 15s
    # The stopping condition is that all work orders either halt, complete,
    # l0r request failed, or transfer failed
    if ( $num_complete == $num_wos ) then
        set not_done = 0
        continue
    endif
end

exit $SUCCESS
