#!/bin/csh -f
#
# Name: get_woids.csh
#
# Purpose: Queries the work_orders table to find the work orders placed for
#   the product request id found in the file passed in as a parameter.  The
#   list of work orders is written to the "tc<test case number>_woids.txt" file.
#
# Parameters: Name of the file with the product request id.

# Create a log file
if ( -e test_case_id ) then
    set tcnum = `cat test_case_id`
    set log = tc${tcnum}.log
    set woid_file = tc${tcnum}_woids.txt
else
    set script = $0:t
    set log = ${script:r}.out
    set woid_file = work_order_id.txt
endif

# Must have one argument
if ( ${#argv} != 1 ) then
    echo "" |& tee -a $log
    echo "    Usage: $0 product_request_WOs.txt" |& tee -a $log
    echo "" |& tee -a $log
    exit 1
endif

set product_req_ids = `awk '{print $1}' $1`
set woids = ""
foreach req_id ($product_req_ids)
    set id = `sqlplus -s ${IAS_DB_COM}` << END
        set head off; 
        SELECT work_order_id FROM work_orders
            WHERE product_request_id='$req_id';
        exit;
END

    set woids = `echo "$woids $id"`
end

echo $woids > $woid_file

exit 0
