#!/bin/csh -f
#  The purpose of this script is to automatically monitor the input list of
#  work order IDs. It will update the WOs to the correct states.
#
#  Usage: halt_work_orders.csh
#----------------------------------------------------------------------------
set SUCCESS = 0
set ERROR = 1

# Create a log file
if ( -e test_case_id ) then
    set id = `cat test_case_id`
    set log = tc${id}.log
    set woid_file = tc${id}_woids.txt
else
    echo "Error: File 'test_case_id' missing"
    exit $ERROR
endif

if ( -e $woid_file ) then
    set wos = `cat $woid_file`
else
    echo "Error: Work order ids file $file missing"
    exit $ERROR
endif

set num_halted = 0
set not_done = 1

echo "" |& tee -a $log
echo "Monitoring work orders..." |& tee -a $log
while ( $not_done )
    set i = 0
    set temp_wos
    foreach wo ($wos)
        @ i++
        if ( $wo == "" ) then
            continue
        endif
        set wostate = `sqlplus -s $IAS_DB_COM` << END
            set head off;
            select state from work_orders where work_order_id='$wo';
            exit;
END

        if ( $wostate == "P" && $num_halted < 5 ) then
            set wostate = `sqlplus -s $IAS_DB_COM` << END
            set head off;
            update work_orders set state = 'H' where work_order_id='$wo';
            exit;
END

            @ num_halted++ 
            if ( $num_halted == 5 ) then
             echo "`date` The first 5 pending work orders have been set to a "\
                "halted state" |& tee -a $log
            endif
        else
            set temp_wos = ($temp_wos $wo)
        endif
    end
    set wos = ($temp_wos)
    sleep 15s
    # The stopping condition is that all work orders either halt, complete,
    # l0r request failed, or transfer failed
    if ( $num_halted == 5 ) then
        set not_done = 0
        continue
    endif
end

exit $SUCCESS
