#!/bin/csh -f

# Create a log file
if ( -e test_case_id ) then
    set tcnum = `cat test_case_id`
    set log = tc${tcnum}.log
else
    set script = $0:t
    set log = ${script:r}.out
endif

# Get the work order IDs
echo "Obtaining WO IDs" |& tee $log
set woid_units = `./get_woids.csh product_request_WOs.txt |& tee -a $log`

# To use the common validation script the work order comment needs to
# indicate which unit the work order is connected to.  Output of the
# get_woids script contains this information in the form of:
#    wo_id,unit_number
set woids = ""
foreach woid_unit ($woid_units)
    set woid = `echo $woid_unit | awk -F, '{print $1}'`
    set unit = `echo $woid_unit | awk -F, '{print $2}'`
    set comment = "TC$tcnum $unit"

    sqlplus -s ${IAS_DB_COM} > /dev/null << END
        UPDATE work_orders SET wo_comment='$comment' WHERE
            work_order_id='$woid';
        exit;
END

    set woids = ($woids $woid)
end

set exp_order_count = `cat product_request_WOs.txt | wc -l`
if ( $#woids != $exp_order_count ) then
    echo "Expected to find $exp_order_count work order ids. Found $#woids"
    exit 1
endif


# Uncomment to short circuit the validation for dry runs
#exit 0

# Run the validation
set exit_status = 0
../tools/validate_wo_output.csh $woids |& tee -a $log
if ( $status ) then
    echo "FAIL" |& tee -a $log
    set exit_status = 1
else
    echo "PASS" |& tee -a $log
endif

exit $exit_status
