#!/bin/csh -f

# Create a log file
if ( -e test_case_id ) then
    set tcnum = `cat test_case_id`
    set log = tc${tcnum}.log
else
    set script = $0:t
    set log = ${script:r}.out
endif
set collection1 = ""
set precollection = ""

# Get the work order IDs
echo "Obtaining WO IDs" |& tee $log
set woid_units = `../tools/get_woids.csh product_request_WOs.txt |& tee -a $log`

# To use the common validation script the work order comment needs to
# indicate which unit the work order is connected to.  Output of the
# get_woids script contains this information in the form of:
#    wo_id,unit_number
set woids = ""
foreach woid_unit ($woid_units)
    set woid = `echo $woid_unit | awk -F, '{print $1}'`
    set unit = `echo $woid_unit | awk -F, '{print $2}'`
    set comment = "TC$tcnum $unit"

    sqlplus -s ${IAS_DB_COM} > /dev/null << END
        UPDATE work_orders SET wo_comment='$comment' WHERE
            work_order_id='$woid';
        exit;
END

    set woids = ($woids $woid)
end

set exp_order_count = `cat product_request_WOs.txt | wc -l`
if ( $#woids != $exp_order_count ) then
    echo "Expected to find $exp_order_count work order ids. Found $#woids"
    exit 1
endif

# Create the tar listing and GCP type files
echo "Creating tar package listings..." |& tee -a $log
foreach wo ($woids)
    pushd $IAS_WO/$wo
    set package = `grep L1G_PACKAGE ${wo}.omf | awk -F'"' '{print $2}'`
    if ($package != "") then
        #  From the tar output, extract the name and size, then pipe through
        # sed to replace the generation date with PRODDATE, so output is 
        # consistent whenever the file was made. The first group in the sed
        # matches all the characters up to the gen date. Then the the date
        # is matched outside of a group. The 2nd group consists of the rest
        # of the filename and the file size.
        tar -tvf $package | awk '{print $6,$3}' | \
          sed 's/^\([[:alnum:]_]\{26\}\)[[:digit:]]\{8\}\(_.*\)/\1PRODDATE\2/'\
           > l1g_tar_package_listing
    endif

    set package = `grep L0R_PACKAGE ${wo}.omf | awk -F'"' '{print $2}'`
    if ($package != "") then
        tar -tvf $package | awk '{print $6,$3}' > l0r_tar_package_listing
    endif

    if ( -e measured.gcp ) then
        awk -F',' '{print $15}' measured.gcp | sort -u > pass1_type
    endif
    if ( -e measured_pass2.gcp ) then
        awk -F',' '{print $15}' measured_pass2.gcp | \
            sort -u > pass2_type
    endif
    popd

    set instance = `sqlplus -s ${IAS_DB_COM}` << END
        set head off; 
        SELECT processing_instance FROM work_orders
            WHERE work_order_id='$wo';
        exit;
END

    if ($instance == "Collection1") then
        set collection1 = ($collection1 $wo)
    else
        set precollection = ($precollection $wo)
    endif
end

# Uncomment to short circuit the validation for dry runs
#exit 0

# Run the validation
set exit_status = 0

echo "Running validation for Collecion1"
run_in_instance.csh -a Collection1 ../tools/validate_wo_output.csh $collection1 |& tee -a $log
if ( $status ) then
    echo "Collection1 FAILED" |& tee -a $log
    set exit_status = 1
else
    echo "Collection1 PASSED" |& tee -a $log
endif

echo "Running validation for Pre-Collecion"
run_in_instance.csh -a Pre-Collection ../tools/validate_wo_output.csh $precollection |& tee -a $log
if ( $status ) then
    echo "Pre-Collection FAILED" |& tee -a $log
    set exit_status = 1
else
    echo "Pre-Collection PASSED" |& tee -a $log
endif
echo ""
echo ""

if ( $exit_status ) then
    echo "Validation FAILED"
else
    echo "Validation PASSED"
endif

exit $exit_status
