#!/usr/bin/perl -w
################################################################################
# NAME: add_wo_and_rad_ids.pl
# ARGS: A file name with the output from the TRAM Loader
# PURPOSE: Adds the Work Order ID and Rad WO Common ID to the TRAM output file
################################################################################

use strict;
use ias_const;
use ias_db;
use File::Copy;

if (@ARGV != 1)
{
    print STDERR "Wrong number of args. Expect 1, the name of the file to " .
                 "add the Rad WO Common IDs to\n";
    exit FAILURE;
}
my $filename = $ARGV[0];
my @contents;

if (! -f $filename)
{
    print STDERR "$filename is not a regular file\n";
    exit FAILURE;
}

my ($user, $pass) = ias_db_GetDBConnectionInfo();
my $dbh_common =  ias_db_ConnectToDB($user, $pass);
if (! defined $dbh_common)
{
    print STDERR "Failed to connect to Common DB\n";
    exit FAILURE;
}

($user, $pass) = ias_db_GetDBConnectionInfo("L8_OLITIRS");
my $dbh_sensor =  ias_db_ConnectToDB($user, $pass);
if (! defined $dbh_sensor)
{
    print STDERR "Failed to connect to Sensor DB\n";
    exit FAILURE;
}

# Open for reading
open (PROD_ID_FILE, "<$filename");

while(<PROD_ID_FILE>)
{
    chomp;
    push(@contents, $_);
}

# Close, and re-Open for writing, but first copy the file to a backup
close PROD_ID_FILE;
copy("$filename", "$filename.bk") or die "Failed to backup $filename $!";
open (PROD_ID_FILE, ">$filename");

foreach my $line(@contents)
{
    my @columns = split(' ', $line);
    if (@columns < 1)
    {
        print STDERR "Expected 1,2 or 3(if re-running) columns in line:$line\n";
        close PROD_ID_FILE;
        # Restore the backup
        move("$filename.bk", $filename);
        exit FAILURE;
    }
    my $prod_req_id = $columns[0];
    my $sql = "SELECT work_order_id from work_orders where "
            . "product_request_id = '$prod_req_id'";
    my $result =  $dbh_common->selectrow_arrayref($sql);
    if (!defined $result)
    {
        print STDERR "Failed to execute $sql\n";
        move("$filename.bk", $filename);
        exit FAILURE;
    }
    my $wo_id = $result->[0];
    $sql = "SELECT radiometric_wo_common_id from "
         . "radiometric_work_order_common WHERE work_order_id = '$wo_id'";
    $result =  $dbh_sensor->selectrow_arrayref($sql);
    if (!defined $result)
    {
        print STDERR "Failed to execute $sql\n";
        move("$filename.bk", $filename);
        exit FAILURE;
    }
    my $rad_id = $result->[0];
    # If using the non-Dev tram loader we will not have scene ID. Add a
    # filler in its place
    if (@columns == 1)
    {
        print PROD_ID_FILE "$columns[0] SCENE_ID $wo_id $rad_id\n";
    }
    else
    {
        print PROD_ID_FILE "$columns[0] $columns[1] $wo_id $rad_id\n";
    }
}
close PROD_ID_FILE;
# Remove the backup
unlink ("$filename.bk");
$dbh_common->disconnect();
$dbh_sensor->disconnect();
exit SUCCESS;
