#!/bin/csh -f
#***************************************************************************
# NAME:      rad_wo_cleanup.csh
#
#  PURPOSE: The script performs the radiometric_work_order_common cleanup
#           normally done by DRM. Since this is a slow process in the
#           database, this script refuses to function if more than 50
#           records are found.
#  RETURNS:
#        Type:  Integer
#        Value: 0 / 1
#
#  USAGE:    ./rad_wo_cleanup.csh
#****************************************************************************
# Create a log file
if ( -e test_case_id ) then
    set tcnum = `cat test_case_id`
    set log = tc${tcnum}.log
    set woid_file = tc${tcnum}_woids.txt
else
    set script = $0:t
    set log = ${script:r}.out
    set woid_file = work_order_id.txt
endif

set count = `sqlplus -s ${IAS_DB_COM}` << END
    set head off; 
    SELECT count(radiometric_wo_common_id) rad_id FROM work_orders wo,
                radiometric_work_order_common rad WHERE wo.work_order_id 
                = rad.work_order_id AND rad.valid = 'N' and wo.state IN 
                ('A', 'C');
    exit;
END

echo "Found $count records to delete" | tee -a $log
if ($count > 50 ) then
    echo "More than 50 records found. Some "\
         "other form of cleanup recommended" |  tee -a $log
    exit 1
else if ($count == 0) then
    echo "No records to delete. Exiting successfully." | tee -a $log
    exit 0
endif

set return = `sqlplus -s ${IAS_DB_COM}` << END
    set head off; 
    DELETE FROM radiometric_work_order_common WHERE
        radiometric_wo_common_id IN 
    (SELECT radiometric_wo_common_id FROM work_orders wo,
                radiometric_work_order_common rad WHERE wo.work_order_id 
                = rad.work_order_id AND rad.valid = 'N' and wo.state IN 
                ('A', 'C'));
    exit;
END
set del_rows = `echo $return | awk '{print $1}'`
if ( $del_rows != $count ) then
    echo "Delete count ($del_rows) is not $count as expected" | tee -a $log
    exit 1;
endif
echo "Records successfully deleted" | tee -a $log
