%%
%% This is the file `testcase.cls', based on `memoir.cls'.
%% Its purpose is to define a class for test documentation.
%%
% The section below is a template of the various components of a test
% case.  Multiple test cases are generated with multiple \testcase sections.
%
% ---------------- Test case template -----------------------
% \testcase{Title of test case}
%
% \authorrevised{Fname Lname}{Mon day, year of last revision}
%
% \begin{purpose}
% A short presentation of the purpose and objectives of the test.
% \end{purpose}
%
% \begin{prerequisites}
% List any prerequisite steps required.
% \end{prerequisites}
%
% \begin{ccrlist}
% \item[CCR number] CCR title
% ...
% \end{ccrlist}
%
% \begin{inputdata}
% List of input data required for the test.
% \end{inputdata}
%
% \begin{verification}
% Itemized list of criteria for a successful test.
% \item The test machine does not blow up.
% ...
% \end{verification}
%
% \begin{steps}
% List of test case steps with the following format for each step:
% & User actions/inputs & Expected results & & Comments/remarks
%   \tabularnewline\hline
% (The "&" represent the column separators. The information for a
% given cell may be as long as required.)
% \end{steps}
% ---------------- End test case template -----------------------
%
%-------------------- identification --------------------------
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{testcase}[2006/03/21 v0.2]
%-------------------- initial code ----------------------------
%-------------------- declaration of options ------------------
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}
%-------------------- execution of options --------------------
\ProcessOptions
%-------------------- package loading -------------------------
\LoadClass[12pt,landscape,twoside,article]{memoir}
\RequirePackage[colorlinks=true,linkcolor=blue,plainpages=false]{hyperref}
\RequirePackage{memhfixc}
\RequirePackage[letterpaper,landscape,margin=0.5in,includeheadfoot]{geometry}
\RequirePackage{array}
\RequirePackage{amsmath}
\RequirePackage{wasysym}
\RequirePackage{mathptmx}
\RequirePackage{longtable}
\RequirePackage{seqsplit}
\RequirePackage{paralist}
%-------------------- main code -------------------------------

\chapterstyle{section}

% Define the \testcase section.
\newcounter{testcase}
\renewcommand\thetestcase{\@arabic\c@testcase}
\newcommand\testcasename{Test Case}
\newcommand*\testcasemark[1]{}
\newcommand{\ruleunder}[1]{{\testcasename\ \ #1%
    \par\nobreak\vskip 1ex \hrule width \linewidth height 2pt}}

\newcommand{\testcase}{\cleardoublepage
    \@startsection{testcase}{1}{\z@}%
        {-3.5ex \@plus -1ex \@minus -.2ex}%
        {2.3ex \@plus .2ex}%
        {\normalfont\Large\bfseries\ruleunder}}%

\newcommand*\l@testcase[2]{%
  \ifnum \c@tocdepth >\z@
    \addpenalty\@secpenalty
    \addvspace{1.0em \@plus\p@}%
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      \testcasename\ #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
    \endgroup
  \fi}

% Define the \authorrevised command.
\newcommand{\authorrevised}[2]{{\bfseries Author:} #1 %
             \hfill{\bfseries Last Revised:} #2 \rule{2in}{0in}}

% Define the \purpose environment.
\newenvironment{purpose}{\vspace{\baselineskip}\noindent
                         \textbf{Purpose and Objectives:}
                         \begin{quote}}
                        {\end{quote}}

% Define the \prerequisites environment.
\newenvironment{prerequisites}{\vspace{\baselineskip}\noindent
                               \textbf{Prerequisite Steps:}
                               \begin{quote}}
                              {\end{quote}}

% Define the \ccrlist environment.
\newenvironment{ccrlist}{\vspace{\baselineskip}\noindent
                         \textbf{CCRs verified by this test:}
                         \list{}{\labelwidth\z@ \itemindent-\leftmargin
                         \let\makelabel\descriptionlabel}}
                        {\endlist}

% Define the \inputdata environment.
\newenvironment{inputdata}{\vspace{\baselineskip}\noindent
                           \textbf{Input Data Required:}\begin{quote}}
                          {\end{quote}}

% Define a standard table format for the input data.
\newenvironment{inputdatatable}
    {\begin{table}[ht]
     \small
     \begin{center}
     \begin{tabular}{>{\raggedright}clccc
                     >{\raggedright}p{0.5\textwidth}}
        \textbf{Set} &
            \textbf{Interval / Scene ID} &
            \textbf{Acquisition Date} &
            \textbf{Path} & \textbf{Row} &
            \textbf{Description}\nl \hline}
    {\hline
     \end{tabular}
     \end{center}
     \end{table}}

% Define the \verification environment.
\newenvironment{verification}{\vspace{\baselineskip}\noindent
                              \textbf{Verification Criteria:} \\[0.1in]
                              This test case will pass if:
                              \begin{itemize}}
                             {\end{itemize}}

% Define the \steps environment.
\newcommand\macrostep[1]{\multicolumn{5}{|p{0.9\textwidth}|}{\textbf{#1}}%
\tabularnewline\hline}
\makeatletter
\newcounter{tabline}[LT@tables]
\makeatother
\DeclareRobustCommand\tabitem{\refstepcounter{tabline}\thetabline}
\newenvironment{steps}[1][\testcasename~Steps]%
{\setcounter{tabline}{0}\vspace{\baselineskip}\noindent
    \addtocounter{table}{-1}
    \begin{longtable}{|>{\tabitem}r|>{\raggedright}p{0.32\textwidth}|
                       >{\raggedright}p{0.32\textwidth}|c|
                       >{\raggedright}p{0.2\textwidth}|}
        \caption*{\textbf{#1}} \\
        \hline
        \multicolumn{1}{|c|}{\textbf{Step}} &
        \multicolumn{1}{c|}{\textbf{User Actions/Inputs}} &
        \multicolumn{1}{c|}{\textbf{Expected Results}} &
        \checked &
        \multicolumn{1}{c|}{\textbf{Comments/Remarks}}
        \tabularnewline\hline
        \hline \endhead
        \endfoot}
    {\end{longtable}}
%%
%% End of file `testcase.cls'.
