#!/usr/bin/perl 
use warnings;
use strict;

##############################################################################
# Description: Update the expected results with a new Landsat Scene Id.
#
# Usage: convert_expected_results.pl <Dataset Path> <Old Id> <New Id>
#
##############################################################################

use File::Basename;

if ($#ARGV != 2)
{
    print "Invalid parameter count\n";
    print "Usage: convert_expected_results.pl <DatasetPath> <OldId> <NewId>\n";
    exit 1;
}

my $dataPath = $ARGV[0];
my $oldId    = $ARGV[1];
my $newId    = $ARGV[2];

if ( ! -d $dataPath )
{
    print "$dataPath does not exist\n";
    exit 1;
}
if (!($oldId =~ /L[COT]8[0-9]{13}[A-Z]{3}[0-9]{2}/ 
        or $oldId =~ /L[COT]8[0-9]{16}[A-Z]{3}[0-9]{2}/ ))
{
    print "Invalid OldId: $oldId\n";
    exit 1;
}
if (!($newId =~ /L[COT]8[0-9]{13}[A-Z]{3}[0-9]{2}/ 
        or $newId =~ /L[COT]8[0-9]{16}[A-Z]{3}[0-9]{2}/ ))
{
    print "Invalid NewId: $newId\n";
    exit 1;
}

print "Converting directory: $dataPath\n";
print "Old Id: $oldId \n";
print "New Id: $newId \n";
print "-----------------------\n";

my @files = glob($dataPath . "/*");
for my $file (@files)
{
    my $basename = basename($file);

    if ($basename !~ /\.TIF$/i)
    {
        print "Replacing $oldId with $newId in $basename\n";
        my $sedCmd = "sed -i 's/$oldId/$newId/g' $file";

        `$sedCmd`;
        if ($? > 0)
        {
            print "sed command failed: $sedCmd\n";
            exit 1;
        }
    }

    if ($basename =~ /$oldId/)
    {
        my $newFilename = $basename;
        $newFilename =~ s/$oldId/$newId/;

        print "Renaming $basename to $newFilename\n";
        my $mvCmd = "mv $file $dataPath/$newFilename";

        `$mvCmd`;
        if ($? > 0)
        {
            print "mv command failed: $mvCmd\n";
            exit 1;
        }
    }
}

print "Complete.\n";
exit 0;
