-- run build_inventory_tables.sql before running this script

create or replace
PACKAGE BODY DBPKG_L0RP_L1_DATA AS

/* Forward declarations */
FUNCTION create_scene(v_landsat_scene_id VARCHAR2) RETURN NUMBER;
FUNCTION create_l0rp_file(v_lmd_scene_id NUMBER) RETURN NUMBER;
FUNCTION create_l1_file(v_lmd_scene_id NUMBER) RETURN NUMBER;

PROCEDURE proc_lpgs_l0rp_data_file
(
    v_landsat_scene_id in varchar2,
    v_file_name in varchar2,
    v_file_date in date,
    v_file_size in number,
    v_file_checksum in varchar2,
    v_file_type in varchar2,
    v_product_file_size in number,
    v_id_or_count out number
) AS

    default_file_id  CONSTANT NUMBER := 555433;
    scene_id         lmd_scene.lmd_scene_id%TYPE;
    file_id          lmd_l0rp_data_file.lmd_l0rp_data_file_id%TYPE;

  BEGIN
    
    BEGIN
      SELECT lmd_scene_id
        INTO scene_id
        FROM lmd_scene
       WHERE landsat_scene_id = v_landsat_scene_id;
    EXCEPTION
      WHEN no_data_found THEN
        -- create scene
        scene_id := create_scene(v_landsat_scene_id);
        IF scene_id IS NULL THEN
          v_id_or_count := default_file_id;
          RETURN;
        END IF;
    END;

    DELETE FROM lmd_l0rp_data_file
     WHERE lmd_scene_id = scene_id
       AND file_type = v_file_type;

    SELECT (nvl(max(lmd_l0rp_data_file_id), 0)) + 1
      INTO file_id
      FROM lmd_l0rp_data_file;

    INSERT INTO lmd_l0rp_data_file
        (lmd_l0rp_data_file_id, lmd_scene_id, file_name, file_date, file_size,
         file_checksum, file_type, product_file_size, date_entered)
    VALUES
        (file_id, scene_id, v_file_name, v_file_date, v_file_size, 
         v_file_checksum, v_file_type, v_product_file_size, sysdate);

    v_id_or_count := file_id;

  END proc_lpgs_l0rp_data_file;

PROCEDURE proc_lpgs_l1_data_file
(
    v_landsat_scene_id in varchar2,
    v_file_name in varchar2,
    v_file_date in date,
    v_file_size in number,
    v_file_checksum in varchar2,
    v_file_type in varchar2,
    v_product_file_size in number,
    v_id_or_count out number
) AS
    default_file_id   CONSTANT NUMBER := 123456;
 
    scene_id     lmd_scene.lmd_scene_id%TYPE;
    file_id      lmd_l1_data_file.lmd_l1_data_file_id%TYPE;

  BEGIN
    BEGIN
      SELECT lmd_scene_id
        INTO scene_id
        FROM lmd_scene
       WHERE landsat_scene_id = v_landsat_scene_id;
    EXCEPTION
      WHEN no_data_found THEN
        -- create scene
        scene_id := create_scene(v_landsat_scene_id);
        IF scene_id IS NULL THEN
          v_id_or_count := default_file_id;
          RETURN;
        END IF;
    END;
    
    DELETE FROM lmd_l1_data_file
     WHERE lmd_scene_id = scene_id
       AND file_type = v_file_type;

    SELECT (nvl(max(lmd_l0rp_data_file_id), 0)) + 1
      INTO file_id
      FROM lmd_l0rp_data_file;

    INSERT INTO lmd_l1_data_file
        (lmd_l1_data_file_id, lmd_scene_id, file_name, file_date, file_size,
         file_checksum, file_type, product_file_size, date_entered)
    VALUES
        (file_id, scene_id, v_file_name, v_file_date, v_file_size, 
         v_file_checksum, v_file_type, v_product_file_size, sysdate);
   
    v_id_or_count := file_id;

  END proc_lpgs_l1_data_file;

PROCEDURE proc_lpgs_l1_lmd_scene_upd
(
    v_bpf_name in varchar2,
    v_central_meridian_lon in number,
    v_cloud_cover_automated in number,
    v_cpf_name in varchar2,
    v_data_type in varchar2,
    v_elevation_source in varchar2,
    v_false_easting in number,
    v_false_easting_unit in varchar2,
    v_false_northing in number,
    v_false_northing_unit in varchar2,
    v_geometric_rmse_along_track in number,
    v_geometric_rmse_across_track in number,
    v_grid_cell_size_pan in number,
    v_grid_cell_size_reflective in number,
    v_grid_cell_size_thermal in number,
    v_landsat_scene_id in varchar2,
    v_l1_location in varchar2,
    v_lpgs_version in varchar2,
    v_map_projection in varchar2,
    v_orientation in varchar2,
    v_pan_lines in number,
    v_pan_samples in number,
    v_reflective_lines in number,
    v_reflective_samples in number,
    v_resampling_option in varchar2,
    v_rlut_file_name in varchar2,
    v_scene_bands_l1 in number,
    v_scene_status in varchar2,
    v_subsetter_version_l1 in varchar2,
    v_thermal_lines in number,
    v_thermal_samples in number,
    v_true_scale_lat in number,
    v_utm_zone in number,
    v_record_count out number
) AS

    v_lmd_scene_id    lmd_scene.lmd_scene_id%TYPE;

  BEGIN
    BEGIN
      SELECT lmd_scene_id
        INTO v_lmd_scene_id
        FROM lmd_scene
       WHERE landsat_scene_id = v_landsat_scene_id;
    EXCEPTION
      WHEN no_data_found THEN
        -- create scene
        v_lmd_scene_id := create_scene(v_landsat_scene_id);
        IF v_lmd_scene_id IS NULL THEN
          v_record_count := 1;
          RETURN;
        END IF;
      WHEN others THEN
        v_record_count := 1;
        RETURN;
    END;

    UPDATE lmd_scene
       SET cloud_cover_automated = v_cloud_cover_automated,
           geometric_rmse_along_track = v_geometric_rmse_along_track,
           geometric_rmse_across_track = v_geometric_rmse_across_track,
           l1_location = v_l1_location,
           bpf_name = v_bpf_name,
           central_meridian_lon = v_central_meridian_lon,
           cpf_name = v_cpf_name,
           data_type = v_data_type,
           elevation_source = v_elevation_source,
           false_easting = v_false_easting,
           false_easting_unit = v_false_easting_unit,
           false_northing = v_false_northing,
           false_northing_unit = v_false_northing_unit,
           grid_cell_size_pan = v_grid_cell_size_pan,
           grid_cell_size_reflective = v_grid_cell_size_reflective,
           grid_cell_size_thermal = v_grid_cell_size_thermal,
           lpgs_version = v_lpgs_version,
           map_projection = v_map_projection,
           orientation = v_orientation,
           pan_lines = v_pan_lines,
           pan_samples = v_pan_samples,
           reflective_lines = v_reflective_lines,
           reflective_samples = v_reflective_samples,
           resampling_option = v_resampling_option,
           rlut_file_name = v_rlut_file_name,
           scene_bands_l1 = v_scene_bands_l1,
           scene_status = v_scene_status,
           subsetter_version_l1 = v_subsetter_version_l1,
           thermal_lines = v_thermal_lines,
           thermal_samples = v_thermal_samples,
           true_scale_lat = v_true_scale_lat,
           utm_zone = v_utm_zone
     WHERE lmd_scene_id = v_lmd_scene_id;

    COMMIT;

    v_record_count := 1;

  EXCEPTION
    WHEN others THEN
      ROLLBACK;
      v_record_count := 1;

  END proc_lpgs_l1_lmd_scene_upd;


PROCEDURE proc_lpgs_l0rp_lmd_scene_upd
(
    v_landsat_scene_id in varchar2,
    v_data_type in varchar2,
    v_l0rp_location in varchar2,
    v_scene_bands_l0rp in number,
    v_subsetter_version_l0rp in varchar2,
    v_record_count out number
) AS

    v_lmd_scene_id    lmd_scene.lmd_scene_id%TYPE;

  BEGIN
    v_record_count := 1;

    BEGIN
      SELECT lmd_scene_id
        INTO v_lmd_scene_id
        FROM lmd_scene
       WHERE landsat_scene_id = v_landsat_scene_id;
    EXCEPTION
      WHEN no_data_found THEN
        -- create scene
        v_lmd_scene_id := create_scene(v_landsat_scene_id);
        IF v_lmd_scene_id IS NULL THEN
          v_record_count := 1;
          RETURN;
        END IF;
      WHEN others THEN
        v_record_count := 1;
        RETURN;
    END;

    UPDATE lmd_scene
       SET l0rp_location = v_l0rp_location,
           subsetter_version_l0rp = v_subsetter_version_l0rp,
           data_type = v_data_type,
           scene_bands_l0rp = v_scene_bands_l0rp
     WHERE lmd_scene_id = v_lmd_scene_id;

    COMMIT;

  EXCEPTION
    WHEN others THEN
      ROLLBACK;
      v_record_count := 1;
  END proc_lpgs_l0rp_lmd_scene_upd;

PROCEDURE proc_lpgs_l1_scene_coord (
   v_landsat_scene_id                     IN VARCHAR2,
   v_corner_ll_lat                        IN NUMBER,
   v_corner_ll_lon                        IN NUMBER,
   v_corner_lr_lat                        IN NUMBER,
   v_corner_lr_lon                        IN NUMBER,
   v_corner_ul_lat                        IN NUMBER,
   v_corner_ul_lon                        IN NUMBER,
   v_corner_ur_lat                        IN NUMBER,
   v_corner_ur_lon                        IN NUMBER,
   v_coordinate_type                      IN VARCHAR2,
   v_scene_center_lat                     IN NUMBER,
   v_scene_center_lon                     IN NUMBER,
   v_id_or_count           OUT NUMBER
) AS
    coord_id       lmd_l1_scene_coordinate.lmd_l1_scene_coordinate_id%TYPE;
    scene_id       lmd_scene.lmd_scene_id%TYPE;
  BEGIN
    
    SELECT lmd_scene_id
      INTO scene_id
      FROM lmd_scene
     WHERE landsat_scene_id = v_landsat_scene_id;

    DELETE FROM lmd_l1_scene_coordinate 
     WHERE lmd_scene_id = scene_id
       AND coordinate_type = v_coordinate_type;

    SELECT nvl(max(lmd_l1_scene_coordinate_id), 0) + 1
      INTO coord_id
      FROM lmd_l1_scene_coordinate;

    INSERT INTO lmd_l1_scene_coordinate
        (lmd_l1_scene_coordinate_id, corner_ll_lat, corner_ll_lon, 
         corner_lr_lat, corner_lr_lon, corner_ul_lat, corner_ul_lon,
         corner_ur_lat, corner_ur_lon, date_entered, date_updated, 
         lmd_scene_id, coordinate_type, scene_center_lat, scene_center_lon)
    VALUES
        (coord_id, v_corner_ll_lat, v_corner_ll_lon, v_corner_lr_lat,
         v_corner_lr_lon, v_corner_ul_lat, v_corner_ul_lon, v_corner_ur_lat,
         v_corner_ur_lon, sysdate, sysdate, scene_id, v_coordinate_type, 
         v_scene_center_lat, v_scene_center_lon);

    v_id_or_count := coord_id;

  END proc_lpgs_l1_scene_coord;

PROCEDURE proc_lpgs_lmd_proc_host
(
    v_landsat_scene_id in varchar2,
    v_hostname in varchar2,
    v_id_or_count out number
) AS
    
    proc_host_id   lmd_processing_host.lmd_processing_host_id%TYPE;
    scene_id       lmd_scene.lmd_scene_id%TYPE;

  BEGIN
    SELECT lmd_scene_id
      INTO scene_id
      FROM lmd_scene
     WHERE landsat_scene_id = v_landsat_scene_id;

    DELETE FROM lmd_processing_host WHERE lmd_scene_id = scene_id;

    SELECT (nvl(max(lmd_processing_host_id), 0)) + 1
      INTO proc_host_id
      FROM lmd_processing_host;

    INSERT INTO lmd_processing_host
        (lmd_processing_host_id, lmd_scene_id, hostname, date_entered)
    VALUES
        (proc_host_id, scene_id, v_hostname, sysdate);

    v_id_or_count := proc_host_id;

  END proc_lpgs_lmd_proc_host;

PROCEDURE proc_lpgs_cloud_cover_alg_ins (
    v_landsat_scene_id in varchar2,
    v_cloud_cover_algorithm in varchar2,
    v_cloud_cover_algorithm_weight in varchar2,
    v_lmd_cloud_cover_algorithm_id out number
) AS

    algorithm_id   lmd_processing_host.lmd_processing_host_id%TYPE;
    scene_id       lmd_scene.lmd_scene_id%TYPE;
    
  BEGIN
    SELECT lmd_scene_id
      INTO scene_id
      FROM lmd_scene
     WHERE landsat_scene_id = v_landsat_scene_id;

    SELECT (nvl(max(lmd_cloud_cover_algorithm_id), 0)) + 1
      INTO algorithm_id
      FROM lmd_cloud_cover_algorithm;

    INSERT INTO lmd_cloud_cover_algorithm
        (lmd_cloud_cover_algorithm_id, lmd_scene_id, cloud_cover_algorithm,
         cloud_cover_algorithm_weight, date_entered)
    VALUES
        (algorithm_id, scene_id, v_cloud_cover_algorithm, 
         v_cloud_cover_algorithm_weight, sysdate);

    v_lmd_cloud_cover_algorithm_id := algorithm_id;
    
  END proc_lpgs_cloud_cover_alg_ins;

PROCEDURE proc_lpgs_cloud_cover_alg_del (
    v_landsat_scene_id in varchar2,
    v_record_count out number,
    v_records_deleted out number
) AS

    scene_id       lmd_scene.lmd_scene_id%TYPE;

  BEGIN
    SELECT lmd_scene_id
      INTO scene_id
      FROM lmd_scene
     WHERE landsat_scene_id = v_landsat_scene_id;

    SELECT count(lmd_cloud_cover_algorithm_id)
      INTO v_record_count
      FROM lmd_cloud_cover_algorithm
     WHERE lmd_scene_id = scene_id;

    DELETE FROM lmd_cloud_cover_algorithm
     WHERE lmd_scene_id = scene_id;

    v_records_deleted := SQL%ROWCOUNT;

  END proc_lpgs_cloud_cover_alg_del;

PROCEDURE proc_lpgs_l1_proj_coord
(
    v_landsat_scene_id in varchar2,
    v_corner_ll_projection_x in number,
    v_corner_ll_projection_y in number,
    v_corner_lr_projection_x in number,
    v_corner_lr_projection_y in number,
    v_corner_ul_projection_x in number,
    v_corner_ul_projection_y in number,
    v_corner_ur_projection_x in number,
    v_corner_ur_projection_y in number,
    v_coordinate_type in varchar2,
    v_lmd_l1_scene_proj_coord_id out number
) AS
  
    coord_id    lmd_l1_scene_proj_coordinate.lmd_l1_scene_proj_coord_id%TYPE; 
    scene_id    lmd_scene.lmd_scene_id%TYPE;
 
  BEGIN
    SELECT lmd_scene_id
      INTO scene_id
      FROM lmd_scene
     WHERE landsat_scene_id = v_landsat_scene_id;

    DELETE FROM lmd_l1_scene_proj_coordinate 
     WHERE lmd_scene_id = scene_id
       AND coordinate_type = v_coordinate_type;

    SELECT nvl(max(lmd_l1_scene_proj_coord_id), 0) + 1
      INTO coord_id
      FROM lmd_l1_scene_proj_coordinate;

    INSERT INTO lmd_l1_scene_proj_coordinate
        (lmd_l1_scene_proj_coord_id, corner_ll_projection_x, 
         corner_ll_projection_y, corner_lr_projection_x, 
         corner_lr_projection_y, corner_ul_projection_x,
         corner_ul_projection_y, corner_ur_projection_x,
         corner_ur_projection_y, date_entered, date_updated, lmd_scene_id,
         coordinate_type)
    VALUES
        (coord_id, v_corner_ll_projection_x, v_corner_ll_projection_y,
         v_corner_lr_projection_x, v_corner_lr_projection_y,
         v_corner_ul_projection_x, v_corner_ul_projection_y,
         v_corner_ur_projection_x, v_corner_ur_projection_y,
         sysdate, sysdate, scene_id, v_coordinate_type);

    v_lmd_l1_scene_proj_coord_id := coord_id;
    
  END proc_lpgs_l1_proj_coord;

FUNCTION func_return_scene_key (
   v_landsat_scene_id             IN VARCHAR2
) RETURN NUMBER IS
  BEGIN
    RETURN 1;
  END func_return_scene_key;

FUNCTION create_scene(
  v_landsat_scene_id VARCHAR2
) RETURN NUMBER IS

    v_lmd_scene_id   lmd_scene.lmd_scene_id%TYPE;
    v_wrs_path       lmd_scene.wrs_path%TYPE;
    v_wrs_row        lmd_scene.wrs_row%TYPE;

  BEGIN

    SELECT nvl(max(lmd_scene_id), 0) + 1
      INTO v_lmd_scene_id
      FROM lmd_scene;

    v_wrs_path := to_number(substr(v_landsat_scene_id, 4, 3));
    v_wrs_row  := to_number(substr(v_landsat_scene_id, 7, 3));

    INSERT INTO lmd_scene 
      (lmd_scene_id, landsat_scene_id, wrs_path, wrs_row, date_entered)
    VALUES
      (v_lmd_scene_id, v_landsat_scene_id, v_wrs_path, v_wrs_row, sysdate);

    RETURN v_lmd_scene_id;

  EXCEPTION
    WHEN others THEN
      RETURN NULL;
  END;

FUNCTION create_l0rp_file(
  v_lmd_scene_id   NUMBER
) RETURN NUMBER IS

    v_file_id   lmd_l0rp_data_file.lmd_l0rp_data_file_id%TYPE;

  BEGIN

    SELECT nvl(max(lmd_l0rp_data_file_id), 0) + 1
      INTO v_file_id
      FROM lmd_l0rp_data_file;

    INSERT INTO lmd_l0rp_data_file 
      (lmd_l0rp_data_file_id, lmd_scene_id, date_entered)
    VALUES
      (v_file_id, v_lmd_scene_id, sysdate);

    RETURN v_file_id;

  EXCEPTION
    WHEN others THEN
      RETURN NULL;
  END;

FUNCTION create_l1_file(
  v_lmd_scene_id   NUMBER
) RETURN NUMBER IS

    v_file_id   lmd_l1_data_file.lmd_l1_data_file_id%TYPE;

  BEGIN

    SELECT nvl(max(lmd_l1_data_file_id), 0) + 1
      INTO v_file_id
      FROM lmd_l1_data_file;

    INSERT INTO lmd_l1_data_file 
      (lmd_l1_data_file_id, lmd_scene_id, date_entered)
    VALUES
      (v_file_id, v_lmd_scene_id, sysdate);

    RETURN v_file_id;

  EXCEPTION
    WHEN others THEN
      RETURN NULL;
  END;

END DBPKG_L0RP_L1_DATA;
/
