#!/usr/bin/perl -w
use strict;

#############################################################################
# Name:     prid2woid.pl
#
# Description: This script translates a list of product request ids into work 
# order ids.  
#
# Usage: prid2woid.pl <prid file> <outupt woid file>
#   <prid_file> -  Name of file containing product request id list in newline
#       delimited format. 
#   <output woid file> - Name of output file
#############################################################################

use DBI;
use IO::File;

# get the name of the file containing the product requests
die "Usage: prid2woid.pl <prid file> <woid file>\n" if (not defined $ARGV[0]);
my $prid_file = $ARGV[0];

# get the name of the output file
die "Usage: prid2woid.pl <prid file> <woid file>\n" if (not defined $ARGV[1]);
my $woid_file = $ARGV[1];

# get the DB connection information
die "IAS_DB_COM is not set\n" if (not defined $ENV{"IAS_DB_COM"});
my ($username, $password) = split(/\//, $ENV{"IAS_DB_COM"});

die "ORACLE_SID is not set\n" if (not defined $ENV{"ORACLE_SID"});
my $sid = $ENV{"ORACLE_SID"};

# load and prepare the product request ids
open PRIDS, "<$prid_file" or die "Error openning $prid_file\n";
my @requests = <PRIDS>;
close PRIDS;
foreach (@requests) { chomp; }

# build the list of product request id for the where clause
my $prid_list = "'" . join("','", @requests) . "'";

# build sql statement
my $sql = "SELECT work_order_id "
        . "  FROM work_orders "
        . " WHERE product_request_id IN ($prid_list) "
        . "   AND wo_replaced = 0 "
        . " ORDER BY product_request_id ASC";

# connect to the database
my $dbh = DBI->connect("DBI:Oracle:$sid", $username, $password,
    {AutoCommit => 0, PrintError => 0});

# prepare and execute the sql statement
my $sth = $dbh->prepare($sql);
if (!$sth)
{
    print "Error preparing sql: $DBI::errstr\n";
    $dbh->disconnect();
    exit 1;
}
if (!$sth->execute())
{
    print "Error executing sql: $DBI::errstr\n";
    $dbh->disconnect();
    exit 1;
}

# open the output file
my $wofile = IO::File->new(">$woid_file");
if (not defined $wofile)
{
    print "Error openning output file $woid_file\n";
    $sth->finish();
    $dbh->disconnect();
    exit 1;
}

# write the work order id to the output file
while (my ($wo) = $sth->fetchrow_array())
{
    print $wofile "$wo\n";
}

# cleanup 
$sth->finish();
$wofile->close();
$dbh->disconnect();
