/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
*******************************************************************************
*
* UNIT NAME:   AnomalyInformation.h
*
* PURPOSE:
* This is the header file for the Anomaly Information dialog, which allows
* the LPGS operators to view, diagnose, and manipulate non-nominal
* system orders.
*
******************************************************************************/

#ifndef ANOMALYINFORMATION_H
#define ANOMALYINFORMATION_H

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "TreeWidgetUtilities.h"
#include "IASSqlQuery.h"
#include "ui_AnomalyInformationBase.h"

class AnomalyInformation : public QDialog, public Ui::AnomalyInformationBase
{
    Q_OBJECT

    public:
        AnomalyInformation(QString prId,
                           QWidget *parent = 0);
        ~AnomalyInformation();

    protected slots:
        void approveProduct();
        void failCancelRequest();
        void changeAnomalyTitle();
        void updateAnomalies();
        void updateAnomalyDetail();
        void createNewWO();
        void activateWO();
        void retryIngestData();
        void filterChanged();
        void printAnomaly();
        void refresh();
        void resumeWO();
        void backupWODir();
        void showAnomalyDetail();
        void showAnomalyPopupMenu(const QPoint &point);
        void showWOPopupMenu(const QPoint &point);
        void showWOParms();
        void setChangeEnabled(const QString &);

    private:
        void setupListViews();
        void setupFilterList();
        vector<twInfo> twiAnomolyInfo;
        static QHash<int, QString> stateHash;
        int twiAINumColumns;
        int ailNumColumns;

        QString strFilterStates;
        QString specifiedPRId;

        QPrinter *printer;

        QMenu *popmWO;
        QMenu *popmAnomaly;

        QAction *actionViewModifyParameters;
        QAction *actionCreateNewWO;

        QAction *actionMenuSep1;
        QAction *actionActivateWO;
        QAction *actionResumeWO;
        QAction *actionRetryIngest;
        QAction *actionApproveProduct;
        QAction *actionBackupWODir;

        QAction *actionMenuSep2;
        QAction *actionFailProduct;

        QSignalMapper *signalMapper;
};

#endif /* ANOMALYINFORMATION_H */

