#ifndef DATEINPUT_H
#define DATEINPUT_H

/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   DateInput.h
 *
 * PURPOSE:
 * This is the declaration file for a DateInput class which consists of a
 * combo box and two spinboxes to input a valid date to be captured.
 *
 *****************************************************************************/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "SpinBox.h"

class DateInput : public QWidget
{ 
    Q_OBJECT

    public:
        DateInput( QWidget* parent = 0, Qt::WindowFlags f = 0 );
        ~DateInput();

        void setDate(const QDate);
        void setDate(const int Y, const int M, const int D);
        void setDay(const int);
        void setMonth(const int);
        void setYear(const int);
        int year();
        int month();
        int day();
        void showTime(bool);
        void setTimeToStart();
        void setTimeToEnd();
        QDate getDate();
        QDateTime getDateTime(bool endOfDay);
        int isValidDate();
        QString toString(bool = false);
        QString oracleFormat(bool = false);

        bool isValid;   //TRUE if the value returned from getDate is valid.
            
    public slots:
        void DayChange();
        void MonthChange();

    protected:
        QHBoxLayout* hbox;

    private:
        QComboBox* cboDateMonth;
        QSpinBox* spinDateDay;
        QSpinBox* spinDateYear;
        SpinBox* spinDateHour;
        SpinBox* spinDateMinute;
        QDate date;
        int timeVisible;
};

#endif // DATEINPUT_H
