#ifndef DATERANGE_H
#define DATERANGE_H

/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   DateRange.h
 *
 * PURPOSE:
 * This is the declaration file for a DateRange class which consists of two
 * DateInput Classe instances.
 *
 *****************************************************************************/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "DateInput.h"

enum direction {horizontal, vertical};

class DateRange : public QWidget
{ 
    Q_OBJECT

    public:
        DateRange(QWidget* parent = 0, Qt::WindowFlags f = 0, 
            int daysDiff = 7, int direction = vertical);
        ~DateRange();
    
        int     daystoEnd();
        int     daystoStart();
        int     getDaysBetween();
        QString getDateQueryString();
        QDate   getStartDate();
        QDate   getStopDate();
        int     getStartDay();
        int     getStopDay();
        int     setStartMonth();
        int     getStopMonth();
        int     getStartYear();
        int     getStopYear();
        bool    isValid(bool notify = FALSE);
        void    issueInvalidWarning();
        QString oracleFormatEnd();
        QString oracleFormatStart();
        void    setDateToCurrent(const int days );
        void    setDaysBetween(const int days);
        void    setStartDate(const QDate date);
        void    setStopDate(const QDate date);
        void    setStartDay(const int day);
        void    setStopDay(const int day);
        void    setStartMonth(const int month);
        void    setStopMonth(const int month);
        void    setStartYear(const int year);
        void    setStopYear(const int year);
        void    showTimes();
        QString toString();

    public slots:
        void setDateToCurrent();

    protected:
        QHBoxLayout *hbox;
        QVBoxLayout *vbox;
        QVBoxLayout *vbox_2;
        QGridLayout *grid;
        QVBoxLayout *vbox_3; 

    private:
        int daysBetween;
        QLabel* lblStartDatetxt;
        DateInput* diStart;
        QLabel* lblStopDatetxt;
        DateInput* diEnd;
        QPushButton* pbReset;
        QLabel *lblResetText;
};
#endif // DATERANGE_H
