/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   LPGSController.h
 *
 * PURPOSE:
 * The LPGSController class provides facilities that the GUI uses to
 * start up, shut down, and query the status of the LPGS system itself.
 *
 *****************************************************************************/

#ifndef LPGSCONTROLLER_H
#define LPGSCONTROLLER_H

/* System Includes */

/* Qt Includes */
#include <QtCore>

/* Local Includes */

#define LPGS_SUCCESS            0
#define LPGS_FAILURE            (-1)

// LPGS_PROCEED and LPGS_CANCEL provide mnemonics for situations
// where the LPGS operator is required to confirm certain system
// operations (such as shutting the system down or starting it
// up, re-ingesting L0R data for a product request, etc.)

#define LPGS_PROCEED            0
#define LPGS_CANCEL             (-1)

#define LPGS_STATUS_UP          1
#define LPGS_STATUS_PARTIAL     2
#define LPGS_STATUS_DOWN        3
#define LPGS_STATUS_UNKNOWN     4

#define LPGS_SHUTDOWN_NONE      0
#define LPGS_SHUTDOWN_GRACEFUL  1
#define LPGS_SHUTDOWN_EXPEDITED 2

class LPGSController : public QObject 
{
    Q_OBJECT

    public:
        LPGSController();
        int getSystemStatus();
        void setShutdownType(int);
        int getShutdownType();

    public slots:
        void startupLPGS();
        void gracefulShutdownLPGS();
        void expeditedShutdownLPGS();

    private:
        bool checkDupShutdownDirective();
        int confirmShutdown(const QString);

        QStringList strlTasks;
        QStringList strlTaskProcIds;
        int shutdownType;

        QString strSystemId;
        QString strLpgsHome;
};

#endif /* LPGSCONTROLLER_H */

