#ifndef MAINWINDOW_H
#define MAINWINDOW_H

/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
  UNIT NAME:   MainWindow.h

  PURPOSE:
      The LPGS MainWindow class provides for the rest of the GUI; it contains
      the main Product Request listview, the LPGS status bar, the toolbars,
      and the pull-down menus that give the operators access to the rest of
      the functionality in the LPGS GUI.
 *****************************************************************************/

/* System Includes */
#include <unistd.h>

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "DateInput.h"
#include "DateRange.h"
#include "DiskUsage.h"
#include "LPGSController.h"
#include "ProductRequestTreeWidget.h"
#include "RecordSetViewer.h"
#include "SystemProcesses.h"
#include "SystemTaskStatus.h"
#include "ProductRequestIncrementalSearch.h"
#include "InterfaceStatus.h"
#include "ui_MainWindowBase.h"

class MainWindow : public QMainWindow, public Ui::MainWindowBase
{
    Q_OBJECT

    public:
        MainWindow(QWidget *parent = 0, Qt::WindowFlags fl = Qt::Window);
        ~MainWindow();
        DateRange *drMain;

    private:
        void refreshStateFilter();
        void setupStaticfilters();
        void setupMenus();
        void setupListView();
        void setupToolBars();
        void updateDateTime();

        QString getDeletablePRSpace();
        float getDirectorySize(const QDir);

        void signalHandler(int);

        static twInfo prInfo[];
    
        QLineEdit *leFindRequest;   // find product request
        QComboBox *cboStateFilter;  // Combo box with filter names
        QComboBox *cboSatelliteFilter; // Combo box with filter names
        QComboBox *cboSensorFilter; // Combo box with filter names
        QComboBox *cboProcedureTypeFilter; // Combo box with filter names
        QComboBox *cboInstanceFilter; // Combo box with filter names
        QLabel *dateTimeLabel;      // Date and time in status bar
        QLabel *statusLabel;        // System status in status bar
        QLabel *numRecordsLabel;    // records returned from query
        QTimer *refreshTimer;       // Product request refresh timer
        QPrinter *printer;
        QString *strHostName;       // hostname system is running on
        QSignalMapper *signalMapper;
        LPGSController *controller;
        SystemTaskStatus *systemTaskStatus;
        DiskUsage *diskUsage;
        RecordSetViewer *sqlEditor;
        SystemProcesses *systemProcesses;
        ProductRequestTreeWidget *twPRs;
        ProductRequestIncrementalSearch *prValidator;
        InterfaceStatus *interfaceStatus;
        QAtomicInt alreadyRefreshing;

    private slots:
        void refreshEvent();
        void updateRecordCount();
        void stopTimer();
        void changeStateFilter(const QString &);
        void openUNIXShell();
        void displayDiskUsage();
        void displayEventLog();
        void displayGUIConfiguration();
        void displaySystemConfiguration();
        void displayInstanceConfiguration();
        void displaySystemProcesses();
        void displaySystemTaskStatus();
        void displayAnomalyInformation();
        void displayNodeConfiguration();
        void displaySoftwareLog();
        void displayRecordSetViewer();
        void openSQLWindow();
        void printRequests();
        void toggleCommonTasks(bool);
        void toggleFindRequest(bool);
        void toggleStateFilters(bool);
        void toggleDateSelect(bool);
        void toggleInterfaceStatuses(bool);
        void refreshMenuToolbars();
        void toggleDate(bool);
        void toggleRecordsReturned(bool);
        void toggleSystemTaskStatus(bool);
        void executePlugin(const QString &cmd);
};

#endif /* MAINWINDOW_H */

