/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   NodeConfiguration
 *
 * PURPOSE:
 * The Node Configuration dialog allows the operator to view the available
 * LPGS processing nodes, set the state of a node to UP or DOWN, and set
 * the maximum number of concurrent work orders for each node.
 *
 *****************************************************************************/

#ifndef NODECONFIGURATION_H
#define NODECONFIGURATION_H

/*
 * The MAX_NODES mnemonic defines the maximum number of processing nodes
 * that can be present in the LPGS processing system. This should be set
 * arbitrarily high, since it only affects the Node Configuration dialog.
 */

#define MAX_NODES   64

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "ui_NodeConfigurationBase.h"

class NodeConfiguration : public QDialog, public Ui::NodeConfigurationBase 
{
    Q_OBJECT

    public:
        NodeConfiguration(QWidget *parent = 0, Qt::WindowFlags fl = 0);
 
    private slots:
        void refreshNodes();
        void accept();
        void applyChanges();
        void valueChanged();

    private:
        void clearNodes();
    
        QLineEdit *leHostname[MAX_NODES]; // Hostname of node
        QComboBox *cboState[MAX_NODES];   // The host state (UP or DOWN)
        QLineEdit *leStatusDate[MAX_NODES]; // The heartbeat (am I alive)
        QLineEdit *leStatus[MAX_NODES];   // The software status UP or DOWN
        QLineEdit *leMaxLoad[MAX_NODES];  // Maximum work order load
        QLineEdit *leCurrLoad[MAX_NODES]; // Current work order load
        QLineEdit *leCpusPerOrder[MAX_NODES]; // Number of CPUs per work order

        int numNodes; // Total number of nodes
};

#endif /* NODECONFIGURATION_H */

