/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   Preferences.h
 *
 * PURPOSE:
 * The Preferences class stores various operator preferences for things
 * such as colors, sorting and filtering options, fonts, etc.  It also
 * provides the rest of the GUI with a convenient mechanism for accessing
 * them.
 *
 *****************************************************************************/

#ifndef PREFERENCES_H
#define PREFERENCES_H

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */

#define MAX_GROUPS  20
#define MAX_FILTERS 20
#define NUM_STATES  31

const QString DEFAULT_GROUP = "Default";

typedef QMap<QString, QString> MapStatesToGroups;
typedef QMapIterator<QString, QString> MapStatesToGroupsIterator;
typedef QMap<QString, QColor> MapGroupToColor;
typedef QMapIterator<QString, QColor> MapGroupToColorIterator;
typedef QMap<QString, QString> MapFilterNameToStates;

class Preferences {

    public:
        Preferences();

        bool areColorsEnabled();
        void setColorsEnabled(bool);

        QStringList groupNames();
        QStringList filterNames();
        QString filterStates(const QString &);
        QString quotedFilterStates(const QString &);

        void addGroup(const QString &);
        void deleteGroup(const QString &);
        void addFilter(const QString &);
        void deleteFilter(const QString &);
        void setFilterStates(const QString &, const QString &);

        QString currFilter;
        MapStatesToGroups group;         // {STATE}{GROUPNAME}
        MapGroupToColor backgroundColor; // {GROUPNAME}{COLOR}
        MapGroupToColor textColor;       // {GROUPNAME}{COLOR}

        QString strRefreshTimer;
        QString strPRDuration;
        QString strEventLogDuration;

        QString strFont;
        QString strSize;
        QString strScrollbackLines;
        QString strColorScheme;
        QString strColorSwitch;
        QString strXtermOptions;
    
        int width;
        int height;

        int commonTasksVisible;
        int findRequestVisible;
        int stateFiltersVisible;
        int dateRangeVisible;
        int interfaceStatusesVisible;
        int statusbarDateVisible;
        int statusbarRecordsReturnedVisible;
        int statusbarSystemStatusVisible;

        bool writePreferencesFile();

    private:
        bool readPreferencesFile();

        bool colorsEnabled;

        QString strPreferencesFilename;

        QStringList strlComments;
        QStringList strlOrderedFilterNames;
        QStringList strlOrderedGroupNames;

        MapFilterNameToStates mapFilterNameToStates; // {FILTERNAME}{STATES}
};

#endif

