/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
******************************************************************************
 *
 * UNIT NAME:   RecordSetViewer.h
 *
 * PURPOSE:
 * This file is the include file for the RecordSetViewer class.   
 *
 *****************************************************************************/
#ifndef RECORDSETVIEWER_H
#define RECORDSETVIEWER_H

// System Includes 
#include <iostream>

// Qt Includes 
#include <QtCore>
#include <QtGui>
#include <QtSql>

// Local Includes 
#include "TreeWidgetUtilities.h"
#include "ui_RecordSetViewerBase.h"

class RecordSetViewer : public QDialog, public Ui::RecordSetViewerBase
{ 
    Q_OBJECT

    public:
        RecordSetViewer(QWidget *parent = 0, Qt::WindowFlags fl = 0);
        ~RecordSetViewer();

    protected:
        void closeEvent(QCloseEvent *event);

    private slots:
            // switches column headers between the native database column
            // titles and modified column values that are more user-friendly
        void switchColumnHeaders();
            // refreshes the contents of the RecordSet
        void refresh();
            // clears the SQL command from the SQL Command line edit entry
            // widget
        void clearSQLCommand();
            // prints the contents of the RecordSetViewer Dialog
        void print();
        void commit();
        bool isUpdateable(const QString);
        void accept();

    private:
        bool askForCommit();
            // printer object
        QPrinter *printer;
            // Queries the database to see if a transaction is in progress
            // Note: This is Oracle specific.
        bool inTransaction(bool &queryok);
};

#endif /* RECORDSETVIEWER_H */

