#ifndef SYSTEMCONFIGURATION_H
#define SYSTEMCONFIGURATION_H

/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   SystemConfiguration.h
 *
 * PURPOSE:
 * This is the delcaration file for the SystemConfiguration class for viewing
 * and modify certain System Configuration Parameters for LPGS.
 * 
 *****************************************************************************/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "DatabaseUtils.h"
#include "LineEditPercent.h"
#include "ui_SystemConfigurationBase.h"

#define MAX_LE_COLUMNS  30
#define MAX_LEP_COLUMNS 30

#define GUI_MODIFY_ERR 3001

typedef struct leInfo
{
    QLineEdit *leObject;    // Pointer to the Line Edit object
    QLabel *lblObject;      // The QLabel that describes this Line Edit
    QString strDbColumn;    // The databse table column the data comes from
    datatype dtType;        // If number, then may need to check constraints
} leInfo;

// Even though the LineEditPercent object inherits QLineEdit's methods,
// A different struct is needed to hold the LineEditPercents because the
// text() and displayText() functions are protected in QLineEdit's class,
// so therefor can not be over-ridden.
typedef struct lepInfo
{
    LineEditPercent *leObject;  // Pointer to the Line Edit Percent object
    QLabel *lblObject;      // The QLabel that describes the LineEditPercent
    QString strDbColumn;    // The databse table column the data comes from
    datatype dtType;        // If number, then may need to check constraints
} lepInfo;

class SystemConfiguration : public QDialog, 
                            public Ui::SystemConfigurationBase
{
    Q_OBJECT

    public:
        SystemConfiguration(QWidget* parent = 0, Qt::WindowFlags fl = 0);

    protected slots:
        void valueChanged();
        void applyChanges();

    private:
        bool checkConstraint(const QString, const QString,
            const QString, const QString, datatype, bool );
        bool validNumber(const QString);
        void initLocalStructs();
        void refreshValues();

        // Number of line edits contained in the leInfo struct.
        int num_allLineEdits;
    
        // Number of LineEditpercent's contained in the lepInfo struct.
        int num_allLineEditPercents;

        // Struct to hold all of the LineEdits that need to be set up
        // for the GUI.
        leInfo allLineEdits[MAX_LE_COLUMNS];
        
        // Struct to hold all of the LineEditPercents that need to be
        // set up for the GUI.
        lepInfo allLineEditPercents[MAX_LEP_COLUMNS];
};

#endif /* SYSTEMCONFIGURATION_H */

