#ifndef SYSTEMPROCESSES_H
#define SYSTEMPROCESSES_H

/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   SystemProcesses.h
 *
 * PURPOSE:
 * This is the declaration file for the SystemProcesses class which provides
 * a window displaying the system processes and relevant information about those
 * processes to the user.
 *
 *****************************************************************************/

/* System Includes */
#include <sys/procfs.h>
#include <sys/types.h>

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "TreeWidgetUtilities.h"

#include "ui_SystemProcessesBase.h"

typedef struct lpgs_proc_node
{
    pid_t pid;           // Process ID of this process
    pid_t ppid;          // Parent process ID of this process
    QString strName;     // Name of the executable
    QString strArgs;     // Arguments given to the executable
    uid_t uid;           // Real user ID for this process
    long procsize;       // Process image size
    long rss;            // Resident set size
    struct lpgs_proc_node *next; // Pointer to next process in list
    int num_children;    // Number of child processes

    QList<struct lpgs_proc_node *> children;
} LPGS_PROC_NODE;

class SystemProcesses : public QDialog, public Ui::SystemProcessesBase
{
    Q_OBJECT

    public:
        SystemProcesses(QWidget *parent = 0);
        ~SystemProcesses();

    public slots:
        void refresh();

    protected slots:
        void killProcess(int);
        void showPopupMenu(const QPoint &point);

    private:
        void buildTree(LPGS_PROC_NODE *nodeptr,
                       QTreeWidgetItem *parent,
                       QTreeWidget *tree);
        void deleteTree();
        void addChild(pid_t, LPGS_PROC_NODE *);
        LPGS_PROC_NODE *findPid(pid_t);
        void buildProcessTree();

        // Popup menu to show for each process when the user right clicks
        QMenu *popmProcess;
    
        // Popup menu for "Kill Process"
        QMenu *popmKillProcess;
        
        // Pointer to the head of the tree
        LPGS_PROC_NODE *head;
        int pagesize;

        // Contains info about the list view to build
        vector<twInfo> twiSystemProcesses;
        
        // Number of columns in the list view (from lvInfo struct array)
        int numColumns;
};

#endif  /* SYSTEMPROCESSES_H */

