/******************************************************************************
*
* NAME:  TreeWidgetUtilities.h
*
* PURPOSE:  This is the declaration (Header) file for the TreeWidgetUtilities
*           class.  TreeWidgetUtilities contains a set of useful static
*           fuctions using QTreeWidgets.  These function include printing a
*           QTreeWidget, writing a QTreeWidget, and building a QTreeWidget.
*
* ASSUMPTIONS AND CONSTRAINTS:
*
*****************************************************************************/
#ifndef TREEWIDGETUTILITIES_H
#define TREEWIDGETUTILITIES_H

/* System Includes */
#include <vector>

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */

// Use namespace std so C++ library objects can be access with specifing
// namespace.
using namespace std;

enum PrintOptions
{
    CurrentState,
    Selected,
    SelectedPlusChildren,
    SelectedPlusAllChildren,
    AllPlusChildren,
    AllPlusAllChildren
};

typedef struct twInfo
{
    QString strColumnTitle; // The heading for this column
    int columnAlignment;    // The alignment for this column
    int columnWidth;        // The width of the column
    bool isClickable;       // if true, then the column heading can
                            // be clicked.
    bool isResizeable;      // if true, then the column size can
                            // be changed by the user at runtime.
    bool doPrint;           // If true, then print when the user
                            // chooses to print.
    int printWidth;         // If -1, then use displayed width
    QString strDbColumn;    // name of database column holding
                            // data for this column
} twInfo;

class TreeWidgetUtilities
{

public:
    static void printTreeWidget(QTreeWidget *twTreeWidget,
                                QPainter &pntPainter,
                                QPrinter *pPrinter,
                                const int margin,
                                int &yPos,
                                int &pageNo,
                                const vector<twInfo> &twMetadata,
                                const int NumberofColumns,
                                const PrintOptions = CurrentState);

    static void printTreeWidget(QTreeWidget *twTreeWidget,
                                QPainter &pntPainter,
                                QPrinter *pPrinter,
                                const int margin,
                                int &yPos,
                                int &pageNo,
                                const PrintOptions = CurrentState);

    static void writeTreeWidgetToFile(QTreeWidget *twTreeWidget,
                                      QFile &file,
                                      const vector<twInfo> &twMetadata,
                                      const int NumberofColumns,
                                      const PrintOptions = CurrentState);

    static void writeTreeWidgetToFile(QTreeWidget *twTreeWidget,
                                      QFile &file,
                                      const PrintOptions = CurrentState);

    static QStringList longestTextFields(QTreeWidget *twTreeWidget,
                                         const vector<twInfo> &twMetadata,
                                         const int NumberofColumns,
                                         const PrintOptions = CurrentState);

    static QStringList longestTextFields(QTreeWidget *twTreeWidget,
                                         const PrintOptions = CurrentState);

    static void buildTreeWidget(QTreeWidget *twTreeWidget,
                                const vector<twInfo> &twMetadata,
                                const int NumberofColumns);

    static QTreeWidgetItem *getTreeWidgetItembyNum(QTreeWidget *twTreeWidget,
                                                   int index);

    static QTreeWidgetItem *getLastChild(QTreeWidget *twTreeWidget);

private:
    static void printColumnHeaders(QTreeWidget *twTreeWidget,
                                   QPainter &pntPainter,
                                   QPrinter *pPrinter,
                                   const int margin,
                                   int &yPos,
                                   const vector<twInfo> &twMetadata,
                                   const int NumberofColumns);

    static void printColumnHeaders(QTreeWidget *twTreeWidget,
                                   QPainter &pntPainter,
                                   QPrinter *pPrinter,
                                   const int margin,
                                   int &yPos);

    static bool printThisItem(QTreeWidgetItem *currItem,
                              PrintOptions desiredPrinting);
};

#endif /* TREEWIDGETUTILITES_H */

