/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
******************************************************************************
 *
 * UNIT NAME:   UserParameters.h
 *
 * PURPOSE:
 * This file is the include file for the UserParameters class.   
 *
 *****************************************************************************/
#ifndef USERPARAMETERS_H
#define USERPARAMETERS_H

// System Includes
#include <iostream>

// Qt Includes 
#include <QtCore>
#include <QtGui>

// Local Includes
#include "ui_UserParametersBase.h"
#include "Utilities.h"
#include "IASErrorDialog.h"
#include "IASSqlQuery.h"

// structure used to hold information read from the database tables
// the lblTxt will hold the name of the database column, lblVal will
// hold the value of the database column
typedef struct 
{  
    QLabel *lblTxt;
    QLineEdit *leVal;
} UserIASParameterItem;

// structure used to hold information about a tab'd items
typedef struct 
{ 
    bool tabExists;      // TRUE once tab exists/is created
    int numberOfRows;    // number of rows in tab
    QWidget *tab;        // pointer to tab (pointer to a QWidget)
    QFormLayout *layout; // pointer to form layout
    QString strNameBase; // base of name used for naming widgets 
    QString strTable;    // name of table being queried, used in error reporting
    QString strTabTitle; // title (caption displayed on tab)
    UserIASParameterItem item[40]; // contains label pairs used to display info
} UserParametersTab;
    

class UserParameters : public QDialog, public Ui::UserParametersBase
{ 
    Q_OBJECT

    public:
        UserParameters(QString prId = "", QString woId = "",
                       QWidget* parent = 0, Qt::WindowFlags fl = 0);
        ~UserParameters();

    protected slots:
        // print the contents of the User Parameters dialog
        void print();

    private:
        // function used to create and fill tabs 
        void buildTab(UserParametersTab *);
        // function used to set values for call to buildTab()
        // for the L0R Data tab
        void buildL0RDataTab();
        // function used to set values for call to buildTab()
        // for the General Information tab
        void buildGeneralInfoTab();
        // function calls remaining build tab functions
        void buildUserParametersDialog();
        // function to print a tab's contents
        void printTab(UserParametersTab *, int &, QPainter *, QFontMetrics *);
        // if TRUE execute SQL command to get data, if FALSE get data 
        // from the QStringLists
        bool query;
        // margin for printing tabs
        int margin;
        // y position used while printing tabs
        int yPos;
        // used to set the maximum label height
        int maxLabelHeight;
        // used to set spacing between labels
        int labelSpacing;
        // product request id to display information about      
        QString strPRID;
        // work order id to display information about      
        QString strWOID;
        // string to hold SQL command before creating a recordset
        QString strSQLCommand;
        // caption to database access errors
        QString strErrorCaption;
        // string used for processing in various functions.
        QString strTemp;
        // qstringlist containing data titles
        QStringList strlIdentifiers;
        // qstirnglist containing data values
        QStringList strlValues;
        // Object to print to
        QPrinter *printer;
        // structure used to hold information for the 
        // General Information tab
        UserParametersTab generalInfoTab;
        // structure used to hold information for the 
        // L0R Data tab
        UserParametersTab L0RDataTab;
};

#endif /* USERPARAMETERS_H */

