/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
*******************************************************************************
*
* UNIT NAME:   WorkOrderParameters.h
*
* PURPOSE:
* Provides a dialog that allows the operator to view and/or modify the
* parameters associated with a work order.  The operator chooses which
* script to view/modify through a combo box on top of the GUI, and a list
* of ParameterListViewItems allows them to examine or modify the values.
*
******************************************************************************/

#ifndef WORKORDERPARAMETERS_H
#define WORKORDERPARAMETERS_H

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

#include "IASParameterModel.h"

/* Local Includes */

#include "ui_WorkOrderParametersBase.h"

class WorkOrderParameters : public QDialog, public Ui::WorkOrderParametersBase
{
    Q_OBJECT

    public:
        WorkOrderParameters(bool editFlag,
                            QString strPRId,
                            QString strWOId,
                            QWidget *parent = 0,
                            Qt::WindowFlags fl = 0);

        bool parametersModified();

    protected slots:
        void accept();
        void reject();
        void populateProcedureSelection();
        void populateScriptSelection();
        void setupParmsTable();
        void scriptChanged(const QString &);
        void updateParms(const QModelIndex& pIndex);
        void setCurrentParmValue(const QModelIndex& cIndex,
                                 const QModelIndex& pIndex);
        void getWorkOrderInstanceInformation();

    private slots:
        void  pauseToggled(bool checked);

    private:
        void insertTypeRequired();
        void insertParmValueItem();
        bool updateParmsTable(int row);
        bool validateParm(int row); // Validates a parameter value

        QString strWOId_;   // Work order identifier
        QString strPRId_;   // Product Request identifier
        QString sensor;     // Work order sensor identifier
        QString satellite;  // Work order satellite identifier
        QString instance;   // Work order instance identifier
        QString currentScriptID;  // Contains the current script ID
        QString currentParmValue; // Contains the current parameters value

        bool editableValues;
        bool parmsModified;

        /* Variables to hold the parameter model */
        IASParameterModel *parameterDataModel;
};

#endif /* WORKORDERPARAMETERS_H */

