/*****************************************************************************
*          Level 1 Product Generation System (LPGS) Software
******************************************************************************
*
* NAME:  ColoredTreeWidgetItem.cpp
*
* PURPOSE:  This is the implementation file for the ColoredTreeWidgetItem
*           class.  This class extends QTreeWidgetItem.  ColoredTreeWidgetItem
*           provides extra functionality to set the background and foreground 
*           colors of QTreeWidgetItems.
*
* ASSUMPTIONS AND CONSTRAINTS:
*
* NOTES:
*
*****************************************************************************/

/* System Includes */

/* Local Includes */
#include "ColoredTreeWidgetItem.h"

ColoredTreeWidgetItem::ColoredTreeWidgetItem(
    QColor qcForeground,    // I: Foreground color of list item
    QColor qcBackground)    // I: Background color of list item
    : QTreeWidgetItem(),
      foregroundBrush_(qcForeground),
      backgroundBrush_(qcBackground)
{
    // Nothing to see here; relevant initializations are already done.
    // Please disperse.
};

/*****************************************************************************/

ColoredTreeWidgetItem::ColoredTreeWidgetItem(
    QColor qcForeground,    // I: Foreground color of list item
    QColor qcBackground,    // I: Background color of list item
    QStringList contents)   // I: List containing contents of list
    : QTreeWidgetItem (contents),
      foregroundBrush_(qcForeground),
      backgroundBrush_(qcBackground)
{
    initColors();
};

/*****************************************************************************/
ColoredTreeWidgetItem::ColoredTreeWidgetItem(
    QColor qcForeground,    // I: Foreground color of list item
    QColor qcBackground,    // I: Background color of list item
    QTreeWidget *parent)    // I: Parent widget
    : QTreeWidgetItem(parent),
      foregroundBrush_(qcForeground),
      backgroundBrush_(qcBackground)
{
    // Nothing to see here; relevant initializations are already done.
    // Please disperse.
};

/*****************************************************************************/

ColoredTreeWidgetItem::ColoredTreeWidgetItem(
    QColor qcForeground,    // I: Foreground color of list item
    QColor qcBackground,    // I: Background color of list item
    QTreeWidget *parent,    // I: Parent widget
    QStringList contents)   // I: List containing contents of list
    : QTreeWidgetItem (parent, contents),
      foregroundBrush_(qcForeground),
      backgroundBrush_(qcBackground)
{
    initColors();
};

/****************************************************************************/

ColoredTreeWidgetItem::ColoredTreeWidgetItem(
    QColor qcForeground,    // I: Foreground color of list item
    QColor qcBackground,    // I: Background color of list item
    QTreeWidgetItem *parent)    // I: Parent widget
    : QTreeWidgetItem(parent),
      foregroundBrush_(qcForeground),
      backgroundBrush_(qcBackground)
{
    // Nothing to see here; relevant initializations are already done.
    // Please disperse.
};

/****************************************************************************/

ColoredTreeWidgetItem::ColoredTreeWidgetItem(
    QColor qcForeground,    // I: Foreground color of list item
    QColor qcBackground,    // I: Background color of list item
    QTreeWidgetItem *parent,    // I: Parent widget
    QStringList contents)   // I: List containing contents of list
    : QTreeWidgetItem (parent, contents),
      foregroundBrush_(qcForeground),
      backgroundBrush_(qcBackground)
{
    initColors();
};

/****************************************************************************/

void ColoredTreeWidgetItem::setColorProperties(
    QColor qcForeground,
    QColor qcBackground)
{
    /****************************************************************
      ***       Name: setColorProperties
      ***    Purpose: This function will change the foreground and
      ***             background colors of the treewidgetitem.
    ******************************************************************/
    foregroundBrush_ = QBrush(qcForeground);
    backgroundBrush_ = QBrush(qcBackground);
    
    initColors();
}

void ColoredTreeWidgetItem::setColoredText(int column, QString text)
{
    /****************************************************************
      ***       Name: setColumnTexts
      ***    Purpose: This function will set the text for the column
                      and set the column's background and forground colors
    ******************************************************************/
    setText(column, text);
    setBackground(column, backgroundBrush_);
    setForeground(column, foregroundBrush_);
}

/****************************************************************************/

void ColoredTreeWidgetItem::initColors()
{
    for (int col = 0; col < columnCount(); ++col)
    {
        setBackground(col, backgroundBrush_);
        setForeground(col, foregroundBrush_);
    }
}

