/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   ErrorEmail.cpp
 *
 * PURPOSE:
 * This is the definition for the ErrorEmail class that allows an
 * operator to send a W/O-failed email notification.
 *
 *****************************************************************************/

/* System Includes */
#include <iostream>

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "ErrorEmail.h"

ErrorEmail::ErrorEmail(QString strWODir, QWidget *parent, Qt::WindowFlags fl) 
  : QDialog(parent, fl)
{
    setupUi(this);

    connect(pushButtonCancel, SIGNAL(clicked()), this, SLOT(reject()));
    connect(pushButtonSend, SIGNAL(clicked()), this, SLOT(send()));

    textEditMsg->setText(strWODir);
}

//*****************************************************************************

void ErrorEmail::send()
{
    QString strTo;
    QString strMsg;
    QString strAddr;
    QString strTime;
    QString strEmail;
    QString strCmd;

    // Get the email address(es), comma- and/or space-delimited works
    strTo = lineEditTo->text();
    if (strTo.isEmpty()) 
    {
        QMessageBox::warning(this, "Email Progress", "No address");
        return;
    }
    
    // Check to make sure there is some message being sent
    strMsg = textEditMsg->toPlainText();
    if (strMsg.length() < 5) 
    {
        QMessageBox::warning(this, "Email Progress", "No message");
        return;
    }

    // Build a name for the file that will hold the email text
    QTime t = QTime::currentTime();
    strTime = t.toString("hhmmss");
    strEmail = "/tmp/lpgsemail" + strTime;

    // Write the email text file
    QFile efile(strEmail);
    if (efile.open(QIODevice::WriteOnly)) 
    {
        QTextStream stream(&efile);
        stream << strMsg << "\n\n";
        efile.close();

        strCmd = "mail -s \"Work Order Failed\" " + strTo + " < " + strEmail;
    
        // Send the email(s)
        if (system(strCmd.toAscii().data()) != 0)
        {
            QMessageBox::critical(this, "Email Error", 
                "Cannot send email");
            return;
        }

        QMessageBox::information(this, "Email Progress", "Email sent");
        efile.remove();
    }
    else
    {
        QMessageBox::critical(this, "Email Error", 
            "Cannot create email file");
        return;
    }

    // Close the dialog
    accept();
}

