/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   InterfaceStatus.cpp
 *
 * PURPOSE:
 * This widget adds and manages the states of interfaces connected to LPGS. It
 * does not refresh on it's own, it needs to be called by the parent during
 * it's refresh.
 *
 *****************************************************************************/

/* Local Includes */
#include "InterfaceStatus.h"
#include "IASSqlQuery.h"

/* Constants */
const int BUTTON_SIZE = 15;

const QString STYLE_UP =
    "QPushButton"
    " {"
        " background-color : #44ff44;"
        " color : black;"
    " }"
    "QToolTip"
    " {"
        " background-color : #44ff44;"
        " color : black;"
    " }";
const QString STYLE_DOWN =
    "QPushButton"
    " {"
        " background-color : #ff4444;"
        " color : black;"
    " }"
    "QToolTip"
    " {"
        " background-color : #ff4444;"
        " color : black;"
    " }";
const QString STYLE_OTHER =
    "QPushButton"
    " {"
        " background-color : #ffff44;"
        " color : black;"
    " }"
    "QToolTip"
    " {"
        " background-color : #ffff44;"
        " color : black;"
    " }";

const QString TRAM_UP =
    "TRAM is set to:  UP";
const QString TRAM_DOWN =
    "TRAM is set to:  DOWN";
const QString TRAM_NO_NEW_ORDERS =
    "TRAM is set to:  NO NEW ORDERS";

const QString SUBSETTER_UP =
    "Subsetter is set to:  UP";
const QString SUBSETTER_DOWN =
    "Subsetter is set to:  DOWN";
const QString SUBSETTER_NO_NEW_REQUESTS =
    "Subsetter is set to:  NO NEW REQUESTS";

const QString PRODUCT_DELIVERY_UP =
    "Product Delivery is set to:  UP";
const QString PRODUCT_DELIVERY_DOWN =
    "Product Delivery is set to:  DOWN";

const QString STATE_UP = "UP";
const QString STATE_DOWN = "DOWN";
const QString STATE_NO_NEW_ORDERS = "NO_NEW_ORDERS";
const QString STATE_NO_NEW_REQUESTS = "NO_NEW_REQUESTS";

/* Create the interface objects and set them up. */
InterfaceStatus::InterfaceStatus(QWidget *parent)
: QWidget(parent)
{
    /* Create the labels and push buttons. */
    lblTramInterfaceStatus = new QLabel("TRAM Status", this);
    pbTramInterfaceStatusState = new QPushButton(this);

    lblSubsetterInterfaceStatus = new QLabel("Subsetter Status", this);
    pbSubsetterInterfaceStatusState = new QPushButton(this);

    lblProductDeliveryStatus = new QLabel("Product Delivery Status", this);
    pbProductDeliveryStatusState = new QPushButton(this);

    /* Create the layout to place them into. */
    QHBoxLayout *layout = new QHBoxLayout(this);
    layout->setSpacing(5);
    layout->setMargin(0);

    /* Add the objects to the layout. */
    layout->addWidget(lblTramInterfaceStatus);
    layout->addWidget(pbTramInterfaceStatusState);

    layout->addWidget(lblSubsetterInterfaceStatus);
    layout->addWidget(pbSubsetterInterfaceStatusState);

    layout->addWidget(lblProductDeliveryStatus);
    layout->addWidget(pbProductDeliveryStatusState);

    /* Adjust the size of the push buttons. */
    pbTramInterfaceStatusState->setMaximumSize(BUTTON_SIZE, BUTTON_SIZE);
    pbTramInterfaceStatusState->setMinimumSize(BUTTON_SIZE, BUTTON_SIZE);

    pbSubsetterInterfaceStatusState->setMaximumSize(BUTTON_SIZE, BUTTON_SIZE);
    pbSubsetterInterfaceStatusState->setMinimumSize(BUTTON_SIZE, BUTTON_SIZE);

    pbProductDeliveryStatusState->setMaximumSize(BUTTON_SIZE, BUTTON_SIZE);
    pbProductDeliveryStatusState->setMinimumSize(BUTTON_SIZE, BUTTON_SIZE);

    /* Create the TRAM menu options and add them to the push button. */
    menuTramState = new QMenu(pbTramInterfaceStatusState);
    menuTramState->addAction("Set to:  UP",
        this, SLOT(changeTramStateTo_UP()));
    menuTramState->addAction("Set to:  DOWN",
        this, SLOT(changeTramStateTo_DOWN()));
    menuTramState->addAction("Set to:  NO_NEW_ORDERS",
        this, SLOT(changeTramStateTo_NO_NEW_ORDERS()));
    pbTramInterfaceStatusState->setMenu(menuTramState);

    /* Create the subsetter menu options and add them to the push button. */
    menuSubsetterState = new QMenu(pbSubsetterInterfaceStatusState);
    menuSubsetterState->addAction("Set to:  UP",
        this, SLOT(changeSubsetterStateTo_UP()));
    menuSubsetterState->addAction("Set to:  DOWN",
        this, SLOT(changeSubsetterStateTo_DOWN()));
    menuSubsetterState->addAction("Set to:  NO_NEW_REQUESTS",
        this, SLOT(changeSubsetterStateTo_NO_NEW_REQUESTS()));
    pbSubsetterInterfaceStatusState->setMenu(menuSubsetterState);

    /* Create the product delivery menu options and add them to the push
       button. */
    menuProductDeliveryState = new QMenu(pbProductDeliveryStatusState);
    menuProductDeliveryState->addAction("Set to:  UP",
        this, SLOT(changeProductDeliveryStateTo_UP()));
    menuProductDeliveryState->addAction("Set to:  DOWN",
        this, SLOT(changeProductDeliveryStateTo_DOWN()));
    pbProductDeliveryStatusState->setMenu(menuProductDeliveryState);

    /* Set the layout for the widget. */
    setLayout(layout);
}

/* Update the widgets objects with the values from the database. */
void
InterfaceStatus::refresh()
{
    IASSqlQuery query;

    /* Get the values from the database. */
    QString sqlCmd = "SELECT tram_interface_state,"
                           " subsetter_interface_state,"
                           " product_delivery_state"
                     " FROM sys_parms";

    if (!query.exec(sqlCmd, __FILE__, __LINE__))
    {
        return;
    }

    query.next(); /* Position on a valid record. */

    QString tramInterfaceState =
        query.value("TRAM_INTERFACE_STATE").toString();
    QString subsetterInterfaceState =
        query.value("SUBSETTER_INTERFACE_STATE").toString();
    QString productDeliveryState =
        query.value("PRODUCT_DELIVERY_STATE").toString();

    /* Determine the TRAM state and update the objects. */
    if (tramInterfaceState == STATE_UP)
    {
        pbTramInterfaceStatusState->setStyleSheet(STYLE_UP);
        lblTramInterfaceStatus->setStyleSheet(STYLE_UP);

        pbTramInterfaceStatusState->setToolTip(TRAM_UP);
        lblTramInterfaceStatus->setToolTip(TRAM_UP);
    }
    else if (tramInterfaceState == STATE_DOWN)
    {
        pbTramInterfaceStatusState->setStyleSheet(STYLE_DOWN);
        lblTramInterfaceStatus->setStyleSheet(STYLE_DOWN);

        pbTramInterfaceStatusState->setToolTip(TRAM_DOWN);
        lblTramInterfaceStatus->setToolTip(TRAM_DOWN);
    }
    else
    {
        pbTramInterfaceStatusState->setStyleSheet(STYLE_OTHER);
        lblTramInterfaceStatus->setStyleSheet(STYLE_OTHER);

        pbTramInterfaceStatusState->setToolTip(TRAM_NO_NEW_ORDERS);
        lblTramInterfaceStatus->setToolTip(TRAM_NO_NEW_ORDERS);
    }

    /* Determine the subsetter state and update the objects. */
    if (subsetterInterfaceState == STATE_UP)
    {
        pbSubsetterInterfaceStatusState->setStyleSheet(STYLE_UP);
        lblSubsetterInterfaceStatus->setStyleSheet(STYLE_UP);

        pbSubsetterInterfaceStatusState->setToolTip(SUBSETTER_UP);
        lblSubsetterInterfaceStatus->setToolTip(SUBSETTER_UP);
    }
    else if (subsetterInterfaceState == STATE_DOWN)
    {
        pbSubsetterInterfaceStatusState->setStyleSheet(STYLE_DOWN);
        lblSubsetterInterfaceStatus->setStyleSheet(STYLE_DOWN);

        pbSubsetterInterfaceStatusState->setToolTip(SUBSETTER_DOWN);
        lblSubsetterInterfaceStatus->setToolTip(SUBSETTER_DOWN);
    }
    else
    {
        pbSubsetterInterfaceStatusState->setStyleSheet(STYLE_OTHER);
        lblSubsetterInterfaceStatus->setStyleSheet(STYLE_OTHER);

        pbSubsetterInterfaceStatusState->setToolTip(SUBSETTER_NO_NEW_REQUESTS);
        lblSubsetterInterfaceStatus->setToolTip(SUBSETTER_NO_NEW_REQUESTS);
    }

    /* Determine the product delivery state and update the objects. */
    if (productDeliveryState == STATE_UP)
    {
        pbProductDeliveryStatusState->setStyleSheet(STYLE_UP);
        lblProductDeliveryStatus->setStyleSheet(STYLE_UP);

        pbProductDeliveryStatusState->setToolTip(PRODUCT_DELIVERY_UP);
        lblProductDeliveryStatus->setToolTip(PRODUCT_DELIVERY_UP);
    }
    else
    {
        pbProductDeliveryStatusState->setStyleSheet(STYLE_DOWN);
        lblProductDeliveryStatus->setStyleSheet(STYLE_DOWN);

        pbProductDeliveryStatusState->setToolTip(PRODUCT_DELIVERY_DOWN);
        lblProductDeliveryStatus->setToolTip(PRODUCT_DELIVERY_DOWN);
    }
}

void
InterfaceStatus::changeTramStateTo_UP()
{
    QString sqlCmd = "UPDATE sys_parms"
                     " SET tram_interface_state = '" + STATE_UP + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::changeTramStateTo_DOWN()
{
    QString sqlCmd = "UPDATE sys_parms"
                     " SET tram_interface_state = '" + STATE_DOWN + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::changeTramStateTo_NO_NEW_ORDERS()
{
    QString sqlCmd = "UPDATE sys_parms"
                   " SET tram_interface_state = '" + STATE_NO_NEW_ORDERS + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::changeSubsetterStateTo_UP()
{
    QString sqlCmd = "UPDATE sys_parms"
                     " SET subsetter_interface_state = '" + STATE_UP + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::changeSubsetterStateTo_DOWN()
{
    QString sqlCmd = "UPDATE sys_parms"
                     " SET subsetter_interface_state = '" + STATE_DOWN + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::changeSubsetterStateTo_NO_NEW_REQUESTS()
{
    QString sqlCmd = "UPDATE sys_parms"
            " SET subsetter_interface_state = '" + STATE_NO_NEW_REQUESTS + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::changeProductDeliveryStateTo_UP()
{
    QString sqlCmd = "UPDATE sys_parms"
                     " SET product_delivery_state = '" + STATE_UP + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::changeProductDeliveryStateTo_DOWN()
{
    QString sqlCmd = "UPDATE sys_parms"
                     " SET product_delivery_state = '" + STATE_DOWN + "'";

    executeSqlCmd(sqlCmd);
}

void
InterfaceStatus::executeSqlCmd(const QString &sqlCmd)
{
    IASSqlQuery query;

    if (!query.exec(sqlCmd, __FILE__, __LINE__))
    { 
        return;
    }

    refresh();
}

