/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   LineEditPercent.cpp
 *
 * PURPOSE:
 * This file is the implementation of the LineEditPercent class.  The 
 * LineEditPercent class is used to hold a line edit object that is a number, 
 * but represents a percent.
 * 
 *****************************************************************************/

/* System Includes */


/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "LineEditPercent.h"

//************************************************************************

LineEditPercent::LineEditPercent(QWidget * parent)	
  : QLineEdit(parent)
{
    this->setValidator(new QIntValidator(0, 100, this));
}

//************************************************************************

void LineEditPercent::setText(const QString & text)	//I: The number to set
    							//   the line edit to
{
     // This function overrides the inheritad QLineEdit's setText function.
     // It sets the text in the LineEditPercent by converting the string
     // passed in to a floating decimal number, multiplying by 100, and
     // then calls QLineEdit's setText function.  This way the programmer
     // passes in the decimal representation of a percent, but when displayed
     // it shows the number as a percent without the decimal.


    float fltNumberAsPercent;
    QString strNewText;

    // Multiply the number by 100 so it is stored and displayed as a valid
    // percent.  When it is retrieved, it will be divided by 100 so the
    // correct value is stored as the decimal representation.    
    fltNumberAsPercent = (text.toFloat()) * 100;

    strNewText.setNum(fltNumberAsPercent);

    QLineEdit::setText(strNewText);    
}

//************************************************************************

QString LineEditPercent::text() const
{
     // This function overrides the inheritad QLineEdit's text() function.
     // It uses QLineEdit's text() function to get the text stored in the
     // LineEditPercent object, but returns a QString of the number divided
     // by 100 so it is a deciaml representation of the percent.

    QString strActualNum;
    float fltActualNum;
    fltActualNum = (QLineEdit::text().toFloat()) / 100;

    strActualNum.setNum(fltActualNum);
    return strActualNum;
}

//************************************************************************

QString LineEditPercent::displayText() const
{
     // This function overrides the inheritad QLineEdit's displayText() 
     // function. It uses QLineEdit's displayText() function to get the text
     // stored in the LineEditPercent object, but returns a QString of the
     // number divided by 100 so it is a decimal representation of the percent.

    QString strActualNum;
    float fltActualNum;
    fltActualNum = (QLineEdit::displayText().toFloat()) / 100;

    strActualNum.setNum(fltActualNum);
    return strActualNum;
}
