/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 *****************************************************************************
 *
 * UNIT NAME:   Utilities.cpp
 *
 * PURPOSE:
 * Miscellaneous utility functions that belong nowhere specific.
 *
 *****************************************************************************/

// System Includes 
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <stdio.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/procfs.h>
#include <stdlib.h>
#include <dirent.h>
#include <pwd.h>
#include <fcntl.h>
#include <unistd.h>
#include <assert.h>
#include <signal.h>

// Qt Includes
#include <QtCore>
#include <QtGui>

// IAS Qt Includes
#include <iasQtWoConst.h>

// Local Includes 
#include "Utilities.h"
#include "IASSqlQuery.h"

static QMap<QString, QString> mapStateToString;
static QMap<QString, QString> mapStringToState;
static QMap<QString, bool> mapStateToWOScriptsMenu;
static QMap<QString, bool> mapStateToWOLogMenu;
static QMap<QString, bool> mapStateToOpenUnixShellMenu;
static QMap<QString, bool> mapStateToCancelPRMenu;
static QMap<QString, bool> mapStateToCancelMultiplePRMenu;
static QMap<QString, bool> mapStateToChangePriorityMenu;
static QMap<QString, bool> mapStateToAnomalyInfoMenu;

/****************************************************************************/

void initializeStateInformation()
{
    // Map state values to display values in the OUI.
    mapStateToString[DB_WO_L0R_NEW] = UI_WO_L0R_NEW_STR;
    mapStateToString[DB_WO_REQUEST_FAILED] = UI_WO_REQUEST_FAILED_STR;
    mapStateToString[DB_WO_L0R_REQUESTED] = UI_WO_L0R_REQUESTED_STR;
    mapStateToString[DB_WO_SUBSETTER_FAILED] = UI_WO_SUBSETTER_FAILED_STR;
    mapStateToString[DB_WO_L0R_READY] = UI_WO_L0R_READY_STR;
    mapStateToString[DB_WO_INGEST_FAILED] = UI_WO_INGEST_FAILED_STR;
    mapStateToString[DB_WO_PENDING] = UI_WO_PENDING_STR;
    mapStateToString[DB_WO_RUNNING] = UI_WO_RUNNING_STR;
    mapStateToString[DB_WO_HALTED] = UI_WO_HALTED_STR;
    mapStateToString[DB_WO_EVALUATE] = UI_WO_EVALUATE_STR;
    mapStateToString[DB_WO_INACTIVE] = UI_WO_INACTIVE_STR;
    mapStateToString[DB_WO_DIAGNOSTIC_COMPLETE] = UI_WO_DIAGNOSTIC_COMPLETE_STR;
    mapStateToString[DB_WO_READY_TO_SHIP] = UI_WO_READY_TO_SHIP_STR;
    mapStateToString[DB_WO_TRANSFER_FAILED] = UI_WO_TRANSFER_FAILED_STR;
    mapStateToString[DB_WO_ABORT_WO] = UI_WO_ABORT_WO_STR;
    mapStateToString[DB_WO_COMPLETE_WO] = UI_WO_COMPLETE_WO_STR;
    mapStateToString[DB_WO_RELEASE_ABORT] = UI_WO_RELEASE_ABORT_STR;
    mapStateToString[DB_WO_RELEASE_COMPLETE] = UI_WO_RELEASE_COMPLETE_STR;
    mapStateToString[DB_WO_ABORTED] = UI_WO_ABORTED_STR;
    mapStateToString[DB_WO_COMPLETED] = UI_WO_COMPLETED_STR;

    // Map the display values back to state values.
    QMapIterator<QString, QString> it(mapStateToString);
    while (it.hasNext())
    {
        it.next();
        mapStringToState[it.value()] = it.key();
    }

    // Only display WO scripts when they are available.
    mapStateToWOScriptsMenu[DB_WO_L0R_NEW] = false;
    mapStateToWOScriptsMenu[DB_WO_REQUEST_FAILED] = false;
    mapStateToWOScriptsMenu[DB_WO_L0R_REQUESTED] = false;
    mapStateToWOScriptsMenu[DB_WO_SUBSETTER_FAILED] = false;
    mapStateToWOScriptsMenu[DB_WO_L0R_READY] = false;
    mapStateToWOScriptsMenu[DB_WO_INGEST_FAILED] = false;
    mapStateToWOScriptsMenu[DB_WO_PENDING] = true;
    mapStateToWOScriptsMenu[DB_WO_RUNNING] = true;
    mapStateToWOScriptsMenu[DB_WO_HALTED] = true;
    mapStateToWOScriptsMenu[DB_WO_EVALUATE] = true;
    mapStateToWOScriptsMenu[DB_WO_INACTIVE] = true;
    mapStateToWOScriptsMenu[DB_WO_DIAGNOSTIC_COMPLETE] = true;
    mapStateToWOScriptsMenu[DB_WO_READY_TO_SHIP] = true;
    mapStateToWOScriptsMenu[DB_WO_TRANSFER_FAILED] = true;
    mapStateToWOScriptsMenu[DB_WO_ABORT_WO] = false;
    mapStateToWOScriptsMenu[DB_WO_COMPLETE_WO] = false;
    mapStateToWOScriptsMenu[DB_WO_RELEASE_ABORT] = false;
    mapStateToWOScriptsMenu[DB_WO_RELEASE_COMPLETE] = false;
    mapStateToWOScriptsMenu[DB_WO_ABORTED] = false;
    mapStateToWOScriptsMenu[DB_WO_COMPLETED] = false;

    // Only display this menu when a WO log file exists.
    mapStateToWOLogMenu[DB_WO_L0R_NEW] = false;
    mapStateToWOLogMenu[DB_WO_REQUEST_FAILED] = false;
    mapStateToWOLogMenu[DB_WO_L0R_REQUESTED] = false;
    mapStateToWOLogMenu[DB_WO_SUBSETTER_FAILED] = false;
    mapStateToWOLogMenu[DB_WO_L0R_READY] = true;
    mapStateToWOLogMenu[DB_WO_INGEST_FAILED] = true;
    mapStateToWOLogMenu[DB_WO_PENDING] = true;
    mapStateToWOLogMenu[DB_WO_RUNNING] = true;
    mapStateToWOLogMenu[DB_WO_HALTED] = true;
    mapStateToWOLogMenu[DB_WO_EVALUATE] = true;
    mapStateToWOLogMenu[DB_WO_INACTIVE] = false;
    mapStateToWOLogMenu[DB_WO_DIAGNOSTIC_COMPLETE] = true;
    mapStateToWOLogMenu[DB_WO_READY_TO_SHIP] = true;
    mapStateToWOLogMenu[DB_WO_TRANSFER_FAILED] = true;
    mapStateToWOLogMenu[DB_WO_ABORT_WO] = false;
    mapStateToWOLogMenu[DB_WO_COMPLETE_WO] = false;
    mapStateToWOLogMenu[DB_WO_RELEASE_ABORT] = false;
    mapStateToWOLogMenu[DB_WO_RELEASE_COMPLETE] = false;
    mapStateToWOLogMenu[DB_WO_ABORTED] = false;
    mapStateToWOLogMenu[DB_WO_COMPLETED] = false;

    // Only display this menu when a WO directory exists. 
    mapStateToOpenUnixShellMenu[DB_WO_L0R_NEW] = false;
    mapStateToOpenUnixShellMenu[DB_WO_REQUEST_FAILED] = false;
    mapStateToOpenUnixShellMenu[DB_WO_L0R_REQUESTED] = false;
    mapStateToOpenUnixShellMenu[DB_WO_SUBSETTER_FAILED] = false;
    mapStateToOpenUnixShellMenu[DB_WO_L0R_READY] = false;
    mapStateToOpenUnixShellMenu[DB_WO_INGEST_FAILED] = true;
    mapStateToOpenUnixShellMenu[DB_WO_PENDING] = true;
    mapStateToOpenUnixShellMenu[DB_WO_RUNNING] = true;
    mapStateToOpenUnixShellMenu[DB_WO_HALTED] = true;
    mapStateToOpenUnixShellMenu[DB_WO_EVALUATE] = true;
    mapStateToOpenUnixShellMenu[DB_WO_INACTIVE] = false;
    mapStateToOpenUnixShellMenu[DB_WO_DIAGNOSTIC_COMPLETE] = true;
    mapStateToOpenUnixShellMenu[DB_WO_READY_TO_SHIP] = true;
    mapStateToOpenUnixShellMenu[DB_WO_TRANSFER_FAILED] = true;
    mapStateToOpenUnixShellMenu[DB_WO_ABORT_WO] = false;
    mapStateToOpenUnixShellMenu[DB_WO_COMPLETE_WO] = false;
    mapStateToOpenUnixShellMenu[DB_WO_RELEASE_ABORT] = false;
    mapStateToOpenUnixShellMenu[DB_WO_RELEASE_COMPLETE] = false;
    mapStateToOpenUnixShellMenu[DB_WO_ABORTED] = false;
    mapStateToOpenUnixShellMenu[DB_WO_COMPLETED] = false;

    // Only display this menu while in halted/failure states.
    // Including the diagnostic complete state. 
    mapStateToCancelPRMenu[DB_WO_L0R_NEW] = false;
    mapStateToCancelPRMenu[DB_WO_REQUEST_FAILED] = true;
    mapStateToCancelPRMenu[DB_WO_L0R_REQUESTED] = false;
    mapStateToCancelPRMenu[DB_WO_SUBSETTER_FAILED] = true;
    mapStateToCancelPRMenu[DB_WO_L0R_READY] = false;
    mapStateToCancelPRMenu[DB_WO_INGEST_FAILED] = true;
    mapStateToCancelPRMenu[DB_WO_PENDING] = false;
    mapStateToCancelPRMenu[DB_WO_RUNNING] = false;
    mapStateToCancelPRMenu[DB_WO_HALTED] = true;
    mapStateToCancelPRMenu[DB_WO_EVALUATE] = true;
    mapStateToCancelPRMenu[DB_WO_INACTIVE] = true;
    mapStateToCancelPRMenu[DB_WO_DIAGNOSTIC_COMPLETE] = true;
    mapStateToCancelPRMenu[DB_WO_READY_TO_SHIP] = false;
    mapStateToCancelPRMenu[DB_WO_TRANSFER_FAILED] = true;
    mapStateToCancelPRMenu[DB_WO_ABORT_WO] = false;
    mapStateToCancelPRMenu[DB_WO_COMPLETE_WO] = false;
    mapStateToCancelPRMenu[DB_WO_RELEASE_ABORT] = false;
    mapStateToCancelPRMenu[DB_WO_RELEASE_COMPLETE] = false;
    mapStateToCancelPRMenu[DB_WO_ABORTED] = false;
    mapStateToCancelPRMenu[DB_WO_COMPLETED] = false;

    // Only display this menu while in halted/failure states.
    // Including the diagnostic complete state.
    mapStateToCancelMultiplePRMenu[DB_WO_L0R_NEW] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_REQUEST_FAILED] = true;
    mapStateToCancelMultiplePRMenu[DB_WO_L0R_REQUESTED] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_SUBSETTER_FAILED] = true;
    mapStateToCancelMultiplePRMenu[DB_WO_L0R_READY] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_INGEST_FAILED] = true;
    mapStateToCancelMultiplePRMenu[DB_WO_PENDING] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_RUNNING] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_HALTED] = true;
    mapStateToCancelMultiplePRMenu[DB_WO_EVALUATE] = true;
    mapStateToCancelMultiplePRMenu[DB_WO_INACTIVE] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_DIAGNOSTIC_COMPLETE] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_READY_TO_SHIP] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_TRANSFER_FAILED] = true;
    mapStateToCancelMultiplePRMenu[DB_WO_ABORT_WO] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_COMPLETE_WO] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_RELEASE_ABORT] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_RELEASE_COMPLETE] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_ABORTED] = false;
    mapStateToCancelMultiplePRMenu[DB_WO_COMPLETED] = false;

    // Don't display this menu while in the completed and aborted states.
    mapStateToChangePriorityMenu[DB_WO_L0R_NEW] = true;
    mapStateToChangePriorityMenu[DB_WO_REQUEST_FAILED] = true;
    mapStateToChangePriorityMenu[DB_WO_L0R_REQUESTED] = true;
    mapStateToChangePriorityMenu[DB_WO_SUBSETTER_FAILED] = true;
    mapStateToChangePriorityMenu[DB_WO_L0R_READY] = true;
    mapStateToChangePriorityMenu[DB_WO_INGEST_FAILED] = true;
    mapStateToChangePriorityMenu[DB_WO_PENDING] = true;
    mapStateToChangePriorityMenu[DB_WO_RUNNING] = true;
    mapStateToChangePriorityMenu[DB_WO_HALTED] = true;
    mapStateToChangePriorityMenu[DB_WO_EVALUATE] = true;
    mapStateToChangePriorityMenu[DB_WO_INACTIVE] = true;
    mapStateToChangePriorityMenu[DB_WO_DIAGNOSTIC_COMPLETE] = true;
    mapStateToChangePriorityMenu[DB_WO_READY_TO_SHIP] = true;
    mapStateToChangePriorityMenu[DB_WO_TRANSFER_FAILED] = true;
    mapStateToChangePriorityMenu[DB_WO_ABORT_WO] = false;
    mapStateToChangePriorityMenu[DB_WO_COMPLETE_WO] = false;
    mapStateToChangePriorityMenu[DB_WO_RELEASE_ABORT] = false;
    mapStateToChangePriorityMenu[DB_WO_RELEASE_COMPLETE] = false;
    mapStateToChangePriorityMenu[DB_WO_ABORTED] = false;
    mapStateToChangePriorityMenu[DB_WO_COMPLETED] = false;

    // Only display this menu for states related to anomalies.
    mapStateToAnomalyInfoMenu[DB_WO_L0R_NEW] = false;
    mapStateToAnomalyInfoMenu[DB_WO_REQUEST_FAILED] = false;
    mapStateToAnomalyInfoMenu[DB_WO_L0R_REQUESTED] = false;
    mapStateToAnomalyInfoMenu[DB_WO_SUBSETTER_FAILED] = false;
    mapStateToAnomalyInfoMenu[DB_WO_L0R_READY] = false;
    mapStateToAnomalyInfoMenu[DB_WO_INGEST_FAILED] = true;
    mapStateToAnomalyInfoMenu[DB_WO_PENDING] = false;
    mapStateToAnomalyInfoMenu[DB_WO_RUNNING] = false;
    mapStateToAnomalyInfoMenu[DB_WO_HALTED] = false;
    mapStateToAnomalyInfoMenu[DB_WO_EVALUATE] = true;
    mapStateToAnomalyInfoMenu[DB_WO_INACTIVE] = true;
    mapStateToAnomalyInfoMenu[DB_WO_DIAGNOSTIC_COMPLETE] = true;
    mapStateToAnomalyInfoMenu[DB_WO_READY_TO_SHIP] = false;
    mapStateToAnomalyInfoMenu[DB_WO_TRANSFER_FAILED] = false;
    mapStateToAnomalyInfoMenu[DB_WO_ABORT_WO] = false;
    mapStateToAnomalyInfoMenu[DB_WO_COMPLETE_WO] = false;
    mapStateToAnomalyInfoMenu[DB_WO_RELEASE_ABORT] = false;
    mapStateToAnomalyInfoMenu[DB_WO_RELEASE_COMPLETE] = false;
    mapStateToAnomalyInfoMenu[DB_WO_ABORTED] = false;
    mapStateToAnomalyInfoMenu[DB_WO_COMPLETED] = false;
}

/****************************************************************************/
QString stringToState(const QString &stringName) // I: string name to look up
{
    // Given the display string from the OUI, return the state

    return mapStringToState[stringName];
}

/****************************************************************************/

QString stateToString(const QString &state) // I: State name to look up
{
    // Given the state, return the string to display in the OUI

    return mapStateToString[state];
}

/****************************************************************************/

bool displayWOScriptsMenu(const QString &state) // I: State name to look up
{
    return mapStateToWOScriptsMenu[state];
}

/****************************************************************************/

bool displayWOLogMenu(const QString &state) // I: State name to look up
{
    return mapStateToWOLogMenu[state];
}

/****************************************************************************/

bool displayOpenUnixShellMenu(const QString &state) // I: State name to look up
{
    return mapStateToOpenUnixShellMenu[state];
}

/****************************************************************************/

bool displayCancelPRMenu(const QString &state) // I: State name to look up
{
    return mapStateToCancelPRMenu[state];
}

/****************************************************************************/

bool displayCancelMultiplePRMenu(const QString &state)// I: State name look up
{
    return mapStateToCancelMultiplePRMenu[state];
}

/****************************************************************************/

bool displayChangePriorityMenu(const QString &state) // I: State name to look up
{
    return mapStateToChangePriorityMenu[state];
}

/****************************************************************************/

bool displayAnomalyInformationMenu(
    const QString &prID,  // I: Product request ID
    const QString &state) // I: State name to look up
{
    // First check to see if the state is guaranteed to have the menu
    // displayed.
    if (mapStateToAnomalyInfoMenu[state])
    {
        return true;
    }
    else
    {
       // See if an anomaly exists.
       QString sqlCmd = "SELECT 1"
                        "  FROM anomalies"
                        " WHERE product_request_id = '" + prID + "'";

       IASSqlQuery query;

       query.exec(sqlCmd, __FILE__, __LINE__);

       if (query.next())
       {
           return true;
       }
       else
       {
           return false;
       }
    }
}

/******************************************************************************/

bool workOrderHasBeenReplaced
(
    const QString &product_request_id,  // I: Product request ID
    const QString &work_order_id        // I: State name to look up
) 
{
    // This function will return true if the work order replace flag
    // has been set for the provided product request id and work order id 
    // in the database otherwise it will return false.
    IASSqlQuery query;
    QString strQuery =
        "SELECT WO_REPLACED FROM WORK_ORDERS "
        "WHERE PRODUCT_REQUEST_ID = '" + product_request_id + "' "
        "AND WORK_ORDER_ID = '" + work_order_id + "'";
    if (query.exec(strQuery, __FILE__, __LINE__))
    {
        if (query.next())
        {
            if (query.value(0).toInt() != 0)
            {
                return true;
            }
        }
    }

    return false;
}

/****************************************************************************/

QStringList stateList()
{
    // Return a list of all the avialable states

    return mapStateToString.values();
}

/****************************************************************************/

QString commaSeparatedList(QStringList &list)
{
    // This function takes a QStringList as its input and returns a
    // QString that contains the contents of the list represented as
    // a parenthesized, comma-separated list.  Its primary purpose
    // is to format a QStringList in a manner that is suitable for
    // an SQL IN query .. i.e., "SELECT * FROM PRODUCT_REQUESTS WHERE
    // STATE IN ( 1, 2, 3, 4, 5, 6 )"

    // Count for the empty list
    if (list.count() == 0)
    {
        return QString("( )");
    }

    QString strList = "( '" + list.join("', '") + "' )";
    return strList;
}

/****************************************************************************/

QStringList workOrderID(const QString strPRID) // I: Product Request ID to
                                               //    find Work Order ID's for.
{
    // This function returns a list of work order IDs that are
    // associated with the given product request.  Nominally, there
    // is only one, but in cases involving anomalies there could
    // be multiple work orders.

    QStringList strlWOID;

    QString strSqlSelect = "SELECT WORK_ORDER_ID FROM WORK_ORDERS WHERE"
    " PRODUCT_REQUEST_ID='" + strPRID + "'";

    IASSqlQuery query;
    bool result = query.exec(strSqlSelect, __FILE__, __LINE__);

    if (result)
    {
        while (query.next())
        {
            strlWOID += query.value("WORK_ORDER_ID").toString();
        }
    }

    return strlWOID;
}

//*****************************************************************************

void failCancelProductRequest(QWidget *parent,
                              const QStringList &prIds,
                              const QStringList &woIds)
{
    QString message = "Fail/Cancel the selected Product Requests that are in "
        "a failed state?\n(This cannot be undone!)";
    QString sqlCmd;

    // Check if ids should be included in message box 
    if (prIds.length() < 10)
    {
        message = "Fail/Cancel Product Requests: \n" + prIds.join("\n") 
            + "?\n(This cannot be undone!)";    
    }

    // Make sure that the operator really intends to do this!
    if (QMessageBox::critical(parent, "Fail/Cancel Product Request",
        message, QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes)
    {
        return;
    }

    QSqlDatabase::database().transaction();

    IASSqlQuery query;

    // Need to cleanup the anomaly table to keep in sync.
    sqlCmd = "UPDATE anomalies"
             "   SET state = " + QString::number(DB_ANOMALY_FAILED) + ", "
             "       date_closed = SYSDATE"
             " WHERE product_request_id in ('" + prIds.join("','") + "')";

    if (!query.exec(sqlCmd, __FILE__, __LINE__))
    {
        QSqlDatabase::database().rollback();
        return;
    }

    sqlCmd = "UPDATE work_orders"
             "   SET state = '" + DB_WO_ABORT_WO + "',"
             "       cancellation_status = 1"
             " WHERE work_order_id in ('" + woIds.join("','") +"')";

    if (!query.exec(sqlCmd, __FILE__, __LINE__))
    {
        QSqlDatabase::database().rollback();
        return;
    }

    QSqlDatabase::database().commit();
}
