/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
 ******************************************************************************
 *
 * UNIT NAME:   WorkOrderScripts.cpp
 *
 * PURPOSE:
 * This is the definition file for the WorkOrderScripts class which provides a
 * dialog that displays information from the wo_scripts table about a certain
 * work order ID.
 *
 *****************************************************************************/

/* System Includes */

/* Qt Includes */
#include <QtCore>
#include <QtGui>

/* Local Includes */
#include "IASErrorDialog.h"
#include "Utilities.h"
#include "WorkOrderScripts.h"
#include "IASUtilities.h"
#include "IASSqlQuery.h"
#include "IASListViewItem.h"
//****************************************************************************

WorkOrderScripts::WorkOrderScripts(const QString strPRID, 
    const QString strWOID, QWidget* parent, Qt::WindowFlags fl) 
  : QDialog(parent, fl)
{
    setupUi(this);

    strInitialWOID = strWOID;
    strWOPRID = strPRID;
    lblPRID->setText(strWOPRID);

    /* columns cannot exceed MAX_WO_COLUMNS */
    twInfo tempTWInfo[] =
    {
        {"Script ID",Qt::AlignLeft,-1,FALSE,TRUE,TRUE,-1,"SCRIPT_ID"},
        {"Sequence #",Qt::AlignCenter,-1,FALSE,TRUE,TRUE,-1,"SEQ_NBR"},
        {"Pause Flag",Qt::AlignLeft,-1,FALSE,TRUE,TRUE,-1,
            "DECODE(PAUSE_FLAG,0,'No Pause',1,'Pause')"},
        {"State",Qt::AlignLeft,-1,FALSE,TRUE,TRUE,-1,
            "DECODE(STATE,'P','Pending','R','Running','C','Complete',"
            "'K','Skipped')"},
        {"Completion Status",Qt::AlignLeft,-1,FALSE,TRUE,TRUE,-1,"DECODE("
            "COMPL_STATUS,'S','Success','F','Failure')"},
        {"Result",Qt::AlignLeft,-1,FALSE,TRUE,TRUE,-1,"FAILURE_REASON"},
    };

    numWOColumns = ARRAY_SIZE(tempTWInfo);
    vector<twInfo> twInfoVector;
    for (int counter = 0; counter < numWOColumns; counter++)
    {
        WOScriptsTWInfo[counter] = tempTWInfo[counter];
        twInfoVector.push_back(tempTWInfo[counter]);
    }

    columnTypes.clear();
    columnTypes << Alpha << Number << Alpha << Alpha << Alpha << Alpha;

    TreeWidgetUtilities::buildTreeWidget(twWOScripts, twInfoVector, 
        numWOColumns);

    connect(pbDismiss, SIGNAL(clicked()), this, SLOT(accept()));
    connect(pbRefresh, SIGNAL(clicked()), this, SLOT(refresh()));
    connect(cboWOID, SIGNAL(activated(QString)), this, SLOT(refresh()));

    refresh();

    for (int counter = 0; counter < numWOColumns; counter++)
        twWOScripts->resizeColumnToContents(counter);
}

//****************************************************************************

void WorkOrderScripts::refresh()
{
    // Refreshes the view of info for the current work order ID
    IASSqlQuery query;
    QString strSqlQuery;
    QString columns = "";
    QTreeWidgetItem *twiTemp;

    refreshWOIDcbo();
  
    // Build the list if columns to select 
    for (int counter = 0; counter < numWOColumns; counter++)
    {
        columns += WOScriptsTWInfo[counter].strDbColumn;
        if (counter != (numWOColumns - 1))
            columns += ",";
    }

    // Build the full sql statement
    strSqlQuery = "SELECT " + columns
                + " FROM wo_scripts "
                + " WHERE work_order_id = '" + cboWOID->currentText() + "'"
                + " ORDER BY seq_nbr DESC";

    // Execute the query and add each script to the list view

    if (query.exec(strSqlQuery, __FILE__, __LINE__))
    {
        twWOScripts->clear();

        while (query.next())
        {
            twiTemp = new IASListViewItem(twWOScripts, columnTypes);
            for (int col = 0; col < numWOColumns; col++)
            {
                twiTemp->setText(col, query.value(col).toString());
            }
        }
    }

    /* Sort ascending by the sequence column */
    twWOScripts->setSortingEnabled(true);
    twWOScripts->sortItems(1, Qt::AscendingOrder);
    twWOScripts->setSortingEnabled(false);
}

//****************************************************************************

void WorkOrderScripts::refreshWOIDcbo()
{
    // Refreshes the selection contents of the combo box that contains the
    // different work order ID's for the product request ID
    QString strSelectedItem = "";

    if (cboWOID->count() > 0)
        strSelectedItem = cboWOID->currentText();
    else
        strSelectedItem = strInitialWOID;

    QStringList strlWOID = workOrderID(strWOPRID);

    cboWOID->clear();
    for (int counter = 0; counter < strlWOID.count(); counter++)
    {
        cboWOID->addItem(strlWOID[counter]);
    }

    if (strSelectedItem != "")
    {
        for (int counter = 0; counter < cboWOID->count(); counter++)
        {
            if (cboWOID->itemText(counter) == strSelectedItem)
                cboWOID->setCurrentIndex(counter);
        } 
    }
}
