/******************************************************************************
               Level 1 Product Generation System (LPGS) Software
*******************************************************************************
*
* UNIT NAME:   main.cpp
*
* PURPOSE:
* This is the GUI entry point.  It performs all up-front initialization,
* and sets up the application and main window objects.
*
******************************************************************************/

/* System Includes */
#include <stdlib.h>
#include <unistd.h>
#include <iostream>

/* Qt Includes */
#include <QtCore>

#include "IASSchemaConfig.h"

/* Local Includes */
#include "IASDatabaseLogin.h"
#include "MainWindow.h"
#include "Preferences.h"
#include "Utilities.h"

extern Preferences *preferences;

void initDBConnections();

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    // Connect to the database
    initDBConnections();

    IASSchemaConfig *inst = IASSchemaConfig::instance();
    if(inst == NULL)
    {
        QMessageBox::critical(0,"Invalid configuration",
            "An error occurred initializing schema configuration.\n"
            "Terminating the application",
            QMessageBox::Ok,0);
        exit(EXIT_FAILURE);
    }

    preferences = new Preferences();

    initializeStateInformation();

    MainWindow *mainWindow = new MainWindow();
    mainWindow->show();
    mainWindow->setAttribute(Qt::WA_DeleteOnClose, true);

    app.setStyle(new QWindowsStyle());
    app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));

    int status = app.exec();

    delete preferences;

    return status;
}

//***********************************************************************
void initDBConnections()
{
    // This function attempts to make a default database connection.
    // It gets the connection information from the IASDatabaseLogin dialog.
    // The IASDatabaseLogin dialog attempts the connect and displays any 
    // appropriate error messages.

    QSqlDatabase defDbase;

    // DB_DRIVER is defined in the IASDatabaseLogin.h header file
    defDbase = QSqlDatabase::addDatabase(DB_DRIVER); 
    if (defDbase.isValid())
    {
        while (!defDbase.isOpen())
        {
            IASDatabaseLogin loginScreen(NULL, "IAS_OUI_DB");
            loginScreen.setDatabase(defDbase);
            loginScreen.exec();

            // If the user clicked the Cancel button, the dialog returns
            // QDialog::Rejected.  If this happens, then exit the program since
            // there will be no database to access.
            if (loginScreen.result() == QDialog::Rejected)
                exit(EXIT_SUCCESS);
        }
    }
    else
    {
        // An error occurred trying to add a database to QSqlDatabase.
        QMessageBox::critical(0, "Database Connection Error",
                              "Requested database driver does not exist.\n"
                              "Terminating the application",
                              QMessageBox::Ok, 0);
        exit(EXIT_FAILURE);
    }
}

