#!/usr/bin/perl -w
use DBI;
use strict;

my $two_task = $ENV { 'TWO_TASK' } or die("TWO_TASK is not set");

my $comm_db_un = $ENV {'IAS_DB_COM' } or die("IAS_DB_COM is not set");
my ($user_id, $password) = split '/', $comm_db_un;

# Connect to Oracle.
my $dbh = DBI->connect( "dbi:Oracle:$two_task", $user_id, ,$password, 
    { AutoCommit => 0 } ) ||
    die( "Couldn't connect to database!" );

# Get the processing nodes from the database
my $sth = $dbh->prepare( qq{ SELECT hostname FROM processing_nodes } );

$sth->execute();

my @hosts = ();
while ( my $hostname = $sth->fetchrow() ) 
{
    push @hosts, $hostname;
}

$sth->finish();
$dbh->disconnect;

# Create the key files if necessary
my $output;
my $keyfile = "$ENV{HOME}/.ssh/id_dsa";
if (-e $keyfile)
{
    print "Using existing ssh keys in $keyfile...\n";
}
else
{
    print "Creating ssh keys in $keyfile ...\n";
    $output = `ssh-keygen -t dsa -f $keyfile <<END


END
`;
}

# Get info from the key
my $mode;
(undef,undef,$mode,undef,undef,undef,undef,undef,undef,undef,undef,undef,undef)
    = stat($keyfile);
$mode = $mode & 07777;
warn "WARNING: Permissions on $keyfile should be 600!\n" 
    unless ($mode == oct(600));

# Distribute the public and private key to each host
#  so that you can go from anywhere to anywhere
#  ssh-copy-id sets permissions on files & directories appropriately
my $key_cmd = qq{ssh-copy-id -i $keyfile.pub};
foreach my $hostname ( @hosts ) 
{
    print "\nSetting up ssh keys on $hostname...\n";

    # First add the public key to the authorized keys
    $output = qx { $key_cmd $hostname };
    if ($? != 0) 
    {
        die "ERROR setting up public key on $hostname:\n$output\n";
    }
    # Now we should be able to ssh there without a password

    # Also copy over the private key
    $output = qx { scp -q -i $keyfile $keyfile $hostname:$keyfile };
    if ($? != 0) 
    {
        die "ERROR copying private key to $hostname:\n$output\n";
    }
}

exit 0;
