#!/bin/csh -ef
#  -e flag will cause the script to exit if any command fails
#  -f flag will keep current environment (skip re-sourcing the cshrc)
# 
# Compile and install the IAS libraries (ias_lib), base applications (ias_base),
# and LPGS-specific applications (lpgs).  Also create a cshrc file for use by
# the operational account.

# Must supply lpgsdev, lpgsit, lpgsst, or lpgsops
if (($#argv != 1) || ($1 !~ lpgs{dev,it,st,ops} )) then
  echo "Usage: $0 lpgsdev|lpgsit|lpgsst|lpgsops"
  exit 1
endif
set lpgsuser=$1
# get the dev/it/st/ops indication
set install_env = `echo $lpgsuser | cut -c 5-`

# Build ias_lib
cd ias_lib
./autogen.sh
./configure
./build
cd ..

# Build ias_base
cd ias_base
./autogen.sh
./configure
make -j4 install
cd ..

# Build lpgs
cd lpgs
./autogen.sh
./configure
make
make install
cd ..

# Precompile the individual python libraries and applications
python3 -m compileall $IASBASE_PYLIB
python3 -m compileall $IAS_BIN

# Create the setup file
./create_setup_file.csh lpgs $install_env

exit 0
