#!/bin/csh -e
############################################################################
# Script to export the source code for LPGS and create tarballs
#
# Parameters:
#       svn root URL (i.e. "https://server/dir")
#       Release number (i.e. 2_3_0)
############################################################################

# Get the svn URL and release parameters
set svn_url = $1
set rel_num = $2

# Perform rudimentary checking on the parameters
if (!($svn_url =~ https://*)) then
    echo Error: Invalid SVN URL
    exit 1
endif

if (!($rel_num =~ ?*_?*_?*)) then
    echo Error: Invalid release number
    exit 1
endif

# Create a base name for the release
set rel = LPGS_${rel_num}

# Create a directory for performing the work and creating the tarballs
mkdir $rel
cd $rel

############# Package the main software ##########################

# Export the software release from svn
svn export ${svn_url}/tags/oli_ias/LPGS_${rel_num}_OPS ${rel}

# Remove the SBU information
rm -r ${rel}/SBU

pushd ${rel}/ias_base/gps/l8_angles/export 
./export_l8_angles.csh ${svn_url}/tags/oli_ias/LPGS_COTS_${rel_num}
popd
cp ${rel}/ias_base/gps/l8_angles/export/l8_angles.tgz ./L8_ANGLES_${rel_num}.tgz

# Create the tarball
tar czf ${rel}.tgz ${rel}

# Clean up the exported directory
rm -r ${rel}

############# Package the database software ######################

# set the database release name
set db_rel = LPGS_DB_${rel_num}

# Export the software release from svn
svn export ${svn_url}/tags/oli_ias/LPGS_DB_${rel_num}_OPS/DATABASE/SUBSYSTEM/LPGS ${db_rel}

# Remove the SBU information
rm -r ${db_rel}/build/SBU

# Create the tarball
tar czf ${db_rel}.tgz ${db_rel}

# Clean up the exported directory
rm -r ${db_rel}

############# Package the COTS software ######################

# set the COTS release name
set cots_rel = LPGS_COTS_${rel_num}

# Export the software release from svn
svn export ${svn_url}/tags/oli_ias/LPGS_COTS_${rel_num} ${cots_rel}

# Remove the packages not needed by LPGS information
rm -rf ${cots_rel}/antlr
rm -rf ${cots_rel}/apache
rm -rf ${cots_rel}/EgFTP
rm -rf ${cots_rel}/GCTP
rm -rf ${cots_rel}/gdal
rm -rf ${cots_rel}/HDF
rm -rf ${cots_rel}/hdfview
rm -rf ${cots_rel}/javahelp
rm -rf ${cots_rel}/jboss
rm -rf ${cots_rel}/mockrunner
rm -rf ${cots_rel}/novas
rm -rf ${cots_rel}/oracle_jdbc
rm -rf ${cots_rel}/product-tools-2.0.1
rm -rf ${cots_rel}/soapui
rm -rf ${cots_rel}/spring
rm -f ${cots_rel}/README.java_lib

# Create the tarball
tar czf ${cots_rel}.tgz ${cots_rel}

# Clean up the exported directory
rm -r ${cots_rel}

echo
echo SUCCESS: Packages created in the ${rel} directory
